<?php
$TRANSLATIONS = array(
"Bookmarks" => "Закладки",
"Failed to import one bookmark, because: " => "Не удалось импортировать одну закладку, потому, что:",
"Bookm." => "Закл.",
"No file provided for import" => "Файл для импорта не предоставлен",
"Unsupported file type for import" => "Не подходящий тип файла для импорта",
"Some Error happened." => "Произошла ошибка.",
"Error" => "Ошибка",
"Tags" => "Метки",
"Filter by tag" => "Фильтр по метке",
"Are you sure you want to remove this bookmark?" => "Вы действительно хотите удалить эту закладку?",
"Warning" => "Предупреждение",
"Are you sure you want to remove this tag from every entry?" => "Вы действительно хотите удалить эту метку из каждой записи?",
"Import error" => "Ошибка импорта",
"Import completed successfully." => "Импортирование завершено успешно.",
"Uploading..." => "Загрузка...",
"Add a bookmark" => "Добавить закладку",
"This URL is already bookmarked! Overwrite?" => "Эта ссылка уже добавлена в закладки! Перезаписать?",
"The title of the page" => "Заголовок страницы",
"The address of the page" => "Адрес страницы",
"Description of the page" => "Описание страницы",
"Save" => "Сохранить",
"Delete" => "Удалить",
"Edit" => "Редактировать",
"Cancel" => "Отмена",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Перетащите эту кнопку в закладки вашего браузера и нажимайте на неё для быстрого добавления страницы в закладки:",
"Add to ownCloud" => "Добавить в ownCloud",
"Address" => "Адрес",
"Filterable Tags" => "Фильтруемые метки",
"You have no bookmarks" => "У вас нет закладок",
"You can also import a bookmark file" => "Вы также можете импортировать файл закладок",
"Bookmarklet" => "Букмарклет",
"Export & Import" => "Экспорт и импорт",
"Export" => "Экспорт",
"Import" => "Импорт"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);";
