<?php return array(
    'root' => array(
        'name' => '__root__',
        'pretty_version' => 'dev-master',
        'version' => 'dev-master',
        'reference' => '89cf12153eca73b192264d2d9e2dd164d4323abd',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => '89cf12153eca73b192264d2d9e2dd164d4323abd',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'brick/math' => array(
            'pretty_version' => '0.13.1',
            'version' => '0.13.1.0',
            'reference' => 'fc7ed316430118cc7836bf45faff18d5dfc8de04',
            'type' => 'library',
            'install_path' => __DIR__ . '/../brick/math',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/inflector' => array(
            'pretty_version' => '1.4.4',
            'version' => '1.4.4.0',
            'reference' => '4bd5c1cdfcd00e9e2d8c484f79150f67e5d355d9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/inflector',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fivefilters/readability.php' => array(
            'pretty_version' => 'v3.3.3',
            'version' => '3.3.3.0',
            'reference' => 'e2ee7b9e49eae89ac7ed2c74b15718100a73b4c8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fivefilters/readability.php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/uri' => array(
            'pretty_version' => '7.7.0',
            'version' => '7.7.0.0',
            'reference' => '8d587cddee53490f9b82bf203d3a9aa7ea4f9807',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/uri-interfaces' => array(
            'pretty_version' => '7.7.0',
            'version' => '7.7.0.0',
            'reference' => '62ccc1a0435e1c54e10ee6022df28d6c04c2946c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri-interfaces',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'marcelklehr/link-preview' => array(
            'pretty_version' => 'v5.0.0',
            'version' => '5.0.0.0',
            'reference' => '59bd8a448a53656a7d0e5cda29d5dd814505b041',
            'type' => 'library',
            'install_path' => __DIR__ . '/../marcelklehr/link-preview',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'masterminds/html5' => array(
            'pretty_version' => '2.10.0',
            'version' => '2.10.0.0',
            'reference' => 'fcf91eb64359852f00d921887b219479b4f21251',
            'type' => 'library',
            'install_path' => __DIR__ . '/../masterminds/html5',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'reference' => 'bb5906edc1c324c9a05aa0873d40117941e5fa90',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '2b4765fddfe3b508ac62f829e852b1501d3f6e8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.1',
            'version' => '1.1.0.0',
            'reference' => 'cb6ce4845ce34a8ad9e68117c10ee90a29919eba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log' => array(
            'pretty_version' => '3.0.2',
            'version' => '3.0.2.0',
            'reference' => 'f16e1d5863e37f8d8c2a01719f5b34baa2b714d3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rowbot/idna' => array(
            'pretty_version' => '0.3.0',
            'version' => '0.3.0.0',
            'reference' => '504900acc8e465a17668a61ae30391d1aebbb4f2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../rowbot/idna',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rowbot/punycode' => array(
            'pretty_version' => '1.0.4',
            'version' => '1.0.4.0',
            'reference' => 'ec116e99cb089a25d45147813d61bfa2deb29328',
            'type' => 'library',
            'install_path' => __DIR__ . '/../rowbot/punycode',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rowbot/url' => array(
            'pretty_version' => '4.1.0',
            'version' => '4.1.0.0',
            'reference' => '3087a67802a11796590e4bb9507981e48b077529',
            'type' => 'library',
            'install_path' => __DIR__ . '/../rowbot/url',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/css-selector' => array(
            'pretty_version' => 'v6.4.24',
            'version' => '6.4.24.0',
            'reference' => '9b784413143701aa3c94ac1869a159a9e53e8761',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/css-selector',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/dom-crawler' => array(
            'pretty_version' => 'v6.4.25',
            'version' => '6.4.25.0',
            'reference' => '976302990f9f2a6d4c07206836dd4ca77cae9524',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/dom-crawler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-ctype' => array(
            'pretty_version' => 'v1.33.0',
            'version' => '1.33.0.0',
            'reference' => 'a3cc8b044a6ea513310cbd48ef7333b384945638',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-ctype',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-normalizer' => array(
            'pretty_version' => 'v1.33.0',
            'version' => '1.33.0.0',
            'reference' => '3833d7255cc303546435cb650316bff708a1c75c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-normalizer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-mbstring' => array(
            'pretty_version' => 'v1.33.0',
            'version' => '1.33.0.0',
            'reference' => '6d857f4d76bd4b343eac26d6b539585d2bc56493',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-mbstring',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'xantios/mimey' => array(
            'pretty_version' => 'v2.2.0',
            'version' => '2.2.0.0',
            'reference' => '8cb6f0c29b8eadde38777ed947847f4253c00b60',
            'type' => 'library',
            'install_path' => __DIR__ . '/../xantios/mimey',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
