OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Adreces d'interès",
    "You bookmarked \"%s\"" : "Heu afegit a les adreces d’interès \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s ha afegit a les adreces d’interès \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Algú ha afegit a les adreces d’interès \"%s\"",
    "You deleted \"%s\"" : "Heu suprimit \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s ha suprimit \"%2$s\"",
    "Someone deleted \"%s\"" : "Algú ha suprimit \"%s\"",
    "You created folder \"%s\"" : "Heu creat la carpeta \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s ha creat la carpeta \"%2$s\"",
    "Someone created folder \"%s\"" : "Algú ha creat la carpeta \"%s\"",
    "You moved folder \"%s\"" : "Heu mogut la carpeta \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s ha mogut la carpeta \"%2$s\"",
    "Someone moved folder \"%s\"" : "Algú ha mogut la carpeta \"%s\"",
    "You deleted folder \"%s\"" : "Heu suprimit la carpeta \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s ha suprimit la carpeta \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Algú ha suprimit la carpeta \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Heu compartit la carpeta \"%1$s\" amb %2$s",
    "You shared folder \"%s\" with someone" : "Heu compartit la carpeta \"%s\" amb algú",
    "%1$s shared folder \"%2$s\" with you" : "%1$s ha compartit la carpeta \"%2$s\" amb tu",
    "Someone shared folder \"%s\" with you" : "Algú ha compartit la carpeta \"%s\" amb tu",
    "You unshared folder \"%1$s\" with %2$s" : "Heu deixat de compartit la carpeta \"%1$s\" amb %2$s",
    "You unshared folder \"%s\" with someone" : "Heu deixat de compartit la carpeta \"%s\" amb algú",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s ha deixat de compartir la carpeta \"%2$s\" amb vostè",
    "Someone unshared folder \"%s\" with you" : "Algú ha deixat de compartir la carpeta \"%s\" amb tu",
    "No file provided for import" : "No s'ha proporcionat cap fitxer per importació",
    "Failed to upload file" : "No s'ha pogut pujar el fitxer",
    "Unsupported file type for import: " : "Tipus de fitxer no compatible per a la importació: ",
    "Bookmarks shared by %s" : "Adreces d'interès compartides per %s",
    "Frequent bookmarks" : "Adreces d'interès freqüents",
    "Recent bookmarks" : "Adreces d'interès recents",
    "Bookmark" : "Adreça d'interès",
    "Bookmark deleted" : "S'ha suprimit l'adreça d'interès",
    "Bookmark created" : "S’ha creat una adreça d'interès",
    "Bookmark moved" : "S' ha mogut l'adreça d'interès",
    "Bookmark updated" : "Adreça d'interès actualitzada",
    "Create bookmark" : "Crea una adreça d'interès",
    "Takes a link and adds it to your collection of bookmarks." : "Pren un enllaç i l'afegeix a la seva col·lecció d'adreces d'interès.",
    "Bookmarks Backups" : "Còpies de seguretat d’adreces d'interès",
    "Collect and manage bookmarks, synced with all your devices" : "Recull i gestiona les adreces d'interès, sincronitzades amb tots els teus dispositius",
    "Do you really want to delete this bookmark?" : "Realment voleu suprimir aquesta adreça d'interès?",
    "Link copied to clipboard" : "Enllaç copiat al porta-retalls",
    "Enter new title" : "Introduïu un títol nou",
    "Select bookmark" : "Seleccioneu una adreça d'interès",
    "You have never clicked this link" : "Mai heu fet clic en aquest enllaç",
    "You have clicked this link {count} times" : "Heu fet clic en aquest enllaç {count} vegades",
    "Details" : "Detalls",
    "Rename" : "Canvia'n el nom",
    "Copy link" : "Copia l'enllaç",
    "Move" : "Mou",
    "Add to folders" : "Afegeix-ho a les carpetes",
    "Put bookmark into trash bin" : "Posa el marcador a la paperera",
    "Restore bookmark" : "Restaura l'adreça d'interès",
    "Delete bookmark permanently" : "Suprimeix l'adreça d'interès permanentment",
    "Content pending" : "Contingut pendent",
    "This content is being downloaded for offline use. Please check back later." : "Aquest contingut s'està baixant per utilitzar-lo fora de línia. Si us plau, torneu-ho a comprovar més tard.",
    "Bookmarked {time} ago" : "Marcat fa {time}",
    "Bookmarked on {date}" : "Marcat a {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Aquests són els vostres elements suprimits. Els elements es suprimiran permanentment al cap de dos mesos.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les adreces d'interès dels fitxers del web, com ara fotografies o PDF, es desaran automàticament als fitxers de Nextcloud, de manera que encara les podeu trobar fins i tot quan l'enllaç estigui desconnectat.",
    "Searching in the current folder only." : "Cerca només a la carpeta actual.",
    "Repeat search in all folders" : "Repetiu la cerca a totes les carpetes",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Els enllaços marcats es revisen regularment i els que no es poden accedir s'enumeren aquí.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Podeu compartir carpetes d'adreces d'interès amb altres persones. Totes les carpetes compartides amb tu es mostren aquí.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Una adreça d'interès pot estar en diverses carpetes alhora. En actualitzar-la, s'actualitzaran totes les còpies. Totes les adreces d'interès duplicades s'enumeren aquí per comoditat.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Carpetes {folders} seleccionades i adreces d'interès {bookmarks}",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["S'ha seleccionat %n adreça d'interès","S'han seleccionat %n adreces d'interès"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n carpeta seleccionada","%n carpetes seleccionades"],
    "Do you really want to delete these items?" : "Realment voleu suprimir aquests elements?",
    "Open all selected" : "Obre totes els seleccionats",
    "Move selection" : "Mou la selecció",
    "Edit tags of selection" : "Edició de les etiquetes de la selecció",
    "Delete selection" : "Suprimeix la selecció",
    "Select all" : "Selecciona-ho tot",
    "Cancel selection" : "Cancel·la la selecció",
    "Sort by created date" : "Ordena per data de creació",
    "Sort by last modified" : "Ordena per darrera modificació",
    "Sort by title" : "Ordena per títol",
    "Sort by click count" : "Ordena per recompte de clics",
    "Sort by manual order" : "Ordena per ordre manual",
    "Sort by URL" : "Ordena per URL",
    "RSS feed copied" : "Canal RSS copiat",
    "Trash Bin" : "Paperera",
    "Go back" : "Torna enrere",
    "Share folder" : "Comparteix la carpeta",
    "Open folder details" : "Obre els detalls de la carpeta",
    "Select one or more tags" : "Seleccionau una o més etiquetes",
    "New" : "Nou",
    "New bookmark" : "Adreça d'interès nova",
    "New folder" : "Carpeta nova",
    "Change to grid view" : "Canvia a la visualització de quadrícula",
    "Change to list view" : "Canvia el mode de visualització a llista",
    "Copy RSS Feed of current view" : "Copia el canal RSS de la visualització actual",
    "The RSS feed requires authentication with your Nextcloud credentials" : "El canal RSS requereix autenticació amb les vostres credencials de Nextcloud",
    "Search" : "Cercar",
    "Empty trash bin" : "Buida la paperera",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["S'està afegint %n adreça d'interès a la carpeta nova","S'estan afegint %n adreces d'interès a la carpeta nova"],
    "Enter a link" : "Introduïu un enllaç",
    "Enter a title" : "Escriviu el títol",
    "No bookmarks found" : "No s'ha trobat cap adreça d'interès",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} carpetes i {bookmarks} adreces d'interès",
    "_%n bookmark_::_%n bookmarks_" : ["%n adreça d'interès","%n adreces d'interès"],
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "Welcome to Bookmarks" : "Benvingut a Adreces d'interès",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Aquesta aplicació us permet gestionar enllaços als vostres llocs preferits al web. Ordena les teves adreces d'interès en carpetes, etiqueta'ls amb etiquetes i comparteix-les amb els altres! L'aplicació comprovarà regularment la disponibilitat de tots els vostres enllaços i mostrarà els enllaços no disponibles. Si afegiu un enllaç a un fitxer al web, el fitxer es baixarà automàticament als vostres fitxers Nextcloud. També podeu importar adreces d'interès exportades des d'altres serveis o sincronitzar directament les adreces d'interès de tots els vostres navegadors amb aquesta aplicació.",
    "Add a bookmark" : "Afegeix una adreça d'interès",
    "Import bookmarks" : "Importa adreces d'interès",
    "Sync with your browser" : "Sincronitzar amb el vostre navegador",
    "Do you really want to permanently delete this folder?" : "Realment voleu suprimir aquesta carpeta permanentment?",
    "Select folder" : "Trieu una carpeta",
    "Enter folder title" : "Escriviu el títol de la carpeta",
    "Shared by {user}" : "Compartit per {user}",
    "Rename folder" : "Canvia el nom de la carpeta",
    "Move folder" : "Mou la carpeta",
    "Put folder into trashbin" : "Posa la carpeta a la paperera",
    "Restore folder" : "Restaura una carpeta",
    "Delete folder permanently" : "Suprimeix la carpeta permanentment",
    "Choose folder" : "Trieu carpeta",
    "Submit" : "Envia",
    "Cancel" : "Cancel·la",
    "Deleting bookmarks" : "S'estan suprimint les adreces d'interès",
    "Deleting selection" : "S'està suprimint la selecció",
    "Importing bookmarks" : "S'estan important les adreces d'interès",
    "Moving selection" : "S'està movent la selecció",
    "Adding selection to folders" : "Afegint selecció a les carpetes",
    "Emptying trashbin" : "Buidant la paperera",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["S' està movent la carpeta %n i algunes adreces d'interès","S’ estan movent %n carpetes i algunes adreces d'interès"],
    "_Moving %n folder_::_Moving %n folders_" : ["S' està movent la carpeta %n","S’estan movent %n carpetes"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movent %n adreça d'interès","Movent %n adreces d'interès"],
    "All bookmarks" : "Totes les adreces d'interès",
    "Recent" : "Recents",
    "Shared with you" : "Compartit amb vós",
    "Files" : "Fitxers",
    "Duplicates" : "Duplicats",
    "Broken links" : "Enllaços trencats",
    "New tag" : "Nova etiqueta",
    "Search tags" : "Cerca etiquetes",
    "Delete" : "Suprimeix",
    "Untagged" : "Sense etiqueta",
    "{used} bookmarks of {available} available" : "{used} Adreces d'interès de {available} disponibles",
    "Bookmarks Settings" : "Configuració d'adreces d'interès",
    "No bookmarked files" : "No hi ha fitxers marcats",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les adreces d'interès a fitxers com ara fotos o PDF es desaran automàticament als fitxers Nextcloud, de manera que encara els podeu trobar fins i tot quan l'enllaç es desconnecti.",
    "Nothing found" : "No s'ha trobat res",
    "Your search yielded no results in the current folder." : "La vostra cerca no ha donat cap resultat a la carpeta actual.",
    "No broken links" : "No hi ha enllaços trencats",
    "No shared folders" : "No hi ha carpetes compartides",
    "No duplicated bookmarks" : "No hi ha adreces d'interès duplicades",
    "No deleted bookmarks" : "No s'ha suprimit cap adreça d'interès",
    "You haven't deleted anything yet." : "Encara no has suprimit res.",
    "No bookmarks here" : "No hi ha cap adreça d'interès",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Afegiu adreces d'interès manualment o importeu-ne d'un fitxer HTML.",
    "Archive path" : "Camí de l'arxiu",
    "Backup path" : "Camí de la còpia de seguretat",
    "Please select \"Add to home screen\" in your browser menu" : "Seleccioneu «Afegeix a la pantalla d'inici» en el menú del vostre navegador",
    "Bookmarks settings" : "Configuració d'adreces d'interès",
    "Import/Export" : "Importació/exportació",
    "Export bookmarks" : "Exporta adreces d'interès",
    "Auto-archiving" : "Arxiu automàtic",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "L'aplicació d'adreces d'interès pot arxivar automàticament el contingut web dels enllaços que heu marcat",
    "Enable archiving" : "Habilita l'arxiu",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Introduïu el camí d'una carpeta als fitxers on s'han d'emmagatzemar les adreces d’interès dels fitxers.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Actualment, l'administrador ha desactivat l'accés a la xarxa per a aquesta aplicació, però és per això que l'arxiu automàtic està desactivat en aquest moment.",
    "Auto-Backup" : "Còpia de seguretat automàtica",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "L'aplicació d'adreces d'interès pot fer una còpia de seguretat automàtica de les adreces d'interès diàriament per evitar la pèrdua de dades en sincronitzar les adreces d'interès entre dispositius.",
    "Enable backups" : "Habilita les còpies de seguretat",
    "Enter the path of a folder in your Files where backups will be stored." : "Introduïu el camí d'una carpeta als vostres fitxers on s'emmagatzemaran les còpies de seguretat.",
    "Client apps" : "Aplicacions de client",
    "Also check out the collection of client apps that integrate with this app: " : "Feu també un cop d'hora al conjunt d'aplicacions client que s'integren amb aquesta aplicació: ",
    "Install web app" : "Instal·la l'aplicació web",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Pots instal·lar aquesta aplicació a la pantalla d'inici del dispositiu per accedir ràpidament les adreces d'interès al teu telèfon. Pots tornar a suprimir fàcilment l'aplicació de la pantalla d'inici si no t'agrada.",
    "Install on home screen" : "Instal·la a la pantalla d'inici",
    "Bookmarklet" : "Miniaplicació d'adreces d'interès",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Arrossegueu-lo a les adreces d'interès del navegador i feu-hi clic per afegir ràpidament una pàgina web a les adreces d'interès.",
    "Add to {instanceName}" : "Afegeix a {instanceName}",
    "Need help?" : "Necessiteu ajuda?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Si tens problemes amb aquesta aplicació Adreces d’interès o tens una idea sobre què es pot millorar, no dubtis a posar-te en contacte fent clic aquí.",
    "Support this project" : "Donar suport a aquest projecte",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "El meu treball en aquesta aplicació Adreces d’interès està impulsat per un model de subscripció voluntària. Si creus que el que faig val la pena, m'agradaria que poguessis recolzar la meva feina. A més, considereu donar una revisió de l'aplicació al magatzem d'aplicacions Nextcloud. Gràcies 💙 ",
    "Created {time} ago" : "Creat fa {time}",
    "Created on {date}" : "Creat en {date}",
    "(Empty title)" : "(Títol buit)",
    "Title" : "Títol",
    "Link" : "Enllaç",
    "Untitled folder" : "Carpeta sense nom",
    "Root folder" : "Carpeta d'arrel",
    "Tags" : "Etiquetes",
    "Select tags and create new ones" : "Seleccioneu etiquetes i creeu-ne de noves",
    "Notes" : "Notes",
    "Notes for this bookmark …" : "Notes per a aquesta adreça d'interès …",
    "Archived file" : "Obre el fitxer arxivat",
    "Open file" : "Obre un fitxer",
    "Download file" : "Baixa el fitxer",
    "Open file location" : "Obre la ubicació del fitxer",
    "Link copied" : "Enllaç copiat",
    "Owner" : "Propietari",
    "Sharing" : "Compartició",
    "Select a user or group" : "Seleccioneu un usuari o un grup",
    "Share link" : "Enllaç de compartició",
    "Reading allowed" : "Lectura permesa",
    "Copy RSS feed" : "Copia canal RSS",
    "Delete link" : "Suprimeix l'enllaç",
    "Create public link" : "Creació d'un enllaç públic",
    "Resharing allowed" : "Tornar a compartir permés",
    "Editing allowed" : "Edició permesa",
    "Allow editing" : "Permet l'edició",
    "Allow resharing" : "Permet compartir de nou",
    "Remove share" : "Suprimeix la compartició",
    "Leave a rating on the Nextcloud App Store" : "Deixa una puntuació al Magatzem d’aplicacions de Nextcloud",
    "Failed to save settings" : "Ha fallat desar els paràmetres",
    "Failed to load settings" : "Ha fallat carregar els paràmetres",
    "Privacy" : "Privadesa",
    "The app will try to access web pages that you add to automatically add information about them." : "L'aplicació intentarà accedir a les pàgines web que afegiu per afegir automàticament informació sobre elles.",
    "Enable accessing and collecting information from the web pages you add" : "Habiliteu l'accés i la recopilació d'informació de les pàgines web que afegiu",
    "Performance" : "Rendiment",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "En una instal·lació amb molts usuaris pot ser útil restringir el nombre d'adreces d'interès per compte.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre màxim permès d'adreces d'interès per compte. (0 sense límit; per defecte no té límit)",
    "Previews" : "Previsualitzacions",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Per mostrar captures de pantalla reals dels vostres llocs web marcats, l'aplicació pot utilitzar serveis de tercers per generar previsualitzacions.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Podeu registrar-vos de forma gratuïta a screeenly.com configurar el vostre propi servidor.",
    "Screeenly API URL" : "URL de l'API de Screeenly",
    "Screeenly API key" : "Clau API de Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clau de l’API de ScreenshotMachine",
    "Webshot" : "Foto web",
    "Webshot API URL" : "URL de l'API de webshot",
    "Generic screenshot API" : "API de captura de pantalla genèrica",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Registreu-vos amb qualsevol dels proveïdors d'API de captures de pantalla i introduïu l'URL de l'API a continuació. Utilitzeu la variable {url} com a marcador de posició per a l'URL de la captura de pantalla. L'API només ha de retornar directament la imatge.",
    "Generic API URL" : "URL de l’API genèric",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Simplement instal·leu la CLI de Pageres de Sindre Sorhus al vostre servidor i Bookmarks la trobarà. Encara podeu afegir variables ENV addicionals per introduir-los als pageres, p. tal com s'indica al marcador de posició:",
    "Pageres ENV variables" : "Variables ENV Pageres",
    "This URL is already bookmarked! Overwrite?" : "Ja teniu aquest URL als Adreces d'interès. Voleu sobreescriure'l?",
    "Enter bookmark title" : "Escriviu el títol de l'adreça d'interès",
    "Enter bookmark URL" : "Introduïu l'adreça URL de l'adreça d'interès",
    "Folder" : "Carpeta",
    "Root Folder" : "Carpeta arrel",
    "Save" : "Desa",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "L'accés a la xarxa està inhabilitat per defecte. Aneu als paràmetres de l'administrador de l'aplicació Adreces d'interès per permetre obtenir previsualitzacions i favicons.",
    "What's new?" : "Quines novetats hi ha?",
    "What" : "Què",
    "Failed to count unavailable bookmarks" : "No s'han pogut comptar les adreces d'interès no disponibles",
    "Failed to count archived bookmarks" : "No s'han pogut comptar les adreces d'interès arxivades",
    "Failed to count duplicated bookmarks" : "No s'han pogut comptar les adreces d'interès duplicades",
    "Failed to load bookmark" : "No s'ha pogut carregar l'adreça d'interès",
    "Failed to find existing bookmark" : "Ha fallat trobar l'adreça d'interès existent",
    "Failed to create bookmark" : "Ha fallat crear l'adreça d'interès",
    "Failed to save bookmark" : "Ha fallat desar l'adreça d'interès",
    "Failed to move bookmark" : "Ha fallat moure l'adreça d'interès",
    "Failed to copy bookmark" : "No s'ha pogut copiar l'adreça d'interès",
    "Failed to delete bookmark" : "Ha fallat suprimir l'adreça d'interès",
    "Failed to rename tag" : "No s'ha pogut canviar el nom de l'etiqueta",
    "Failed to load tags" : "Ha fallat carregar les etiquetes",
    "Failed to load folders" : "Ha fallat carregar les carpetes",
    "Failed to load deleted folders" : "No s'han pogut carregar les carpetes suprimides",
    "Failed to load deleted bookmarks" : "No s'han pogut carregar les adreces d'interès suprimides",
    "Failed to delete folder" : "Ha fallat suprimir la carpeta",
    "Failed to move folder" : "No s'ha pogut moure la carpeta",
    "Failed to create folder" : "Ha fallat crear la carpeta",
    "Failed to move parts of selection" : "Ha fallat moure les parts de la selecció.",
    "Failed to delete parts of selection" : "Ha fallat suprimir parts de la selecció.",
    "Failed to fetch bookmarks." : "Ha fallat obtenir les adreces d'interès.",
    "Failed to store setting" : "No s'ha pogut desar el paràmetre",
    "Failed to load setting {key}" : "No s'ha pogut carregar el paràmetre {key}",
    "Failed to update share {shareId}" : "No s'ha pogut actualitzar la compartició {shareId}",
    "Failed to delete share {shareId}" : "No s'ha pogut suprimir la compartició {shareId}",
    "Create bookmarks for mentioned links" : "Creeu adreces d'interès per als enllaços esmentats",
    "No links found in this message" : "No s'han trobat enllaços en aquest missatge",
    "Bookmarks feed" : "Canal d'adreces d'interès"
},
"nplurals=2; plural=(n != 1);");
