<?php
$TRANSLATIONS = array(
"Bookmarks" => "Отметки",
"Bookm." => "Отмет.",
"No file provided for import" => "Не беше предоставен файл за зареждане",
"Unsupported file type for import" => "Неподдържан файл за внасяне.",
"Some Error happened." => "Случисе някаква Грешка.",
"Error" => "Грешка",
"Tags" => "Етикети",
"Filter by tag" => "Филтриране по етикет",
"Are you sure you want to remove this bookmark?" => "Сигурен ли си, че искаш да премахнеш отметката?",
"Warning" => "Предупреждение",
"Are you sure you want to remove this tag from every entry?" => "Сигурен ли си че желаеш да премахнеш този етикет от всеки запис?",
"Import error" => "Грешка при внасянето",
"Import completed successfully." => "Внасянето завърши успешно.",
"Uploading..." => "Качване...",
"Add a bookmark" => "Добави отметка",
"This URL is already bookmarked! Overwrite?" => "Това URL вече е отбелязано! Презаписване?",
"The title of the page" => "Заглавие на страницата",
"The address of the page" => "Адрес на страницата",
"Description of the page" => "Описание на страницата",
"Save" => "Запис",
"Delete" => "Изтриване",
"Edit" => "Промяна",
"Cancel" => "Отказ",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Довлачи това в лентата с отметки на браузъра си и го натискай, когато искаш да отметнеш бързо някоя страница:",
"Add to ownCloud" => "Добави в ownCloud",
"Address" => "Адрес",
"Filterable Tags" => "Етикети подлежащи на Филтриране",
"You have no bookmarks" => "Нямаш отметки",
"You can also import a bookmark file" => "Можеш също да заредиш файл с отметки",
"Bookmarklet" => "Отметка",
"Export & Import" => "Експорт и Внасяне",
"Export" => "Експорт",
"Import" => "Внасяне"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
