OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "You bookmarked \"%s\"" : "Has guardado «%s»",
    "%1$s bookmarked \"%2$s\"" : "%1$s ha guardado «%2$s»",
    "Someone bookmarked \"%s\"" : "Alguien ha guardado «%s»",
    "You deleted \"%s\"" : "Has eliminado «%s»",
    "%1$s deleted \"%2$s\"" : "%1$s ha eliminado «%2$s»",
    "Someone deleted \"%s\"" : "Alguien ha eliminado «%s»",
    "You created folder \"%s\"" : "Has creado la carpeta «%s»",
    "%1$s created folder \"%2$s\"" : "%1$s ha creado la carpeta «%2$s»",
    "Someone created folder \"%s\"" : "Alguien ha creado la carpeta «%s»",
    "You moved folder \"%s\"" : "Has movido la carpeta «%s»",
    "%1$s moved folder \"%2$s\"" : "%1$s ha movido la carpeta «%2$s»",
    "Someone moved folder \"%s\"" : "Alguien ha movido la carpeta «%s»",
    "You deleted folder \"%s\"" : "Has eliminado la carpeta «%s»",
    "%1$s deleted folder \"%2$s\"" : "%1$s ha eliminado la carpeta «%2$s»",
    "Someone deleted folder \"%s\"" : "Alguien ha eliminado la carpeta «%s»",
    "You shared folder \"%1$s\" with %2$s" : "Has compartido la carpeta «%1$s» con %2$s",
    "You shared folder \"%s\" with someone" : "Has compartido la  carpeta «%s» con alguien",
    "%1$s shared folder \"%2$s\" with you" : "%1$s ha compartido la carpeta «%2$s» contigo",
    "Someone shared folder \"%s\" with you" : "Alguien ha compartido la carpeta «%s» contigo",
    "You unshared folder \"%1$s\" with %2$s" : "Has dejado de compartir la carpeta «%1$s» con %2$s",
    "You unshared folder \"%s\" with someone" : "Has dejado de compartir la carpeta «%s» con alguien",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s ha dejado de compartir la carpeta «%2$s» contigo",
    "Someone unshared folder \"%s\" with you" : "Alguien ha dejado de compartir la carpeta «%s» contigo",
    "No file provided for import" : "No se seleccionó un archivo para importar",
    "Failed to upload file" : "Error al subir el archivo",
    "Unsupported file type for import: " : "Tipo de archivo a importar no soportado:",
    "Bookmarks shared by %s" : "Marcadores compartidos por %s",
    "Frequent bookmarks" : "Marcadores frecuentes",
    "Recent bookmarks" : "Marcadores recientes",
    "Bookmark" : "Marcador",
    "Bookmark deleted" : "Marcador eliminado",
    "Bookmark created" : "Marcador creado",
    "Bookmark moved" : "Marcador movido",
    "Bookmark updated" : "Marcador actualizado",
    "Create bookmark" : "Crear marcador",
    "Takes a link and adds it to your collection of bookmarks." : "Toma un enlace y lo añade a tu colección de marcadores.",
    "Bookmarks Backups" : "Copia de seguridad de Marcadores",
    "Collect and manage bookmarks, synced with all your devices" : "Recopile y administre marcadores, sincronizados con todos sus dispositivos",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Ordena los marcadores en carpetas\n- 🏷 Añade etiquetas y notas personales\n- ☠ Encuentra enlaces rotos y duplicados\n- 📲 Sincroniza con todos sus navegadores y dispositivos\n- 📔 Almacena versiones archivadas de sus enlaces por si son retirados\n- 🔍 Búsqueda de texto completo en los contenidos de los sitios\n- 👪 Comparta marcadores con otros usuarios, grupos y equipos a través de enlaces públicos\n- ⚛ Genera feeds RSS de sus recolecciones\n- 📈 Estadísticas de con qué frecuencia accede a qué enlaces\n- 🔒 Copias de seguridad automáticas de su colección de marcadores\n- 💼 Widgets para Dashboard integrados para enlaces frecuentes y recientes\n\nRequerimientos:\n - Extensiones PHP:\n   - intl: *\n   - mbstring: *\n - cuando se usa MySQL, debe usar al menos v8.0",
    "Do you really want to delete this bookmark?" : "¿Estás seguro de que quieres eliminar este marcador?",
    "Link copied to clipboard" : "Enlace copiado al portapapeles",
    "Enter new title" : "Introduce el título nuevo",
    "Select bookmark" : "Seleccione un marcador",
    "You have never clicked this link" : "Nunca ha hecho clic en este enlace",
    "You have clicked this link {count} times" : "Has hecho clic en este enlace {count} veces",
    "Details" : "Detalles",
    "Rename" : "Renombrar",
    "Copy link" : "Copiar enlace",
    "Move" : "Mover",
    "Add to folders" : "Añadir a carpetas",
    "Put bookmark into trash bin" : "Colocar el marcador en la papelera de reciclaje",
    "Restore bookmark" : "Restaurar marcador",
    "Delete bookmark permanently" : "Borrar marcador permanentemente",
    "Content pending" : "Contenido pendiente",
    "This content is being downloaded for offline use. Please check back later." : "Este contenido se está descargando para usarlo offline. Por favor, comprueba de nuevo más tarde.",
    "Bookmarked {time} ago" : "Se agregó como marcador hace {time}",
    "Bookmarked on {date}" : "Se agregó como marcador en {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Estos son sus elementos eliminados. Serán eliminados permanentemente después de dos meses.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Los marcadores de archivos en la web, como fotos o PDF, se guardarán automáticamente en sus archivos de Nextcloud, por lo que aún puede encontrarlos incluso cuando el enlace no esté disponible.",
    "Searching in the current folder only." : "Buscando únicamente en la carpeta actual.",
    "Repeat search in all folders" : "Repetir la búsqueda en todas las carpetas",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Los enlaces con marcadores se comprueban regularmente y aquellos que no pueden ser accedidos se listan aquí.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Puede compartir carpetas de marcadores con otros. Todas las carpetas compartidas con Ud. se listan aquí.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Un marcador puede estar en varias carpetas a la vez. Al actualizarlo, se actualizarán todas las copias. Todos los marcadores duplicados se listan aquí para mayor comodidad.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Seleccionadas {folders} carpetas y {bookmarks} marcadores",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Seleccionado %n marcador","Seleccionados %n marcadores","Seleccionados %n marcadores"],
    "_Selected %n folder_::_Selected %n folders_" : ["Seleccionada%n carpeta","Seleccionadas %n carpetas","Seleccionadas %n carpetas"],
    "Do you really want to delete these items?" : "¿Estás seguro de que quieres eliminar estos elementos?",
    "Open all selected" : "Abrir todos los seleccionados",
    "Move selection" : "Mover la selección",
    "Edit tags of selection" : "Editar etiquetas de la selección",
    "Delete selection" : "Borrar la selección",
    "Select all" : "Seleccionar todo",
    "Cancel selection" : "Cancelar selección",
    "Sort by created date" : "Ordenar por fecha de creación",
    "Sort by last modified" : "Ordenar por último modificado",
    "Sort by title" : "Ordenar por título",
    "Sort by click count" : "Ordenar por número de clics",
    "Sort by manual order" : "Ordenar manualmente",
    "Sort by URL" : "Ordenar por URL",
    "RSS feed copied" : "Fuente RSS copiada",
    "Trash Bin" : "Papelera de reciclaje",
    "Go back" : "Ir atrás",
    "Share folder" : "Compartir carpeta",
    "Open folder details" : "Abrir detalles de la carpeta",
    "Select one or more tags" : "Selecciona una o más etiquetas",
    "New" : "Nuevo",
    "New bookmark" : "Nuevo marcador",
    "New folder" : "Nueva carpeta",
    "Change to grid view" : "Cambiar a vista de cuadrícula",
    "Change to list view" : "Cambiar a vista de lista",
    "Copy RSS Feed of current view" : "Copiar la Fuente RSS de la vista actual",
    "The RSS feed requires authentication with your Nextcloud credentials" : "La Fuente RSS requiere autenticar con tus credenciales de Nextcloud",
    "Search" : "Buscar",
    "Empty trash bin" : "Vacíar la papelera",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Añadiendo %n marcador a una nueva carpeta","Añadiendo %n marcadores a una nueva carpeta","Añadiendo %n marcadores a una nueva carpeta"],
    "Enter a link" : "Introduce un enlace",
    "Enter a title" : "Introduce un título",
    "No bookmarks found" : "No se han encontrado marcadores",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} carpetas {bookmarks} marcadores",
    "_%n bookmark_::_%n bookmarks_" : ["%n marcador","%n marcadores","%n marcadores"],
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
    "Welcome to Bookmarks" : "Bienvenido a Marcadores",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Esta app le permite gestionar enlaces a sus lugares favoritos de la web. ¡Organice sus marcadores en carpetas, etiquete los mismos y compártelos con otros!. La app verificará periódicamente su disponibilidad y mostrará los que ya no son accesibles. Si añade un enlace a un archivo en la web, el mismo será automáticamente descargado a sus Archivos de Nextcloud. También puede importar marcadores de otros servicios o sincronizar directamente sus marcadores de todos sus navegadores con esta app.",
    "Add a bookmark" : "Añadir un marcador",
    "Import bookmarks" : "Importar marcadores",
    "Sync with your browser" : "Sincroniza con tu navegador",
    "Do you really want to permanently delete this folder?" : "¿Realmente desea eliminar permanentemente esta carpeta?",
    "Select folder" : "Selecciona carpeta",
    "Enter folder title" : "Introduce el título de la carpeta",
    "Shared by {user}" : "Compartidos por {user}",
    "Rename folder" : "Renombrar carpeta",
    "Move folder" : "Mover carpeta",
    "Put folder into trashbin" : "Colocar carpeta en la papelera de reciclaje",
    "Restore folder" : "Restaurar carpeta",
    "Delete folder permanently" : "Eliminar carpeta permanentemente",
    "Choose folder" : "Elegir carpeta",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Deleting bookmarks" : "Eliminando marcadores",
    "Deleting selection" : "Borrando la selección",
    "Importing bookmarks" : "Importando marcadores",
    "Moving selection" : "Moviendo la selección",
    "Adding selection to folders" : "Añadiendo selección a las carpetas",
    "Emptying trashbin" : "Vaciando papelera",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Moviendo %n carpeta y algunos marcadores","Moviendo %n carpetas y algunos marcadores","Moviendo %n carpetas y algunos marcadores"],
    "_Moving %n folder_::_Moving %n folders_" : ["Moviendo %n carpeta","Moviendo %n carpetas","Moviendo %n carpetas"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Moviendo %n marcador","Moviendo %n marcadores","Moviendo %n marcadores"],
    "All bookmarks" : "Todos los marcadores",
    "Recent" : "Reciente",
    "Shared with you" : "Compartido con Ud.",
    "Files" : "Archivos",
    "Duplicates" : "Duplicados",
    "Broken links" : "Enlaces rotos",
    "New tag" : "Nueva etiqueta",
    "Search tags" : "Buscar etiquetas",
    "Delete" : "Eliminar",
    "Untagged" : "Sin etiquetar",
    "{used} bookmarks of {available} available" : "{used} marcadores de {available} disponibles",
    "Bookmarks Settings" : "Ajustes de Marcadores",
    "No bookmarked files" : "Sin archivos marcadores",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Marcar archivos como fotos o PDF harán que se guarden automáticamente en tus archivos de Nextcloud, para que puedas encontrarlos incluso cuando el enlace queda fuera de línea.",
    "Nothing found" : "No se encontró nada",
    "Your search yielded no results in the current folder." : "Su búsqueda no arrojó resultados en la carpeta actual.",
    "No broken links" : "No hay enlaces rotos",
    "No shared folders" : "No hay carpetas compartidas",
    "No duplicated bookmarks" : "No hay marcadores duplicados",
    "No deleted bookmarks" : "No hay marcadores eliminados",
    "You haven't deleted anything yet." : "No ha eliminado nada todavía.",
    "No bookmarks here" : "No hay marcadores aquí",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Añada marcadores manualmente o importe desde un archivo HTML.",
    "Archive path" : "Ruta de archivo",
    "Backup path" : "Ruta de acceso a copias de seguridad",
    "Please select \"Add to home screen\" in your browser menu" : "Por favor, selecciona \"Añadir a inicio\" en el menú de tu navegador",
    "Bookmarks settings" : "Configuraciones de marcadores",
    "Import/Export" : "Importar/Exportar",
    "Export bookmarks" : "Exportar marcadores",
    "Auto-archiving" : "Archivado automático",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "La aplicación de marcadores puede archivar automáticamente el contenido web de los enlaces que haya marcado",
    "Enable archiving" : "Habilitar el archivado",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Ingrese la ruta de una carpeta en sus Archivos donde se almacenarán los archivos marcados.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Actualmente su administrador ha desactivado el acceso a la red para esta app. Por ello, el archivado automático está deshabilitado por el momento.",
    "Auto-Backup" : "Respaldo automático",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "La aplicación de marcadores puede respaldar automáticamente sus marcadores diariamente para prevenir pérdida de información al sincronizar marcadores entre dispositivos.",
    "Enable backups" : "Habilitar respaldos",
    "Enter the path of a folder in your Files where backups will be stored." : "Ingrese la ruta de una carpeta en sus Archivos donde se almacenarán los respaldos.",
    "Context Chat integration" : "Integración con Context Chat",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "La app de marcadores puede hacer que Context Chat disponga del contenido textual de los sitios web que tiene guardados en los marcadores de manera automática, lo que permite hacer preguntas acerca y recibir respuestas basándose en esos contenidos. Sólo estará disponible si el archivado automático está habilitado.",
    "Context chat is currently not installed, but is required for this feature." : "Context chat no está actualmente instalado, pero se requiere para esta característica.",
    "Enable Context Chat integration" : "Habilitar la integración con Context Chat",
    "Client apps" : "Apps clientes",
    "Also check out the collection of client apps that integrate with this app: " : "Mira también la colección apps cliente que se integran con esta app:",
    "Install web app" : "Instalar aplicación web",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Puede instalar esta aplicación en la pantalla de inicio de su dispositivo para acceder rápidamente a sus marcadores en su teléfono. Si no le gusta, puede eliminar fácilmente la aplicación de su pantalla de inicio de nuevo.",
    "Install on home screen" : "Instalar en la pantalla de inicio",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Arrástrelo a los marcadores de su navegador y haga clic en él para marcar rápidamente una página web.",
    "Add to {instanceName}" : "Añadir a {instanceName}",
    "Need help?" : "¿Necesita ayuda?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Si tienes problemas con esta app de Marcadores, o tienes una idea sobre lo que se puede mejorar, no dudes en ponenerte en contacto pulsado aquí.",
    "Support this project" : "Apoya este proyecto",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Mi trabajo en esta app de Marcadores está impulsado por un modelo de suscripción voluntario. Si cree que lo que hago vale la pena, me haría feliz que ud. pueda apoyar mi trabajo. Además, por favor considere dejar una opinión sobre la misma en el app store de Nextcloud. Gracias 💙",
    "Created {time} ago" : "Creado hace {time}",
    "Created on {date}" : "Creado el {date}",
    "(Empty title)" : "(Título vacío)",
    "Title" : "Título",
    "Link" : "Enlace",
    "Untitled folder" : "Carpeta sin título",
    "Root folder" : "Carpeta raíz",
    "Tags" : "Etiquetas",
    "Select tags and create new ones" : "Selecciona etiquetas y crea nuevas",
    "Notes" : "Notas",
    "Notes for this bookmark …" : "Notas para este marcador …",
    "Archived file" : "Archivo archivado",
    "Open file" : "Abrir archivo",
    "Download file" : "Descargar archivo",
    "Open file location" : "Abrir ubicación del archivo",
    "Link copied" : "Enlace copiado",
    "Owner" : "Propietario",
    "Sharing" : "Compartir",
    "Select a user or group" : "Selecciona un usuario o grupo",
    "Share link" : "Compartir enlace",
    "Reading allowed" : "Permitido leer",
    "Copy RSS feed" : "Copiar fuente RSS",
    "Delete link" : "Eliminar enlace",
    "Create public link" : "Crear un enlace público",
    "Resharing allowed" : "Permitido compartir",
    "Editing allowed" : "Permitido editar",
    "Allow editing" : "Permitir edición",
    "Allow resharing" : "Permitir compartir",
    "Remove share" : "Eliminar el recurso compartido",
    "Would you like to support this project?" : "¿Desea apoyar este proyecto?",
    "Leave a rating on the Nextcloud App Store" : "Deja una valoración en la Tienda de Aplicaciones de Nextcloud",
    "Failed to save settings" : "Fallo al guardar configuraciones",
    "Failed to load settings" : "Fallo al cargar configuraciones",
    "Privacy" : "Privacidad",
    "The app will try to access web pages that you add to automatically add information about them." : "La app intentará acceder a las páginas web que añades para obtener automáticamente información sobre ellas.",
    "Enable accessing and collecting information from the web pages you add" : "Permitir el acceso y recolección información de las páginas web que añadas",
    "Performance" : "Rendimiento",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "En una instalación con un gran número de usuarios, resultará útil limitar el número de marcadores en cada cuenta.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Número máximo de marcadores permitidos en cada cuenta. (Sin límite = 0; por omisión no hay límite)",
    "Previews" : "Vista previa",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Para mostrar capturas reales de tus sitios guardados, la app puede usar servicios de terceras partes para generas las vistas previas.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Puedes apuntarte gratis en screeenlly.com o configurar tu propio servidor.",
    "Screeenly API URL" : "URL de la API de Screeenly",
    "Screeenly API key" : "Clave de API de Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clave API de ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "API de captura de pantalla genérica",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Regístrese con cualquiera de los proveedores de API para capturas de pantalla y ponga la URL de la API a continuación. Utilice la variable {url} como un marcador de posición para la URL que se capturará. La API debe devolver sólo la imagen directamente.",
    "Generic API URL" : "URL de la API genérica",
    "Pageres CLI" : "CLI de pageres",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Simplemente instale la CLI de Pageres de Sindre Sorhus en su servidor y Marcadores la encontrará. Todavía puede añadir variables ENV adicionales para suministrar a pageres, p.ej. como se indica en el marcador de posición:",
    "Pageres ENV variables" : "Variables de ambiente de Pageres",
    "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya existe como marcador!\n¿Sobreescribir?",
    "Enter bookmark title" : "Introducir título del marcador",
    "Enter bookmark URL" : "Introducir URL del marcador",
    "Folder" : "Carpeta",
    "Root Folder" : "Carpeta Raíz",
    "Save" : "Guardar",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "El acceso a la red está desactivado por defecto. Vaya a la configuración del administrador a por la configuración de la app Marcadores y permite la toma de previsualizaciones y favicons.",
    "What's new?" : "¿Qué novedades hay?",
    "What" : "Qué",
    "Failed to count unavailable bookmarks" : "Fallo al contar los marcadores no disponibles",
    "Failed to count archived bookmarks" : "Fallo al contar los marcadores archivados",
    "Failed to count duplicated bookmarks" : "Fallo al contar los marcadores duplicados",
    "Failed to count bookmarks" : "Fallo al enumerar marcadores",
    "Failed to load bookmark" : "Fallo al cargar marcador.",
    "Failed to find existing bookmark" : "Fallo al encontrar marcador existente",
    "Failed to create bookmark" : "Fallo al crear marcador",
    "Failed to save bookmark" : "Fallo al guardar marcador",
    "Failed to move bookmark" : "Fallo al mover marcador",
    "Failed to copy bookmark" : "Fallo al copiar marcador",
    "Failed to delete bookmark" : "Fallo al eliminar marcador",
    "Failed to restore bookmark" : "Fallo al restaurar marcador",
    "Import successful" : "Importación exitosa",
    "Failed to rename tag" : "Fallo al renombrar la etiqueta",
    "Failed to load tags" : "Fallo al cargar etiquetas",
    "Failed to load folders" : "Fallo al cargar carpetas",
    "Failed to load deleted folders" : "Fallo al cargar las carpetas borradas",
    "Failed to load deleted bookmarks" : "Fallo al cargar los marcadores eliminados",
    "Failed to delete folder" : "Fallo al eliminar carpeta",
    "Failed to move folder" : "Fallo al mover carpeta",
    "Failed to restore folder" : "Fallo al restaurar carpeta",
    "Failed to create folder" : "Fallo al crear carpeta",
    "Failed to load children order" : "Fallo al cargar el orden de los objetos descendientes",
    "Failed to move parts of selection" : "Fallo al mover partes de la selección",
    "Failed to copy parts of selection" : "Fallo al copiar partes de la selección",
    "Failed to delete parts of selection" : "Fallo al borrar partes de la selección",
    "Failed to tag parts of selection" : "Fallo al etiquetar partes de la selección",
    "Failed to fetch bookmarks." : "Fallo al recuperar marcadores.",
    "Failed to store setting" : "Fallo al guardar configuración",
    "Failed to load setting {key}" : "Fallo al cargar la configuración {key}",
    "Failed to create share for folder {folderId}" : "Fallo al crear recurso compartido para la carpeta {folderId}",
    "Failed to update share {shareId}" : "Fallo al actualizar el recurso compartido {shareId}",
    "Failed to delete share {shareId}" : "Fallo al eliminar el recurso compartido {shareId}",
    "Failed to create public link for folder {folderId}" : "Fallo al crear enlace público de recurso compartido para la carpeta {folderId}",
    "Failed to delete public link for folder {folderId}" : "Fallo al eliminar enlace público de recurso compartido para la carpeta {folderId}",
    "Failed to permanently delete parts of trash bin" : "Fallo al borrar de manera permanente partes de la papelera de reciclaje",
    "Create bookmarks for mentioned links" : "Crear marcadores para los enlaces mencionados",
    "No links found in this message" : "No se han encontrado enlaces en este mensaje",
    "Bookmarks feed" : "Fuente de marcadores"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
