OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Обележивач",
    "You bookmarked \"%s\"" : "Маркирали сте „%s",
    "%1$s bookmarked \"%2$s\"" : "%1$s је маркирао „%2$s”",
    "Someone bookmarked \"%s\"" : "Неко је маркирао „%s",
    "You deleted \"%s\"" : "Обрисали сте „%s",
    "%1$s deleted \"%2$s\"" : "%1$s је обрисао %2$s”",
    "Someone deleted \"%s\"" : "Неко је обрисао %s”",
    "You created folder \"%s\"" : "Креирали сте фолдер %s”",
    "%1$s created folder \"%2$s\"" : "%1$s је креирао фолдер %2$s”",
    "Someone created folder \"%s\"" : "Неко је креирао фолдер %s”",
    "You moved folder \"%s\"" : "Преместили сте фолдер %s”",
    "%1$s moved folder \"%2$s\"" : "%1$s је преместио фолдер %2$s”",
    "Someone moved folder \"%s\"" : "Неко је преместио фолдер %s”",
    "You deleted folder \"%s\"" : "Обрисали сте фолдер „%s”",
    "%1$s deleted folder \"%2$s\"" : "%1$s је обрисао фолдер %2$s”",
    "Someone deleted folder \"%s\"" : "Неко је обрисао фолдер %s”",
    "You shared folder \"%1$s\" with %2$s" : "Поделили сте фолдер %1$s” са %2$s",
    "You shared folder \"%s\" with someone" : "Поделили сте фолдер %s” са неким",
    "%1$s shared folder \"%2$s\" with you" : "%1$s је поделио фолдер %2$s” са вама",
    "Someone shared folder \"%s\" with you" : "Неко је поделио фолдер %s” са вама",
    "You unshared folder \"%1$s\" with %2$s" : "Прекинули сте дељење фолдера %1$s” са %2$s",
    "You unshared folder \"%s\" with someone" : "Прекинули сте дељење фолдера %s” са неким",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s је прекинуо дељење фолдера %2$s” са вама",
    "Someone unshared folder \"%s\" with you" : "Неко је прекинуо дељење фолдера %s” са вама",
    "No file provided for import" : "није дат фајл за увоз",
    "Failed to upload file" : "Отпремање фајла није успело",
    "Unsupported file type for import: " : "Увози се тип фајла који није подржан:",
    "Bookmarks shared by %s" : "%s поделио обележиваче",
    "Frequent bookmarks" : "Чести маркери",
    "Recent bookmarks" : "Скорашњи маркери",
    "Bookmark" : "Маркер",
    "Bookmark deleted" : "Маркер је обрисан",
    "Bookmark created" : "Маркер је креиран",
    "Bookmark moved" : "Маркер је премештен",
    "Bookmark updated" : "Маркер је ажуриран",
    "Create bookmark" : "Креирај маркер",
    "Takes a link and adds it to your collection of bookmarks." : "Узима линк и додаје га у вашу колекцију маркера.",
    "Bookmarks Backups" : "Резервне копије маркера",
    "Collect and manage bookmarks, synced with all your devices" : "Сакупите и управљајте маркерима, синхронизовано на свим вашим уређајима",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Сортирајте маркере у фолдере\n- 🏷 Додајте ознаке и личне белешке\n- ☠ Пронађите неисправне линкове и дупликате\n- 📲 Синхронизујте са свим вашим прегледачима и уређајима\n- 📔 Чувајте архивиране верзије линкова у случају да се уклоне са мреже\n- 🔍 Претражујте по пуном тексту сајта\n- 👪 Делите маркере са другим корисницима, групама и тимовима, или јавним линковима\n- ⚛ Генеришите RSS новости о својим колекцијама\n- 📈 Статистика о томе колико често приступате одређеним линковима\n- 🔒 Аутоматске резервне копије ваших маркера\n- 💼 Уграђени су виџети Контролне табле за честе и скорашње линкове\n\nЗахтеви:\n - PHP проширења:\n   - intl: *\n   - mbstring: *\n - када се користи MySQL, мора бити барем верзија v8.0",
    "Do you really want to delete this bookmark?" : "Да ли заиста желите да обришете овај маркер?",
    "Link copied to clipboard" : "Веза копирана у оставу",
    "Enter new title" : "Унесите нови наслов",
    "Select bookmark" : "Изабери обележивач",
    "You have never clicked this link" : "Никада пре нисте кликнули овај линк",
    "You have clicked this link {count} times" : "Кликнули сте овај линк {count} пута",
    "Details" : "Детаљи",
    "Rename" : "Преименуј",
    "Copy link" : "Копирај везу",
    "Move" : "Премести",
    "Add to folders" : "Додај у фолдере",
    "Put bookmark into trash bin" : "Премести маркер у корпу за отпатке",
    "Restore bookmark" : "Врати маркер",
    "Delete bookmark permanently" : "Обриши трајно маркер",
    "Content pending" : "Чека се на садржај",
    "This content is being downloaded for offline use. Please check back later." : "Овај садржај је преузет за коришћење ван мреже. Молимо вас да проверите касније.",
    "Bookmarked {time} ago" : "Маркирано пре {time}",
    "Bookmarked on {date}" : "Маркирано дана {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Ово су ставке које сте обрисали. Након два месеца, обрисаће се неповратно.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Маркери на фајлове на вебу, као што су фотографије или PDF документи ће се аутоматски сачувати у ваше Nextcloud фајлове, тако да ћете моћи да их пронађете чак и када линк више не буде на мрежи.",
    "Searching in the current folder only." : "Претрага се врши само у текућем фолдеру.",
    "Repeat search in all folders" : "Понови претрагу по свим фолдерима",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Марикирани линкови се редовно проверавају и овде су наведени они до којих не може да се дође.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Фолдере са маркерима можете да делите са осталима. Овде су наведени сви фолдери које је неко поделио са вама.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Један маркер може да се налази у више фолдера одједном. Када га ажурирате, ажурирају се све копије. Да би вам било лакше, овде су наведени сви маркери дупликати.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Одабрано {folders} фасцикла(е) и {bookmarks} обележивач(а)",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Одабрано %n обележивач","Одабрано %n обележивача","Одабрано %n обележивача"],
    "_Selected %n folder_::_Selected %n folders_" : ["Одабрана %n фасцикла","Одабране %n фасцикле","Одабрано %n фасцикли"],
    "Do you really want to delete these items?" : "Да ли заиста желите да обришете ове ставке?",
    "Open all selected" : "Отвори све одабране",
    "Move selection" : "Премести одабир",
    "Edit tags of selection" : "Уреди ознаке изабраних",
    "Delete selection" : "Обриши одабир",
    "Select all" : "Одабери све ",
    "Cancel selection" : "Поништи одабир",
    "Sort by created date" : "Поређај по датуму креирања",
    "Sort by last modified" : "Поређај по последњем времену измене",
    "Sort by title" : "Поређај по наслову",
    "Sort by click count" : "Поређај по броју кликова на маркер",
    "Sort by manual order" : "Поређај по ручно дефинисаном редоследу",
    "Sort by URL" : "Поређај по URL адреси",
    "RSS feed copied" : "RSS довод копиран",
    "Trash Bin" : "Корпа за отпатке",
    "Go back" : "Иди назад",
    "Share folder" : "Дели фолдер",
    "Open folder details" : "Отвори детаље фолдера",
    "Select one or more tags" : "Одаберите једну или више ознака",
    "New" : "Нов",
    "New bookmark" : "Нови обележивач",
    "New folder" : "Нова фасцикла",
    "Change to grid view" : "Пређи на поглед мреже",
    "Change to list view" : "Пређи на поглед листе",
    "Copy RSS Feed of current view" : "Копирај RSS Новости текућег погледа",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS новост захтева аутентификацију са вашим Nextcloud креденцијалима",
    "Search" : "Претрага",
    "Empty trash bin" : "Испразни корпу за отпатке",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Додаје се %n маркер у нови фолдер","Додају се %n маркера у нову фолдер","Додаје се %nмаркера у нови фолдер"],
    "Enter a link" : "Унесите везу",
    "Enter a title" : "Унесите наслов",
    "No bookmarks found" : "Није пронађен ниједан маркер",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} фолдера и {bookmarks} маркера",
    "_%n bookmark_::_%n bookmarks_" : ["%n маркер","%n маркера","%n маркера"],
    "_%n folder_::_%n folders_" : ["%n фолдер","%n фолдера","%n фолдера"],
    "Welcome to Bookmarks" : "Добродошли у Маркере",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Ова апликација вам омогућава да управљате линковима на своја омиљена места на вебу. Сортирајте ваше маркере у фолдере, означите иг ознакама и делите их са другима! Апликација ће редовно проверавати доступност ваших линкова и приказаће оне који више нису доступни. Ако додате линк на фајл на вебу, он ће се аутоматски преузети у ваше Nextcloud Фајлове. Овом апликацијом такође можете и да увезете маркере који су били извезени из других сервиса, или да их директно синхронизујете из свих ваших прегледача.",
    "Add a bookmark" : "Додај обележивач",
    "Import bookmarks" : "Увези маркере",
    "Sync with your browser" : "Синхронизација са вашим прегледачем",
    "Do you really want to permanently delete this folder?" : "Да ли заиста желите да трајно обришете овај фолдер?",
    "Select folder" : "Одабери фасциклу",
    "Enter folder title" : "Унесите назив фасцикле",
    "Shared by {user}" : "Поделио {user}",
    "Rename folder" : "Преименуј фасциклу",
    "Move folder" : "Премести фолдер",
    "Put folder into trashbin" : "Премести фолдер у корпу за отпатке",
    "Restore folder" : "Врати фолдер",
    "Delete folder permanently" : "Обриши трајно фолдер",
    "Choose folder" : "Одаберите фасциклу",
    "Submit" : "Пошаљи",
    "Cancel" : "Поништи",
    "Deleting bookmarks" : "Брисање маркера",
    "Deleting selection" : "Брисање изабраних",
    "Importing bookmarks" : "Маркери се увозе",
    "Moving selection" : "Изабрани се премештају",
    "Adding selection to folders" : "Додавање изабраних у фолдере",
    "Emptying trashbin" : "Корпа за отпатке се празни",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Премештам %n фасциклу и неке обележиваче","Премештам %n фасцикле и неке обележиваче","Премештам %n фасцикли и неке обележиваче"],
    "_Moving %n folder_::_Moving %n folders_" : ["Премештам %n фасциклу","Премештам %n фасцикле","Премештам %n фасцикли "],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Премештам %n обележивач","Премештам %n обележивача","Премештам %n обележивача"],
    "All bookmarks" : "Све забелешке",
    "Recent" : "Скорашње",
    "Shared with you" : "Дељено са Вама",
    "Files" : "Фајлови",
    "Duplicates" : "Дупликати",
    "Broken links" : "Неисправни линкови",
    "New tag" : "Нова ознака",
    "Search tags" : "Претражи ознаке",
    "Delete" : "Обриши",
    "Untagged" : "Неозначени",
    "{used} bookmarks of {available} available" : "Искоришћено {used} од {available} доступних обележивача",
    "Bookmarks Settings" : "Подешавања маркера",
    "No bookmarked files" : "Нема маркираних фајлова",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Маркери на фајлове као што су фотографије или PDF документи ће се аутоматски сачувати у ваше Nextcloud фајлове, тако да ћете моћи да им приступите чак и онда када се линк уклони са мреже.",
    "Nothing found" : "Ништа није пронађено",
    "Your search yielded no results in the current folder." : "Ваша претрага по текућем фолдеру није вратила ниједан резултат.",
    "No broken links" : "Нема неисправних линкова",
    "No shared folders" : "Нема дељених фолдера",
    "No duplicated bookmarks" : "Нема маркера дупликата",
    "No deleted bookmarks" : "Нема обрисанох маркера",
    "You haven't deleted anything yet." : "Још увек нисте ништа обрисали.",
    "No bookmarks here" : "Овде нема обележивача",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Ручно додавање маркера или увоз маркера из HTML фајла.",
    "Archive path" : "Путања архиве",
    "Backup path" : "Путања резервне копије",
    "Please select \"Add to home screen\" in your browser menu" : "Молимо вас да у менију вашег прегледача изаберете „Додај на почетни екран",
    "Bookmarks settings" : "Подешавања маркера",
    "Import/Export" : "Увоз/Извоз",
    "Export bookmarks" : "Извоз маркера",
    "Auto-archiving" : "Ауто-архивирање",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Апликација маркера може аутоматски да архивира веб садржај линкова које маркирате",
    "Enable archiving" : "Укључи архивирање",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Унесите ппутању фолдера у вашим Фајловима где ће се чувати маркирани фајлови.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Ваш администратор је тренутно овој апликацији забранио приступ мрежи, па је услед тога тренутно искључено аутоматско архивирање.",
    "Auto-Backup" : "Ауто-резервна копија",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Апликација маркера може аутоматски да прави резервне копије ваших маркера на дневном нивоу и тако спречи губитак података када се маркери синхронизују између уређаја.",
    "Enable backups" : "Укључи резервне копије",
    "Enter the path of a folder in your Files where backups will be stored." : "Унесите путању фолдера у вашим Фајловима где ће се чувати резервне копије.",
    "Context Chat integration" : "Интеграција са Контекст четом",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Текстуалне садржаје веб сајтова које маркирате апликација маркера може да аутоматски да учини доступним Контекст чету, па тако имате могућност да постављате питања у вези са тим садржајима, као и да добијте одговоре на њих. Ово је доступно само када је укључено ауто-архивирање.",
    "Context chat is currently not installed, but is required for this feature." : "Контекст чет тренутно није инсталиран, а неопходан је за ову функционалност.",
    "Enable Context Chat integration" : "Укључи интеграцију са Контекст четом",
    "Client apps" : "Клијентске апликације",
    "Also check out the collection of client apps that integrate with this app: " : "Такође погледајте и колекцију клијентских апликација које се интегришу са овом апликацијом:",
    "Install web app" : "Инсталирај веб апликацију",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Ову апликацију можете да инсталирате на почетни екран вашег уређаја и добијете брзи приступ вашим маркерима на мобилном телефону. Ако вам се не свиша, апликацију можете једноставно да уклоните са почетног екрана.",
    "Install on home screen" : "Инсталирај на почетни екран",
    "Bookmarklet" : "Забележник",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Превуците ово у маркере вашег прегледача и кликните на њега када желите брзо да маркирате веб страницу.",
    "Add to {instanceName}" : "Додај на {instanceName} ",
    "Need help?" : "Треба вам помоћ?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Ако имате проблема са апликацијом Маркери или имате идеју о томе шта би могло да се унапреди, не оклевајте да ступите у везу са нама тако што ћете кликнути овде.",
    "Support this project" : "Подржите овај пројекат",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Мој рад на овој Bookmarks апликацији се заснива на моделу добровољне претплате. Ако сматрате да ово што радим вреди, ваша подршка мог труда би ми пуно значила. Такође размотрите могућност да оцените апликацију у Nextcloud продавници апликација. Хвала 💙 ",
    "Created {time} ago" : "Креирано пре {time}",
    "Created on {date}" : "Креирано дана {date}",
    "(Empty title)" : "(Без наслова)",
    "Title" : "Наслов",
    "Link" : "Веза",
    "Untitled folder" : "Неименовани фолдер",
    "Root folder" : "Корена фасцикла",
    "Tags" : "Ознаке",
    "Select tags and create new ones" : "Изаберите ознаке и креирајте нове",
    "Notes" : "Белешке",
    "Notes for this bookmark …" : "Белешке за овај маркер ...",
    "Archived file" : "Архивирани фајл",
    "Open file" : "Отвори фајл",
    "Download file" : "Преузми фајл",
    "Open file location" : "Отвори локацију фајла",
    "Link copied" : "Веза ископирана",
    "Owner" : "Власник",
    "Sharing" : "Дељење",
    "Select a user or group" : "Одаберите корисника или групу",
    "Share link" : "Веза дељења",
    "Reading allowed" : "Дозвољено је читање",
    "Copy RSS feed" : "Копирај RSS довод",
    "Delete link" : "Обриши везу",
    "Create public link" : "Направи јавну везу",
    "Resharing allowed" : "Дозвољено је накнадно дељење",
    "Editing allowed" : "Дозвољено је уређивање",
    "Allow editing" : "Дозволи уређивање",
    "Allow resharing" : "Дозволи дељење даље",
    "Remove share" : "Уклони дељење",
    "Would you like to support this project?" : "Желите ли да подржите овај пројекат?",
    "Leave a rating on the Nextcloud App Store" : "Оставите оцену на Nextcloud Продавнице апликација.",
    "Failed to save settings" : "Грешка у чувању поставки",
    "Failed to load settings" : "Грешка у дохватању поставки",
    "Privacy" : "Приватност",
    "The app will try to access web pages that you add to automatically add information about them." : "Апликација покушати да приступа веб страницама које додате да би аутоматски додала информације о њима.",
    "Enable accessing and collecting information from the web pages you add" : "Укључи приступање и скупљање информација са веб страна које додате",
    "Performance" : "Перформансе",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "На инсталацијама са много корисника може бити од користи да се ограничи број маркера по налогу.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Максимални дозвољени број обележивача по налогу. (0 за неограничено; подразумевано је неограничено)",
    "Previews" : "Прегледи",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Да би приказала реалне снимке екрана ваших маркираних веб сајтова, апликација може да употреби сервисе трећих страна помоћу којих генерише прегледе.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Можете се или бесплатно регистровати на screeenly.com или подесити сопствени сервер.",
    "Screeenly API URL" : "УРЛ Screeenly АПИ-ја",
    "Screeenly API key" : "АПИ кључ за Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API кључ",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Општи API за прављење слика екрана",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Пријавите се на било који API понуђача услуге прављења снимка екрана и унесите испод API URL. Употребите променљиву {url} као чувар места за URL којем се прави снимак екрана. API мора да врати само директну слику.",
    "Generic API URL" : "URL општег API ",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Једноставно инсталирајте Pageres CLI аутора Sindre Sorhus на ваш сервер и Bookmarks ће га пронаћи. Још увек можете да креирати додатне ENV променљиве које ће се прослеђивати у pageres, нпр. као што је назначено у чувару места:",
    "Pageres ENV variables" : "Pageres ENV променљиве",
    "This URL is already bookmarked! Overwrite?" : "Овај УРЛ је већ убачен! Пребрисати?",
    "Enter bookmark title" : "Унеси име обележивача",
    "Enter bookmark URL" : "Унеси адресу за бележење",
    "Folder" : "Фасцикла",
    "Root Folder" : "Корена фасцикла",
    "Save" : "Сачувај",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Мрежни приступ је подразумевано искључен. Идите на администраторска подешавања апликације Маркери да дозволите добављање прегледа и favicon икона (икона веб сајта на адресној линији, испред адресе).",
    "What's new?" : "Шта је ново?",
    "What" : "Шта",
    "Failed to count unavailable bookmarks" : "Није успело пребројавање недоступних маркера",
    "Failed to count archived bookmarks" : "Није успело пребројавање архивираних маркера",
    "Failed to count duplicated bookmarks" : "Није успело пребројавање маркера дупликата",
    "Failed to count bookmarks" : "Није успело бројање маркера",
    "Failed to load bookmark" : "Није успело учитавање маркера",
    "Failed to find existing bookmark" : "Неспешно тражење постојећег обележивача",
    "Failed to create bookmark" : "Грешка при креирању обележивача",
    "Failed to save bookmark" : "Грешка при чувању обележивача",
    "Failed to move bookmark" : "Грешка при премештању обележивача",
    "Failed to copy bookmark" : "Није успело копирање маркера",
    "Failed to delete bookmark" : "Грешка при брисању обележивача",
    "Failed to restore bookmark" : "Није успело враћање маркера",
    "Import successful" : "Увоз успешан",
    "Failed to rename tag" : "Није успела промена назива маркера",
    "Failed to load tags" : "Грешка при учитавању ознака",
    "Failed to load folders" : "Грешка при учитавању фасцикли",
    "Failed to load deleted folders" : "Није успело учитавање обрисаних фолдера",
    "Failed to load deleted bookmarks" : "Није успело учитавање обрисаних маркера",
    "Failed to delete folder" : "Грешка при брисању фасцикле",
    "Failed to move folder" : "Није успело премештање фолдера",
    "Failed to restore folder" : "Није успело враћање фолдера",
    "Failed to create folder" : "Грешка при креирању фасцикле",
    "Failed to load children order" : "Није успело учитавање редоследа деце",
    "Failed to move parts of selection" : "Грешка при премештању одабраних делова",
    "Failed to copy parts of selection" : "Није успело копирање делова избора",
    "Failed to delete parts of selection" : "Грешка при брисању одабраних делова",
    "Failed to tag parts of selection" : "Није успело означавање делова избора",
    "Failed to fetch bookmarks." : "Грешка при дохватању обележивача.",
    "Failed to store setting" : "Није успело чување подешавања",
    "Failed to load setting {key}" : "Грешка при учитавањеу подешавања {key}",
    "Failed to create share for folder {folderId}" : "Није успело креирање дељења за фолдер {folderId}",
    "Failed to update share {shareId}" : "Грешка при ажурирању дељења {shareId}",
    "Failed to delete share {shareId}" : "Грешка при брисању дељења {shareId}",
    "Failed to create public link for folder {folderId}" : "Није успело креирање јавног линка за фолдер {folderId}",
    "Failed to delete public link for folder {folderId}" : "Није успело брисање јавног линка за фолдер {folderId}",
    "Failed to permanently delete parts of trash bin" : "Није успело трајно брисање делова корпе за отпатке",
    "Create bookmarks for mentioned links" : "Креирај маркере за наведене линкове",
    "No links found in this message" : "У овој поруци није пронађен ниједан линк",
    "Bookmarks feed" : "Довод обележивача"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
