<?php
$TRANSLATIONS = array(
"Bookmarks" => "Lieszeechen",
"Bookm." => "Liesz.",
"No file provided for import" => "Keen Fichier ugi fir ze importéieren",
"Unsupported file type for import" => "Fichierstyp net ënnerstëtzt fir den Import",
"Some Error happened." => "Et ass e Feeler geschitt.",
"Error" => "Feeler",
"Tags" => "Etiketten",
"Filter by tag" => "No Etikett filteren",
"Are you sure you want to remove this bookmark?" => "Wëlls du dëst Lieszeeche sécher läschen?",
"Warning" => "Warnung",
"Are you sure you want to remove this tag from every entry?" => "Wëlls du dës Etikett sécher bei all Element läschen?",
"Import error" => "Import-Feeler",
"Import completed successfully." => "Import erfollegräich ofgeschloss.",
"Uploading..." => "Lueden erop...",
"Add a bookmark" => "Lieszeechen dobäisetzen",
"This URL is already bookmarked! Overwrite?" => "Dës URL ass schonn als Lieszeeche gespäichert! Iwwerschreiwen?",
"The title of the page" => "Den Titel vun der Säit",
"The address of the page" => "D'Adress vun der Säit",
"Description of the page" => "Beswchreiwung vun der Säit",
"Save" => "Späicheren",
"Delete" => "Läschen",
"Edit" => "Änneren",
"Cancel" => "Ofbriechen",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Zéi dat heiten an d'Lieszeeche vun dengem Browser a klick drop, wann  s de eng Websäit séier wëlls bei d'Lieszeeche setzen:",
"Add to ownCloud" => "An d'ownCloud setzen",
"Address" => "Adress",
"Filterable Tags" => "Filtréierbar Etiketten",
"You have no bookmarks" => "Du hues keng Lieszeechen",
"You can also import a bookmark file" => "Du kanns och e Lieszeeche-Fichier importéieren",
"Bookmarklet" => "Lieszeechen",
"Export & Import" => "Exportéieren an Importéieren",
"Export" => "Exportéieren",
"Import" => "Importéieren"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
