<?php
$TRANSLATIONS = array(
"Bookmarks" => "收藏",
"Warning" => "警告",
"Close" => "關閉",
"Save" => "儲存",
"Delete" => "刪除",
"Edit" => "編輯",
"Cancel" => "取消",
"Address" => "地址",
"Add" => "加入",
"Settings" => "設定",
"Export" => "輸出",
"Import" => "導入"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
