OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcapaginas",
    "You bookmarked \"%s\"" : "Avètz marcat « %s »",
    "%1$s bookmarked \"%2$s\"" : "%1$s a marcat « %2$s »",
    "Someone bookmarked \"%s\"" : "Qualqu’un a marcat « %s »",
    "You deleted \"%s\"" : "Avètz suprimit « %s »",
    "%1$s deleted \"%2$s\"" : "%1$s a suprimit « %2$s »",
    "Someone deleted \"%s\"" : "Qualqu’un a suprimit « %s »",
    "You created folder \"%s\"" : "Avètz creat lo dossièr « %s »",
    "Bookmark" : "Marcapagina",
    "Bookmark deleted" : "Marcapagina suprimit",
    "Bookmark created" : "Marcapagina creat",
    "Bookmark moved" : "Marcapagina desplaçat",
    "Bookmark updated" : "Marcapagina actualizat",
    "Create bookmark" : "Crear marcapagina",
    "Enter new title" : "Picar títol novèl",
    "Select bookmark" : "Seleccionar marcapagina",
    "Details" : "Detalhs",
    "Rename" : "Renomenar",
    "Copy link" : "Copiar lo ligam",
    "Move" : "Move",
    "Cancel selection" : "Anullar la seleccion",
    "Go back" : "Revenir en arrière",
    "New" : "Novèl",
    "New folder" : "Novèl dorsièr",
    "Search" : "Recercar",
    "Enter a link" : "Dintrar un ligam",
    "Enter a title" : "Dintrar un títol",
    "_%n folder_::_%n folders_" : ["%n dossièr","%n dossièrs"],
    "Rename folder" : "Renomenar lo repertòri",
    "Submit" : "Transmetre",
    "Cancel" : "Anullar",
    "Recent" : "Recents",
    "Shared with you" : "Partejat amb vos",
    "Files" : "Fichièrs",
    "Delete" : "Suprimir",
    "Need help?" : "Besonh d’ajuda ?",
    "Title" : "Títol",
    "Link" : "Ligam",
    "Tags" : "Etiquetas",
    "Notes" : "Nòtas",
    "Open file" : "Dobrir fichièr",
    "Link copied" : "Ligam copiat",
    "Owner" : "Owner",
    "Sharing" : "Partiment",
    "Share link" : "Partejar lo ligam",
    "Editing allowed" : "Modificacion autorizada",
    "Allow editing" : "Permetre la modificacion",
    "Failed to save settings" : "Fracàs de l’enregistrament dels paramètres",
    "Privacy" : "Confidencialitat",
    "Folder" : "Dorsièr",
    "Save" : "Salvar"
},
"nplurals=2; plural=(n > 1);");
