OC.L10N.register(
    "bookmarks",
    {
    "Details" : "விவரங்கள்",
    "Rename" : "பெயர்மாற்றம்",
    "Move" : "Move",
    "New" : "புதிய",
    "Search" : "Search",
    "Cancel" : "இரத்து செய்க",
    "Shared with you" : "Shared with you",
    "Files" : "கோப்புகள்",
    "Delete" : "நீக்குக",
    "Title" : "தலைப்பு",
    "Link" : "Link",
    "Tags" : "சீட்டுகள்",
    "Notes" : "குறிப்புகள்",
    "Owner" : "Owner",
    "Share link" : "Share link",
    "Folder" : "கோப்புறை",
    "Save" : "சேமிக்க "
},
"nplurals=2; plural=(n != 1);");
