<?php
$TRANSLATIONS = array(
"Bookmarks" => "Grāmatzīmes",
"Bookm." => "Grāmatz.",
"No file provided for import" => "Neviena datne nav dota importēšanai",
"Unsupported file type for import" => "Importēšanai neatbalstītie datņu tipi",
"Some Error happened." => "Notikusi kāda kļūda",
"Error" => "Kļūda",
"Tags" => "Birkas",
"Filter by tag" => "Atlasīt pēc birkas",
"Are you sure you want to remove this bookmark?" => "Vai tiešām vēlaties izņemt šo grāmatzīmi?",
"Warning" => "Brīdinājums",
"Are you sure you want to remove this tag from every entry?" => "Vai tiešām vēlaties izņemt šo birku no katra ieraksta?",
"Import error" => "Importēšanas kļūda",
"Import completed successfully." => "Importēšana ir veiksmīgi pabeigta.",
"Uploading..." => "Augšupielādē...",
"Add a bookmark" => "Pievienot grāmatzīmi",
"This URL is already bookmarked! Overwrite?" => "Šī saite jau ir pievienota grāmatzīmēm. Pārrakstīt?",
"The title of the page" => "Lapas virsraksts",
"The address of the page" => "Lapas adrese",
"Description of the page" => "Lapas apraksts",
"Save" => "Saglabāt",
"Delete" => "Izdzēst",
"Edit" => "Rediģēt",
"Cancel" => "Atcelt",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Ievelc šo savās pārlūka grāmatzīmēs un spied uz tā, kad vēlies ātri pievienot tīmekļa lapu grāmatzīmēm:",
"Add to ownCloud" => "Pievienot ownCloud",
"Address" => "Adrese",
"Filterable Tags" => "Atlasāmas birkas",
"You have no bookmarks" => "Jums nav grāmatzīmju",
"You can also import a bookmark file" => "Jūs varat arī importēt grāmatzīmes datni",
"Bookmarklet" => "Sīkgrāmatzīme",
"Export & Import" => "Eksportēt un importēt",
"Export" => "Eksportēt",
"Import" => "Importēt"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);";
