<?php
$TRANSLATIONS = array(
"Bookmarks" => "Lesezeichen",
"Failed to import one bookmark, because: " => "Beim Import eines Lesezeichens ist ein Fehler aufgetreten, weil:",
"Bookm." => "Lesez.",
"No file provided for import" => "Es wurde keine Datei zum Import zur Verfügung gestellt",
"Unsupported file type for import" => "Dateityp wird für den Import nicht unterstützt",
"Some Error happened." => "Es ist ein Fehler aufgetreten.",
"Error" => "Fehler",
"Tags" => "Tags",
"Filter by tag" => "Filtern nach Schlagwort",
"Are you sure you want to remove this bookmark?" => "Soll dieses Lesezeichen wirklich entfernt werden?",
"Warning" => "Warnung",
"Are you sure you want to remove this tag from every entry?" => "Soll dieses Schlagwort wirklich von allen Einträgen entfernt werden?",
"Import error" => "Import Fehler",
"Import completed successfully." => "Der Import wurde erfolgreich abgeschlossen.",
"Uploading..." => "Hochladen…",
"Add a bookmark" => "Ein Lesezeichen hinzufügen",
"This URL is already bookmarked! Overwrite?" => "Diese URL hat schon ein Lesezeichen! Soll es ersetzt werden?",
"The title of the page" => "Der Titel der Seite",
"The address of the page" => "Die Adresse der Seite",
"Description of the page" => "Die Beschreibung der Seite",
"Save" => "Speichern",
"Delete" => "Löschen",
"Edit" => "Bearbeiten",
"Cancel" => "Abbrechen",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Ziehe dies zu Deinen Browser-Lesezeichen und klicke darauf, wenn Du eine Website schnell den Lesezeichen hinzufügen willst.",
"Add to ownCloud" => "Zu ownCloud hinzufügen",
"Address" => "Adresse",
"Filterable Tags" => "Filterbare Tags",
"You have no bookmarks" => "Du hast keine Lesezeichen",
"You can also import a bookmark file" => "Du kannst auch eine Lesezeichen-Datei importieren",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Export & Import",
"Export" => "Exportieren",
"Import" => "Importieren"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
