OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "نشانک‌ها",
    "You bookmarked \"%s\"" : "You bookmarked \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s bookmarked \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Someone bookmarked \"%s\"",
    "You deleted \"%s\"" : "You deleted \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s deleted \"%2$s\"",
    "Someone deleted \"%s\"" : "Someone deleted \"%s\"",
    "You created folder \"%s\"" : "You created folder \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s created folder \"%2$s\"",
    "Someone created folder \"%s\"" : "Someone created folder \"%s\"",
    "You moved folder \"%s\"" : "You moved folder \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s moved folder \"%2$s\"",
    "Someone moved folder \"%s\"" : "Someone moved folder \"%s\"",
    "You deleted folder \"%s\"" : "You deleted folder \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s deleted folder \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Someone deleted folder \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "You shared folder \"%1$s\" with %2$s",
    "You shared folder \"%s\" with someone" : "You shared folder \"%s\" with someone",
    "%1$s shared folder \"%2$s\" with you" : "%1$s shared folder \"%2$s\" with you",
    "Someone shared folder \"%s\" with you" : "Someone shared folder \"%s\" with you",
    "You unshared folder \"%1$s\" with %2$s" : "You unshared folder \"%1$s\" with %2$s",
    "You unshared folder \"%s\" with someone" : "You unshared folder \"%s\" with someone",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s unshared folder \"%2$s\" with you",
    "Someone unshared folder \"%s\" with you" : "Someone unshared folder \"%s\" with you",
    "No file provided for import" : "هیچ پرونده ای برای واردکردن ارائه نشده است",
    "Bookmarks shared by %s" : "Bookmarks shared by %s",
    "Frequent bookmarks" : "Frequent bookmarks",
    "Recent bookmarks" : "Recent bookmarks",
    "Bookmark" : "نشانک",
    "Bookmark deleted" : "Bookmark deleted",
    "Bookmark created" : "Bookmark created",
    "Bookmark moved" : "Bookmark moved",
    "Bookmark updated" : "Bookmark updated",
    "Create bookmark" : "Create bookmark",
    "Takes a link and adds it to your collection of bookmarks." : "Takes a link and adds it to your collection of bookmarks.",
    "Bookmarks Backups" : "Bookmarks Backups",
    "Do you really want to delete this bookmark?" : "Do you really want to delete this bookmark?",
    "Link copied to clipboard" : "پیوند در حافظه موقت کپی شده",
    "Enter new title" : "Enter new title",
    "Select bookmark" : "نشانک را انتخاب کنید",
    "Details" : "جزئیات",
    "Rename" : "تغییرنام",
    "Copy link" : "کپی کردن لینک",
    "Move" : "انتقال",
    "Add to folders" : "Add to folders",
    "Content pending" : "Content pending",
    "This content is being downloaded for offline use. Please check back later." : "This content is being downloaded for offline use. Please check back later.",
    "Bookmarked {time} ago" : "Bookmarked {time} ago",
    "Bookmarked on {date}" : "Bookmarked on {date}",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline.",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bookmarked links are checked regularly and the ones that cannot be reached are listed here.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "You can share bookmark folders with others. All folders shared with you are listed here.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Selected {folders} folders and {bookmarks} bookmarks",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["انتخاب شده %n نشانک","انتخاب شده %n نشانک های"],
    "_Selected %n folder_::_Selected %n folders_" : ["Selected %n folder","Selected %n folders"],
    "Do you really want to delete these items?" : "Do you really want to delete these items?",
    "Open all selected" : "Open all selected",
    "Move selection" : "انتخاب را جابجا کنید",
    "Edit tags of selection" : "Edit tags of selection",
    "Delete selection" : "انتخاب را حذف کنید",
    "Select all" : "انتخاب همه",
    "Cancel selection" : "Cancel selection",
    "Sort by created date" : "Sort by created date",
    "Sort by last modified" : "Sort by last modified",
    "Sort by title" : "Sort by title",
    "Sort by click count" : "Sort by click count",
    "Sort by manual order" : "Sort by manual order",
    "Sort by URL" : "Sort by URL",
    "RSS feed copied" : "RSS feed copied",
    "Go back" : "برگرد",
    "Share folder" : "اشتراک‌گذاری پوشه",
    "Select one or more tags" : "یک یا چند تگ را انتخاب کنید",
    "New" : "جدید",
    "New bookmark" : "New bookmark",
    "New folder" : "پوشه جدید",
    "Change to grid view" : "Change to grid view",
    "Change to list view" : "Change to list view",
    "Copy RSS Feed of current view" : "Copy RSS Feed of current view",
    "The RSS feed requires authentication with your Nextcloud credentials" : "The RSS feed requires authentication with your Nextcloud credentials",
    "Search" : "جستجو",
    "Empty trash bin" : "خالی کردن سطل زباله",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Adding %n bookmark to new folder","Adding %n bookmarks to new folder"],
    "Enter a link" : "پیوند را وارد کنید",
    "Enter a title" : "Enter a title",
    "No bookmarks found" : "No bookmarks found",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} folders and {bookmarks} bookmarks",
    "_%n bookmark_::_%n bookmarks_" : ["%n نشانک","%n نشانک"],
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "Welcome to Bookmarks" : "Welcome to Bookmarks",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app.",
    "Add a bookmark" : "یک نشانک اضافه کنید",
    "Import bookmarks" : "Import bookmarks",
    "Sync with your browser" : "Sync with your browser",
    "Select folder" : "Select folder",
    "Enter folder title" : "عنوان پوشه را وارد کنید",
    "Shared by {user}" : "Shared by {user}",
    "Rename folder" : "تغییر نام پوشه",
    "Move folder" : "Move folder",
    "Choose folder" : "Choose folder",
    "Submit" : "ارسال",
    "Cancel" : "لغو",
    "Deleting bookmarks" : "Deleting bookmarks",
    "Deleting selection" : "Deleting selection",
    "Importing bookmarks" : "Importing bookmarks",
    "Moving selection" : "Moving selection",
    "Adding selection to folders" : "Adding selection to folders",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["در حال انتقال %nپوشه ها و برخی نشانک ها","در حال انتقال %n پوشه ها و برخی نشانک ها"],
    "_Moving %n folder_::_Moving %n folders_" : ["در حال انتقال %n پوشه","در حال انتقال %n پوشه ها"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["در حال انتقال %n نشانک","در حال انتقال %n نشانک ها"],
    "All bookmarks" : "همه نشانک‌ها",
    "Recent" : "اخیر",
    "Shared with you" : "با شما به اشتراک گذاشته شده است",
    "Files" : "پرونده‌ها",
    "Duplicates" : "Duplicates",
    "Broken links" : "Broken links",
    "New tag" : "New tag",
    "Search tags" : "Search tags",
    "Delete" : "حذف",
    "Untagged" : "غیرقابل تشخیص",
    "{used} bookmarks of {available} available" : "{used} bookmarks of {available} available",
    "No bookmarked files" : "No bookmarked files",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline.",
    "No broken links" : "No broken links",
    "No shared folders" : "No shared folders",
    "No duplicated bookmarks" : "No duplicated bookmarks",
    "No bookmarks here" : "در اینجا هیچ نشانک وجود ندارد",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Add bookmarks manually or import bookmarks from a HTML file.",
    "Archive path" : "Archive path",
    "Backup path" : "Backup path",
    "Please select \"Add to home screen\" in your browser menu" : "Please select \"Add to home screen\" in your browser menu",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Enter the path of a folder in your Files where bookmarked files should be stored.",
    "Enter the path of a folder in your Files where backups will be stored." : "Enter the path of a folder in your Files where backups will be stored.",
    "Client apps" : "برنامه های مشتری",
    "Also check out the collection of client apps that integrate with this app: " : "همچنین مجموعه برنامه های مشتری که با این برنامه ادغام شده اند را بررسی کنید:",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it.",
    "Install on home screen" : "Install on home screen",
    "Bookmarklet" : "نشانک",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Drag this to your browser bookmarks and click it to quickly bookmark a webpage.",
    "Add to {instanceName}" : "افزودن به {instanceName}",
    "Need help?" : "کمک لازم دارید ؟",
    "Created {time} ago" : "Created {time} ago",
    "Created on {date}" : "Created on {date}",
    "Title" : "عنوان",
    "Link" : "پیوند",
    "Untitled folder" : "Untitled folder",
    "Root folder" : "پوشهٔ ریشه",
    "Tags" : "برچسب‌ها",
    "Select tags and create new ones" : "Select tags and create new ones",
    "Notes" : "یادداشت ها",
    "Notes for this bookmark …" : "Notes for this bookmark …",
    "Archived file" : "Archived file",
    "Open file" : "باز کردن فایل",
    "Download file" : "دانلود فایل",
    "Open file location" : "Open file location",
    "Link copied" : "پیوند رونوشت شد",
    "Owner" : "صاحب",
    "Sharing" : "هم‌رسانی",
    "Select a user or group" : "گزینش یک کاربر یا گروه",
    "Share link" : "هم‌رسانی پیوند",
    "Reading allowed" : "خواندن مجاز",
    "Copy RSS feed" : "رونوشت از خوراک RSS",
    "Delete link" : "حذف پیوند",
    "Create public link" : "ایجاد پیوند عمومی",
    "Resharing allowed" : "بازهم‌رساندن مجاز",
    "Editing allowed" : "ویراستن مجاز",
    "Allow editing" : "اجازهٔ ویراستن",
    "Allow resharing" : "اجازهٔ بازهم‌رساندن",
    "Remove share" : "برداشتن هم‌رسانی",
    "Failed to save settings" : "تنظیمات ذخیره نشدند",
    "Failed to load settings" : "تنظیمات بارگیری نشد",
    "Privacy" : "محرمانگی",
    "Enable accessing and collecting information from the web pages you add" : "دسترسی و جمع آوری اطلاعات از صفحات وب اضافه شده را فعال کنید",
    "Performance" : "کارایی",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "حداکثر تعداد نشانک های مجاز در هر حساب. (0 بدون محدودیت است ؛ پیش فرض هیچ محدودیتی نیست)",
    "Previews" : "پیش نمایش ها",
    "Screeenly" : "صفحه نمایش",
    "You can either sign up for free at screeenly.com or setup your own server." : "می توانید به صورت رایگان در screeenly.com ثبت نام کنید یا سرور خود را راه اندازی کنید.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Pageres ENV variables",
    "This URL is already bookmarked! Overwrite?" : "این URL از قبل نشانک گذاری شده است! دوباره نشانک گذاری شود؟",
    "Enter bookmark title" : "عنوان نشانک را وارد کنید",
    "Enter bookmark URL" : "URL نشانک را وارد کنید",
    "Folder" : "پوشه",
    "Root Folder" : "Root Folder",
    "Save" : "ذخیره",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons.",
    "What's new?" : "What's new?",
    "What" : "What",
    "Failed to count unavailable bookmarks" : "Failed to count unavailable bookmarks",
    "Failed to count archived bookmarks" : "Failed to count archived bookmarks",
    "Failed to count duplicated bookmarks" : "Failed to count duplicated bookmarks",
    "Failed to load bookmark" : "Failed to load bookmark",
    "Failed to find existing bookmark" : "یافتن نشانک موجود انجام نشد",
    "Failed to create bookmark" : "ایجاد نشانک انجام نشد",
    "Failed to save bookmark" : "ذخیره نشانک انجام نشد",
    "Failed to move bookmark" : "انتقال نشانک انجام نشد",
    "Failed to copy bookmark" : "Failed to copy bookmark",
    "Failed to delete bookmark" : "حذف نشانک انجام نشد",
    "Failed to rename tag" : "Failed to rename tag",
    "Failed to load tags" : "بارگیری برچسب ها انجام نشد",
    "Failed to load folders" : "بارگیری پوشه ها انجام نشد",
    "Failed to delete folder" : "پوشه حذف نشد",
    "Failed to create folder" : "پوشه ایجاد نشد",
    "Failed to move parts of selection" : "جابجایی بخش های انتخاب انجام نشد",
    "Failed to delete parts of selection" : "حذف قسمتهای انتخاب انجام نشد",
    "Failed to fetch bookmarks." : "واکشی نشانک ها انجام نشد.",
    "Failed to load setting {key}" : "شکست در بار کردن تنظیم {key}",
    "Failed to update share {shareId}" : "Failed to update share {shareId}",
    "Failed to delete share {shareId}" : "Failed to delete share {shareId}",
    "Create bookmarks for mentioned links" : "Create bookmarks for mentioned links",
    "No links found in this message" : "No links found in this message",
    "Bookmarks feed" : "بازخورد نشانک ها"
},
"nplurals=2; plural=(n > 1);");
