<?php
$TRANSLATIONS = array(
"Bookmarks" => "书签",
"Bookm." => "书签",
"No file provided for import" => "未提供导入文件",
"Unsupported file type for import" => "不支持导入的文件类型",
"Some Error happened." => "出错了。",
"Error" => "错误",
"Tags" => "标签",
"Filter by tag" => "按标签过滤",
"Are you sure you want to remove this bookmark?" => "您确定要删除改书签吗？",
"Warning" => "警告",
"Are you sure you want to remove this tag from every entry?" => "确定要从所有条目中移除此标签？",
"Import error" => "导入错误",
"Import completed successfully." => "导入成功完成。",
"Uploading..." => "上传中...",
"Add a bookmark" => "新增一个书签",
"This URL is already bookmarked! Overwrite?" => "当前地址已经存在！确认覆盖吗？",
"The title of the page" => "页面名称",
"The address of the page" => "页面地址",
"Description of the page" => "页面描述",
"Save" => "保存",
"Delete" => "删除",
"Edit" => "编辑",
"Cancel" => "取消",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "拖曳此处到您的浏览器书签处，点击可以将网页快速增加到书签中。",
"Add to ownCloud" => "增加到 ownCloud",
"Address" => "地址",
"Filterable Tags" => "可过滤标签",
"You have no bookmarks" => "您暂无书签",
"You can also import a bookmark file" => "您可以导入书签文件",
"Bookmarklet" => "书签",
"Export & Import" => "导入导出",
"Export" => "导出",
"Import" => "导入"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
