<?php
$TRANSLATIONS = array(
"Bookmarks" => "Sayt qeydiyyatları",
"Bookm." => "Qeyd.",
"No file provided for import" => "Götürmək üçün heç bir fayl təqdim edilməyib",
"Unsupported file type for import" => "Fayl tipi götürülmə üçün dəstəklənmir",
"Some Error happened." => "Bəzi səhv baş verdi.",
"Error" => "Səhv",
"Tags" => "Işarələr",
"Filter by tag" => "Əsas-a görə süzgəc",
"Are you sure you want to remove this bookmark?" => "Bu işarətləməni silməyinizdən əminsinizmi?",
"Warning" => "Xəbərdarlıq",
"Are you sure you want to remove this tag from every entry?" => "İstənilən qeydiyyatdan bu başlığın silinməsinə əminsinizmi?",
"Import error" => "Əlavə səhvi",
"Import completed successfully." => "Əlavə uğurla bitdi.",
"Uploading..." => "Serverə yüklənir...",
"Add a bookmark" => "Sayt qeydıyyatı əlavə et",
"This URL is already bookmarked! Overwrite?" => "URL artıq işarətlənib! Yenidən işarətlənsin?",
"The title of the page" => "Səhifənin başlığı",
"The address of the page" => "Səhifənin ünvanı",
"Description of the page" => "Səhifə üçün açıqlama",
"Save" => "Saxlamaq",
"Delete" => "Sil",
"Edit" => "Dəyişiklik et",
"Cancel" => "Dayandır",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Web səhifəni tez qeydə almaq istəyirsinizsə, onu öz browser-nizin qeydiyyat ünvanına dartın və üstünə sıxın.",
"Add to ownCloud" => "ownCloud-a əlavə et",
"Address" => "Ünvan",
"Filterable Tags" => "Fitlrlənəbilən işarətlər",
"You have no bookmarks" => "Sizin səhifə qeydiyyatınız yoxdur",
"You can also import a bookmark file" => "Siz həmçinin işartlənmə faylını import edə bilərsiniz",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Çıxarış & Əlavə ",
"Export" => "Çıxarış",
"Import" => "Əlavə et"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
