<?php
$TRANSLATIONS = array(
"Bookmarks" => "Bokmerkje",
"Bookm." => "Bokm.",
"No file provided for import" => "Inga fil gjeve for importering",
"Unsupported file type for import" => "Ustøtta filtype for importering",
"Some Error happened." => "Ein feil oppstod.",
"Error" => "Feil",
"Tags" => "Emneord",
"Filter by tag" => "Filtrer etter emneord",
"Are you sure you want to remove this bookmark?" => "Er du sikker på at du vil fjerne dette bokmerket?",
"Warning" => "Åtvaring",
"Are you sure you want to remove this tag from every entry?" => "Er du sikker på at du vil fjerna dette emneordet frå alle oppføringane?",
"Import error" => "Feil ved importering",
"Import completed successfully." => "Importering fullførte utan feil.",
"Uploading..." => "Lastar opp …",
"Add a bookmark" => "Legg til eit bokmerkje",
"This URL is already bookmarked! Overwrite?" => "Denne URL er allereie bokmerkt, overskriv?",
"The title of the page" => "Tittelen på sida",
"The address of the page" => "Adressa til sida",
"Description of the page" => "Skildring av sida",
"Save" => "Lagra",
"Delete" => "Slett",
"Edit" => "Endra",
"Cancel" => "Avbryt",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Dra denne knappen til bokmerkjelinja i nettlesaren din og klikk han når du vil laga eit bokmerkje raskt:",
"Add to ownCloud" => "Legg til i ownCloud",
"Address" => "Adresse",
"Filterable Tags" => "Filtreringsbare emneord",
"You have no bookmarks" => "Du har inga bokmerkje",
"You can also import a bookmark file" => "Du kan og importere ei bokmerke fil",
"Bookmarklet" => "Bokmerkjeknapp",
"Export & Import" => "Eksporter/importer",
"Export" => "Eksporter",
"Import" => "Importer"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
