OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Organize os seus favoritos em pastas\n- 🏷 Adicione tags e notas pessoais\n- ☠ Encontre links quebrados e duplicados\n- 📲 Sincronize com todos os seus browsers e dispositivos\n- 📔 Armazene versões arquivadas dos seus links caso sejam despublicados\n- 🔍 Pesquisa de texto completo no conteúdo do site\n- 👪 Partilhe favoritos com outros utilizadores, grupos e equipas ou através de links públicos\n- ⚛ Gerar feeds RSS das suas coleções\n- 📈 Estatísticas sobre a frequência de acesso a cada link\n- 🔒 Backups automáticos da sua coleção de favoritos\n- 💼 Widgets integrados no painel para links frequentes e recentes\n\nRequisitos:\n - Extensões PHP:\n   - intl: *\n   - mbstring: *\n - Quando utilizar o MySQL, utilize pelo menos a versão 8.0",
    "Link copied to clipboard" : "Ligação copiada para a área de transferência",
    "Details" : "Detalhes",
    "Rename" : "Renomear",
    "Copy link" : "Copiar hiperligação",
    "Move" : "Mover",
    "This content is being downloaded for offline use. Please check back later." : "Este conteúdo está a ser transferido para utilização ''off-line''. Por favor, volte mais tarde.",
    "Edit tags of selection" : "Editar etiquetas da seleção",
    "Select all" : "Selecionar tudo",
    "Go back" : "Voltar",
    "Share folder" : "Partilhar pasta",
    "New" : "Novo",
    "New folder" : "Nova pasta",
    "Search" : "Pesquisa sobre",
    "Empty trash bin" : "Esvaziar a reciclagem",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Esta aplicação permite que gerencie links para os seus sites favoritos. Organize os seus favoritos em pastas, adicione etiquetas e partilhe-as com outras pessoas! A aplicação verifica regularmente a disponibilidade de todos os seus links e exibe os links indisponíveis. Se adicionar um link para um ficheiro na web, o ficheiro será automaticamente descarregado para os seus Ficheiros Nextcloud. Também pode importar favoritos exportados de outros serviços ou sincronizar diretamente os favoritos de todos os seus navegadores com esta aplicação.",
    "Add a bookmark" : "Adicionar um marcador",
    "Shared by {user}" : "Shared by {user}",
    "Rename folder" : "Renomear pasta",
    "Choose folder" : "Escolher pasta",
    "Submit" : "Submeter",
    "Cancel" : "Cancelar",
    "All bookmarks" : "Todos os marcadores",
    "Recent" : "Recentes",
    "Shared with you" : "Partilhado consigo",
    "Files" : "Ficheiros",
    "Search tags" : "Pesquisar Etiquetas",
    "Delete" : "Apagar",
    "Need help?" : "Precisa de ajuda?",
    "Created on {date}" : "Criado em {date}",
    "Title" : "Título",
    "Link" : "Link",
    "Root folder" : "Pasta raiz",
    "Tags" : "Etiquetas",
    "Select tags and create new ones" : "Selecionar etiquetas e criar novas",
    "Notes" : "Notas",
    "Open file" : "Abrir ficheiro",
    "Download file" : "Transferir ficheiro",
    "Link copied" : "Link copiado",
    "Owner" : "Proprietário",
    "Sharing" : "Partilha",
    "Select a user or group" : "Selecionar utilizador ou grupo",
    "Share link" : "Share link",
    "Create public link" : "Criar link público",
    "Allow editing" : "Permitir edição",
    "Allow resharing" : "Permitir repartilha",
    "Failed to save settings" : "Erro ao gravar as definições",
    "Privacy" : "Privacidade",
    "Performance" : "Performance",
    "Folder" : "Pasta",
    "Save" : "Guardar",
    "Failed to load tags" : "Falha ao carregar as etiquetas",
    "Failed to create public link for folder {folderId}" : "Falha ao criar link público para a pasta {folderId}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
