<?php
$TRANSLATIONS = array(
"Bookmarks" => "Könyvjelzők",
"Bookm." => "Könyvj.",
"No file provided for import" => "Nincs megadva az importálandó fájl",
"Unsupported file type for import" => "Az importálandó fájltípus nem támogatott",
"Some Error happened." => "Valami hiba történt",
"Error" => "Hiba",
"Tags" => "Címkék",
"Filter by tag" => "Szűrés címkék szerint",
"Are you sure you want to remove this bookmark?" => "Biztosan törölni szeretnéd ezt a könyvjelzőt?",
"Warning" => "Figyelmeztetés",
"Are you sure you want to remove this tag from every entry?" => "Biztos benne, hogy ezt a címkét el szeretné távolítani az összes bejegyzésből?",
"Import error" => "Hiba történt az importáláskor",
"Import completed successfully." => "Az importálás sikeresen befejeződött.",
"Uploading..." => "Feltöltés...",
"Add a bookmark" => "Könyvjelző hozzáadása",
"This URL is already bookmarked! Overwrite?" => "Ez az URL már a könyvjelzők között van! Felül akarod írni?",
"The title of the page" => "Az oldal neve",
"The address of the page" => "Az oldal webcíme",
"Description of the page" => "Az oldal leírása",
"Save" => "Mentés",
"Delete" => "Törlés",
"Edit" => "Szerkesztés",
"Cancel" => "Mégsem",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Húzza át ezt a gombot a böngészőprogram \"Könyvjelzők\" sávjába! Ha ezután rákattint, akkor az aktuális weboldal címét ide fogja menteni.",
"Add to ownCloud" => "Hozzáadni az ownCloud-hoz",
"Address" => "Cím",
"Filterable Tags" => "Szűrhető címkék",
"You have no bookmarks" => "Nincsenek könyvjelzői",
"You can also import a bookmark file" => "Akár importálhatsz is egy könyvjelző fájlt",
"Bookmarklet" => "Könyvjelző",
"Export & Import" => "Export és import",
"Export" => "Exportálás",
"Import" => "Importálás"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
