OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bogmærker",
    "You bookmarked \"%s\"" : "Du lavede et bogmærke for \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s lavede bogmærke for \"%2$s\"",
    "Someone bookmarked \"%s\"" : "En person lavede bogmærke for \"%s\"",
    "You deleted \"%s\"" : "Du slettede \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s slettede \"%2$s\"",
    "Someone deleted \"%s\"" : "Nogen slettede \"%s\"",
    "You created folder \"%s\"" : "Du oprettede mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s oprettede mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "Nogen oprettede mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttede mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttede mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "Nogen flyttede mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du slettede mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s slettede mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Nogen slettede mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delte mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du slettede mappen \"%s\" med en anden",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delte mappen \"%2$s\" med dig",
    "Someone shared folder \"%s\" with you" : "Nogen delte mappen \"%s\" med dig",
    "You unshared folder \"%1$s\" with %2$s" : "Du stoppede deling af mapen \"%1$s\" med %2$s",
    "You unshared folder \"%s\" with someone" : "De stoppede deling af mappen \"%s\" med en person",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s stoppede deling af mappen \"%2$s\" med dig",
    "Someone unshared folder \"%s\" with you" : "Nogen stoppede deling af mappen \"%s\" med dig",
    "No file provided for import" : "Ingen fil til import",
    "Failed to upload file" : "Kunne ikke uploade fil",
    "Unsupported file type for import: " : "Ikke understøttet filtype til import:",
    "Bookmarks shared by %s" : "Bogmærker delt af %s",
    "Frequent bookmarks" : "Hyppige bogmærker",
    "Recent bookmarks" : "Seneste bogmærker",
    "Bookmark" : "Bogmærke",
    "Bookmark deleted" : "Bogmærke blev slettet",
    "Bookmark created" : "Bogmærke blev oprettet",
    "Bookmark moved" : "Bogmærke blev flyttet",
    "Bookmark updated" : "Bogmærke blev opdateret",
    "Create bookmark" : "Opret bogmærke",
    "Takes a link and adds it to your collection of bookmarks." : "Tager imod et link og føjer det til din bogmærkesamling.",
    "Bookmarks Backups" : "Backup af bogmærker",
    "Collect and manage bookmarks, synced with all your devices" : "Indsaml og administrer bogmærker, synkroniseret med alle dine apparater",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Sorter bogmærker i mapper\n- 🏷 Tilføj tags og personlige noter\n- ☠ Find brudte links og dubletter\n- 📲 Synkroniser med alle dine browsere og apparater\n- 📔 Gem arkiverede versioner af dine links i tilfælde af at de bliver afpublicerede\n- 🔍 Fuldtekst søgning på andet wbestedsindhold\n- 👪 Del bogmærker med andre brugere, grupper og teams eller via offentlige links\n- ⚛ Generer RSS feeds ud fra dine samlinger\n- 📈 Statistik på hvor tit du tilgår hvilke links\n- 🔒 Automatiske backups af din bogmærkesamling\n- 💼 Indbyggede kontrolpanel widgets for hyppige og nylige links\n\nKrav:\n - PHP udvidelser:\n   - intl: *\n   - mbstring: *\n - hvis MySQL anvendes, så minimum v8.0",
    "Do you really want to delete this bookmark?" : "Vil du virkelig slette dette bogmærke?",
    "Link copied to clipboard" : "Link kopieret til udklipsholder",
    "Enter new title" : "Angiv ny titel",
    "Select bookmark" : "Vælg bogmærke",
    "You have never clicked this link" : "Du har aldrig klikket på dette link",
    "You have clicked this link {count} times" : "Du har klikket på dette link {count} gange",
    "Details" : "Detaljer",
    "Rename" : "Omdøb",
    "Copy link" : "Kopiér link",
    "Move" : "Flyt",
    "Add to folders" : "Tilføj til mapper",
    "Put bookmark into trash bin" : "Smid bormærker i skraldespand",
    "Restore bookmark" : "Genskab bogmærker",
    "Delete bookmark permanently" : "Slet bogmærker permanent",
    "Content pending" : "Afventende indhold",
    "This content is being downloaded for offline use. Please check back later." : "Dette indhold downloades til offline brug. Tjek venligst igen senere.",
    "Bookmarked {time} ago" : "Bogmærke oprettet for {time} siden",
    "Bookmarked on {date}" : "Bogmærke oprettet den {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Dette er dine slettede elementer. Elementer vil blive slette permanent efter to måneder.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bogmærker til filer på internettet, såsom billeder eller pdf'er vil automatisk blive gemt til dine Nextcloud filer, så du stadig kan finde dem når forbindelsen går offline.",
    "Searching in the current folder only." : "Søg kun i den aktuelle mappe.",
    "Repeat search in all folders" : "Gentag søgning i alle mapper",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bogmærkede links kontrolleres jævnligt, og de som ikke kan nås vises her.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Du kan dele bogmærkemapper med andre. Alle mapper som deles af dig vises her.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Et bogmærke kan være i flere mapper på samme tid. Når det opdateres, så opdateres alle kopier. Alle dubletter af bogmærker vises her for nemhedens skyld.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valgte {folders} mapper og {bookmarks} bogmærker",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valgt %n bogmærke","Valgt %n bogmærker"],
    "_Selected %n folder_::_Selected %n folders_" : ["Valgte %n mappe","Valgte %n mapper"],
    "Do you really want to delete these items?" : "Vil du virkelig slette disse elementer?",
    "Open all selected" : "Åbn alle valgte",
    "Move selection" : "Flyt valgte",
    "Edit tags of selection" : "Redigér tags for det markerede",
    "Delete selection" : "Slet valgte",
    "Select all" : "Vælg alle",
    "Cancel selection" : "Annuller valg",
    "Sort by created date" : "Sorter efter oprettelsesdato",
    "Sort by last modified" : "Sorter efter sidst ændret",
    "Sort by title" : "Sorter efter titel",
    "Sort by click count" : "Sorter efter klikantal",
    "Sort by manual order" : "Sorter efter manuel rækkefølge",
    "Sort by URL" : "Sorter efter URL",
    "RSS feed copied" : "RSS feed kopieret",
    "Trash Bin" : "Papirkurv",
    "Go back" : "Gå tilbage",
    "Share folder" : "Del mappe",
    "Open folder details" : "Åben mappedetaljer",
    "Select one or more tags" : "Vælg et eller flere tags",
    "New" : "Ny",
    "New bookmark" : "Nyt bogmærke",
    "New folder" : "Ny mappe",
    "Change to grid view" : "Skift til gittervisning",
    "Change to list view" : "Skift til listevisning",
    "Copy RSS Feed of current view" : "Kopiér RSS feed for  den aktuelle visning",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feedet kræver godkendelse med dine Nextcloud legitimationsoplysninger",
    "Search" : "Søg",
    "Empty trash bin" : "Tøm papirkurv",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Tilføjelse af %n bogmærke til ny mappe","Tilføjelse af %n bogmærker til ny mappe"],
    "Enter a link" : "Angiv et link",
    "Enter a title" : "Angiv en titel",
    "No bookmarks found" : "Ingen bogmærker fundet",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} mapper og {bookmarks} bogmærker",
    "_%n bookmark_::_%n bookmarks_" : ["%n bogmærke","%n bogmærker"],
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "Welcome to Bookmarks" : "Velkommen til bogmærker",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Denne app giver dig mulighed for at administrere links til dine yndlingssteder på nettet. Sortér dine bogmærker i mapper, mærk dem med tags og del dem med andre! Appen vil regelmæssigt tjekke alle dine links for tilgængelighed og vise utilgængelige links. Hvis du tilføjer et link til en fil på nettet, vil filen automatisk blive downloadet til dine Nextcloud-filer. Du kan også importere bogmærker eksporteret fra andre tjenester eller direkte synkronisere bogmærker fra alle dine browsere med denne app.",
    "Add a bookmark" : "Tilføj et bogmærke",
    "Import bookmarks" : "Importér bogmærker",
    "Sync with your browser" : "Synkroniser med din browser",
    "Do you really want to permanently delete this folder?" : "Ønsker du virkelig at slette denne mappe permanent?",
    "Select folder" : "Vælg mappe",
    "Enter folder title" : "Angiv mappenavn",
    "Shared by {user}" : "Delt af {user}",
    "Rename folder" : "Omdøb mappe",
    "Move folder" : "Flyt mappe",
    "Put folder into trashbin" : "Placer mappe i papirkurv",
    "Restore folder" : "Genskab mappe",
    "Delete folder permanently" : "Slet mappe permanent",
    "Choose folder" : "Vælg mappe",
    "Submit" : "Send",
    "Cancel" : "Annuller",
    "Deleting bookmarks" : "Sletter bogmærker",
    "Deleting selection" : "Sletter valgte",
    "Importing bookmarks" : "Importerer bogmærker",
    "Moving selection" : "Flytter valgte",
    "Adding selection to folders" : "Tilføjer valgte til mapper",
    "Emptying trashbin" : "Tømmer papirkurv",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flytter %n mappe og nogle bogmærker","Flytter %n mapper og nogle bogmærker"],
    "_Moving %n folder_::_Moving %n folders_" : ["Flytter %n mappe","Flytter %n mapper"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flytter %n bogmærke","Flytter %n bogmærker"],
    "All bookmarks" : "Alle bogmærker",
    "Recent" : "Seneste",
    "Shared with you" : "Delt med dig",
    "Files" : "Filer",
    "Duplicates" : "Dubletter",
    "Broken links" : "Ødelagte links",
    "New tag" : "Nyt tag",
    "Search tags" : "Søg tags",
    "Delete" : "Slet",
    "Untagged" : "Ikke tagget",
    "{used} bookmarks of {available} available" : "{used} bogmærker ud af {available} tilgængelige",
    "Bookmarks Settings" : "Bormærkeindstillinger",
    "No bookmarked files" : "Ingen bogmærkede filer",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bogmærker til filer som fotos eller PDF'er gemmes automatisk i dine Nextcloud filer, så du stadig kan finde dem, selv når linket går offline.",
    "Nothing found" : "Intet fundet",
    "Your search yielded no results in the current folder." : "Din søgning fandt ikke nogen resultater i den aktuelle mappe.",
    "No broken links" : "Ingen ødelagte links",
    "No shared folders" : "Ingen delte mapper",
    "No duplicated bookmarks" : "Ingen duplikerede bogmærker",
    "No deleted bookmarks" : "Ingen slettede bogmærker",
    "You haven't deleted anything yet." : "Du har endnu ikke slettet noget.",
    "No bookmarks here" : "Ingen bogmærker her",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Tilføj bogmærker manuelt eller importer bogmærker fra en HTML fil.",
    "Archive path" : "Arkivsti",
    "Backup path" : "Backup sti",
    "Please select \"Add to home screen\" in your browser menu" : "Vælg venligst \"Tilføj til startskærmen\" i din browsermenu",
    "Bookmarks settings" : "Bogmærkeindstillinger",
    "Import/Export" : "Importér/Eksportér",
    "Export bookmarks" : "Eksportér bogmærker",
    "Auto-archiving" : "Autoarkivering",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Bogmærke app'en kan automatisk arkivere webindholdet for links   som du har bogmærket",
    "Enable archiving" : "Aktiver arkivering",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Indtast stien til en mappe i dine filer, hvor bogmærkede filer skal gemmes.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Aktuelt har din administrator deaktiveret netværksadgangen for denne app. Hvilket betyder at autoarkivering for øjeblikket er deaktiveret.",
    "Auto-Backup" : "Auto backup",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Bogmærke app'en kan automatisk tage backup af dine bogmærker på daglig basis, for at forhindre datatab når der synkroniseres bogmærker på tværs af apparater.",
    "Enable backups" : "Aktiver backups",
    "Enter the path of a folder in your Files where backups will be stored." : "Indtast stien til en mappe i dine filer, hvor sikkerhedskopier vil blive gemt.",
    "Context Chat integration" : "Kontekst chatintegration",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Bogmærke app'en kan automatisk gøre den tekstuelle kontekst tilgængelig til kontekstchat for de websteder som du bogmærker, hvilket giver mulighed for at stille spørgsmål om og får svar baseret på indholdet. Dette er kun tilgængeligt hvis auto-arkivering er aktiveret.",
    "Context chat is currently not installed, but is required for this feature." : "Kontekstchat er aktuelt ikke installeret, men er krævet til denne funktion.",
    "Enable Context Chat integration" : "Aktiver kontekstchat integration",
    "Client apps" : "Klient apps",
    "Also check out the collection of client apps that integrate with this app: " : "Kontroller også samlingen af klientapps, der integreres med denne app:",
    "Install web app" : "Installer web app",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Du kan installere denne app på din enheds startskærm for hurtigt at få adgang til dine bogmærker på din telefon. Du kan nemt fjerne appen fra din startskærm igen, hvis du ikke kan lide den.",
    "Install on home screen" : "Installer på startskærmen",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Træk dette til dine browserbogmærker, og klik på det for hurtigt at bogmærke en webside.",
    "Add to {instanceName}" : "Tilføj til {instanceName}",
    "Need help?" : "Brug for hjælp?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Hvis du oplever problemer med denne bogmærke app eller har idéer til hvad der kan forbedres, så tøv ikke, men tag kontakt ved at klikke her.",
    "Support this project" : "Understøt dette projekt",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Mit arbejde på denne bogmærke app er brødfødet via en frivillig abonnementsmodel. Hvis du at det jeg gør er værdifuldt, så bliver jeg glad hvis du vil understøtte mit arbejde. Overvej venligst også at skrive en vurdering af app'en på Nextcloud app store. Tak 💙 ",
    "Created {time} ago" : "Oprettet for {time} siden",
    "Created on {date}" : "Oprettet den {date}",
    "(Empty title)" : "(Tom titel)",
    "Title" : "Titel",
    "Link" : "Link",
    "Untitled folder" : "Unavngivet mappe",
    "Root folder" : "Rodmappe",
    "Tags" : "Tags",
    "Select tags and create new ones" : "Vælg tags og opret nye",
    "Notes" : "Noter",
    "Notes for this bookmark …" : "Noter til dette bogmærke...",
    "Archived file" : "Arkiveret fil",
    "Open file" : "Åbn fil",
    "Download file" : "Download fil",
    "Open file location" : "Åbn filplacering",
    "Link copied" : "Link kopieret",
    "Owner" : "Ejer",
    "Sharing" : "Deling",
    "Select a user or group" : "Vælg en bruger eller gruppe",
    "Share link" : "Del link",
    "Reading allowed" : "Læsning tilladt",
    "Copy RSS feed" : "Kopiér RSS feed",
    "Delete link" : "Slet link",
    "Create public link" : "Opret offentligt link",
    "Resharing allowed" : "Videredeling tilladt",
    "Editing allowed" : "Redigering tilladt",
    "Allow editing" : "Tillad redigering",
    "Allow resharing" : "Tillad videredeling",
    "Remove share" : "Fjern deling",
    "Leave a rating on the Nextcloud App Store" : "Efterlad en vurdering på Nextcloud app store",
    "Failed to save settings" : "Kunne ikke gemme indstillinger",
    "Failed to load settings" : "Fejl ved indlæsning af indstillinger",
    "Privacy" : "Privatliv",
    "The app will try to access web pages that you add to automatically add information about them." : "Denne app vil forsøge at tilgå websider, som du tilføjer, for automatisk at tilføje information om dem.",
    "Enable accessing and collecting information from the web pages you add" : "Aktiver adgang til og indsamling af oplysninger fra de websider, du tilføjer",
    "Performance" : "Ydelse",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installation med mange brugere kan det være nyttigt at begrænse antallet af bogmærker pr. konto.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimalt tilladt antal bogmærker pr. konto. (0 for ingen grænse; standard er ingen grænse)",
    "Previews" : "Forhåndsvisning",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "For at kunne vise reelle skærmbilleder af dine bogmærkede websteder, så kan app'en anvende tredjeparts services til at generere forhåndsvisninger.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Du kan enten tilmelde dig gratis på screeneenly.com eller opsætte din egen server.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API nøgle",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API nøgle",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Generisk skærmbillede API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Registrer hos en af skærmbillede API leverandørerne og angive  API URL'en nedenfor. Anvend variablen {url} som en pladsholder til URL'en der skal tages skærmbillede af. API'en må kun returnere billedet direkte.",
    "Generic API URL" : "Generisk API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Installer blot Pageres CLI'en af Sindre Sorhus på din server og bogmærke app'en vil finde det. Du kan stadig tilføje yderligere ENV vars til at føde pageres, fx som indikeret i pladsholderen:",
    "Pageres ENV variables" : "Pageres ENV variabler",
    "This URL is already bookmarked! Overwrite?" : "Denne URL har allerede et bogmærke. Overskriv?",
    "Enter bookmark title" : "Angiv titel på bogmærke",
    "Enter bookmark URL" : "Angiv bogmærke URL",
    "Folder" : "Mappe",
    "Root Folder" : "Rodmappe",
    "Save" : "Gem",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Netværksadgang er deaktiveret som standard. Gå til administratorindstillinger for bogmærke-appen for at tillade hentning af forhåndsvisninger og favicons.",
    "What's new?" : "Hvad er nyt?",
    "What" : "Hvad",
    "Failed to count unavailable bookmarks" : "Kunne ikke tælle utilgængelige bogmærker",
    "Failed to count archived bookmarks" : "Kunne ikke tælle arkiverede bogmærker",
    "Failed to count duplicated bookmarks" : "Kunne ikke tælle duplikerede bogmærker",
    "Failed to count bookmarks" : "Kunne ikke tælle bogmærker",
    "Failed to load bookmark" : "Bogmærke kunne ikke indlæses",
    "Failed to find existing bookmark" : "Kunne ikke finde eksisterende bogmærke",
    "Failed to create bookmark" : "Kunne ikke oprette bogmærke",
    "Failed to save bookmark" : "Kunne ikke gemme bogmærke",
    "Failed to move bookmark" : "Kunne ikke flytte bogmærke",
    "Failed to copy bookmark" : "Kunne ikke kopiere bogmærke",
    "Failed to delete bookmark" : "Kunne ikke slette bogmærke",
    "Failed to restore bookmark" : "Kunne ikke genskabe bogmærker",
    "Import successful" : "Import gennemført",
    "Failed to rename tag" : "Kunne ikke omdøbe tag",
    "Failed to load tags" : "Kunne ikke indlæse tags",
    "Failed to load folders" : "Fejl ved indlæsning af mapper",
    "Failed to load deleted folders" : "Kunne ikke indlæse slettede mapper",
    "Failed to load deleted bookmarks" : "Kunne ikke indlæse slettede bogmærker",
    "Failed to delete folder" : "Fejl ved sletning af mappe",
    "Failed to move folder" : "Kunne ikke flytte mappe",
    "Failed to restore folder" : "Kunne ikke genskabe mappe",
    "Failed to create folder" : "Kunne ikke oprette mappe",
    "Failed to load children order" : "Kunne ikke indlæse rækkefølge for underpunkter",
    "Failed to move parts of selection" : "Fejl ved flytning af dele af det valgte",
    "Failed to copy parts of selection" : "Kunne ikke kopiere dele af det valgte",
    "Failed to delete parts of selection" : "Kunne ikke slette dele af det valgte",
    "Failed to tag parts of selection" : "Kunne ikke tagge dele af det valgte",
    "Failed to fetch bookmarks." : "Kunne ikke indlæse bogmærker.",
    "Failed to store setting" : "Kunne ikke lagre indstilling",
    "Failed to load setting {key}" : "Indstillingen {key} kunne ikke indlæses",
    "Failed to create share for folder {folderId}" : "Kunne ikke oprette deling for mappen {folderId}",
    "Failed to update share {shareId}" : "Kunne ikke opdatere deling {shareId}",
    "Failed to delete share {shareId}" : "Kunne ikke slette deling {shareId}",
    "Failed to create public link for folder {folderId}" : "Kunne ikke oprette offentligt link for mappen {folderId}",
    "Failed to delete public link for folder {folderId}" : "Kunne ikke slette offentligt link til mappen {folderId}",
    "Failed to permanently delete parts of trash bin" : "Kunne ikke permanent slette dele af skraldespanden",
    "Create bookmarks for mentioned links" : "Opret bogmærker til omtalte links",
    "No links found in this message" : "Ingen links fundet i denne besked",
    "Bookmarks feed" : "Bogmærkefeed"
},
"nplurals=2; plural=(n != 1);");
