<?php
$TRANSLATIONS = array(
"Bookmarks" => "Semne de carte",
"Bookm." => "Bookm.",
"No file provided for import" => "Niciun fișier furnizat pentru import",
"Unsupported file type for import" => "Tipul de fișier nu este suportat pentru importări",
"Some Error happened." => "A avut loc o eroare.",
"Error" => "Eroare",
"Tags" => "Cuvinte cheie",
"Filter by tag" => "Filtrare după marcaj",
"Are you sure you want to remove this bookmark?" => "Eşti sigur că vrei să ştergi acest semn de carte?",
"Warning" => "Atenție",
"Are you sure you want to remove this tag from every entry?" => "Ești sigur că vrei să ștergi acest marcaj din fiecare înscriere?",
"Import error" => "Eroare de import",
"Import completed successfully." => "Importarea a fost completată cu succes",
"Uploading..." => "Încărcare...",
"Add a bookmark" => "Adaugă un semn de carte",
"This URL is already bookmarked! Overwrite?" => "Acest URL există deja in bookmark! Rescrieți?",
"The title of the page" => "Titlul paginii",
"The address of the page" => "Adresa paginii",
"Description of the page" => "Descrierea paginii",
"Save" => "Salvează",
"Delete" => "Șterge",
"Edit" => "Editează",
"Cancel" => "Anulare",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Trage acest semn în semnele de carte din navigatorul tău web când dorești să salvezi rapid un semn către o pagină web:",
"Add to ownCloud" => "Adaugă la ownCloud",
"Address" => "Adresă",
"Filterable Tags" => "Etichete Filtrabile",
"You have no bookmarks" => "Nu ai niciun semn de carte",
"You can also import a bookmark file" => "Deasemenea poţi să imporţi un fişier cu semnele de carte",
"Bookmarklet" => "Marcator",
"Export & Import" => "Exportă & Importă",
"Export" => "Exportă",
"Import" => "Importă"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));";
