/*! For license information please see bookmarks-node_modules_nextcloud_dialogs_dist_chunks_PublicAuthPrompt-CfOE69qY_mjs.js.LICENSE.txt */
"use strict";(self.webpackChunkbookmarks=self.webpackChunkbookmarks||[]).push([["node_modules_nextcloud_dialogs_dist_chunks_PublicAuthPrompt-CfOE69qY_mjs"],{66329(t,e,a){a.r(e),a.d(e,{default:()=>b});var n=a(85471),i=a(53053),s=a(21777),r=a(85168),o=a(94219),l=a(371),c=a(82182),u=a(93095),m=a(39580);const d=(0,i.c0)("public").build(),p=(0,n.pM)({name:"PublicAuthPrompt",components:{NcDialog:o.A,NcNoteCard:l.A,NcTextField:c.A},props:{nickname:{type:String,default:""},title:{type:String,default:(0,u.t)("Guest identification")},text:{type:String,default:""},notice:{type:String,default:""},submitLabel:{type:String,default:(0,u.t)("Submit name")},cancellable:{type:Boolean,default:!1}},emits:["close"],setup:()=>({t:u.t}),data:()=>({name:""}),computed:{dialogButtons(){const t={label:(0,u.t)("Cancel"),variant:"tertiary",callback:()=>this.$emit("close")},e={label:this.submitLabel,type:"submit",variant:"primary"};return this.cancellable?[t,e]:[e]},defaultNotice(){return this.notice?this.notice:this.nickname?(0,u.t)("You are currently identified as {nickname}.",{nickname:this.nickname}):(0,u.t)("You are currently not identified.")}},watch:{nickname:{handler(){this.name=this.nickname},immediate:!0},name(){const t=this.name.trim?.()||"",e=this.$refs.input?.$el.querySelector("input");if(!e)return;const a=function(t){if(""===t.trim())return(0,u.t)("Names must not be empty.");if(t.startsWith("."))return(0,u.t)("Names must not start with a dot.");if(t.length>64)return(0,u.t)("Names may be at most 64 characters long.");try{return(0,m.KT)(t),""}catch(t){if(!(t instanceof m.di))throw t;switch(t.reason){case m.nF.Character:return(0,u.t)('"{char}" is not allowed inside a name.',{char:t.segment});case m.nF.ReservedName:return(0,u.t)('"{segment}" is a reserved name and not allowed.',{segment:t.segment});case m.nF.Extension:return t.segment.match(/\.[a-z]/i)?(0,u.t)('"{extension}" is not an allowed name.',{extension:t.segment}):(0,u.t)('Names must not end with "{extension}".',{extension:t.segment});default:return(0,u.t)("Invalid name.")}}}(t);e.setCustomValidity(a),e.reportValidity()}},methods:{onSubmit(){const t=this.$refs.input,e=this.name.trim();if(""===e)return t.setCustomValidity((0,u.t)("You cannot leave the name empty.")),t.reportValidity(),void t.focus();if(e.length<2)return t.setCustomValidity((0,u.t)("Please enter a name with at least 2 characters.")),t.reportValidity(),void t.focus();try{(0,s.L$)(e)}catch(e){return(0,r.Qg)((0,u.t)("Failed to set nickname.")),console.error("Failed to set nickname",e),void t.focus()}d.setItem("public-auth-prompt-shown","true"),this.$emit("close",this.name)}}});var h=function(){var t=this,e=t._self._c;return t._self._setupProxy,e("NcDialog",{staticClass:"public-auth-prompt",attrs:{buttons:t.dialogButtons,"data-cy-public-auth-prompt-dialog":"","is-form":"","no-close":"",name:t.title},on:{submit:t.onSubmit}},[t.text?e("p",{staticClass:"public-auth-prompt__text"},[t._v(" "+t._s(t.text)+" ")]):t._e(),e("NcNoteCard",{staticClass:"public-auth-prompt__header",attrs:{text:t.defaultNotice,type:"info"}}),e("NcTextField",{ref:"input",staticClass:"public-auth-prompt__input",attrs:{"data-cy-public-auth-prompt-dialog-name":"",label:t.t("Name"),placeholder:t.t("Enter your name"),required:!t.cancellable,minlength:"2",maxlength:"64",name:"name"},model:{value:t.name,callback:function(e){t.name=e},expression:"name"}})],1)},f=[];const b=(0,u.n)(p,h,f,!1,null,"a2f36bdb").exports}}]);
//# sourceMappingURL=bookmarks-node_modules_nextcloud_dialogs_dist_chunks_PublicAuthPrompt-CfOE69qY_mjs.js.map?v=e74945b57b7dbf8ab438