OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Mion-fhiosrachadh",
    "Rename" : "Thoir ainm ùr air",
    "Copy link" : "Dèan lethbhreac dhen cheangal",
    "Move" : "Gluais",
    "Select all" : "Tagh na h-uile",
    "New folder" : "Pasgan ùr",
    "Search" : "Lorg",
    "Empty trash bin" : "Falamhaich an sgudal",
    "_%n folder_::_%n folders_" : ["%n phasgan","%n phasgan","%n pasganan","%n pasgan"],
    "Cancel" : "Sguir dheth",
    "Files" : "Faidhlichean",
    "Delete" : "Sguab às",
    "Link" : "Ceangal",
    "Tags" : "Tagaichean",
    "Notes" : "Nòtaichean",
    "Link copied" : "Chaidh lethbhreac dhen cheangal a dhèanamh",
    "Sharing" : "Co-roinneadh",
    "Share link" : "Ceangal co-roinnidh",
    "Allow editing" : "Ceadaich deasachadh",
    "Allow resharing" : "Ceadaich co-roinneadh às ùr",
    "Privacy" : "Prìobhaideachd",
    "Save" : "Sàbhail"
},
"nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
