OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Záložky",
    "You bookmarked \"%s\"" : "Pridali ste záložku „%s“",
    "%1$s bookmarked \"%2$s\"" : "%1$s ako záložka „%2$s“",
    "Someone bookmarked \"%s\"" : "Niekto pridal záložku „%s“",
    "You deleted \"%s\"" : "Odstránili ste „%s“",
    "%1$s deleted \"%2$s\"" : "%1$s odstránené \"%2$s\"",
    "Someone deleted \"%s\"" : "Niekto odstránil „%s“",
    "You created folder \"%s\"" : "Vytvorili ste priečinok „%s“",
    "%1$s created folder \"%2$s\"" : "%1$s vytvoril priečinok „%2$s“",
    "Someone created folder \"%s\"" : "Niekto vytvoril priečinok „%s“",
    "You moved folder \"%s\"" : "Premiestnili preičinok „%s“",
    "%1$s moved folder \"%2$s\"" : "%1$s premiestnil priečinok „%2$s“",
    "Someone moved folder \"%s\"" : "Niekto premiestnil priečinok „%s“",
    "You deleted folder \"%s\"" : "Odstránili ste priečinok „%s“",
    "%1$s deleted folder \"%2$s\"" : "%1$s odstránil priečinok „%2$s“",
    "Someone deleted folder \"%s\"" : "Niekto odstránil priečinok „%s“",
    "You shared folder \"%1$s\" with %2$s" : "Zdieľali ste priečinok „%1$s“ s %2$s",
    "You shared folder \"%s\" with someone" : "Zdieľali ste s niekym priečinok „%s“",
    "%1$s shared folder \"%2$s\" with you" : "%1$s zdieľal s vami priečinok „%2$s“",
    "Someone shared folder \"%s\" with you" : "Niekto s vami zdieľal priečinok „%s“",
    "You unshared folder \"%1$s\" with %2$s" : "Zrušili ste zdieľanie priečinka „%1$s“ s %2$s",
    "You unshared folder \"%s\" with someone" : "S niekym ste zrušili zdieľanie priečinka „%s“",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s s vami zrušil zdieľanie priečinka „%2$s“",
    "Someone unshared folder \"%s\" with you" : "Niekto s vami zrušil zdieľanie priečinka „%s“",
    "No file provided for import" : "Nie je k dispozícii žiadny súbor na import",
    "Failed to upload file" : "Chyba pri nahrávaní súboru",
    "Unsupported file type for import: " : "Nepodporovaný typ súboru pre import:",
    "Bookmarks shared by %s" : "Záložky, ktoré zdieľa %s",
    "Frequent bookmarks" : "Časté záložky",
    "Recent bookmarks" : "Aktuálne záložky",
    "Bookmark" : "Záložka",
    "Bookmark deleted" : "Záložka zmazaná",
    "Bookmark created" : "Záložka vytvorená",
    "Bookmark moved" : "Záložka presunutá",
    "Bookmark updated" : "Záložka auktualizovaná",
    "Create bookmark" : "Vytvoriť záložku",
    "Takes a link and adds it to your collection of bookmarks." : "Zoberte odkaz a pridajte ho k vašim záložkám.",
    "Bookmarks Backups" : "Zálohy záložiek",
    "Collect and manage bookmarks, synced with all your devices" : "Zbierajte a spravujte záložky synchronizované so všetkými vašimi zariadeniami",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Zoraďte záložky do priečinkov\n- 🏷 Pridajte značky a osobné poznámky\n- ☠ Nájdite nefunkčné odkazy a duplikáty\n- 📲 Synchronizujte so všetkými svojimi prehliadačmi a zariadeniami\n- 📔 Uchovávajte archivované verzie svojich odkazov pre prípad, že budú zrušené\n- 🔍 Fulltextové vyhľadávanie v obsahu stránky\n- 👪 Zdieľajte záložky s ostatnými užívateľmi, skupinami a tímami alebo prostredníctvom verejných odkazov\n- ⚛ Vytvorte RSS kanály svojich zbierok\n- 📈 Štatistiky o tom, ako často pristupujete ku ktorým odkazom\n- 🔒 Automatické zálohovanie vašej zbierky záložiek\n- 💼 Vstavané miniaplikácie Dashboard pre časté a najnovšie odkazy\n\nPožiadavky:\n- PHP rozšírenia:\n- intl: *\n- mbstring: *\n- pri používaní MySQL používajte aspoň v8.0",
    "Do you really want to delete this bookmark?" : "Naozaj chcete zmazať všetky svoje záložky?",
    "Link copied to clipboard" : "Odkaz bol skopírovaný do schránky",
    "Enter new title" : "Zadajte nový nadpis",
    "Select bookmark" : "Vybrať záložku",
    "You have never clicked this link" : "Na tento odkaz ste nikdy neklikli",
    "You have clicked this link {count} times" : "Na tento link ste klikli {count} krát",
    "Details" : "Detaily",
    "Rename" : "Premenovať",
    "Copy link" : "Kopíruj odkaz",
    "Move" : "Presunúť",
    "Add to folders" : "Pridať do priečinkov",
    "Put bookmark into trash bin" : "Zahodiť záložku do koša",
    "Restore bookmark" : "Obnoviť záložku",
    "Delete bookmark permanently" : "Natrvalo odstrániť záložku",
    "Content pending" : "Čakajúci obsah",
    "This content is being downloaded for offline use. Please check back later." : "Tento obsah sa sťahuje na použitie v režime offline. Skúste to znova neskôr.",
    "Bookmarked {time} ago" : "Záložka vytvorená {time} dozadu",
    "Bookmarked on {date}" : "Záložka vytvorená {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Tu nájdete vaše zmazané položky. Položky sa vymažú permanentne po dvoch mesiacoch.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Záložky súborov na webe, ako sú fotografie alebo PDF, sa automaticky uložia do vašich súborov Nextcloud, takže ich stále nájdete, aj keď je odkaz offline.",
    "Searching in the current folder only." : "Hľadanie iba v aktuálnom adresári.",
    "Repeat search in all folders" : "Opakovať vyhľadávanie vo všetkých adresároch",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Odkazy v záložkách sú pravidelne kontrolované a tu sú uvedené tie, ktoré nie sú dostupné.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Priečinky so záložkami môžete zdieľať s ostatnými. Všetky priečinky zdieľané s vami sú uvedené tu.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Jedna záložka môže byť vo viacerých priečinkoch naraz. Jej aktualizáciou sa aktualizujú všetky kópie. Všetky duplicitné záložky sú tu uvedené pre pohodlie.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Vybraté {folders} priečinky a {bookmarks} záložky",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Vybraná %n záložka","Vybrané %n záložky","Vybrané %n záložky","Vybraných %n záložiek"],
    "_Selected %n folder_::_Selected %n folders_" : ["Vybratý %n priečinok","Vybraté %n priečinky","Vybraté %n priečinky","Vybratých %n priečinkov"],
    "Do you really want to delete these items?" : "Naozaj chcete odstrániť tieto položky?",
    "Open all selected" : "Otvoriť všetky vybraté",
    "Move selection" : "Presunúť vybraté",
    "Edit tags of selection" : "Editovať šťítky vybraných",
    "Delete selection" : "Zmazať výbrané",
    "Select all" : "Vybrať všetko",
    "Cancel selection" : "Zrušiť výber",
    "Sort by created date" : "Zoradiť podľa dátumu vytvorenia",
    "Sort by last modified" : "Zoradiť podľa dátumu poslednej zmeny",
    "Sort by title" : "Zoradiť podľa nadpisu",
    "Sort by click count" : "Zoradiť podľa počtu kliknutí",
    "Sort by manual order" : "Zoradiť manuálne",
    "Sort by URL" : "Zoradiť podľa URL",
    "RSS feed copied" : "RSS kanál je skopírovaný",
    "Trash Bin" : "Kôš",
    "Go back" : "Ísť späť",
    "Share folder" : "Sprístupniť priečinok",
    "Open folder details" : "Otvoriť podrobnosti o adresáre",
    "Select one or more tags" : "Zvoliť jeden alebo viac štítkov",
    "New" : "Nový",
    "New bookmark" : "Nová záložka",
    "New folder" : "Nový priečinok",
    "Change to grid view" : "Prepnúť na zobrazenie v mriežke",
    "Change to list view" : "Prepnúť na zobrazenie v zozname",
    "Copy RSS Feed of current view" : "Skopírovať RSS kanál aktuálneho zobrazenia",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Informačný kanál RSS vyžaduje autentizáciu pomocou vašich prihlasovacích údajov Nextcloud",
    "Search" : "Hľadať",
    "Empty trash bin" : "Vyprázdniť kôš",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Pridávam %n záložku do nového priečinka","Pridávam %n záložiek do nového priečinka","Pridávam %n záložiek do nového priečinka","Pridávam %n záložiek do nového priečinka"],
    "Enter a link" : "Zadať link",
    "Enter a title" : "Zadať názov",
    "No bookmarks found" : "Žiadne záložky neboli nájdené",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} priečinky a {bookmarks} záložky",
    "_%n bookmark_::_%n bookmarks_" : ["%n záložka","%n záložiek","%n záložiek","%n záložiek"],
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinkov","%n priečinkov","%n priečinkov"],
    "Welcome to Bookmarks" : "Vitajte v Záložkách",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Táto aplikácia vám umožňuje spravovať odkazy na vaše obľúbené miesta na webe. Roztrieďte svoje záložky do priečinkov, označte ich štítkami a sprístupnite ich ostatným! Aplikácia pravidelne kontroluje dostupnosť všetkých vašich odkazov a zobrazuje nedostupné odkazy. Ak pridáte odkaz na súbor na webe, súbor sa automaticky stiahne do vašich Nextcloud Súborov. Môžete tiež importovať záložky exportované z iných služieb alebo priamo synchronizovať záložky zo všetkých svojich prehliadačov pomocou tejto aplikácie.",
    "Add a bookmark" : "Pridať záložku",
    "Import bookmarks" : "Importovať záložky",
    "Sync with your browser" : "Synchronizovať s vašim prehliadačom",
    "Do you really want to permanently delete this folder?" : "Naozaj chcete navždy zmazať tento adresár?",
    "Select folder" : "Vybrať priečinok",
    "Enter folder title" : "Zadať názov priečinka",
    "Shared by {user}" : "Zdieľa {user}",
    "Rename folder" : "Premenovať priečinok",
    "Move folder" : "Presunúť priečinok",
    "Put folder into trashbin" : "Zahodiť adresár do koša",
    "Restore folder" : "Obnoviť adresár",
    "Delete folder permanently" : "Narvalo odstrániť adresár",
    "Choose folder" : "Vyberte priečinok",
    "Submit" : "Odoslať",
    "Cancel" : "Zrušiť",
    "Deleting bookmarks" : "Mažem záložky",
    "Deleting selection" : "Maže sa výber",
    "Importing bookmarks" : "Importujem záložky",
    "Moving selection" : "Presúvam vybrané",
    "Adding selection to folders" : "Pridávam vybrané do priečinkov",
    "Emptying trashbin" : "Vyprázdňujem kôš",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Presúva sa %n priečinok a niektoré záložky","Presúvajú sa %n priečinky a niektoré záložky","Presúvajú sa %n priečinky a niektoré záložky","Presúva sa %n priečinkov a niektoré záložky"],
    "_Moving %n folder_::_Moving %n folders_" : ["Presúva sa %n priečinok","Presúvajú sa %n priečinky","Presúvajú sa %n priečinky","Presúva sa %n priečinkov"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Presúva sa %n záložka","Presúvajú sa %n záložky","Presúvajú sa %n záložky","Presúva sa %n záložiek"],
    "All bookmarks" : "Všetky záložky",
    "Recent" : "Nedávne",
    "Shared with you" : "Zdieľané s vami",
    "Files" : "Súbory",
    "Duplicates" : "Duplicity",
    "Broken links" : "Poškodené odkazy",
    "New tag" : "Nový štítok",
    "Search tags" : "Vyhľadať štítky",
    "Delete" : "Zmazať",
    "Untagged" : "Bez štítku",
    "{used} bookmarks of {available} available" : "{used} záložky z {available} dostupných",
    "Bookmarks Settings" : "Nastavenia Záložiek",
    "No bookmarked files" : "Žiadne záložky súborov",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Záložky súborov, ako sú fotografie alebo PDF, sa automaticky uložia do vašich súborov Nextcloud, takže ich stále nájdete, aj keď je odkaz offline.",
    "Nothing found" : "Nič sa nenašlo",
    "Your search yielded no results in the current folder." : "Vaše vyhľadávanie neprinieslo žiadne výsledky v aktuálnom priečinku.",
    "No broken links" : "Žiadne poškodené odkazy",
    "No shared folders" : "Žiadne zdieľané priečinky",
    "No duplicated bookmarks" : "Žiadne duplikovanéq záložky",
    "No deleted bookmarks" : "Žiadne zmazané záložky",
    "You haven't deleted anything yet." : "Zatiaľ ste nič neodstránili.",
    "No bookmarks here" : "Žiadne záložky",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Pridajte záložky ručne alebo ich importujte z HTML súboru.",
    "Archive path" : "Archivovať cestu",
    "Backup path" : "Cesta k zálohám",
    "Please select \"Add to home screen\" in your browser menu" : "Prosím vyberte \"Pridať na domovskú obrazovku\" v menu vašeho prehliadača",
    "Bookmarks settings" : "Nastavenia záložiek",
    "Import/Export" : "Import/Export",
    "Export bookmarks" : "Exportovať záložky",
    "Auto-archiving" : "Auto-archivácia",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Aplikácia na záložky môže automaticky archivovať webový obsah odkazov, ktoré ste si uložili do záložiek.",
    "Enable archiving" : "Povoliť archivovanie",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Vložte cestu k priečinku kde sa budú ukladať súbory v záložkách.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Váš správca však momentálne zakázal tejto aplikácii prístup k sieti, a preto je automatická archivácia momentálne zakázaná.",
    "Auto-Backup" : "Auto-zálohovanie",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Aplikácia na záložky môže automaticky zálohovať vaše záložky denne, aby sa zabránilo strate údajov pri synchronizácii záložiek medzi zariadeniami.",
    "Enable backups" : "Povoliť zálohovanie",
    "Enter the path of a folder in your Files where backups will be stored." : "Vložte cestu k priečinku kde sa budú ukladať zálohy.",
    "Context Chat integration" : "Integrácia kontextového chatu",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Aplikácia záložky dokáže automaticky sprístupniť textový obsah webových stránok, ktoré si uložíte do záložiek, v kontextovom chate, čo umožňuje klásť otázky a dostávať odpovede na základe tohto obsahu. Toto je k dispozícii iba v prípade, že je povolená automatická archivácia.",
    "Context chat is currently not installed, but is required for this feature." : "Kontextový chat momentálne nie je nainštalovaný, ale je potrebný pre túto funkciu.",
    "Enable Context Chat integration" : "Povoliť integráciu kontextového chatu",
    "Client apps" : "Aplikácie klienta",
    "Also check out the collection of client apps that integrate with this app: " : "Pozrite si sadu klientskych aplikácií, ktoré sa integrujú do tejto aplikácie:",
    "Install web app" : "Inštalovať webovú aplikáciu",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Môžete si nainštalovať túto aplikáciu na domovskú obrazovku vašeho zariadenia pre rýchly prístup k vašim záložkám na vašom telefóne. Môžete jednoducho odstrániť aplikáciu z vašej domovskej obrazovky, ak sa vám to nebude páčiť.",
    "Install on home screen" : "Nainštalovať na domovskú obrazovku",
    "Bookmarklet" : "Záložky",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Potiahnite túto položku do záložiek prehliadača a kliknutím pridajte stránku do záložiek.",
    "Add to {instanceName}" : "Pridať do {instanceName}",
    "Need help?" : "Potrebujete pomoc?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Ak máte problémy s aplikáciou Záložky alebo máte nápad, čo by sa dalo zlepšiť, neváhajte nás kontaktovať kliknutím sem.",
    "Support this project" : "Podporte tente projekt",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Moja práca na aplikácii Záložky je poháňaná modelom dobrovoľného predplatného. Ak si myslíte, že to, čo robím, má zmysel, budem rád, ak podporíte moju prácu. Zvážte tiež, že by ste aplikácii dali recenziu v obchode s aplikáciami Nextcloud. Ďakujem 💙",
    "Created {time} ago" : "Vytvorené  {time} spätne",
    "Created on {date}" : "Vytvorené {date}",
    "(Empty title)" : "(Prázdny názov)",
    "Title" : "Názov",
    "Link" : "Odkaz",
    "Untitled folder" : "Priečinok bez názvu",
    "Root folder" : "Koreňový priečinok",
    "Tags" : "Štítky",
    "Select tags and create new ones" : "Vyberte štítky a vytvorte nové",
    "Notes" : "Poznámky",
    "Notes for this bookmark …" : "Poznámky pre túto záložku ...",
    "Archived file" : "Archivovaný súbor",
    "Open file" : "Otvoriť súbor",
    "Download file" : "Stiahnuť súbor",
    "Open file location" : "Otvoriť umiestnenie súboru",
    "Link copied" : "Odkaz bol skopírovaný",
    "Owner" : "Majiteľ",
    "Sharing" : "Zdieľanie",
    "Select a user or group" : "Vyberte používateľa alebo skupinu",
    "Share link" : "Sprístupniť odkaz",
    "Reading allowed" : "Čítanie povolené",
    "Copy RSS feed" : "Kopírovať RSS kanál",
    "Delete link" : "Zmazať odkaz",
    "Create public link" : "Vytvoriť verejný odkaz",
    "Resharing allowed" : "Opätovné zdieľanie je povolené",
    "Editing allowed" : "Úpravy povolené",
    "Allow editing" : "Povoliť úpravy",
    "Allow resharing" : "Povoliť zdieľanie ďalej",
    "Remove share" : "Odstrániť zdieľanie",
    "Leave a rating on the Nextcloud App Store" : "Zanechajte hodnotenie v obchode Nextcloud App Store",
    "Failed to save settings" : "Nepodarilo sa uložiť nastavenia",
    "Failed to load settings" : "Nepodarilo sa načítať nastavenia",
    "Privacy" : "Súkromie",
    "The app will try to access web pages that you add to automatically add information about them." : "Aplikácia sa pokúsi o prístup k webovým stránkam, ktoré pridáte, aby o nich automaticky zistila informácie.",
    "Enable accessing and collecting information from the web pages you add" : "Povoľte prístup a zhromažďovanie informácií z pridaných webových stránok",
    "Performance" : "Výkon",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "V inštalácii s veľkým počtom používateľov môže byť užitočné obmedziť počet záložiek v jednom účte.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximálny povolený počet záložiek na účet. (0 bez limitu; predvolená hodnota bez limitu)",
    "Previews" : "Náhľady",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Pre zobrazenie skutočných snímok obrazovky vašich webových stránok so záložkami môže aplikácia na generovanie náhľadov použiť služby tretích strán.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Môžete sa bezplatne zaregistrovať na adrese screeenly.com alebo si nastaviť vlastný server.",
    "Screeenly API URL" : "Screenly API URL",
    "Screeenly API key" : "Screenly API kľúč",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Kľúč k API služby ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL API služby Webshot",
    "Generic screenshot API" : "Všeobecné rozhranie API pre snímky obrazovky",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Zaregistrujte sa u ktoréhokoľvek z poskytovateľov rozhrania API snímkov obrazovky a nižšie zadajte adresu URL rozhrania API. Použite premennú {url} ako zástupný symbol pre adresu URL na snímku obrazovky. Rozhranie API musí priamo vrátiť iba obrázok.",
    "Generic API URL" : "Všeobecné rozhranie API pre URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Jednoducho si na svoj server nainštalujte Pageres CLI od Sindre Sorhus a Záložky si ho nájdu. Stále môžete pridať ďalšie premenné ENV, ktoré sa majú pridávať na stránky, napr. ako je uvedené v zástupnom symbole:",
    "Pageres ENV variables" : "Premennné prostredia Pageres",
    "This URL is already bookmarked! Overwrite?" : "Táto webová adresa sa už v záložkách nachádza. Chcete ju prepísať?",
    "Enter bookmark title" : "Zadať názov záložky",
    "Enter bookmark URL" : "Zadajte URL záložky",
    "Folder" : "Priečinok",
    "Root Folder" : "Koreňový priečinok",
    "Save" : "Uložiť",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Prístup k sieti je v predvolenom nastavení zakázaný. Prejdite do nastavení správcu pre aplikáciu záložiek a povoľte načítanie ukážok a favikónov.",
    "What's new?" : "Čo je nové?",
    "What" : "Čo",
    "Failed to count unavailable bookmarks" : "Nepodarilo sa spočítať neprístupné záložky",
    "Failed to count archived bookmarks" : "Nepodarilo sa spočítať archivované záložky",
    "Failed to count deleted bookmarks" : "Nepodarilo sa spočítať vymazané záložky",
    "Failed to count duplicated bookmarks" : "Chyba pri spočítavaní duplikovaných záložiek",
    "Failed to count bookmarks" : "Nepodarilo sa spočítať záložky",
    "Failed to load bookmark" : "Nepodarilo sa načítať záložku",
    "Failed to find existing bookmark" : "Nepodarilo sa nájsť existujúcu záložku",
    "Failed to create bookmark" : "Nepodarilo sa vytvoriť záložku",
    "Failed to save bookmark" : "Nepodarilo sa uložiť záložku",
    "Failed to move bookmark" : "Nepodarilo sa presunúť záložku",
    "Failed to copy bookmark" : "Chyba pri kopírovaní záložky",
    "Failed to delete bookmark" : "Nepodarilo sa zmazať záložky",
    "Failed to restore bookmark" : "Obnovenie záložky zlyhalo",
    "Import successful" : "Import bol úspešný",
    "Failed to rename tag" : "Nepodarilo sa premenovať štítok",
    "Failed to load tags" : "Nepodarilo sa načítať štítky",
    "Failed to load folders" : "Nepodarilo sa načítať priečinky",
    "Failed to load deleted folders" : "Nepodarilo sa načítať zmazané adresáre",
    "Failed to load deleted bookmarks" : "Nepodarilo sa načítať zmazané záložky",
    "Failed to delete folder" : "Nepodarilo sa zmazať priečinok",
    "Failed to move folder" : "Presun adresára zlyhal",
    "Failed to restore folder" : "Obnovenie priečinka zlyhalo",
    "Failed to create folder" : "Nepodarilo sa vytvoriť priečinok",
    "Failed to load children order" : "Nepodarilo sa načítať poradie detí",
    "Failed to move parts of selection" : "Zlyhal presun časti výberu",
    "Failed to copy parts of selection" : "Nepodarilo sa skopírovať časť výberu",
    "Failed to delete parts of selection" : "Zlyhalo zmazanie časti výberu",
    "Failed to tag parts of selection" : "Označenie častí výberu sa nepodarilo",
    "Failed to fetch bookmarks." : "Nepodarilo sa načítať záložky",
    "Failed to store setting" : "Nepodarilo sa uložiť nastavenie",
    "Failed to load setting {key}" : "Nepodarilo sa načítať nastavenie {key}",
    "Failed to create share for folder {folderId}" : "Nepodarilo sa vytvoriť zdieľaný priečinok{folderId}",
    "Failed to update share {shareId}" : "Nepodarilo sa aktualizovať zdieľanie {shareId}",
    "Failed to delete share {shareId}" : "Nepodarilo sa zmazať zdieľanie {shareId}.",
    "Failed to create public link for folder {folderId}" : "Nepodarilo sa vytvoriť verejný odkaz na priečinok{folderId}",
    "Failed to delete public link for folder {folderId}" : "Nepodarilo sa odstrániť verejný odkaz na priečinok{folderId}",
    "Failed to permanently delete parts of trash bin" : "Nepodarilo sa natrvalo odstrániť časť koša",
    "Create bookmarks for mentioned links" : "Vytvorte záložky pre uvedené odkazy",
    "No links found in this message" : "V tejto správe sa nenašli žiadne odkazy",
    "Bookmarks feed" : "Kanál záložiek"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
