<?php
$TRANSLATIONS = array(
"Bookmarks" => "বুকমার্ক",
"Bookm." => "বুকএম.",
"No file provided for import" => "ইম্পোর্টের জন্য প্রদান করা কোন ফাইল",
"Unsupported file type for import" => "ইমপোর্টের জন্য অসমর্থিত ফাইল টাইপ",
"Error" => "ভুল",
"Tags" => "ট্যাগ্স",
"Filter by tag" => "ট্যাগ দ্বারা ফিল্টার করুন",
"Warning" => "সতর্কীকরণ",
"Are you sure you want to remove this tag from every entry?" => "আপনি আপনার প্রতি এন্ট্রি থেকে এই ট্যাগটি মুছে ফেলার ব্যাপারে নিশ্চিত?",
"Import error" => "ইম্পোর্ট ত্রুটি",
"Import completed successfully." => "ইম্পোর্ট সফলভাবে সম্পন্ন হয়েছে।",
"Uploading..." => "আপলোডইং ...",
"Add a bookmark" => "বুকমার্ক অ্যাড করুন ",
"The title of the page" => "পৃষ্ঠার শিরোনাম",
"The address of the page" => "পৃষ্ঠার ঠিকানা",
"Description of the page" => "পৃষ্ঠার বিবরণ",
"Save" => "সেভ",
"Delete" => "মুছে ফেলা",
"Edit" => "এডিট",
"Cancel" => "বাতিল করা",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "আপনার ব্রাউজারের বুকমার্কে এটি ড্র্যাগ করে নিয়ে যান এবং এটা ক্লিক করুন, যখন আপনি দ্রুত একটি ওয়েব পেজ বুকমার্ক করতে চান:",
"Add to ownCloud" => "OwnCloud এ যোগ করুন",
"Address" => "ঠিকানা",
"You have no bookmarks" => "আপনার কোন বুকমার্ক নেই",
"Bookmarklet" => "বুকমার্কলেট",
"Export & Import" => "এক্সপোর্ট ও ইম্পোর্ট",
"Export" => "এক্সপোর্ট",
"Import" => "ইম্পোর্ট"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
