OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Detajet",
    "Rename" : "Rename",
    "Copy link" : "Kopjo linkun",
    "Move" : "Zhvendos",
    "Select all" : "Zgjidhi të gjitha",
    "Go back" : "Shko prapa",
    "New" : "I ri",
    "New folder" : "Dosje e re",
    "Search" : "Kërko",
    "_%n folder_::_%n folders_" : ["%n dosje","%n dosje"],
    "Rename folder" : "Riemërtoni dosjen",
    "Choose folder" : "Zgjidhni dosjen",
    "Submit" : "Dërgo",
    "Cancel" : "Anullo",
    "Recent" : "Së fundmi",
    "Shared with you" : "E ndarë me ju",
    "Files" : "Skedarët",
    "Delete" : "Fshij",
    "Untagged" : "E paetiketuar",
    "Bookmarklet" : "Libër Shënues",
    "Need help?" : "Ju duhet ndihmë?",
    "Title" : "Titulli",
    "Link" : "Lidhje",
    "Tags" : "Etiketat",
    "Notes" : "Shënime",
    "Open file" : "Hap skedarin",
    "Download file" : "Shkarko skedarin",
    "Link copied" : "Linku u kopjua",
    "Owner" : "Zotëruesi",
    "Sharing" : "Ndarje",
    "Share link" : "Share link",
    "Allow editing" : "Lejo redaktimin",
    "Allow resharing" : "Lejo rindarje",
    "Privacy" : "Privatësia",
    "Previews" : "Parapamjet",
    "Folder" : "Skedari",
    "Save" : "Ruaj"
},
"nplurals=2; plural=(n != 1);");
