OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Detaljar",
    "Rename" : "Gje nytt namn",
    "Copy link" : "Kopier lenkje",
    "Move" : "Move",
    "Select all" : "Merk alt",
    "New" : "Ny",
    "New folder" : "Ny mappe",
    "Search" : "Søk",
    "Empty trash bin" : "Tøm søppel korg",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "Choose folder" : "Vel mappe",
    "Cancel" : "Avbryt",
    "Shared with you" : "Shared with you",
    "Files" : "Filer",
    "Delete" : "Ta bort",
    "Need help?" : "Treng du hjelp?",
    "Title" : "Tittel",
    "Link" : "Lenkje",
    "Tags" : "Emneord",
    "Notes" : "Notat",
    "Open file" : "Opne fil",
    "Link copied" : "Lenkje kopiert",
    "Owner" : "Owner",
    "Sharing" : "Deling",
    "Share link" : "Del lenkje",
    "Allow editing" : "Tillat endring",
    "Allow resharing" : "Tillat vidaredeling",
    "Privacy" : "Personvern",
    "Folder" : "Mappe",
    "Save" : "Lagre"
},
"nplurals=2; plural=(n != 1);");
