<?php
$TRANSLATIONS = array(
"Bookmarks" => "Segnalibri",
"Failed to import one bookmark, because: " => "Importazione di un segnalibro non riuscita, causa:",
"Bookm." => "Segnal.",
"No file provided for import" => "Non è stato fornito alcun file da importare",
"Unsupported file type for import" => "Tipo di file non supportato per l'importazione",
"Some Error happened." => "Si sono verificati alcuni errori.",
"Error" => "Errore",
"Tags" => "Tag",
"Filter by tag" => "Filtro per etichetta",
"Are you sure you want to remove this bookmark?" => "Sei sicuro di voler rimuovere questo segnalibro?",
"Warning" => "Avviso",
"Are you sure you want to remove this tag from every entry?" => "Sei sicuro di voler rimuovere questo tag da ogni voce?",
"Import error" => "Errore di importazione",
"Import completed successfully." => "Importazione completata correttamente.",
"Uploading..." => "Caricamento in corso...",
"Add a bookmark" => "Aggiungi un segnalibro",
"This URL is already bookmarked! Overwrite?" => "Questo URL è già tra i segnalibri! Vuoi sovrascriverlo?",
"The title of the page" => "Il titolo della pagina",
"The address of the page" => "L'indirizzo della pagina",
"Description of the page" => "Descrizione della pagina",
"Save" => "Salva",
"Delete" => "Elimina",
"Edit" => "Modifica",
"Cancel" => "Annulla",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Quando vuoi creare rapidamente un segnalibro, trascinalo sui segnalibri del browser e fai clic su di esso:",
"Add to ownCloud" => "Aggiungi a ownCloud",
"Address" => "Indirizzo",
"Filterable Tags" => "Etichette filtrabili",
"You have no bookmarks" => "Non hai segnalibri",
"You can also import a bookmark file" => "Puoi importare anche un file di segnalibri",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Esporta e importa",
"Export" => "Esporta",
"Import" => "Importa"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
