OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Detailer",
    "Rename" : "Ëmbenennen",
    "Copy link" : "Link kopéieren",
    "Move" : "Verschieben",
    "Select all" : "All auswielen",
    "Go back" : "Zeréckgoen",
    "New" : "Nei",
    "New folder" : "Neien Dossier",
    "Search" : "Search",
    "Empty trash bin" : "Eidel Dreckskëscht",
    "_%n folder_::_%n folders_" : ["¦%n Dossier","¦%n Dossieren"],
    "Rename folder" : "Dossier ëmbenennen",
    "Cancel" : "Ofbriechen",
    "Recent" : "Rezent",
    "Shared with you" : "Mat dir gedeelt",
    "Files" : "Fichieren",
    "Delete" : "Läschen",
    "Title" : "Titel",
    "Link" : "Link",
    "Tags" : "Tags",
    "Notes" : "Notizen",
    "Open file" : "Fichier opmaachen",
    "Link copied" : "Link kopéiert",
    "Owner" : "Owner",
    "Sharing" : "Gedeelt",
    "Share link" : "Link deelen",
    "Allow editing" : "Beaarbechten erlaben",
    "Allow resharing" : "Resharing erlaben",
    "Folder" : "Dossier",
    "Save" : "Späicheren"
},
"nplurals=2; plural=(n != 1);");
