OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Zaznamki",
    "You bookmarked \"%s\"" : "Ustvarite zaznamek »%s«",
    "%1$s bookmarked \"%2$s\"" : "%1$s ustvari zaznamek »%2$s«",
    "Someone bookmarked \"%s\"" : "Nekdo ustvari zaznamek »%s«",
    "You deleted \"%s\"" : "Izbrišete »%s«",
    "%1$s deleted \"%2$s\"" : "%1$s izbriše »%2$s«",
    "Someone deleted \"%s\"" : "Nekdo izbriše »%s«",
    "You created folder \"%s\"" : "Ustvarite mapo »%s«",
    "%1$s created folder \"%2$s\"" : "%1$s ustvari mapo »%2$s«",
    "Someone created folder \"%s\"" : "Nekdo ustvari mapo »%s«",
    "You moved folder \"%s\"" : "Premaknete mapo »%s«",
    "%1$s moved folder \"%2$s\"" : "%1$s premakne mapo »%2$s«",
    "Someone moved folder \"%s\"" : "Nekdo premakne mapo »%s«",
    "You deleted folder \"%s\"" : "Izbrišete mapo »%s«",
    "%1$s deleted folder \"%2$s\"" : "%1$s izbriše mapo »%2$s«",
    "Someone deleted folder \"%s\"" : "Nekdo izbriše mapo »%s«",
    "You shared folder \"%1$s\" with %2$s" : "Omogočite souporabo mape »%1$s« z »%2$s«",
    "You shared folder \"%s\" with someone" : "Omogočite souporabo mape »%s«",
    "%1$s shared folder \"%2$s\" with you" : "%1$s vam omogoči souporabo mape »%2$s«",
    "Someone shared folder \"%s\" with you" : "Nekdo vam omogoči souporabo mape »%s«",
    "You unshared folder \"%1$s\" with %2$s" : "Prekinili ste souporabo mape »%1$s« z »%2$s«",
    "You unshared folder \"%s\" with someone" : "Z nekom ste prekinili souporabo mape »%s«",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s vam onemogoči souporabo mape »%2$s«",
    "Someone unshared folder \"%s\" with you" : "Nekdo vam onemogoči souporabo mape »%s«",
    "No file provided for import" : "Ni navedenih datotek za uvoz",
    "Failed to upload file" : "Pošiljanje datoteke je spodletelo",
    "Bookmarks shared by %s" : "Zaznamki v souporabi z %s",
    "Frequent bookmarks" : "Pogosti zaznamki",
    "Recent bookmarks" : "Nedavni zaznamki",
    "Bookmark" : "Zaznamek",
    "Bookmark deleted" : "Zaznamek je izbrisan",
    "Bookmark created" : "Zaznamek je ustvarjen",
    "Bookmark moved" : "Zaznamek je premaknjen",
    "Bookmark updated" : "Zaznamek je posodobljen",
    "Create bookmark" : "Ustvari zaznamek",
    "Takes a link and adds it to your collection of bookmarks." : "Prevzame povezavo in jo doda v zbirko zaznamkov.",
    "Bookmarks Backups" : "Varnostne kopije zaznamkov",
    "Do you really want to delete this bookmark?" : "Ali ste prepričani, da želite izbrisati ta zaznamek?",
    "Link copied to clipboard" : "Povezava je kopirana v odložišče",
    "Enter new title" : "Vpis novega naslova",
    "Select bookmark" : "Izbor zaznamka",
    "Details" : "Podrobnosti",
    "Rename" : "Preimenuj",
    "Copy link" : "Kopiraj povezavo",
    "Move" : "Premakni",
    "Add to folders" : "Dodaj med mape",
    "Content pending" : "Vsebina na čakanju",
    "This content is being downloaded for offline use. Please check back later." : "Vsebina se prejema krajevno za delo brez povezave. Preverite kasneje ...",
    "Bookmarked {time} ago" : "Zaznamek ustvarjen pred {time}",
    "Bookmarked on {date}" : "Zaznamek ustvarjen {date}",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Zaznamki do datotek, kot so slike in dokumenti PDF, bodo samodejno shranjeni med datoteke Nextcloud, zato je dostop mogoč tudi ko povezava ni več na voljo.",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Zaznamki so stalno pod nadzorom, povezave, ki jih ni mogoče doseči, pa so navedene na tem mestu.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Mape z zaznamki je mogoče deliti z drugimi. Na tem mestu so navedene vse mape, ki so v souporabi.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Ena zaznamek je lahko sočasno v več mapah. Posodobitev se odrazi v vseh kopijah, dvojniki pa so zaradi preglednosti navedeni na tem mestu.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Izbrane mape {folders} in zaznamki {bookmarks}",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Izbran je %n zaznamek","Izbrana sta %n zaznamka","Izbrani so %n zaznamki","Izbranih je %n zaznamkov"],
    "_Selected %n folder_::_Selected %n folders_" : ["Izbrana je %n mapa","Izbrani sta %n mapi","Izbrane so %n mape","Izbranih je %n map"],
    "Do you really want to delete these items?" : "Ali ste prepričani, da želite izbrisati te predmete?",
    "Open all selected" : "Odpri vse izbrane",
    "Move selection" : "Premakni izbor",
    "Edit tags of selection" : "Uredi oznake izbire",
    "Delete selection" : "Izbriši izbor",
    "Select all" : "Izberi vse",
    "Cancel selection" : "Prekliči izbor",
    "Sort by created date" : "Razvrsti po datumu ustvarjanja",
    "Sort by last modified" : "Razvrsti po datumu spremembe",
    "Sort by title" : "Razvrsti po naslovu",
    "Sort by click count" : "Razvrsti po številu klikov",
    "Sort by manual order" : "Razvrsti ročno",
    "Sort by URL" : "Razvrsti po naslovu URL",
    "RSS feed copied" : "Vir RSS je kopiran",
    "Go back" : "Skoči nazaj",
    "Share folder" : "Omogoči souporabo mape",
    "Select one or more tags" : "Izbor enega oziroma več zaznamkov",
    "New" : "Novo",
    "New bookmark" : "Nov zaznamek",
    "New folder" : "Nova mapa",
    "Change to grid view" : "Preklopi na mrežni pogled",
    "Change to list view" : "Preklopi na seznamski pogled",
    "Copy RSS Feed of current view" : "Kopiraj vir RSS trenutnega pogleda",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Vir RSS zahteva overitev z vašimi poverili Nextcloud",
    "Search" : "Poišči",
    "Empty trash bin" : "Izprazni smeti",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Dodajanje %n zaznamka v novo mapo","Dodajanje %n zaznamkov v novo mapo","Dodajanje %n zaznamkov v novo mapo","Dodajanje %n zaznamkov v novo mapo"],
    "Enter a link" : "Vnesite povezavo",
    "Enter a title" : "Vpis naslova",
    "No bookmarks found" : "Ni najdenih zaznamkov",
    "{folders} folders and {bookmarks} bookmarks" : "Izbrane mape {folders} in zaznamki {bookmarks}",
    "_%n bookmark_::_%n bookmarks_" : ["%n zaznamek","%n zaznamka","%n zaznamki","%n zaznamkov"],
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n map"],
    "Welcome to Bookmarks" : "Dobrodošli med Zaznamki",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Program omogoča upravljanje povezav priljubljenih spletnih mest. Omogoča razvrščanje zaznamkov v mape, označevanje z oznakami in izmenjavo z drugimi uporabniki! Program samodejno preverja razpoložljivost vpisanih povezav in prikaže nedostopne. Povezave do datotek na spletu sprožijo samodejen prenos v oblak Nextcloud. Prav tako je mogoče uvoziti zaznamke iz drugih storitev in neposredno usklajevanje zaznamkov iz vseh brskalnikov.",
    "Add a bookmark" : "Dodaj zaznamek",
    "Import bookmarks" : "Uvozi zaznamke",
    "Sync with your browser" : "Uskladi z brskalnikom",
    "Select folder" : "Izbor mape",
    "Enter folder title" : "Vnesite naziv mape",
    "Shared by {user}" : "V skupni rabi z {user}",
    "Rename folder" : "Preimenuj mapo",
    "Move folder" : "Premakni mapo",
    "Delete folder permanently" : "Izbriši mapo trajno",
    "Choose folder" : "Izbor mape",
    "Submit" : "Pošlji",
    "Cancel" : "Prekliči",
    "Deleting bookmarks" : "Brisanje zaznamkov",
    "Deleting selection" : "Brisanje izbora",
    "Importing bookmarks" : "Uvažanje zaznamkov",
    "Moving selection" : "Premikanje izbora",
    "Adding selection to folders" : "Dodajanje izbire za mape",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Premikanje mape %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov"],
    "_Moving %n folder_::_Moving %n folders_" : ["Poteka premikanje %n mape","Poteka premikanje %n map","Poteka premikanje %n map","Poteka premikanje %n map"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Poteka premikanje %n zaznamka","Poteka premikanje %n zaznamkov","Poteka premikanje %n zaznamkov","Poteka premikanje %n zaznamkov"],
    "All bookmarks" : "Vsi zaznamki",
    "Recent" : "Nedavne",
    "Shared with you" : "V souporabi z vami",
    "Files" : "Datoteke",
    "Duplicates" : "Podvojeno",
    "Broken links" : "Okvarjene povezave",
    "New tag" : "Nova oznaka",
    "Search tags" : "Poišči oznake",
    "Delete" : "Izbriši",
    "Untagged" : "Neoznačeno",
    "{used} bookmarks of {available} available" : "Uporabljeno {used} od razpoložljivih {available}",
    "No bookmarked files" : "Ni še dodanih zaznamkov datotek",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Zaznamki do datotek, kot so slike in dokumenti PDF, bodo samodejno shranjeni med datoteke Nextcloud, zato je dostop mogoč tudi pri delu brez povezave.",
    "No broken links" : "Ni okvarjenih povezav",
    "No shared folders" : "Ni map v souporabi",
    "No duplicated bookmarks" : "Ni podvojenih zaznamkov",
    "No bookmarks here" : "Ni še dodanih zaznamkov.",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Zaznamke dodajte ročno ali jih uvozite iz datoteke HTML.",
    "Archive path" : "Arhiviraj pot",
    "Backup path" : "Varnostna kopija poti",
    "Please select \"Add to home screen\" in your browser menu" : "V meniju brskalnika izberite možnost »Dodaj na začetni zaslon«",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Vpis poti do mape med Datotekami, kjer bi morali biti shranjeni zaznamki datotek",
    "Enter the path of a folder in your Files where backups will be stored." : "Vpis poti do mape med Datotekami, kjer naj bodo shranjene varnostne kopije zaznamkov.",
    "Client apps" : "Odjemalski programi",
    "Also check out the collection of client apps that integrate with this app: " : "Preverite tudi zbirko programov, ki se povezujejo z zmožnostmi:",
    "Install web app" : "Namesti spletni program",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Program je mogoče dodati na začetni zaslon za hiter dostop do zaznamkov na telefonu. Prav tako je program mogoče enostavno odstraniti z začetnega zaslona.",
    "Install on home screen" : "Namesti na začetni zaslon",
    "Bookmarklet" : "Program za zaznamke",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Potegnite to med zaznamke brskalnika in kliknite za hitro dodajanje zaznamka spletne strani.",
    "Add to {instanceName}" : "Dodaj {instanceName} ",
    "Need help?" : "Ali potrebujete pomoč?",
    "Created {time} ago" : "Ustvarjeno {time}",
    "Created on {date}" : "Ustvarjeno {date}",
    "Title" : "Naslov",
    "Link" : "Povezava",
    "Untitled folder" : "Neimenovana mapa",
    "Root folder" : "Korenska mapa",
    "Tags" : "Oznake",
    "Select tags and create new ones" : "Izberi oznake in ustvari nove",
    "Notes" : "Opombe",
    "Notes for this bookmark …" : "Opombe za zaznamek ...",
    "Archived file" : "Arhivirane datoteke",
    "Open file" : "Odpri datoteko",
    "Download file" : "Prejmi datoteko",
    "Open file location" : "Odpri mesto datoteke",
    "Link copied" : "Povezava je kopirana",
    "Owner" : "Lastnik",
    "Sharing" : "Souporaba",
    "Select a user or group" : "Izbor imena uporabnika oziroma skupine",
    "Share link" : "Povezava za souporabo",
    "Reading allowed" : "Branje je dovoljeno",
    "Copy RSS feed" : "Kopiraj vir RSS",
    "Delete link" : "Izbriši povezavo",
    "Create public link" : "Ustvari javno povezavo",
    "Resharing allowed" : "Nadaljnje omogočanje souporabe je dovoljeno",
    "Editing allowed" : "Urejanje je dovoljeno",
    "Allow editing" : "Dovoli urejanje",
    "Allow resharing" : "Dovoli nadaljnje omogočanje souporabe",
    "Remove share" : "Odstrani souporabo",
    "Failed to save settings" : "Shranjevanje nastavitev je spodletelo",
    "Failed to load settings" : "Nalaganje nastavitev je spodletelo.",
    "Privacy" : "Zasebnost",
    "Enable accessing and collecting information from the web pages you add" : "Omogoči dostop in zbiranje podatkov z dodanih spletnih strani",
    "Performance" : "Delovanje",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Na sistemu z velikim številom uporabnikov je priporočeno omejiti število zaznamkov na račun",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Največje dovoljeno število zaznamkov na račun (privzeta vrednost je 0 – brez omejitve)",
    "Previews" : "Predogledi",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Lahko se brezplačno vpišete na spletni strani screeenly.com, ali pa nastavite svoj strežnik.",
    "Screeenly API URL" : "Naslov URL vmesnika Screeenly API",
    "Screeenly API key" : "Ključ vmesnika Screeenly API",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Ključ vmesnika API ScreenshotMachine",
    "Webshot" : "Slika spletne strani",
    "Webshot API URL" : "Slika spletne strani API URL",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Spremenljivke Pageres ENV",
    "This URL is already bookmarked! Overwrite?" : "Ta naslov URL je že dodan med zaznamke. Ali ga želite prepisati?",
    "Enter bookmark title" : "Naslov zaznamka",
    "Enter bookmark URL" : "Naslov URL zaznamka",
    "Folder" : "Mapa",
    "Root Folder" : "Korenska mapa",
    "Save" : "Shrani",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Omrežni dostop je onemogočen privzeto. Med skrbniškimi nastavitvami za program zaznamkov so zbrane možnosti pridobivanja predogleda in ikon.",
    "What's new?" : "Kaj je novega?",
    "What" : "Dejanje",
    "Failed to count unavailable bookmarks" : "Štetje nerazpoložljivih zaznamkov je spodletelo",
    "Failed to count archived bookmarks" : "Štetje arhiviranih zaznamkov je spodletelo",
    "Failed to count duplicated bookmarks" : "Preštevanje podvojenih zaznamkov je spodletelo",
    "Failed to load bookmark" : "Nalaganje zaznamka je spodletelo",
    "Failed to find existing bookmark" : "Dostop do obstoječega zaznamka je spodletel",
    "Failed to create bookmark" : "Ustvarjanje zaznamka je spodletelo",
    "Failed to save bookmark" : "Shranjevanje zaznamka je spodletelo",
    "Failed to move bookmark" : "Premikanje zaznamka je spodletelo",
    "Failed to copy bookmark" : "Kopiranje zaznamka je spodletelo",
    "Failed to delete bookmark" : "Brisanje zaznamka je spodletelo",
    "Failed to rename tag" : "Preimenovanje oznake je spodletelo",
    "Failed to load tags" : "Nalaganje oznak je spodletelo",
    "Failed to load folders" : "Nalaganje map je spodletelo",
    "Failed to delete folder" : "Brisanje mape je spodletelo",
    "Failed to create folder" : "Ustvarjanje mape je spodletelo",
    "Failed to move parts of selection" : "Premikanje delov izbire je spodletelo",
    "Failed to delete parts of selection" : "Brisanje dela izbora je spodletelo",
    "Failed to fetch bookmarks." : "Pridobivanje zaznamkov je spodletelo",
    "Failed to load setting {key}" : "Nalaganje ključa nastavitve {key} je spodletelo",
    "Failed to update share {shareId}" : "Posodabljanje {shareId} je spodletelo",
    "Failed to delete share {shareId}" : "Brisanje {shareId} je spodletelo",
    "Create bookmarks for mentioned links" : "Ustvari zaznamke za omenjene povezave",
    "No links found in this message" : "V tem sporočilu ni povezav",
    "Bookmarks feed" : "Vir zaznamkov"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
