"use strict";(self.webpackChunkbookmarks=self.webpackChunkbookmarks||[]).push([["node_modules_nextcloud_dialogs_dist_chunks_index-BMbtc3xh_mjs"],{83731(e,s,d){d.d(s,{FilePickerVue:()=>_});const _=(0,d(85471).$V)(()=>Promise.all([d.e("vendors-node_modules_nextcloud_files_dist_index_mjs-node_modules_nextcloud_vue_dist_Component-c57add"),d.e("vendors-node_modules_nextcloud_dialogs_dist_chunks_FilePicker-JKNLPCbR_mjs")]).then(d.bind(d,11202)))}}]);
//# sourceMappingURL=bookmarks-node_modules_nextcloud_dialogs_dist_chunks_index-BMbtc3xh_mjs.js.map?v=89a0f1aa1666fdc781ab