OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Zakładki",
    "You bookmarked \"%s\"" : "Dodałeś do zakładek \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s dodał do zakładek \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Ktoś dodał do zakładek \"%s\"",
    "You deleted \"%s\"" : "Usunąłeś \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s usunął \"%2$s\"",
    "Someone deleted \"%s\"" : "Ktoś usunął \"%s\"",
    "You created folder \"%s\"" : "Utworzyłeś katalog \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s utworzył katalog \"%2$s\"",
    "Someone created folder \"%s\"" : "Ktoś utworzył katalog \"%s\"",
    "You moved folder \"%s\"" : "Przeniosłeś katalog \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s przeniósł katalog \"%2$s\"",
    "Someone moved folder \"%s\"" : "Ktoś przeniósł katalog \"%s\"",
    "You deleted folder \"%s\"" : "Usunąłeś katalog \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s usunął katalog \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Ktoś usunął katalog \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Udostępniasz katalog \"%1$s\" dla %2$s",
    "You shared folder \"%s\" with someone" : "Udostępniasz komuś katalog \"%s\"",
    "%1$s shared folder \"%2$s\" with you" : "%1$s udostępnia Tobie katalog \"%2$s\"",
    "Someone shared folder \"%s\" with you" : "Ktoś udostępnia Tobie katalog \"%s\"",
    "You unshared folder \"%1$s\" with %2$s" : "Zatrzymałeś udostępnianie katalogu \"%1$s\" dla %2$s",
    "You unshared folder \"%s\" with someone" : "Zatrzymałeś komuś udostępnianie katalogu \"%s\"",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s zatrzymał Tobie udostępnianie katalogu \"%2$s\"",
    "Someone unshared folder \"%s\" with you" : "Ktoś zatrzymał Tobie udostępnianie katalogu \"%s\"",
    "No file provided for import" : "Brak pliku do importu",
    "Failed to upload file" : "Nie udało się wysłać pliku",
    "Unsupported file type for import: " : "Nieobsługiwany typ pliku do importu:",
    "Bookmarks shared by %s" : "Zakładki udostępnione przez %s",
    "Frequent bookmarks" : "Częste zakładki",
    "Recent bookmarks" : "Najnowsze zakładki",
    "Bookmark" : "Zakładka",
    "Bookmark deleted" : "Usunięto zakładkę",
    "Bookmark created" : "Utworzono zakładkę",
    "Bookmark moved" : "Przeniesiono zakładkę",
    "Bookmark updated" : "Zaktualizowano zakładkę",
    "Create bookmark" : "Utwórz zakładkę",
    "Takes a link and adds it to your collection of bookmarks." : "Pobiera łącze i dodaje je do Twojej kolekcji zakładek.",
    "Bookmarks Backups" : "Kopie zapasowe zakładek",
    "Collect and manage bookmarks, synced with all your devices" : "Zbieraj i zarządzaj zakładkami, synchronizowanymi na wszystkich Twoich urządzeniach",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📁 Sortuj zakładki w foldery\n- 🏷 Dodawaj tagi i osobiste notatki\n- ☠ Znajduj uszkodzone i zduplikowane linki\n- 📲 Synchronizuj ze wszystkimi przeglądarkami i urządzeniami\n- 📔 Przechowuj zarchiwizowane wersje linków na wypadek ich usunięcia\n- 🔍 Pełnotekstowe wyszukiwanie w treści stron\n- 👪 Udostępniaj zakładki innym użytkownikom, grupom i zespołom lub za pomocą publicznych linków\n- ⚛ Generuj kanały RSS ze swoich kolekcji\n- 📈 Statystyki dotyczące częstotliwości otwierania linków\n- 🔒 Automatyczne kopie zapasowe kolekcji zakładek\n- 💼 Wbudowane widgety w Panelu do najczęściej używanych i ostatnio odwiedzanych linków\n\nWymagania: \n- rozszerzenia PHP: \n  - intl, *\n  - mbstring; *\n  - w przypadku używania MySQL, przynajmniej wersja 8.0",
    "Do you really want to delete this bookmark?" : "Czy na pewno chcesz usunąć zakładkę?",
    "Link copied to clipboard" : "Link skopiowany do schowka",
    "Enter new title" : "Wpisz nowy tytuł",
    "Select bookmark" : "Wybierz zakładkę",
    "You have never clicked this link" : "Nigdy nie kliknąłeś tego linku",
    "You have clicked this link {count} times" : "Kliknąłeś ten link {count} razy",
    "Details" : "Szczegóły",
    "Rename" : "Zmień nazwę",
    "Copy link" : "Kopiuj link",
    "Move" : "Przenieś",
    "Add to folders" : "Dodaj do katalogów",
    "Put bookmark into trash bin" : "Przenieś zakładkę do kosza",
    "Restore bookmark" : "Przywróć zakładkę",
    "Delete bookmark permanently" : "Usuń zakładkę na stałe",
    "Content pending" : "Zawartość oczekująca",
    "This content is being downloaded for offline use. Please check back later." : "Ta zawartość jest pobierana do użytku offline. Sprawdź później.",
    "Bookmarked {time} ago" : "Dodano do zakładek {time} temu",
    "Bookmarked on {date}" : "Dodano do zakładek {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "To są Twoje usunięte elementy. Zostaną trwale usunięte po dwóch miesiącach.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Zakładki do plików internetowych, takich jak zdjęcia lub pliki PDF, będą automatycznie zapisywane w Twoich plikach Nextcloud, dzięki czemu nadal będziesz mógł je znaleźć, nawet gdy link przejdzie w tryb offline.",
    "Searching in the current folder only." : "Wyszukiwanie tylko w bieżącym katalogu.",
    "Repeat search in all folders" : "Powtórz wyszukiwanie we wszystkich katalogach",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Linki do Zakładek są regularnie sprawdzane. Tutaj są wymienione te, do których nie można dotrzeć.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Możesz udostępniać katalogi zakładek innym osobom. Tutaj znajdują się wszystkie udostępnione Tobie katalogi.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Jedna zakładka może znajdować się jednocześnie w wielu katalogach. Aktualizacja spowoduje zaktualizowanie wszystkich kopii. Wszystkie zduplikowane zakładki są wymienione tutaj dla udogodnienia.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Wybrano katalogi {folders} i zakładki {bookmarks}",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Zaznaczono %n zakładkę","Zaznaczono %n zakładki","Zaznaczono %n zakładek","Zaznaczono %n zakładek"],
    "_Selected %n folder_::_Selected %n folders_" : ["Wybrano %n katalog","Wybrano %n katalogi","Wybrano %n katalogów","Wybrano %n katalogów"],
    "Do you really want to delete these items?" : "Czy na pewno chcesz usunąć elementy?",
    "Open all selected" : "Otwórz wszystkie wybrane",
    "Move selection" : "Przenieś wybrane",
    "Edit tags of selection" : "Edytuj etykiety wyboru",
    "Delete selection" : "Usuń wybrane",
    "Select all" : "Wybierz wszystko",
    "Cancel selection" : "Anuluj wybrane",
    "Sort by created date" : "Sortuj według daty utworzenia",
    "Sort by last modified" : "Sortuj według ostatniej modyfikacji",
    "Sort by title" : "Sortuj według tytułu",
    "Sort by click count" : "Sortuj według liczby kliknięć",
    "Sort by manual order" : "Sortuj według kolejności ustawionej",
    "Sort by URL" : "Sortuj według adresu URL",
    "RSS feed copied" : "Skopiowano kanał RSS",
    "Trash Bin" : "Kosz",
    "Go back" : "Wstecz",
    "Share folder" : "Udostępnij katalog",
    "Open folder details" : "Otwórz szczegóły folderu",
    "Select one or more tags" : "Wybierz jedną lub więcej etykiet",
    "New" : "Nowy",
    "New bookmark" : "Nowa zakładka",
    "New folder" : "Nowy katalog",
    "Change to grid view" : "Zmień na widok siatki",
    "Change to list view" : "Zmień na widok listy",
    "Copy RSS Feed of current view" : "Kopiuj kanał RSS bieżącego widoku",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Źródło RSS wymaga uwierzytelnienia za pomocą poświadczeń Nextcloud",
    "Search" : "Szukaj",
    "Empty trash bin" : "Opróżnij kosz",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Dodawanie %n zakładki do nowego katalogu","Dodawanie %n zakładek do nowego katalogu","Dodawanie %n zakładek do nowego katalogu","Dodawanie %n zakładek do nowego katalogu"],
    "Enter a link" : "Wpisz link",
    "Enter a title" : "Wpisz tytuł",
    "No bookmarks found" : "Nie znaleziono zakładek",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} katalogi i {bookmarks} zakładki",
    "_%n bookmark_::_%n bookmarks_" : ["%n zakładka","%n zakładki","%n zakładek","%n zakładek"],
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "Welcome to Bookmarks" : "Witamy w Zakładkach",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Aplikacja ta umożliwia zarządzanie linkami do ulubionych miejsc w sieci. Sortuj zakładki do katalogów, oznaczaj je etykietami i udostępniaj innym! Aplikacja będzie regularnie sprawdzać dostępność wszystkich Twoich linków i wyświetlać niedostępne linki. Jeśli dodasz link do pliku w Internecie, plik zostanie automatycznie pobrany do Twoich plików Nextcloud. Możesz także importować zakładki wyeksportowane z innych usług lub bezpośrednio synchronizować zakładki ze wszystkich przeglądarek za pomocą tej aplikacji.",
    "Add a bookmark" : "Dodaj zakładkę",
    "Import bookmarks" : "Importuj zakładki",
    "Sync with your browser" : "Zsynchronizuj z przeglądarką",
    "Do you really want to permanently delete this folder?" : "Czy na pewno chcesz trwale usunąć ten folder?",
    "Select folder" : "Wybierz katalog",
    "Enter folder title" : "Wpisz nazwę katalogu",
    "Shared by {user}" : "Udostępnione przez {user}",
    "Rename folder" : "Zmień nazwę katalogu",
    "Move folder" : "Przenieś katalog",
    "Put folder into trashbin" : "Przenieś folder do kosza",
    "Restore folder" : "Przywróć folder",
    "Delete folder permanently" : "Usuń folder na stałe",
    "Choose folder" : "Wybierz katalog",
    "Submit" : "Wyślij",
    "Cancel" : "Anuluj",
    "Deleting bookmarks" : "Usuwanie zakładek",
    "Deleting selection" : "Usuwanie zaznaczenia",
    "Importing bookmarks" : "Importowanie zakładek",
    "Moving selection" : "Przenoszenie zaznaczenia",
    "Adding selection to folders" : "Dodawanie zaznaczenia do katalogu",
    "Emptying trashbin" : "Opróżnianie kosza",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Przenoszenie %n katalogu i niektórych zakładek","Przenoszenie %n katalogów i niektórych zakładek","Przenoszenie %n katalogów i niektórych zakładek","Przenoszenie %n katalogów i niektórych zakładek"],
    "_Moving %n folder_::_Moving %n folders_" : ["Przenoszenie %n katalogu","Przenoszenie %n katalogów","Przenoszenie %n katalogów","Przenoszenie %n katalogów"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Przenoszenie %n zakładki","Przenoszenie %n zakładek","Przenoszenie %n zakładek","Przenoszenie %n zakładek"],
    "All bookmarks" : "Wszystkie zakładki",
    "Recent" : "Ostatnie",
    "Shared with you" : "Udostępnione Tobie",
    "Files" : "Pliki",
    "Duplicates" : "Duplikaty",
    "Broken links" : "Uszkodzone linki",
    "New tag" : "Nowa etykieta",
    "Search tags" : "Szukaj etykiet",
    "Delete" : "Usuń",
    "Untagged" : "Bez etykiety",
    "{used} bookmarks of {available} available" : "{used} zakładki z {available} dostępnych",
    "Bookmarks Settings" : "Ustawienia zakładek",
    "No bookmarked files" : "Brak plików zakładek",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Zakładki do plików, takich jak zdjęcia lub pliki PDF, zostaną automatycznie zapisane w Twoich plikach Nextcloud, więc możesz je nadal znaleźć, nawet gdy link przejdzie w tryb offline.",
    "Nothing found" : "Nic nie znaleziono",
    "Your search yielded no results in the current folder." : "Twoje wyszukiwanie nie przyniosło żadnych wyników w bieżącym katalogu.",
    "No broken links" : "Brak uszkodzonych linków",
    "No shared folders" : "Brak udostępnionych katalogów",
    "No duplicated bookmarks" : "Brak zduplikowanych zakładek",
    "No deleted bookmarks" : "Brak usuniętych zakładek",
    "You haven't deleted anything yet." : "Jeszcze nic nie usunąłeś.",
    "No bookmarks here" : "Brak zakładek",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Dodaj zakładki ręcznie lub zaimportuj zakładki z pliku HTML.",
    "Archive path" : "Ścieżka archiwum",
    "Backup path" : "Ścieżka do kopii zapasowej",
    "Please select \"Add to home screen\" in your browser menu" : "W menu przeglądarki wybierz opcję \"Dodaj do ekranu głównego\"",
    "Bookmarks settings" : "Ustawienia zakładek",
    "Import/Export" : "Import/Eksport",
    "Export bookmarks" : "Eksportuj zakładki",
    "Auto-archiving" : "Automatyczna archiwizacja",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Aplikacja zakładek może automatycznie archiwizować zawartość internetową odnośników, które dodałeś do zakładek",
    "Enable archiving" : "Włącz archiwizację",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Wprowadź ścieżkę katalogu do swoich Plików, w którym powinny być przechowywane pliki z zakładek.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Obecnie administrator wyłączył dostęp sieciowy dla tej aplikacji, dlatego automatyczne archiwizowanie jest w tej chwili wyłączone.",
    "Auto-Backup" : "Automatyczne tworzenie kopii zapasowych",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Aplikacja zakładek może codziennie automatycznie tworzyć kopie zapasowe zakładek, aby zapobiec utracie danych podczas synchronizowania zakładek na różnych urządzeniach.",
    "Enable backups" : "Włącz kopie zapasowe",
    "Enter the path of a folder in your Files where backups will be stored." : "Wprowadź ścieżkę katalogu w swoich Plikach, w którym będą przechowywane kopie zapasowe.",
    "Context Chat integration" : "Integracja z Context Chat",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Aplikacja zakładek może automatycznie udostępniać tekstową zawartość stron internetowych, które dodasz do zakładek, w Context Chat, co pozwala zadawać pytania i uzyskiwać odpowiedzi na podstawie tej zawartości. Funkcja dostępna tylko wtedy, gdy włączone jest automatyczne archiwizowanie.",
    "Context chat is currently not installed, but is required for this feature." : "Context Chat nie jest obecnie zainstalowany, ale jest wymagany do tej funkcji.",
    "Enable Context Chat integration" : "Włącz integrację z Context Chat",
    "Client apps" : "Aplikacje klienckie",
    "Also check out the collection of client apps that integrate with this app: " : "Sprawdź także kolekcję aplikacji klienckich, które integrują się z tą aplikacją: ",
    "Install web app" : "Zainstaluj aplikację internetową",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Możesz dodać aplikację do ekranu głównego swojego urządzenia, aby szybko uzyskać dostęp do zakładek w telefonie. Jeżeli nie będziesz jej potrzebować, będziesz mógł ją łatwo usunąć z ekranu głównego.",
    "Install on home screen" : "Zainstaluj na ekranie głównym",
    "Bookmarklet" : "Skryptozakładka",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Aby szybko dodać stronę do zakładek, przeciągnij ją do zakładek przeglądarki i kliknij.",
    "Add to {instanceName}" : "Dodaj do {instanceName}",
    "Need help?" : "Potrzebujesz pomocy?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Jeśli masz problemy z tą aplikacją Zakładki lub masz pomysł, co można by ulepszyć, nie wahaj się kliknąć tutaj, aby się skontaktować.",
    "Support this project" : "Wesprzyj ten projekt",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Moja praca nad aplikacją Zakładki opiera się na dobrowolnym modelu subskrypcyjnym. Jeśli uważasz, że to co robię, ma wartość, będzie mi miło, jeśli wesprzesz moją pracę. Proszę również, rozważ zostawienie opinii o aplikacji w sklepie Nextcloud. Dziękuję 💙",
    "Created {time} ago" : "Utworzono {time} temu",
    "Created on {date}" : "Utworzono {date}",
    "(Empty title)" : "(Bez tytułu)",
    "Title" : "Tytuł",
    "Link" : "Link",
    "Untitled folder" : "Katalog bez tytułu",
    "Root folder" : "Katalog główny",
    "Tags" : "Etykiety",
    "Select tags and create new ones" : "Wybierz etykiety i utwórz nowe",
    "Notes" : "Notatki",
    "Notes for this bookmark …" : "Uwagi dotyczące tej zakładki…",
    "Archived file" : "Zarchiwizowany plik",
    "Open file" : "Otwórz plik",
    "Download file" : "Pobierz plik",
    "Open file location" : "Otwórz lokalizację pliku",
    "Link copied" : "Link skopiowany",
    "Owner" : "Właściciel",
    "Sharing" : "Udostępnianie",
    "Select a user or group" : "Wybierz użytkownika lub grupę",
    "Share link" : "Udostępnij link",
    "Reading allowed" : "Czytanie dozwolone",
    "Copy RSS feed" : "Kopiuj kanał RSS",
    "Delete link" : "Usuń link",
    "Create public link" : "Utwórz link publiczny",
    "Resharing allowed" : "Udostępnianie dalej dozwolone",
    "Editing allowed" : "Edytowanie dozwolone",
    "Allow editing" : "Zezwalaj na edytowanie",
    "Allow resharing" : "Zezwalaj na udostępnianie dalej",
    "Remove share" : "Usuń udostępnienie",
    "Leave a rating on the Nextcloud App Store" : "Zostaw ocenę w sklepie z aplikacjami Nextcloud",
    "Failed to save settings" : "Nie udało się zapisać ustawień",
    "Failed to load settings" : "Nie udało się wczytać ustawień",
    "Privacy" : "Prywatność",
    "The app will try to access web pages that you add to automatically add information about them." : "Aplikacja będzie próbować uzyskać dostęp do stron internetowych, które dodajesz, aby automatycznie pobrać o nich informacje.",
    "Enable accessing and collecting information from the web pages you add" : "Włącz dostęp, co umożliwi zbieranie informacji z dodawanych stron internetowych",
    "Performance" : "Wydajność",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "W przypadku instalacji z wieloma użytkownikami przydatne może być ograniczenie liczby zakładek na konto.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksymalna dozwolona liczba zakładek dla konta (0 dla braku limitu; domyślnie brak limitu)",
    "Previews" : "Podglądy",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Aby wyświetlić prawdziwe zrzuty ekranu zapisanych stron, aplikacja może korzystać z usług firm trzecich do generowania podglądów.",
    "Screeenly" : "Screenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Możesz zarejestrować się za darmo na screeenly.com lub skonfigurować własny serwer.",
    "Screeenly API URL" : "Adres URL API dla Screeenly",
    "Screeenly API key" : "Klucz API dla Screenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Klucz API ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Adres URL interfejsu API Webshot",
    "Generic screenshot API" : "Ogólny interfejs API zrzutów ekranu",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Zarejestruj się u dowolnego dostawcy API zrzutów ekranu i wpisz poniżej adres URL API. Użyj zmiennej {url} jako zastępnika adresu URL do zrzutu ekranu. API musi zwracać wyłącznie obraz bezpośrednio.",
    "Generic API URL" : "Ogólny URL API",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Po prostu zainstaluj Pagres CLI od Sindre Sorhusa na swoim serwerze, a Zakładki go wykryją. Nadal możesz dodać dodatkowe zmienne środowiskowe (ENV), które mają być przekazane do pagres, np. jak wskazano w zastępniku:",
    "Pageres ENV variables" : "Zmienne Pageres ENV",
    "This URL is already bookmarked! Overwrite?" : "Ten URL jest już w zakładkach! Nadpisać?",
    "Enter bookmark title" : "Wpisz tytuł zakładki",
    "Enter bookmark URL" : "Wpisz adres URL zakładki",
    "Folder" : "Katalog",
    "Root Folder" : "Katalog główny",
    "Save" : "Zapisz",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Dostęp do sieci jest domyślnie wyłączony. Przejdź do ustawień administratora aplikacji zakładek, aby umożliwić pobieranie podglądów i ikon favicon.",
    "What's new?" : "Co nowego?",
    "What" : "Co",
    "Failed to count unavailable bookmarks" : "Nie udało się zliczyć niedostępnych zakładek",
    "Failed to count archived bookmarks" : "Nie udało się zliczyć zarchiwizowanych zakładek",
    "Failed to count deleted bookmarks" : "Nie udało się policzyć usuniętych zakładek",
    "Failed to count duplicated bookmarks" : "Nie udało się zliczyć zduplikowanych zakładek",
    "Failed to count bookmarks" : "Nie udało się zliczyć zakładek",
    "Failed to load bookmark" : "Nie udało się załadować zakładki",
    "Failed to find existing bookmark" : "Nie udało się znaleźć istniejącej zakładki",
    "Failed to create bookmark" : "Nie udało się utworzyć zakładki",
    "Failed to save bookmark" : "Nie udało się zapisać zakładki",
    "Failed to move bookmark" : "Nie udało się przenieść zakładki",
    "Failed to copy bookmark" : "Nie udało się skopiować zakładki",
    "Failed to delete bookmark" : "Nie udało się usunąć zakładki",
    "Failed to restore bookmark" : "Nie udało się przywrócić zakładki",
    "Import successful" : "Zaimportowano pomyślnie",
    "Failed to rename tag" : "Nie można zmienić nazwy etykiety",
    "Failed to load tags" : "Nie udało się załadować etykiet",
    "Failed to load folders" : "Nie udało się załadować katalogów",
    "Failed to load deleted folders" : "Nie udało się załadować usuniętych folderów",
    "Failed to load deleted bookmarks" : "Nie udało się załadować usuniętych zakładek",
    "Failed to delete folder" : "Nie udało się usunąć katalogu",
    "Failed to move folder" : "Nie udało się przenieść folderu",
    "Failed to restore folder" : "Nie udało się przywrócić folderu",
    "Failed to create folder" : "Nie udało się utworzyć katalogu",
    "Failed to load children order" : "Nie udało się załadować kolejności elementów podrzędnych",
    "Failed to move parts of selection" : "Nie udało się przenieść wybranej części",
    "Failed to copy parts of selection" : "Nie udało się skopiować zaznaczonych części",
    "Failed to delete parts of selection" : "Nie udało się usunąć wybranej części",
    "Failed to tag parts of selection" : "Nie udało się oznaczyć zaznaczonych części",
    "Failed to fetch bookmarks." : "Nie udało się pobrać zakładek.",
    "Failed to store setting" : "Nie udało się zachować ustawienia",
    "Failed to load setting {key}" : "Nie udało się wczytać ustawienia {key}",
    "Failed to create share for folder {folderId}" : "Nie udało się udostępnić folderu {folderId}",
    "Failed to update share {shareId}" : "Nie udało się zaktualizować udostępnienia {shareId}",
    "Failed to delete share {shareId}" : "Nie udało się usunąć udostępnienia {shareId}",
    "Failed to create public link for folder {folderId}" : "Nie udało się utworzyć publicznego linku do folderu {folderId}",
    "Failed to delete public link for folder {folderId}" : "Nie udało się usunąć publicznego linku do folderu {folderId}",
    "Failed to permanently delete parts of trash bin" : "Nie udało się trwale usunąć części kosza",
    "Create bookmarks for mentioned links" : "Utwórz zakładki dla wspomnianych linków",
    "No links found in this message" : "Nie znaleziono linków w tej wiadomości",
    "Bookmarks feed" : "Kanał zakładek"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
