OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Laster-markak",
    "You bookmarked \"%s\"" : "\"%s\" laster-marka gorde duzu",
    "%1$s bookmarked \"%2$s\"" : "%1$s(e)k \"%2$s\" laster-marka gorde du",
    "Someone bookmarked \"%s\"" : "Norbaitek \"%s\" laster-marka gorde du",
    "You deleted \"%s\"" : "\"%s\" ezabatu duzu",
    "%1$s deleted \"%2$s\"" : "%1$s(e)k \"%2$s\" ezabatu du",
    "Someone deleted \"%s\"" : "Norbaitek \"%s\" ezabatu du",
    "You created folder \"%s\"" : "\"%s\" karpeta sortu duzu",
    "%1$s created folder \"%2$s\"" : "%1$s(e)k \"%2$s\" karpeta sortu du",
    "Someone created folder \"%s\"" : "Norbaitek \"%s\" karpeta sortu du",
    "You moved folder \"%s\"" : "\"%s\" karpeta eraman duzu",
    "%1$s moved folder \"%2$s\"" : "%1$s(e)k \"%2$s\" karpeta eraman du",
    "Someone moved folder \"%s\"" : "Norbaitek \"%s\" karpeta eraman du",
    "You deleted folder \"%s\"" : "\"%s\" karpeta ezabatu duzu",
    "%1$s deleted folder \"%2$s\"" : "%1$s(e)k \"%2$s\" karpeta ezabatu du",
    "Someone deleted folder \"%s\"" : "Norbaitek \"%s\" karpeta ezabatu du",
    "You shared folder \"%1$s\" with %2$s" : "\"%1$s\" karpeta %2$s(r)ekin partekatu duzu",
    "You shared folder \"%s\" with someone" : "\"%s\" karpeta norbaitekin partekatu duzu",
    "%1$s shared folder \"%2$s\" with you" : "%1$s(e)k \"%2$s\" karpeta zurekin partekatu du",
    "Someone shared folder \"%s\" with you" : "Norbaitek \"%s\" karpeta zurekin partekatu du",
    "You unshared folder \"%1$s\" with %2$s" : "\"%1$s\" karpeta %2$s(r)ekin partekatzeari utzi diozu",
    "You unshared folder \"%s\" with someone" : "\"%s\" karpeta norbaitekin partekatzeari utzi diozu",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s(e)k \"%2$s\" karpeta zurekin partekatzeari utzi dio",
    "Someone unshared folder \"%s\" with you" : "Norbaitek \"%s\" karpeta zurekin partekatzeari utzi dio",
    "No file provided for import" : "Ez da inportatzeko fitxategirik hornitu",
    "Failed to upload file" : "Fitxategia kargatzeak huts egin du",
    "Unsupported file type for import: " : "Inportatzeko fitxategi mota ez onartua:",
    "Bookmarks shared by %s" : "Laster-markak %s(r)engatik partekatuak",
    "Frequent bookmarks" : "Maiz erabilitako laster-markak",
    "Recent bookmarks" : "Azken laster-markak",
    "Bookmark" : "Laster-marka",
    "Bookmark deleted" : "Laster-marka ezabatu da",
    "Bookmark created" : "Laster-marka sortu da",
    "Bookmark moved" : "Laster-marka eraman da",
    "Bookmark updated" : "Laster-marka eguneratu da",
    "Create bookmark" : "Sortu laster-marka",
    "Takes a link and adds it to your collection of bookmarks." : "Esteka bat hartu eta laster-marken bildumara gehitzen du.",
    "Bookmarks Backups" : "Laster-markak babeskopiak",
    "Collect and manage bookmarks, synced with all your devices" : "Gorde eta kudeatu laster-markak, zure gailu guztietan sinkronizaturik",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Ordenatu laster-markak karpetetan\n- 🏷 Gehitu etiketak eta ohar pertsonalak\n- ☠ Aurkitu hautsitako estekak eta bikoiztuak\n- 📲 Zure arakatzaile eta gailu guztiekin sinkronizatu\n- 📔 Zure esteken artxibatutako bertsioak gordetzen ditu\n- 🔍 Testu osoko bilaketa gunearen edukietan\n- 👪 Partekatu laster-markak beste erabiltzaileekin, taldeekin edo esteka publikoen bidez\n- ⚛ Zure bildumako RSS iturriak sortu\n- 📈 Maiz sartzen zaren esteken estatistikek \n- 🔒 Zure laster-marken bildumaren babeskopia automatikoak\n- 💼 Ohiko esteketarako eta lotura berrietarako aginte-mahaiaren trepetak\n\nBaldintzak:\n- PHP luzapenak:\n- intl: *\n- mbstring: *\n- MySQL erabiltzen duzunean, erabili gutxienez v8.0",
    "Do you really want to delete this bookmark?" : "Ziur zaude laster-marka hau ezabatu nahi duzula?",
    "Link copied to clipboard" : "Arbelara kopiatutako esteka",
    "Enter new title" : "Sartu izenburu berria",
    "Select bookmark" : "Hautatu laster-marka",
    "You have never clicked this link" : "Ez duzu inoiz esteka hau sakatu",
    "You have clicked this link {count} times" : "Esteka hau {count}sakatu izan duzu ",
    "Details" : "Xehetasunak",
    "Rename" : "Berrizendatu",
    "Copy link" : "Kopiatu esteka",
    "Move" : "Mugitu",
    "Add to folders" : "Gehitu karpetetara",
    "Put bookmark into trash bin" : "Jarri laster-marka zakarrontzian",
    "Restore bookmark" : "Berrezarri laster-marka",
    "Delete bookmark permanently" : "Ezabatu laster-marka betiko",
    "Content pending" : "Edukia betetzeke",
    "This content is being downloaded for offline use. Please check back later." : "Eduki hau deskargatzen ari da, offline erabili ahal izateko. Begiratu beranduago.",
    "Bookmarked {time} ago" : "Duela {denbora} laster-marka jarri zen",
    "Bookmarked on {date}" : "{data}-n laster-marka jarria",
    "These are your deleted items. Items will be deleted permanently after two months." : "Hauek zure ezabaturiko elementuak dira. Bi hilabeteren ondoren betirako ezabatzen dira.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Webean dauden fitxategien laster-markak, argazkiak edo PDFak bezala, automatikoki gordeko dira zure Nextcloud fitxategietan, nahiz eta orria lineaz kanpo egon aurki ditzazun.",
    "Searching in the current folder only." : "Uneko karpetan soilik bilatzen.",
    "Repeat search in all folders" : "Errepikatu bilaketa karpeta guztietan",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Laster-markatutako estekak aldizka egiaztatzen dira eta atzitu ezin direnak hemen zerrendatzen dira.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Besteekin laster-marken karpetak parteka ditzakezu. Zurekin partekatutako karpeta guztiak hemen zerrendatzen dira.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Laster-marka bat hainbat karpetatan egon daiteke aldi berean. Eguneratzen baduzu, kopia guztiak eguneratuko dira. Bikoiztutako laster-marka guztiak hemen zerrendatzen dira, zure erosotasunerako.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Hautaturiko {folders} karpetak eta {bookmarks} laster-markak",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Laster-marka %n hautatuta","%n laster-marka hautatuta"],
    "_Selected %n folder_::_Selected %n folders_" : ["Karpeta %n hautatuta","%n karpeta hautatuta"],
    "Do you really want to delete these items?" : "Ziur zaude elementu hauek ezabatu nahi dituzula?",
    "Open all selected" : "Ireki hautatutako guztiak",
    "Move selection" : "Mugitu hautapena",
    "Edit tags of selection" : "Editatu hautaturiko etiketak",
    "Delete selection" : "Ezabatu hautapena",
    "Select all" : "Hautatu denak",
    "Cancel selection" : "Utzi hautapena",
    "Sort by created date" : "Ordenatu sortze-dataren arabera",
    "Sort by last modified" : "Ordenatu azken aldaketaren arabera",
    "Sort by title" : "Ordenatu izenburuaren arabera",
    "Sort by click count" : "Ordenatu klik kopuruaren arabera ",
    "Sort by manual order" : "Ordenatu eskuz",
    "Sort by URL" : "Ordenatu URLaren arabera",
    "RSS feed copied" : "RSS jarioa kopiatuta",
    "Trash Bin" : "Zakarrontzia",
    "Go back" : "Atzera",
    "Share folder" : "Partekatu karpeta",
    "Open folder details" : "Ireki karpetaren xehetasunak",
    "Select one or more tags" : "Hautatu etiketa bat edo gehiago",
    "New" : "Berria",
    "New bookmark" : "Laster-marka berria",
    "New folder" : "Karpeta berria",
    "Change to grid view" : "Aldatu sareta ikuspegira",
    "Change to list view" : "Aldatu zerrenda ikuspegira",
    "Copy RSS Feed of current view" : "Kopiatu uneko ikuspegiaren RSS jarioa",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RRSak zure Nexcloud kredentzialekin autentifikatzea eskatzen du ",
    "Search" : "Bilatu",
    "Empty trash bin" : "Hustu zakarrontzia",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Laster-marka %n gehitzen karpeta berrira","%n laster-marka gehitzen karpeta berrira"],
    "Enter a link" : "Sartu esteka",
    "Enter a title" : "Sartu izenburu bat",
    "No bookmarks found" : "Ez da laster-markarik aurkitu",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} karpetak eta {bookmarks} laster-markak",
    "_%n bookmark_::_%n bookmarks_" : ["Laster-marka %n","%n laster-marka"],
    "_%n folder_::_%n folders_" : ["karpeta %n","%n karpeta"],
    "Welcome to Bookmarks" : "Ongi etorri Laster-marketara",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Aplikazio honek sarean gogoko dituzun tokietarako estekak kudeatzeko aukera ematen dizu. Ordenatu zure laster-markak karpetetan, etiketatu eta partekatu besteekin! Aplikazioak aldian-aldian zure esteka guztiak egiaztatuko ditu erabilgarritasuna eta erabilgarri ez dauden estekak bistaratuko ditu. Webeko fitxategi bati esteka gehitzen badiozu, fitxategia automatikoki deskargatuko da zure Nextcloud Fitxategietara. Beste zerbitzu batzuetatik esportatutako laster-markak ere inporta ditzakezu edo zure arakatzaile guztietako laster-markak zuzenean sinkroniza ditzakezu aplikazio honekin.",
    "Add a bookmark" : "Gehitu laster-marka bat",
    "Import bookmarks" : "Inportatu laster-markak",
    "Sync with your browser" : "Sinkronizatu zure nabigatzailearekin",
    "Do you really want to permanently delete this folder?" : "Ziur zaude karpeta hau betiko ezabatu nahi duzula?",
    "Select folder" : "Hautatu karpeta",
    "Enter folder title" : "Sartu karpetaren izenburua",
    "Shared by {user}" : "{user}(e)k partekatua",
    "Rename folder" : "Berrizendatu karpeta",
    "Move folder" : "Lekuz aldatu karpeta",
    "Put folder into trashbin" : "Jarri karpeta zakarrontzian",
    "Restore folder" : "Berrezarri karpeta",
    "Delete folder permanently" : "Ezabatu karpeta betirako",
    "Choose folder" : "Aukeratu karpeta",
    "Submit" : "Bidali",
    "Cancel" : "Utzi",
    "Deleting bookmarks" : "Laster-markak ezabatzen",
    "Deleting selection" : "Hautapena ezabatzen",
    "Importing bookmarks" : "Laster-markak inportatzen",
    "Moving selection" : "Hautapena mugitzen",
    "Adding selection to folders" : "Hautapena karpetetara gehitzen",
    "Emptying trashbin" : "Zakarrontzia husten",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Karpeta %n eta laster-marka batzuk mugitzen","%n karpeta eta laster-marka batzuk mugitzen"],
    "_Moving %n folder_::_Moving %n folders_" : ["Karpeta %n mugitzen","%n karpeta mugitzen"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Laster-marka %n mugitzen","%n laster-marka mugitzen"],
    "All bookmarks" : "Laster-marka guztiak",
    "Recent" : "Azkenak",
    "Shared with you" : "Zurekin partekatuta",
    "Files" : "Fitxategiak",
    "Duplicates" : "Duplikatuak",
    "Broken links" : "Hautsitako estekak",
    "New tag" : "Etiketa berria",
    "Search tags" : "Bilatu etiketak",
    "Delete" : "Ezabatu",
    "Untagged" : "Etiketatu gabe",
    "{used} bookmarks of {available} available" : "{available} laster-marketatik {used} erabilita",
    "Bookmarks Settings" : "Laster-marken ezarpenak",
    "No bookmarked files" : "Ez dago laster-marka fitxategirik",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Laster-marka guztiak betiko kendu dira zure kontutik",
    "Nothing found" : "Ez da ezer aurkitu",
    "Your search yielded no results in the current folder." : "Zure bilaketak ez du emaitzarik eman uneko karpetan.",
    "No broken links" : "Ez dago esteka apurturik",
    "No shared folders" : "Ez dago partekatutako karpetarik",
    "No duplicated bookmarks" : "Ez dago bikoiztutako laster-markarik",
    "No deleted bookmarks" : "Ez dago ezabatutako laster-markarik",
    "You haven't deleted anything yet." : "Oraindik ez duzu ezer ezabatu.",
    "No bookmarks here" : "Ez dago laster-markarik hemen",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Gehitu laster-markak eskuz edo inportatu HTML fitxategi batetik.",
    "Archive path" : "Artxibatu bidea",
    "Backup path" : "Bebeskopia bide-izena",
    "Please select \"Add to home screen\" in your browser menu" : "Hautatu \"Gehitu hasierako pantailan\" nabigatzaileko menuan",
    "Bookmarks settings" : "Laster-marken ezarpenak",
    "Import/Export" : "Inportatu/Esportatu",
    "Export bookmarks" : "Esportatu laster-markak",
    "Auto-archiving" : "Artxibo automatikoa",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Laster-markak aplikazioak automatikoki gorde ditzake laster-markak dituzun esteken web-edukia",
    "Enable archiving" : "Gaitu gordetzea",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Sartu zure Files-en dagoen karpeta baten bide-izena laster-markatutako fitxategiak biltzeko.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Une honetan zure administratzaileak aplikazio honen sarerako sarbidea desgaitu du, horregatik artxibo automatikoa desgaituta dago momentu honetan.",
    "Auto-Backup" : "Babeskopia automatikoa",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Laster-markak aplikazioak zure laster-marken babeskopia egin dezake egunero, datuak galtzea saihesteko, gailuen artean laster-markak sinkronizatzean.",
    "Enable backups" : "Gaitu babeskopiak",
    "Enter the path of a folder in your Files where backups will be stored." : "Sartu babeskopiak gordeko diren karpeta baterako bide-izena zure Files-en.",
    "Client apps" : "Bezero-aplikazioak",
    "Also check out the collection of client apps that integrate with this app: " : "Ikuskatu, baita, aplikazio honekin integratuta dagoen bezero aplikazioen bilduma",
    "Install web app" : "Instalatu web aplikazioa",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Aplikazio hau gailuko hasierako pantailan instalatu dezakezu telefonoan laster-markak azkar sartzeko. Erraz ken dezakezu aplikazioa hasierako pantailatik, gustatzen ez bazaizu.",
    "Install on home screen" : "Instalatu hasierako pantailan",
    "Bookmarklet" : "Applet-marka",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Arrastatu hau zure nabigatzaileko laster-marken gunera eta egin klik  webgune baten laster-marka azkar-azkar egiteko.",
    "Add to {instanceName}" : "Gehitu {instanceName} instantziari",
    "Need help?" : "Laguntza behar duzu?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Bookmarks aplikazio honekin arazoak badituzu edo hobetu daitekeenari buruzko ideiarik baduzu, ez izan zalantzarik eta jarri harremanetan hemen klik eginez.",
    "Support this project" : "Proiektu hau babestu",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Bookmarks aplikazio honetan nire lana borondatezko harpidetza-eredu batek elikatzen du. Egiten dudanak merezi duela uste baduzu, pozik egongo nintzateke nire lana babestuko bazenu. Horretaz gain, saiatu aplikazioari berrikuspena ematea Nextcloud aplikazio dendan. Eskerrik asko 💙",
    "Created {time} ago" : "Duela {time} sortua",
    "Created on {date}" : "Sortze-data {date}",
    "(Empty title)" : "(Izenburu hutsa)",
    "Title" : "Izenburua",
    "Link" : "Esteka",
    "Untitled folder" : "Izen gabeko karpeta",
    "Root folder" : "Erro-karpeta",
    "Tags" : "Etiketak",
    "Select tags and create new ones" : "Hautatu etiketak eta sortu berriak",
    "Notes" : "Oharrak",
    "Notes for this bookmark …" : "Laster-marka honentzako oharrak...",
    "Archived file" : "Artxibatutako fitxategia",
    "Open file" : "Ireki fitxategia",
    "Download file" : "Deskargatu fitxategia",
    "Open file location" : "Ireki fitxategiaren kokalekua",
    "Link copied" : "Esteka kopiatu da",
    "Owner" : "Jabea",
    "Sharing" : "Partekatzea",
    "Select a user or group" : "Hautatu erabiltzaile edo taldea",
    "Share link" : "Partekatu esteka",
    "Reading allowed" : "Irakurketa baimenduta",
    "Copy RSS feed" : "Kopiatu RSS jarioa",
    "Delete link" : "Ezabatu esteka",
    "Create public link" : "Sortu esteka publikoa",
    "Resharing allowed" : "Birpartekatzea onartuta",
    "Editing allowed" : "Edizioa baimenduta",
    "Allow editing" : "Baimendu editatzea",
    "Allow resharing" : "Baimendu birpartekatzea",
    "Remove share" : "Kendu partekatzea",
    "Leave a rating on the Nextcloud App Store" : "Eman balorazio bat Nextcloud Aplikazioen Biltegian",
    "Failed to save settings" : "Ezarpenak gordetzeak huts egin du",
    "Failed to load settings" : "Ezarpenak kargatzeak huts egin du",
    "Privacy" : "Pribatutasuna",
    "The app will try to access web pages that you add to automatically add information about them." : "Zuk gehitzen dituzun web orriak atzitzen saiatuko da aplikazioa, automatikoki beraiei buruzko informazioa gehitzeko.",
    "Enable accessing and collecting information from the web pages you add" : "Gaitu zuk gehitzen dituzun web orrietara sarbidea eta informazio bilketa",
    "Performance" : "Errendimendua",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Erabiltzaile asko dituen instalazio batean, erabilgarri izan daiteke muga jartzea kontu bakoitzak sor ditzakeen laster-marka kopuruari.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Kontu bakoitzeko onartutako laster-marka gehienezko kopurua. (0 mugarik gabe;  mugarik gabe lehenetsita)",
    "Previews" : "Aurrebistak",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Zuk gordetako web orrien pantaila-argazkiak erakusteko, aplikazioak hirugarrenen zerbitzuak erabil ditzake aurrebista sortzeko.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Doan erregistratu zaitezke screeenly.com webgunean edo zure zerbitzari propioa konfiguratu.",
    "Screeenly API URL" : "Screeenly APIaren URLa",
    "Screeenly API key" : "Screeenly APIaren gakoa",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API-aren gakoa",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot APIaren URLa",
    "Generic screenshot API" : "Pantaila-argazkiaren API orokorra",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Eman izena pantaila-argazkiarako API-hornitzaileren batekin eta jarri behean APIaren URLa. Erabili  {url} aldagaia pantaila-argazkiaren URLrako leku-marka gisa. APIak irudia bakarrik itzuli behar du zuzenean.",
    "Generic API URL" : "APIaren URL generikoa",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Instalatu Sindre Sorhus-en Pageres CLI zure zerbitzarian eta Laster-markak-ek aurkituko du. Oraindik ENV aldarazte gehigarriak gehi ditzakezu orrialdeetara elikatzeko, adibidez. leku-markak adierazten duen moduan:",
    "Pageres ENV variables" : "Pageres ENV aldagaiak",
    "This URL is already bookmarked! Overwrite?" : "URL hau dagoeneko laster-marketan dago. Gainidatzi nahi duzu?",
    "Enter bookmark title" : "Sartu laster-markaren izenburua",
    "Enter bookmark URL" : "Sartu laster-marka URL",
    "Folder" : "Karpeta",
    "Root Folder" : "Erro-karpeta",
    "Save" : "Gorde",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Sarerako sarbidea desgaituta dago lehenespenez. Joan laster-marken aplikazioko administratzailearen ezarpenetara baimentzeko aurrebistak eta gogoko-ikonoak eskuratzea.",
    "What's new?" : "Zer berri?",
    "What" : "Zer",
    "Failed to count unavailable bookmarks" : "Erabilgarri ez diren laster-marken kopuruak huts egin du",
    "Failed to count archived bookmarks" : "Artxibatutako laster-marken kopuruak huts egin du",
    "Failed to count duplicated bookmarks" : "Ezin izan dira bikoiztutako laster-markak zenbatu",
    "Failed to load bookmark" : "Laster-marka kargatzeak huts egin du",
    "Failed to find existing bookmark" : "Existitzen den laster-markaren bilaketak huts egin du",
    "Failed to create bookmark" : "Laster-markaren sorrerak huts egin du",
    "Failed to save bookmark" : "Laster-markaren gordeketak huts egin du",
    "Failed to move bookmark" : "Laster-marka mugitzeak huts egin du",
    "Failed to copy bookmark" : "Laster-marka kopiatzeak huts egin du",
    "Failed to delete bookmark" : "Laster-marka ezabatzeak huts egin du",
    "Import successful" : "Inportazioa ondo joan da",
    "Failed to rename tag" : " Etiketaren izena aldatzeak huts egin du",
    "Failed to load tags" : "Etiketak kargatzeak huts egin du",
    "Failed to load folders" : "Karpetak kargatzeak huts egin du",
    "Failed to load deleted folders" : "Ezabaturiko karpetak kargatzeak huts egin du",
    "Failed to load deleted bookmarks" : "Ezabatutako laster-markak kargatzeak huts egin du",
    "Failed to delete folder" : "Karpeta ezabatzeak huts egin du",
    "Failed to move folder" : "Karpeta mugitzeak huts egin du",
    "Failed to create folder" : "Karpeta sortzeak huts egin du",
    "Failed to move parts of selection" : "Hautaketaren zati batzuk mugitzeak huts egin du",
    "Failed to delete parts of selection" : "Hautaketaren zati batzuk ezabatzeak huts egin du",
    "Failed to fetch bookmarks." : "Laster-markak ekartzeak huts egin du.",
    "Failed to store setting" : "Ezin izan dira gorde ezarpenak",
    "Failed to load setting {key}" : "{key} ezarpena kargatzeak huts egin du",
    "Failed to update share {shareId}" : "{shareId} partekatzea eguneratzeak huts egin du",
    "Failed to delete share {shareId}" : "{shareId} partekatzea ezabatzeak huts egin du",
    "Create bookmarks for mentioned links" : "Sortu laster-markak aipatutako esteketarako",
    "No links found in this message" : "Ez da estekarik aurkitu mezu honetan",
    "Bookmarks feed" : "Laster-marken jarioa"
},
"nplurals=2; plural=(n != 1);");
