OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "북마크",
    "You bookmarked \"%s\"" : "\"%s\"을(를) 북마크에 추가함",
    "%1$s bookmarked \"%2$s\"" : "%1$s님이 \"%2$s\"을(를) 북마크에 추가함",
    "Someone bookmarked \"%s\"" : "누군가 \"%s\"을(를) 북마크에 추가함",
    "You deleted \"%s\"" : "\"%s\"을(를) 삭제함",
    "%1$s deleted \"%2$s\"" : "%1$s님이 \"%2$s\"을(를) 삭제함",
    "Someone deleted \"%s\"" : "누군가 \"%s\"을(를) 삭제함",
    "You created folder \"%s\"" : "폴더 \"%s\"을(를) 생성함",
    "%1$s created folder \"%2$s\"" : "%1$s님이 폴더 \"%2$s\"을(를) 생성함",
    "Someone created folder \"%s\"" : "누군가 폴더 \"%s\"을(를) 생성함",
    "You moved folder \"%s\"" : "폴더 \"%s\"을 이동함",
    "%1$s moved folder \"%2$s\"" : "%1$s님이 폴더 \"%2$s\"을(를) 이동함",
    "Someone moved folder \"%s\"" : "누군가 폴더 \"%s\"을(를) 이동함",
    "You deleted folder \"%s\"" : "폴더 \"%s\"을(를) 삭제함",
    "%1$s deleted folder \"%2$s\"" : "%1$s님이 폴더 \"%2$s\"을(를) 삭제함",
    "Someone deleted folder \"%s\"" : "누군가 폴더 \"%s\"을(를) 삭제함",
    "You shared folder \"%1$s\" with %2$s" : "폴더 \"%1$s\"을(를) %2$s와(과) 공유함",
    "You shared folder \"%s\" with someone" : "폴더 \"%s\"을(를) 누군가와 공유함",
    "%1$s shared folder \"%2$s\" with you" : "%1$s님이 폴더 \"%2$s\"을(를) 공유함",
    "Someone shared folder \"%s\" with you" : "누군가 폴더 \"%s\"을(를) 공유함",
    "You unshared folder \"%1$s\" with %2$s" : "폴더 \"%1$s\"에 대한 %2$s와(과)의 공유를 해체함",
    "You unshared folder \"%s\" with someone" : "폴더 \"%s\"에 대한 누군가와의 공유를 해제함",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s님이 폴더 \"%2$s\"에 대한 공유를 해제함",
    "Someone unshared folder \"%s\" with you" : "누군가 \"%s\"에 대한 공유를 해제함",
    "No file provided for import" : "가져올 파일을 지정하지 않았음",
    "Bookmarks shared by %s" : "%s님이 공유한 북마크 ",
    "Frequent bookmarks" : "자주 방문한 북마크",
    "Recent bookmarks" : "최근 북마크",
    "Bookmark" : "북마크",
    "Bookmark deleted" : "북마크가 삭제됨",
    "Bookmark created" : "북마크가 생성됨",
    "Bookmark moved" : "북마크가 이동함",
    "Bookmark updated" : "북마크가 갱신됨",
    "Create bookmark" : "북마크 생성",
    "Takes a link and adds it to your collection of bookmarks." : "링크를 북마크 목록에 추가하십시오.",
    "Bookmarks Backups" : "북마크 백업",
    "Collect and manage bookmarks, synced with all your devices" : "북마크를 수집하고 관리하며 모든 기기와 동기화됩니다.",
    "Do you really want to delete this bookmark?" : "이 북마크를 삭제하시겠습니까?",
    "Link copied to clipboard" : "링크가 클립보드로 복사됨",
    "Enter new title" : "새로운 제목 입력",
    "Select bookmark" : "북마크 선택",
    "You have never clicked this link" : "이 링크를 클릭한 적이 없음",
    "You have clicked this link {count} times" : "이 링크를 {count}번 클릭함",
    "Details" : "자세한 정보",
    "Rename" : "이름 바꾸기",
    "Copy link" : "링크 복사",
    "Move" : "이동",
    "Add to folders" : "폴더에 추가",
    "Put bookmark into trash bin" : "북마크를 휴지통으로 이동",
    "Restore bookmark" : "북마크 복원",
    "Delete bookmark permanently" : "북마크를 영구적으로 삭제",
    "Content pending" : "콘텐츠 보류 중",
    "This content is being downloaded for offline use. Please check back later." : "이 콘텐츠는 오프라인 사용을 위해 다운로드 중입니다. 나중에 다시 확인해 주세요.",
    "Bookmarked {time} ago" : "{time} 전에 북마크에 추가됨",
    "Bookmarked on {date}" : "{date}에 북마크됨",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "사진이나 PDF와 같은 웹상의 파일에 대한 북마크는 자동으로 Nextcloud 파일에 저장되므로 링크가 오프라인이 되어도 해당 파일을 계속 찾을 수 있습니다.",
    "Searching in the current folder only." : "현재 폴더에서만 검색합니다.",
    "Repeat search in all folders" : "모든 폴더에서 검색 반복",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "북마크된 링크는 정기적으로 확인되며 접속할 수 없는 링크는 여기에 나열됩니다.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "북마크 폴더를 다른 사람과 공유할 수 있습니다. 나와 공유된 모든 폴더가 여기에 나열됩니다.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "하나의 북마크는 동시에 여러 폴더에 있을 수 있습니다. 업데이트하면 모든 사본이 업데이트됩니다. 편의를 위해 모든 중복된 북마크가 여기에 나열됩니다.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "선택한 {folders} 폴더 및 {bookmarks} 북마크",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["선택된 %n 북마크들"],
    "_Selected %n folder_::_Selected %n folders_" : ["선택된 %n 폴더들"],
    "Do you really want to delete these items?" : "이 항목들을 정말로 삭제하시겠습니까?",
    "Open all selected" : "선택한 항목 모두 열기",
    "Move selection" : "선택 항목 이동",
    "Edit tags of selection" : "선택 항목의 태그 편집",
    "Delete selection" : "선택 항목 삭제",
    "Select all" : "Select all",
    "Cancel selection" : "선택 항목 취소",
    "Sort by created date" : "만들어진 순서로 정렬",
    "Sort by last modified" : "최종 수정순으로 정렬",
    "Sort by title" : "제목순으로 정렬",
    "Sort by click count" : "클릭수를 기준으로 정렬",
    "Sort by manual order" : "수동 기준으로 정렬",
    "Sort by URL" : "URL로 정렬",
    "RSS feed copied" : "RSS 피드가 복사됨",
    "Trash Bin" : "휴지통",
    "Go back" : "뒤로 가기",
    "Share folder" : "폴더 공유",
    "Select one or more tags" : "하나 이상의 태그를 선택",
    "New" : "새로 만들기",
    "New bookmark" : "새로운 북마크",
    "New folder" : "새 폴더",
    "Change to grid view" : "바둑판식 보기로 변경",
    "Change to list view" : "목록 보기로 변경",
    "Copy RSS Feed of current view" : "현재 보기의 RSS 피드 복사",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS 피드에는 Nextcloud 자격 증명을 사용한 인증이 필요합니다.",
    "Search" : "검색",
    "Empty trash bin" : "휴지통 비우기",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["새로운 폴더에 %n북마크 추가"],
    "Enter a link" : "링크를 입력하시오.",
    "Enter a title" : "제목 입력",
    "No bookmarks found" : "북마크를 찾을 수 없음",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} 폴더 및 {bookmarks} 북마크",
    "_%n bookmark_::_%n bookmarks_" : ["%n북마크"],
    "_%n folder_::_%n folders_" : ["폴더 %n개"],
    "Welcome to Bookmarks" : "북마크에 오신 것을 환영합니다",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "이 앱을 사용하면 웹에서 즐겨찾는 장소에 대한 링크를 관리할 수 있습니다. 북마크를 폴더로 분류하고, 태그로 라벨을 지정하고, 다른 사람들과 공유하세요! 앱은 정기적으로 모든 링크의 가용성을 확인하고 사용할 수 없는 링크를 표시합니다. 웹에서 파일에 대한 링크를 추가하면 파일이 자동으로 Nextcloud Files에 다운로드됩니다. 또한 이 앱을 사용하여 다른 서비스에서 내보낸 북마크를 가져오거나 모든 브라우저의 북마크를 직접 동기화할 수도 있습니다.",
    "Add a bookmark" : "북마크 추가",
    "Import bookmarks" : "북마크 불러오기",
    "Sync with your browser" : "브라우저와 동기화",
    "Do you really want to permanently delete this folder?" : "정말로 이 폴더를 영구적으로 삭제하시겠습니까?",
    "Select folder" : "폴더 선택",
    "Enter folder title" : "폴더명을 입력하시오.",
    "Shared by {user}" : "{user}가 공유한",
    "Rename folder" : "폴더 이름 바꾸기",
    "Move folder" : "폴더 이동",
    "Put folder into trashbin" : "폴더를 휴지통에 넣기",
    "Restore folder" : "폴더 복원",
    "Delete folder permanently" : "폴더를 영구적으로 삭제",
    "Choose folder" : "폴더 선택",
    "Submit" : "제출",
    "Cancel" : "취소",
    "Deleting bookmarks" : "북마크 삭제",
    "Deleting selection" : "선택 항목 삭제",
    "Importing bookmarks" : "북마크 불러오기 ",
    "Moving selection" : "선택 항목 이동",
    "Adding selection to folders" : "폴더에 선택 항목 추가",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n폴더와 일부 북마크 이동"],
    "_Moving %n folder_::_Moving %n folders_" : ["%n폴더 이동"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n북마크 이동"],
    "All bookmarks" : "모든 북마크",
    "Recent" : "최근 항목",
    "Shared with you" : "나와 공유됨",
    "Files" : "파일",
    "Duplicates" : "사본",
    "Broken links" : "끊어진 링크",
    "New tag" : "새로운 태그",
    "Search tags" : "태그 검색",
    "Delete" : "삭제",
    "Untagged" : "태그 지우기",
    "{used} bookmarks of {available} available" : "{available}의 {used} 북마크 사용 가능",
    "No bookmarked files" : "북마크된 파일 없음",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "사진이나 PDF와 같은 파일에 대한 북마크는 자동으로 Nextcloud 파일에 저장되므로 링크가 오프라인이 되어도 해당 파일을 계속 찾을 수 있습니다.",
    "Nothing found" : "아무것도 찾을 수 없음",
    "Your search yielded no results in the current folder." : "현재 폴더에서 검색 결과가 없습니다.",
    "No broken links" : "끊어진 링크 없음",
    "No shared folders" : "공유된 폴더 없음",
    "No duplicated bookmarks" : "중복된 북마크 없음",
    "No deleted bookmarks" : "삭제된 북마크 없음",
    "You haven't deleted anything yet." : "아직 아무 것도 삭제하지 않았습니다!",
    "No bookmarks here" : "북마크가 없음",
    "Add bookmarks manually or import bookmarks from a HTML file." : "북마크를 수동으로 추가하거나 HTML 파일에서 북마크를 가져옵니다.",
    "Archive path" : "보관 경로",
    "Backup path" : "백업 경로",
    "Please select \"Add to home screen\" in your browser menu" : "브라우저 메뉴에서 \"홈 화면에 추가\"를 선택하세요.",
    "Bookmarks settings" : "북마크 설정",
    "Import/Export" : "불러오기/내보내기",
    "Export bookmarks" : "북마크 내보내기",
    "Auto-archiving" : "자동 보관",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "북마크 앱은 북마크한 링크의 웹 콘텐츠를 자동으로 보관할 수 있습니다.",
    "Enable archiving" : "보관 활성화",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "북마크된 파일을 저장할 폴더 경로를 입력하세요.",
    "Auto-Backup" : "자동 백업",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "북마크 앱은 북마크를 매일 자동으로 백업하여 여러 기기에서 북마크를 동기화할 때 데이터 손실을 방지할 수 있습니다.",
    "Enable backups" : "백업 활성화",
    "Enter the path of a folder in your Files where backups will be stored." : "백업이 저장될 파일의 ​​폴더 경로를 입력하세요.",
    "Client apps" : "클라이언트 앱",
    "Also check out the collection of client apps that integrate with this app: " : "또한 이 앱과 통합되는 클라이언트 앱 컬렉션도 확인하세요:",
    "Install web app" : "웹 앱 설치",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "기기 홈 화면에 이 앱을 설치하면 휴대전화의 북마크에 빠르게 액세스할 수 있습니다. 마음에 들지 않으면 홈 화면에서 앱을 쉽게 제거할 수 있습니다.",
    "Install on home screen" : "홈 화면에 설치",
    "Bookmarklet" : "북마크릿",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "이것을 브라우저 북마크로 드래그하고 클릭하면 웹페이지를 빠르게 북마크할 수 있습니다.",
    "Add to {instanceName}" : "{instanceName}에 더하기",
    "Need help?" : "도움이 필요한가요?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "이 북마크 앱에 문제가 있거나 개선할 수 있는 사항에 대한 아이디어가 있는 경우 주저하지 말고 여기를 클릭하여 문의하세요.",
    "Support this project" : "이 프로젝트에 기여해주세요",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "이 북마크 앱에 대한 작업은 자발적인 구독 모델에 힘입어 이루어졌습니다. 해당 작업이 가치 있다고 생각하신다면, 서포트 해 주시면 기쁘겠습니다. 또한 Nextcloud 앱 스토어에서 앱에 대한 리뷰를 제공하는 것을 고려해 보세요. 감사합니다💙 ",
    "Created {time} ago" : "{time} 전에 생성됨",
    "Created on {date}" : "{date}에 생성됨",
    "(Empty title)" : "(빈 제목)",
    "Title" : "직위",
    "Link" : "링크",
    "Untitled folder" : "이름 없는 폴더",
    "Root folder" : "루트 폴더",
    "Tags" : "태그",
    "Select tags and create new ones" : "태그를 선택하고 새 태그를 만듭니다.",
    "Notes" : "Notes",
    "Notes for this bookmark …" : "이 북마크에 대한 참고 사항…",
    "Archived file" : "보관된 파일",
    "Open file" : "파일 열기",
    "Download file" : "파일 다운로드",
    "Open file location" : "파일 위치 열기",
    "Link copied" : "링크 복사됨",
    "Owner" : "Owner",
    "Sharing" : "공유",
    "Select a user or group" : "사용자 또는 그룹 선택",
    "Share link" : "링크 공유",
    "Reading allowed" : "읽기가 허용됨",
    "Copy RSS feed" : "RSS 피드 복사",
    "Delete link" : "링크 삭제",
    "Create public link" : "공개 링크 만들기",
    "Resharing allowed" : "재공유가 허용됨",
    "Editing allowed" : "수정 허용됨",
    "Allow editing" : "수정 허용",
    "Allow resharing" : "재공유 허용",
    "Remove share" : "공유 삭제",
    "Leave a rating on the Nextcloud App Store" : "Nextcloud App Store에 평가를 남겨주세요",
    "Failed to save settings" : "환경설정 저장 실패",
    "Failed to load settings" : "환경설정 로딩 실패",
    "Privacy" : "프라이버시",
    "The app will try to access web pages that you add to automatically add information about them." : "앱은 귀하가 추가한 웹 페이지에 대한 정보를 자동으로 추가하기 위해 액세스를 시도합니다.",
    "Enable accessing and collecting information from the web pages you add" : "추가한 웹페이지에서 정보에 액세스하고 수집할 수 있습니다.",
    "Performance" : "성능",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "계정이 대량으로 존재할 경우 계정 당 최대 북마크 수를 제한하는 것이 좋습니다.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "계정 당 최대 북마크 수 (0을 입력할 시 무제한이며 이는 기본값입니다.)",
    "Previews" : "미리 보기",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "북마크된 웹사이트의 실제 스크린샷을 표시하기 위해 앱은 제 3자의 서비스를 사용하여 미리보기를 생성할 수 있습니다.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "screeenly.com에서 무료로 가입하거나 자체 서버를 설정할 수 있습니다.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API 키",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API 키",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Generic screenshot API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "스크린샷 API 제공업체에 가입하고 아래에 API URL을 입력하세요. 스크린샷을 찍을 URL의 자리 표시자로 {url} 변수를 사용하세요. API는 이미지만 직접 반환해야 합니다.",
    "Generic API URL" : "Generic API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "서버에 Sindre Sorhus의 Pageres CLI를 설치하기만 하면 북마크가 이를 찾아줍니다. Pageres에 공급할 추가 ENV 변수를 계속 추가할 수 있습니다. 자리 표시자에 표시된 대로:",
    "Pageres ENV variables" : "Pageres ENV 변수",
    "This URL is already bookmarked! Overwrite?" : "이 URL이 북마크에 이미 추가되어 있습니다! 덮어쓰시겠습니까?",
    "Enter bookmark title" : "북마크 제목을 입력하시오.",
    "Enter bookmark URL" : "북마크 URL을 입력하시오.",
    "Folder" : "폴더",
    "Root Folder" : "최상위 폴더",
    "Save" : "저장",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "네트워크 액세스는 기본적으로 비활성화되어 있습니다. 미리보기 및 파비콘 가져오기를 허용하려면 북마크 앱의 관리자 설정으로 이동하세요.",
    "What's new?" : "새로운 항목",
    "What" : "무엇을",
    "Failed to count unavailable bookmarks" : "사용할 수 없는 북마크를 계산하지 못했습니다.",
    "Failed to count archived bookmarks" : "보관된 북마크 수를 계산하지 못했습니다.",
    "Failed to count duplicated bookmarks" : "중복된 북마크를 계산하지 못했습니다.",
    "Failed to load bookmark" : "북마크를 로드하지 못했습니다.",
    "Failed to find existing bookmark" : "기존 북마크를 찾지 못했습니다.",
    "Failed to create bookmark" : "북마크를 생성하지 못했습니다.",
    "Failed to save bookmark" : "북마크를 저장하지 못했습니다.",
    "Failed to move bookmark" : "북마크를 이동시키지 못했습니다.",
    "Failed to copy bookmark" : "북마크를 복사하지 못했습니다.",
    "Failed to delete bookmark" : "북마크를 삭제하지 못했습니다.",
    "Failed to rename tag" : "태그명을 재설정하지 못했습니다.",
    "Failed to load tags" : "태그 불러오기 실패",
    "Failed to load folders" : "폴더를 로드하지 못했습니다.",
    "Failed to load deleted folders" : "삭제된 폴더를 로드하지 못했습니다.",
    "Failed to load deleted bookmarks" : "삭제된 북마크를 로드하지 못했습니다.",
    "Failed to delete folder" : "폴더를 삭제하지 못했습니다",
    "Failed to move folder" : "폴더를 이동시키지 못했습니다",
    "Failed to create folder" : "폴더를 생성하지 못했습니다",
    "Failed to fetch bookmarks." : "북마크를 가져오지 못했습니다.",
    "Failed to store setting" : "설정을 저장하지 못했습니다.",
    "Failed to load setting {key}" : "{key} 설정을 로드하지 못했습니다.",
    "Failed to update share {shareId}" : "{shareId} 공유를 업데이트하지 못했습니다.",
    "Failed to delete share {shareId}" : "{shareId} 공유를 삭제하지 못했습니다.",
    "Create bookmarks for mentioned links" : "언급된 링크에 대한 북마크 만들기",
    "No links found in this message" : "이 메시지에는 링크가 없습니다",
    "Bookmarks feed" : "북마크 피드"
},
"nplurals=1; plural=0;");
