<?php
$TRANSLATIONS = array(
"Bookmarks" => "خەتكۈچلەر",
"Bookm." => "خەتكۈچ.",
"No file provided for import" => "ئەكىرىشكە ھېچقانداق ھۆججەت تەمىنلەنمىگەن",
"Unsupported file type for import" => "ئەكىرىشنى قوللىمايدىغان ھۆججەت تىپى",
"Error" => "خاتالىق",
"Tags" => "بەلگەلەر",
"Filter by tag" => "بەلگە بويىچە سۈز",
"Warning" => "ئاگاھلاندۇرۇش",
"Are you sure you want to remove this tag from every entry?" => "بۇ بەلگىنى ھەممە تۈرلەردىن راستىنلا چىقىرىۋېتەمسىز؟",
"Import error" => "ئەكىرىش خاتالىقى",
"Import completed successfully." => "ئەكىرىش مۇۋەپپەقىيەتلىك تاماملاندى.",
"Uploading..." => "يۈكلەۋاتىدۇ…",
"Add a bookmark" => "خەتكۈچتىن بىرنى قوش",
"The title of the page" => "بۇ بەتنىڭ ماۋزۇسى",
"The address of the page" => "بەتنىڭ ئادرېسى",
"Description of the page" => "بەتنىڭ چۈشەندۈرۈلۈشى",
"Save" => "ساقلا",
"Delete" => "ئۆچۈر",
"Edit" => "تەھرىر",
"Cancel" => "ۋاز كەچ",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "سىز تور بەتنى تېز سۈرئەتتە خەتكۈچكە قوشماقچى بولغاندا، بۇنى توركۆرگۈڭىزنىڭ خەتكۈچىگە سۆرەپ، ئۇنى چېكىڭ، ",
"Address" => "ئادرېس",
"You have no bookmarks" => "ھېچقانداق خەتكۈچىڭىز يوق",
"Bookmarklet" => "خەتكۈچ",
"Export & Import" => "ئەكىر ياكى چىقار",
"Export" => "چىقار",
"Import" => "ئەكىر"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
