OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Detalles",
    "Rename" : "Renombrar",
    "Copy link" : "Copiar liga",
    "Move" : "Mover",
    "Select all" : "Seleccionar todo",
    "Go back" : "Regresar",
    "New" : "Nuevo",
    "New folder" : "Carpeta nueva",
    "Search" : "Buscar",
    "Empty trash bin" : "Vaciar la papelera de reciclaje",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
    "Choose folder" : "Seleccioanr carpeta",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Recent" : "Reciente",
    "Shared with you" : "Compartido con usted",
    "Files" : "Archivos",
    "Delete" : "Borrar",
    "Bookmarklet" : "Marcador a código",
    "Need help?" : "¿Necesitas ayuda?",
    "Title" : "Título",
    "Link" : "Liga",
    "Tags" : "Etiquetas",
    "Notes" : "Notas",
    "Open file" : "Abrir archivo",
    "Download file" : "Descargar archivo",
    "Owner" : "Dueño",
    "Sharing" : "Compartiendo",
    "Share link" : "Compartir liga",
    "Allow editing" : "Permitir edición",
    "Allow resharing" : "Permitir volver a compartir",
    "Privacy" : "Privacidad",
    "Folder" : "Carpeta",
    "Save" : "Guardar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
