OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Boekmerke",
    "No file provided for import" : "Geen lêer verskaf om in te voer nie ",
    "Details" : "Besonderhede",
    "Rename" : "Hernoem",
    "Copy link" : "Kopieer skakel",
    "Move" : "Skuif",
    "Select all" : "Kies alle",
    "Go back" : "Gaan terug",
    "New" : "Nuut",
    "New folder" : "Nuwe vouer",
    "Search" : "Soek",
    "_%n folder_::_%n folders_" : ["%n gids","%n gidse"],
    "Add a bookmark" : "Voeg 'n boekmerk by",
    "Choose folder" : "Kies vouer",
    "Submit" : "Dien in",
    "Cancel" : "Kanselleer",
    "Recent" : "Onlangs",
    "Shared with you" : "Met u gedeel",
    "Files" : " Lêers",
    "Delete" : "Skrap",
    "Bookmarklet" : "Boekmerkie",
    "Need help?" : "Hulp nodig?",
    "Title" : "Titel",
    "Link" : "Skakel",
    "Tags" : "Merkers",
    "Notes" : "Notas",
    "Open file" : "Open lêer",
    "Download file" : "Laai lêer af",
    "Link copied" : "Skakel gekopieer",
    "Owner" : "Eienaar",
    "Share link" : "Deelskakel",
    "Allow editing" : "Laat redigering toe",
    "Privacy" : "Privaatheid",
    "Previews" : "Voorskoue",
    "This URL is already bookmarked! Overwrite?" : "'n Boekmerk van die URL bestaan reeds. Skryf oor?",
    "Folder" : "Vouer",
    "Save" : "Stoor"
},
"nplurals=2; plural=(n != 1);");
