<?php
$TRANSLATIONS = array(
"Bookmarks" => "Bókamerki",
"Bookm." => "Bókam.",
"No file provided for import" => "Engin skrá valin til innflutnings",
"Unsupported file type for import" => "Ekki er hægt að flytja inn þessa tegund af bókamerki",
"Some Error happened." => "Einhver villa varð.",
"Error" => "Villa",
"Tags" => "Merki",
"Filter by tag" => "Sía eftir merkjum",
"Are you sure you want to remove this bookmark?" => "Ertu viss um að þú viljir fjarlægja þetta bókamerki?",
"Warning" => "Aðvörun",
"Are you sure you want to remove this tag from every entry?" => "Ertu viss um að þú viljir fjarlægja þetta merki úr öllum færslum?",
"Import error" => "Innflutningsvilla",
"Import completed successfully." => "Tókst að flytja inn",
"Uploading..." => "Sendi inn ...",
"Add a bookmark" => "Bæta við bókamerki",
"This URL is already bookmarked! Overwrite?" => "Þessi slóð er þegar bókamerkt! Skrifa yfir?",
"The title of the page" => "Titill síðunnar",
"The address of the page" => "Slóð á síðuna",
"Description of the page" => "Lýsing á síðunni",
"Save" => "Vista",
"Delete" => "Eyða",
"Edit" => "Breyta",
"Cancel" => "Hætta við",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Dragðu þetta yfir í bókamerkin í vafranum þínu og smelltu, ef þú vilt bæta við bókamerki fyrir þessa vefsíðu á fljótlegan hátt:",
"Add to ownCloud" => "Bæta við í ownCloud",
"Address" => "Slóð",
"Filterable Tags" => "Síanlegt merki",
"You have no bookmarks" => "Þú ert ekki með nein bókamerki",
"You can also import a bookmark file" => "Þú getur einnig flutt inn bókamerkjaskrá",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Inn- og útflutningur",
"Export" => "Flytja út",
"Import" => "Flytja inn"
);
$PLURAL_FORMS = "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);";
