<?php
$TRANSLATIONS = array(
"Warning" => "चेतावनी ",
"Close" => "बंद करें ",
"Save" => "सहेजें",
"Cancel" => "रद्द करें ",
"Add" => "डाले",
"Settings" => "सेटिंग्स"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
