<?php
$TRANSLATIONS = array(
"Bookmarks" => "책갈피",
"Bookm." => "책갈피",
"No file provided for import" => "가져올 파일을 지정하지 않았음",
"Unsupported file type for import" => "가져올 수 없는 파일 형식임",
"Some Error happened." => "오류가 발생했습니다.",
"Error" => "오류",
"Tags" => "태그",
"Filter by tag" => "태그로 필터링",
"Are you sure you want to remove this bookmark?" => "이 책갈피를 삭제하시겠습니까?",
"Warning" => "경고",
"Are you sure you want to remove this tag from every entry?" => "모든 항목에서 이 태그를 삭제하시겠습니까?",
"Import error" => "가져오기 오류",
"Import completed successfully." => "성공적으로 가져왔습니다.",
"Uploading..." => "업로드 중...",
"Add a bookmark" => "책갈피 추가",
"This URL is already bookmarked! Overwrite?" => "이 URL이 이미 책갈피에 추가되어 있습니다! 덮어쓰시겠습니까?",
"The title of the page" => "페이지 제목",
"The address of the page" => "페이지 주소",
"Description of the page" => "페이지 설명",
"Save" => "저장",
"Delete" => "삭제",
"Edit" => "편집",
"Cancel" => "취소",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "웹 브라우저 책갈피 항목에 다음 링크를 끌어다 놓으면 나중에 볼 웹 페이지를 빠르게 구독할 때 사용할 수 있습니다:",
"Add to ownCloud" => "ownCloud에 추가",
"Address" => "주소",
"Filterable Tags" => "필터 가능한 태그",
"You have no bookmarks" => "책갈피가 없습니다",
"You can also import a bookmark file" => "책갈피 파일을 가져올 수 있습니다",
"Bookmarklet" => "북마크릿",
"Export & Import" => "내보내기 및 가져오기",
"Export" => "내보내기",
"Import" => "가져오기"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
