<?php
$TRANSLATIONS = array(
"Bookmarks" => "اشارات المرجعية",
"Bookm." => "مرجعيه.",
"No file provided for import" => "لم يتم اضافة ملف للتدخيل",
"Unsupported file type for import" => "نوعية الملف غير صالحه للاستيراد",
"Error" => "خطأ",
"Tags" => "فئاة",
"Filter by tag" => "تصفيه حسب الفئه",
"Warning" => "تحذير",
"Are you sure you want to remove this tag from every entry?" => "هل أنت متاكد أنك تريد حذف هذه الفئه من جميع المدخولات؟",
"Import error" => "لقد فشل الإستيراد",
"Import completed successfully." => "تم الاستيراد بنجاح",
"Uploading..." => "ترفيع...",
"Add a bookmark" => "أضف إشارة مرجعية",
"The title of the page" => "أسم هذه الصفحه",
"The address of the page" => "عنوان هذه الصفحه",
"Description of the page" => "وصف هذه الصفحه",
"Save" => "حفظ",
"Delete" => "حذف",
"Edit" => "تعديل",
"Cancel" => "الغاء",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "اسحب هذه الى قائمة المرجعيه في متصفحك, و اضغط عليه عندما تريد اضافة صفحه :",
"Add to ownCloud" => "أضف إلى سحابتك الخاصه \"أوون كلاود\"",
"Address" => "عنوان",
"You have no bookmarks" => "لا يوجد عندك صفحات مرجعيه",
"Bookmarklet" => "المرجعيه",
"Export & Import" => "تصدير و استيراد",
"Export" => "تصدير المعلومات",
"Import" => "استيراد"
);
$PLURAL_FORMS = "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;";
