<?php
$TRANSLATIONS = array(
"Bookmarks" => "ចំណាំ",
"Bookm." => "ចំណាំ",
"No file provided for import" => "គ្មានឯកសារ​ផ្តល់​អោយ​ ដើម្បី​នាំចូលទេ",
"Unsupported file type for import" => "ប្រភេទឯកសារមិនគាំទ្រ​ដើម្បីនាំយកចូល",
"Error" => "កំហុស",
"Tags" => "ស្លាក",
"Filter by tag" => "ច្រោះដោយស្លាក",
"Warning" => "បម្រាម",
"Are you sure you want to remove this tag from every entry?" => "តើអ្នក​ចង់​លុបស្លាកនេះពី​គ្រប់កន្លែង​​ទាំងអស់មែន?",
"Import error" => "ការនាំយកចូលមានបញ្ហា",
"Import completed successfully." => "ការនាំយកចូល គឺសម្រេចជោគជ័យ",
"Uploading..." => "កំពុងដាក់បញ្ចូល...",
"Add a bookmark" => "ដាក់​ចូលទៅបញ្ជីចំណាំ",
"The title of the page" => "ចំណងជើង​នៃទំព័រ",
"The address of the page" => "អាស័យដ្ឋាន​នៃទំព័រ",
"Description of the page" => "ការពណ៌នានៃទំព័រ",
"Save" => "រក្សាទុក",
"Delete" => "លុប",
"Edit" => "កែ",
"Cancel" => "លើកលែង",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "បើ​អ្នក​ចង់​ចំណាំ​គេហទំព័រ​ណាមួយយ៉ាង​ឆាប់​រហ័ស សូម​ទាញ​របស់​នេះ​ទៅ​ដាក់​នៅ​កន្លែង​ចំណាំ​របស់​កម្មវិធី​អ៊ីនធឺណិត ហើយ​ចុច​វា៖",
"Add to ownCloud" => "ដាក់ចូល ownCloud",
"Address" => "អាសយដ្ឋាន",
"You have no bookmarks" => "អ្នក​មិន​មាន​ចំណាំ​ទេ",
"Bookmarklet" => "បញ្ជីចំណាំ",
"Export & Import" => "នាំចេញ & នាំចូល",
"Export" => "នាំយកចេញ",
"Import" => "នាំយកចូល"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
