<?php
$TRANSLATIONS = array(
"Bookmarks" => "Marcadores",
"Bookm." => "Marcad.",
"No file provided for import" => "Nun s'especificó nengún ficheru pa importar",
"Unsupported file type for import" => "Tipu de ficheru non sofitáu pa importar",
"Some Error happened." => "Dalgún error asocedió",
"Error" => "Fallu",
"Tags" => "Etiquetes",
"Filter by tag" => "Filtriar por etiquetes",
"Are you sure you want to remove this bookmark?" => "¿De xuru quies desaniciar esti marcador?",
"Warning" => "Avisu",
"Are you sure you want to remove this tag from every entry?" => "¿De xuru que quies desaniciar esta etiqueta de toles entraes?",
"Import error" => "Fallu d'importación",
"Import completed successfully." => "Importacióncompletada correchamente",
"Uploading..." => "Xubiendo...",
"Add a bookmark" => "Amestar un marcador",
"This URL is already bookmarked! Overwrite?" => "¡Esta URL ya ta marcada! ¿Quies sobrescribila?",
"The title of the page" => "El títulu de la páxina",
"The address of the page" => "La direición de la páxina",
"Description of the page" => "Descripción de la páxina",
"Save" => "Guardar",
"Delete" => "Desaniciar",
"Edit" => "Editar",
"Cancel" => "Encaboxar",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Arrastra dende equí a los marcadores del to restolador web, y fai clic cuando quieras marcar una páxina web rápidamente:",
"Add to ownCloud" => "Amestar a ownCloud",
"Address" => "Direición",
"Filterable Tags" => "Etiquetes filtrables",
"You have no bookmarks" => "Nun tienes marcadores",
"You can also import a bookmark file" => "Tamién pues importar un ficheru de marcadores",
"Bookmarklet" => "Marcador de JavaScript",
"Export & Import" => "Importar y Esportar",
"Export" => "Esportar",
"Import" => "Importar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
