OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Järjehoidjad",
    "You bookmarked \"%s\"" : "Sina märkisid „%s“ järjehoidjaks",
    "%1$s bookmarked \"%2$s\"" : "%1$s märkis „%2$s“ järjehoidjaks",
    "Someone bookmarked \"%s\"" : "Keegi märkis „%s“ järjehoidjaks",
    "You deleted \"%s\"" : "Sa kustutasid „%s“",
    "%1$s deleted \"%2$s\"" : "%2$s kustutas %1$s",
    "Someone deleted \"%s\"" : "Keegi kustutas „%s“",
    "You created folder \"%s\"" : "Sa lõid kausta „%s“",
    "%1$s created folder \"%2$s\"" : "%1$s lõi kausta „%2$s“",
    "Someone created folder \"%s\"" : "Keegi lõi „%s“ kausta",
    "You moved folder \"%s\"" : "Sina teisaldasid „%s“ kausta",
    "%1$s moved folder \"%2$s\"" : "%1$s teisaldas „%2$s“ kausta",
    "Someone moved folder \"%s\"" : "Keegi teisaldas „%s“ kausta uude kohta",
    "You deleted folder \"%s\"" : "Sa kustutasid „%s“  kausta",
    "%1$s deleted folder \"%2$s\"" : "Kasutaja „%1$s“ kustutas „%2$s“ kausta",
    "Someone deleted folder \"%s\"" : "Keegi kustutas „%s“ kausta",
    "You shared folder \"%1$s\" with %2$s" : "Sa jagasid „%1$s“ järjehoidjat „%2$s“ kasutajaga",
    "You shared folder \"%s\" with someone" : "Sina jagasid „%s“ kausta kellegagi",
    "%1$s shared folder \"%2$s\" with you" : "%1$s jagas „%2$s“ kausta sinuga",
    "Someone shared folder \"%s\" with you" : "Keegi jagas „%s“ kausta sinuga",
    "You unshared folder \"%1$s\" with %2$s" : "Sina eemaldasid „%2$s“ kasutaja „%1$s“ kausta jagamisest",
    "You unshared folder \"%s\" with someone" : "Sina eemaldasid kellegi „%s“ kausta jagamisest",
    "%1$s unshared folder \"%2$s\" with you" : "„%1$s“ eemaldas sinult „%2$s“ kausta jagamise",
    "Someone unshared folder \"%s\" with you" : "Keedi lõpetas „%s“ kausta jagamise sinule",
    "No file provided for import" : "Sa pole sisestanud impordiks vajalikku faili",
    "Failed to upload file" : "Faili üleslaadimine ei õnnestunud",
    "Unsupported file type for import: " : "Failitüüp pole importimiseks toetatud:",
    "Bookmarks shared by %s" : "%s jagatud järjehoidjad",
    "Frequent bookmarks" : "Sagedased järjehoidjad",
    "Recent bookmarks" : "Hiljutised järjehoidjad",
    "Bookmark" : "Järjehoidja",
    "Bookmark deleted" : "Järjehoidja on kustutatud",
    "Bookmark created" : "Järjehoidja on loodud",
    "Bookmark moved" : "Järjehoidja on teisaldatud",
    "Bookmark updated" : "Järjehoidja on uuendatud",
    "Create bookmark" : "Lisa järjehoidja",
    "Takes a link and adds it to your collection of bookmarks." : "Võtab lingi ja lisab ta sinu järjehoidjate kogumikku.",
    "Bookmarks Backups" : "Järjehoidjate varukoopiad",
    "Collect and manage bookmarks, synced with all your devices" : "Kogu ja halda järjehoidjaid ning sünkroni neid oma kõikidesse seadmetesse",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Rühmita järjehoidjaid kaustadesse\n- 🏷 Lisa silte ja märkmeid\n- ☠ Leia mittetoimivaid linke ja topeltkirjeid\n- 📲 Sünkroniseeri oma kõikide brauserite ja nutiseadmete vahel\n- 📔 Kui lehed peaks veebist kaduma, siis saad ennetavalt säilitada nende arhiveeritud versioone\n- 🔍 Täistekstiotsing saidi sisust\n- 👪 Jaga järjehoidjaid teiste kasutajatega, gruppide ja tiimidega, aga ka avalike linkidena\n- ⚛ Koosta oma kogumikust RSS-uudisvoog\n- 📈 Linkide klõpsimise statistika\n- 🔒 Automaatsed varukoopiad järjehoidjate kogumikust\n- 💼 Sagedaste ja hiljutiste linkide vidin juhtpaneeli jaoks\n\nEeldused:\n - PHP lisamoodulid:\n   - intl: *\n   - mbstring: *\n - MySQL-i puhul peab versioon olema vähemalt 8.0",
    "Do you really want to delete this bookmark?" : "Oled sa kindel, et soovid selle järjehoidja kustutada?",
    "Link copied to clipboard" : "Link on lõikelauale kopeeritud",
    "Enter new title" : "Sisesta uus pealkiri",
    "Select bookmark" : "Vali järjehoidja",
    "You have never clicked this link" : "Sa pole seda linki mitte kunagi klõpsinud",
    "You have clicked this link {count} times" : "Sa oled seda linki klõpsinud {count} korda",
    "Details" : "Üksikasjad",
    "Rename" : "Muuda nime",
    "Copy link" : "Kopeeri link",
    "Move" : "Teisalda",
    "Add to folders" : "Lisa kaustade hulka",
    "Put bookmark into trash bin" : "Viska järjehoidja prügikasti",
    "Restore bookmark" : "Taasta järjehoidja",
    "Delete bookmark permanently" : "Kustuta järjehoidja jäädavalt",
    "Content pending" : "Sisu laadimine on ootel",
    "This content is being downloaded for offline use. Please check back later." : "See sisu on vallasrežiimis kasutamiseks veel allalaadimisel. Palun vaata mingi aja pärast uuesti.",
    "Bookmarked {time} ago" : "Lisatud {time} tagasi",
    "Bookmarked on {date}" : "Lisatud {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Need on sinu poolt kustutatud kirjed, mis lõplikult kustuvad kahe kuu pärast.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Järjehoidjad veebis leiduvatele failidele (nagu fotod või PDF-failid) salvestuvad automaatselt Nexctcloudi failirakendusse ja seega saad neid leida ka siis kui link pole enam leitav.",
    "Searching in the current folder only." : "Otsin vaid praeguses kaustas",
    "Repeat search in all folders" : "Korda otsinguid kõikides kaustades",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "See rakendus aeg-ajalt kontrollib järjehoidjate toimimist ning need, mis on kaotsis, saavad olema nähtavad siin.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Sa võid järjehoidjaid teistega jagada. Kõik jagatud kaustad on siin kirjas.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Üks järjehoidja võib korraga asuda mitmes kaustas ja tema uuendamine uuendab ka kõik koopiad. Topeltjärjehoidjad on siin kirjas vaid mugavuse mõttes.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valisid {folders} kausta ja {bookmarks} järjehoidjat",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valisid %n järjehoidja","Valisid %n järjehoidjat"],
    "_Selected %n folder_::_Selected %n folders_" : ["Valisid %n kausta","Valisid %n kausta"],
    "Do you really want to delete these items?" : "Oled sa kindel, et soovid valitud objektid kustutada?",
    "Open all selected" : "Ava kõik valitud",
    "Move selection" : "Teisalda valik",
    "Edit tags of selection" : "Muuda valiku silte",
    "Delete selection" : "Kustuta valik",
    "Select all" : "Vali kõik",
    "Cancel selection" : "Katkesta valimine",
    "Sort by created date" : "Järjesta loomise aja alusel",
    "Sort by last modified" : "Järjesta viimase muutmise aja alusel",
    "Sort by title" : "Järjesta pealkirja järgi",
    "Sort by click count" : "Järjesta klikkide alusel",
    "Sort by manual order" : "Järjesta sinu loodud viisil",
    "Sort by URL" : "Järjesta võrguaadressi alusel",
    "RSS feed copied" : "RSS-voog on kopeeritud",
    "Trash Bin" : "Prügikast",
    "Go back" : "Mine tagasi",
    "Share folder" : "Jaga kausta",
    "Open folder details" : "Ava kausta üksikasjad",
    "Select one or more tags" : "Vali üks või enam silti",
    "New" : "Uus",
    "New bookmark" : "Uus järjehoidja",
    "New folder" : "Uus kaust",
    "Change to grid view" : "Muuda ruudustikuvaateks",
    "Change to list view" : "Muuda loendivaateks",
    "Copy RSS Feed of current view" : "Kopeeri praegune vaade RSS-voona",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Selle uudisvoo kasutamine eeldab autentimist sinu tavalise Nexctloudi kasutajanime ja salasõnaga",
    "Search" : "Otsi",
    "Empty trash bin" : "Tühjenda prügikast",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Lisan %n järjehoidja uude kausta","Lisan %n järjehoidjat uude kausta"],
    "Enter a link" : "Sisesta link",
    "Enter a title" : "Sisesta pealkiri",
    "No bookmarks found" : "Järjehoidjaid ei leidu",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} kausta ja {bookmarks} järjehoidjat",
    "_%n bookmark_::_%n bookmarks_" : ["%n järjehoidja","%n järjehoidjat"],
    "_%n folder_::_%n folders_" : ["%n kaust","%n kausta"],
    "Welcome to Bookmarks" : "Tere tulemast kasutama järjehoidjate rakendust",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "See rakendus võimaldab sul hallata veebi lemmiklehtede linke. Rühmita linke kaustadesse, lisa silte ja jaga teistega! Aeg-ajalt rakendus kontrollib linkide toimimist ja annab sulle teida neist, mis ei toimi. Kui lisad lingi veebis asuvale failile, siis laaditakse fail alla ka sinu Nextcloudi failirakendusse. Loomulikult saad muudest rakendustest eksporditud järjehoidjaid importida ning kõiki järjehoidjaid sünkroonida ka sinu baruserite vahel.",
    "Add a bookmark" : "Lisa järjehoidja",
    "Import bookmarks" : "Impordi järjehoidjaid",
    "Sync with your browser" : "Sünkroniseeri oma veebibrauseriga",
    "Do you really want to permanently delete this folder?" : "Kas oled kindel, et tahad selle kausta jäädavalt kustutada?",
    "Select folder" : "Vali kaust",
    "Enter folder title" : "Sisesta kausta pealkiri",
    "Shared by {user}" : "Jagaja: {user}",
    "Rename folder" : "Muuda kausta nime",
    "Move folder" : "Teisalda kausta",
    "Put folder into trashbin" : "Viska kaust prügikasti",
    "Restore folder" : "Taasta kaust",
    "Delete folder permanently" : "Kustuta kaust jäädavalt",
    "Choose folder" : "Vali kaust",
    "Submit" : "Saada",
    "Cancel" : "Loobu",
    "Deleting bookmarks" : "Kustutan järjehoidjaid",
    "Deleting selection" : "Kustutan valikut",
    "Importing bookmarks" : "Impordin järjehoidjaid",
    "Moving selection" : "Teisaldan valikut",
    "Adding selection to folders" : "Lisan valikut kaustadesse",
    "Emptying trashbin" : "Tühjendan prügikasti",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Teisaldan %n kausta ja mõned järjehoidjad","Teisaldan %n kausta ja mõned järjehoidjad"],
    "_Moving %n folder_::_Moving %n folders_" : ["Teisaldan %n kausta","Teisaldan %n kausta"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Teisaldan %n järjehoidja","Teisaldan %n järjehoidjat"],
    "All bookmarks" : "Kõik järjehoidjad",
    "Recent" : "Hiljutised",
    "Frequently clicked" : "Sageli klõpsatud",
    "Shared with you" : "Sinuga jagatud",
    "Files" : "Failid",
    "Duplicates" : "Topeltjärjehoidjad",
    "Broken links" : "Katkised lingid",
    "New tag" : "Uus silt",
    "Search tags" : "Otsi silte",
    "Delete" : "Kustuta",
    "Untagged" : "Sildistamata",
    "{used} bookmarks of {available} available" : "Saadaval on {used} järjehoidjat {available}-st",
    "Bookmarks Settings" : "Järjehoidjate seadistused",
    "No bookmarked files" : "Järjehoidjaks märgitud faile pole",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Järjehoidjad failidele (nagu fotod või PDF-failid) salvestuvad automaatselt Nexctcloudi failirakendusse ja seega saad neid leida ka siis kui link pole enam leitav.",
    "Nothing found" : "Mitte midagi ei leidu",
    "Your search yielded no results in the current folder." : "Otsingul praeguses kaustas polnud tulemusi.",
    "No broken links" : "Katkisi linke pole",
    "No shared folders" : "Jagatud kaustu pole",
    "No duplicated bookmarks" : "Topeltjärjehoidjaid  pole",
    "No deleted bookmarks" : "Kustutatud järjehoidjaid pole",
    "You haven't deleted anything yet." : "Sa pole veel mitte midagi kustutanud.",
    "No bookmarks here" : "Siin ei leidu järjehoidjaid",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Lisa järjehoidjad käsitsi või impordi nad HTML-vormingus järjehoidjate failist.",
    "Archive path" : "Arhiivi asukoht",
    "Backup path" : "Varukoopia asukoht",
    "Please select \"Add to home screen\" in your browser menu" : "Palun vali oma veebibrauseri menüüst „Lisa avavaatesse“",
    "Bookmarks settings" : "Järjehoidjate seadistused",
    "Import/Export" : "Import/Eksport",
    "Export bookmarks" : "Ekspordi järjehoidjaid",
    "Auto-archiving" : "Automaatne arhiveerimine",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Järjehoidjate rakendus võib järjehoidjatena salvestatud linkide veebisisu automaatselt arhiveerida",
    "Enable archiving" : "Lülita arhiveerimine sisse",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Sisesta järjehoidjate salvestamiseks kaust failirakendusest",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Automaatne arhiveerimine hetkel ei toimi, sest peakasutaja on  keelanud ligipääsu võrgule.",
    "Auto-Backup" : "Automaatne varundus",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Järjehoidjate rakendus võib sinu järjehoidjad iga päev automaatselt varundada ja tagada andmete säilimise, kui erinevate nutiseadmete vahel sünkroniseerides tekib vigu.",
    "Enable backups" : "Lülita varundamine sisse",
    "Enter the path of a folder in your Files where backups will be stored." : "Sisesta varukoopia salvestamiseks kaust failirakendusest",
    "Context Chat integration" : "Kontekstuaalse vestluse lõiming",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Järjehoidjate rakendus oskab automaatselt teha sinu poolt kontekstuaalsesse vestlusesse järjehoidjana lisatud saitide tekstilise sisu kättesaadavaks. See võimaldab antud sisu kohta küsida ja saada vastuseid. Antud funktsionaalsus on kasutatav vaid siis, kui automaatne arhiveerimine on sisse lülitatud.",
    "Context chat is currently not installed, but is required for this feature." : "Kontekstuaalne vestlus on hetkel paigaldamata, aga antud funktsionaalsus eeldab seda.",
    "Enable Context Chat integration" : "Võta kontekstuaalse vestluse lõiming kasutusele",
    "Client apps" : "Klientraendused",
    "Also check out the collection of client apps that integrate with this app: " : "Vaata ka ülevaadet klientrakendustest, mis liidestuvad selle serverirakendusega:",
    "Install web app" : "Paigalda veebirakendus",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Kui tahad järjehoidjaid nutiseadmes mugavalt kasutada, siis võid selle rakenduse lisada seadme avalehele. Kui see sulle ei sobi, siis saad lingi eemaldada.",
    "Install on home screen" : "Lisa avavaatesse",
    "Bookmarklet" : "Käivitatava koodiga järjehoidja",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Kiireks järjehoidja lisamiseks lohista ta oma veebibrauserite järjehoidjate vaatesse ja klõpsa.",
    "Add to {instanceName}" : "Lisa {instanceName}-sse",
    "Need help?" : "Vajad abi?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Kui sul on probleeme selle järjehoidjate rakendusega või sul tekkis mõte, mida annaks parandada, siis klõpsi järgnevat linki ja kirjuta meile.",
    "Support this project" : "Toeta seda arendusprojekti",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Minu töö selle Järjehoidjate rakendusega põhineb vabatahtlikel tellimustel. Kui sulle meeldib, mida ma olem teinud, siis ma oleksin rõõmus, kui sa minu tööd oleksid nõus toetama. Lisaks palun koosta ka arvustus Nextcloudi rakendustepoes. Suur tänu 💙",
    "Created {time} ago" : "Loodud {time} tagasi",
    "Created on {date}" : "Loodud {date}",
    "(Empty title)" : "(Tühipealkiri)",
    "Title" : "Pealkiri",
    "Link" : "Link",
    "Untitled folder" : "Nimetu kaust",
    "Root folder" : "Juurkaust",
    "Tags" : "Sildid",
    "Select tags and create new ones" : "Vali silte või loo uusi silte",
    "Notes" : "Märkmed",
    "Notes for this bookmark …" : "Selle järjehoidja märkmed…",
    "Archived file" : "Arhiveeritud fail",
    "Open file" : "Ava fail",
    "Download file" : "Laadi fail alla",
    "Open file location" : "Ava faili asukoht",
    "Link copied" : "Link kopeeritud",
    "Owner" : "Omanik",
    "Sharing" : "Jagamine",
    "Select a user or group" : "Vali kasutaja või grupp",
    "Share link" : "Jaga linki",
    "Reading allowed" : "Lugemine on lubatud",
    "Copy RSS feed" : "Kopeeri uudisvoog",
    "Delete link" : "Kustuta link",
    "Create public link" : "Loo avalik link",
    "Resharing allowed" : "Edasijagamine on lubatud",
    "Editing allowed" : "Muutmine on lubatud",
    "Allow editing" : "Luba muutmine",
    "Allow resharing" : "Luba edasijagamine",
    "Remove share" : "Eemalda jagamine",
    "Would you like to support this project?" : "Kas sa sooviksid seda projekti toetada?",
    "Leave a rating on the Nextcloud App Store" : "Hinda meid Nextcloudi rakendustepoes",
    "Failed to save settings" : "Seadistuste salvestamine ei õnnestunud",
    "Failed to load settings" : "Seadistuste laadimine ei õnnestunud",
    "Privacy" : "Privaatsus",
    "The app will try to access web pages that you add to automatically add information about them." : "See rakendus proovib sinu lisatud veebilehti avada ning nende kohta automaatselt vajalikku teavet lisada.",
    "Enable accessing and collecting information from the web pages you add" : "Luba järjehoidja lisamisel täiendavate andmete küsimist ja kogumist vastavast veebisaidist",
    "Performance" : "Jõudlus",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Kui selles serveris on väga palju kasutajaid, siis võib olla vajalik piirata kasutajakohaste järjehoidjate arvu.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimaalne lubatud järjehoidjate arv kasutajakonto kohta (0 tähistab, et piirang puudub ja see on ka vaikimisi väärtus).",
    "Previews" : "Eelvaated",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Tagamaks, et järjehoidjaks lisatud veebisaitidest on tehtud õiged ekraanitõmmised, on sul võimalik kasutada kolmandate osapoolte teenuseid nende jäädvustamiseks.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Sa võid kas liitud screeenly.com teenuses või võtta kasutusele oma serveri",
    "Screeenly API URL" : "Screeenly API võrguaadress",
    "Screeenly API key" : "Screeenly API võti",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine'i API võti",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API võrguaadress",
    "Generic screenshot API" : "Üldine ekraanitõmmiste API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Liitu mõne ekraanitõmmiste teenusepakkujaga ja sisesta nende API võrguaadress siia. Ekraanitõmmise tegemisel kasuta võrguaadressis kohatäitjat „{url}“. API päring peab vastuseks andma vaid pildifaili.",
    "Generic API URL" : "Üldise ekraanitõmmiste API võrguaadress",
    "Pageres CLI" : "Pageresi CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Lihtsalt paigalda Sindre Sorhuse loodud Pageres CLI oma serverisse ja see Järjehoidjate rakendus leiab ta üles.  Lisaks saad pageresile keskkonnamuutujatena sisu ette anda, näiteks kohatäitjatena:",
    "Pageres ENV variables" : "Pageresi keskonnamuutujad",
    "This URL is already bookmarked! Overwrite?" : "See võrguaadress on juba lisatud järjehoidjaks! Kas uuendame andmeid?",
    "Enter bookmark title" : "Sisesta järjehoidja pealkiri",
    "Enter bookmark URL" : "Sisesta järjehoidja võrguaadress",
    "Folder" : "Kaust",
    "Root Folder" : "Juurkaust",
    "Save" : "Salvesta",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Ligipääs võrgule on vaikimisi keelatud. Kui sa seda vajad, et eelvaadete ja tunnuspiltide laadimine toimiks, siis ava haldusseadistused ja luba võrgu kasutamine.",
    "What's new?" : "Mida on uut?",
    "What" : "Mis",
    "Failed to count unavailable bookmarks" : "Ei õnnestunud lugeda kokku saadaval mitteolevaid järjehoidjaid",
    "Failed to count archived bookmarks" : "Ei õnnestunud lugeda kokku arhiveeritud järjehoidjaid",
    "Failed to count deleted bookmarks" : "Kustutatud järjehoidjate kokkulugemine ei õnnestunud",
    "Failed to count duplicated bookmarks" : "Ei õnnestunud lugeda kokku topeltjärjehoidjaid",
    "Failed to count bookmarks" : "Järjehoidjate loendamine ei õnnestunud",
    "Failed to load bookmark" : "Järjehoidja laadmine ei õnnestunud",
    "Failed to find existing bookmark" : "Olemasoleva järjehoidja leidmine ei õnnestunud",
    "Failed to create bookmark" : "Järjehoidja loomine ei õnnestunud",
    "Failed to save bookmark" : "Järjehoidja salvestamine ei õnnestunud",
    "Failed to move bookmark" : "Järjehoidja teisaldamine ei õnnestunud",
    "Failed to copy bookmark" : "Järjehoidjat ei õnnestunud kopeerida",
    "Failed to delete bookmark" : "Järjehoidja kustutamine ei õnnestunud",
    "Failed to restore bookmark" : "Järjehoidja taastamine ei õnnestunud",
    "Import successful" : "Importimine õnnestus",
    "Failed to rename tag" : "Ei õnnestunud muuta sildi teksti",
    "Failed to load tags" : "Siltide laadimine ei õnnestunud",
    "Failed to load folders" : "Kaustade laadimine ei õnnestunud",
    "Failed to load deleted folders" : "Ei õnnestunud laadida tühistatud kaustu",
    "Failed to load deleted bookmarks" : "Ei õnnestunud laadida kustutatud järjehoidjaid",
    "Failed to delete folder" : "Kausta kustutamine ei õnnestunud",
    "Failed to move folder" : "Kausta teisaldamine ei õnnestunud",
    "Failed to restore folder" : "Kausta taastamine ei õnnestunud",
    "Failed to create folder" : "Kausta loomine ei õnnestunud",
    "Failed to load children order" : "Järglasobjektide järjekorra laadimine ei õnnestunud",
    "Failed to move parts of selection" : "Osa valiku teisaldamine ei õnnestunud",
    "Failed to copy parts of selection" : "Osa valiku kopeerimine ei õnnestunud",
    "Failed to delete parts of selection" : "Osa valiku kustutamine ei õnnestunud",
    "Failed to tag parts of selection" : "Osale valikust siltide lisamine ei õnnestunud",
    "Failed to fetch bookmarks." : "Järjehoidjate laadimine ei õnnestunud",
    "Failed to store setting" : "Seadistust ei õnnestunud salvestada",
    "Failed to load setting {key}" : "„{key}“ seadistuse laadimine ei õnnestunud",
    "Failed to create share for folder {folderId}" : "{folderId} kausta jagamine ei õnnestunud",
    "Failed to update share {shareId}" : "„{shareId}“ jagamise uuendamine ei õnnestunud",
    "Failed to delete share {shareId}" : "„{shareId}“ jagamise kustutamine ei õnnestunud",
    "Failed to create public link for folder {folderId}" : "{folderId} kausta avaliku lingi loomine ei õnnestunud",
    "Failed to delete public link for folder {folderId}" : "{folderId} kausta avaliku lingi kustutamine ei õnnestunud",
    "Failed to permanently delete parts of trash bin" : "Osa prügikasti sisu jäädav kustutamine ei õnnestunud",
    "Create bookmarks for mentioned links" : "Lisa mainitud linkide kohta ka järjehoidjad",
    "No links found in this message" : "Selles sõnumis pole linke",
    "Bookmarks feed" : "Järjehoidjate rss-voog"
},
"nplurals=2; plural=(n != 1);");
