OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bókamerki",
    "You bookmarked \"%s\"" : "Þú bókamerktir \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s bókamerkti \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Einhver bókamerkti \"%s\"",
    "You deleted \"%s\"" : "Þú eyddir \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s eyddi \"%2$s\"",
    "Someone deleted \"%s\"" : "Einhver eyddi \"%s\"",
    "You created folder \"%s\"" : "Þú bjóst til möppuna \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s bjó til möppuna \"%2$s\"",
    "Someone created folder \"%s\"" : "Einhver bjó til möppuna \"%s\"",
    "You moved folder \"%s\"" : "Þú færðir möppuna \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s færði möppuna \"%2$s\"",
    "Someone moved folder \"%s\"" : "Einhver færði möppuna \"%s\"",
    "You deleted folder \"%s\"" : "Þú eyddir möppunni \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s eyddi möppunni \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Einhver eyddi möppunni \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Þú deildir möppunni \"%1$s\" með %2$s",
    "You shared folder \"%s\" with someone" : "Þú deildir möppunni \"%s\" með einhverjum",
    "%1$s shared folder \"%2$s\" with you" : "%1$s deildi möppunni \"%2$s\" með þér",
    "Someone shared folder \"%s\" with you" : "Einhver deildi möppunni \"%s\" með þér",
    "You unshared folder \"%1$s\" with %2$s" : "Þú hættir að deila möppunni \"%1$s\" með %2$s",
    "You unshared folder \"%s\" with someone" : "Þú hættir að deila möppunni \"%s\" með einhverjum",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s hætti að deila möppunni \"%2$s\" með þér",
    "Someone unshared folder \"%s\" with you" : "Einhver hætti að deila möppunni \"%s\" með þér",
    "No file provided for import" : "Engin skrá valin til innflutnings",
    "Failed to upload file" : "Mistókst að senda inn skrá",
    "Unsupported file type for import: " : "Ekki er hægt að flytja inn þessa skráartegund: ",
    "Bookmarks shared by %s" : "Bókamerki deilt af %s",
    "Frequent bookmarks" : "Algeng bókamerki",
    "Recent bookmarks" : "Nýleg bókamerki",
    "Bookmark" : "Bókamerki",
    "Bookmark deleted" : "Bókamerki eytt",
    "Bookmark created" : "Bókamerki búið til",
    "Bookmark moved" : "Bókamerki fært",
    "Bookmark updated" : "Bókamerki uppfært",
    "Create bookmark" : "Búa til bókamerki",
    "Takes a link and adds it to your collection of bookmarks." : "Tekur slóðir og bætir þeim í bókamerkin þín.",
    "Bookmarks Backups" : "Öryggisafrit bókamerkja",
    "Collect and manage bookmarks, synced with all your devices" : "Sýslaðu með og safnaðu bókamerkjum, samstillt við öll tækin þín",
    "Do you really want to delete this bookmark?" : "Viltu örugglega eyða þessu bókamerki?",
    "Link copied to clipboard" : "Tengill afritaður á klippispjald",
    "Enter new title" : "Settu inn nýjan titil",
    "Select bookmark" : "Veldu bókamerki",
    "You have never clicked this link" : "Þú hefur aldrei smellt á þennan tengil",
    "You have clicked this link {count} times" : "Þú hefur smellt á þennan tengil {count} sinnum",
    "Details" : "Nánar",
    "Rename" : "Endurnefna",
    "Copy link" : "Afrita tengil",
    "Move" : "Færa",
    "Add to folders" : "Bæta í möppur",
    "Put bookmark into trash bin" : "Setja bókamerki í ruslið",
    "Restore bookmark" : "Endurheimta bókamerki",
    "Delete bookmark permanently" : "Eyða bókamerki endanlega",
    "Content pending" : "Efni sem bíður",
    "This content is being downloaded for offline use. Please check back later." : "Verið er að sækja þetta efni til að geta notað það án nettengingar. Athugaðu aftur síðar.",
    "Bookmarked {time} ago" : "Sett í bókamerki fyrir {time} síðan",
    "Bookmarked on {date}" : "Sett í bókamerki {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Þetta eru eyddu atriðin þín, þeim verður eytt endanlega eftir tvo mánuði.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bókamerki á vefnum sem vísa á skrár eins og ljósmyndir eða PDF-skrár verða sjálfkrafa vistuð í Nextcloud-skrárnar þínar, þannig að þú getir samt fundið þær þó svo tengillinn verði ónettengdur.",
    "Searching in the current folder only." : "Leita einungis í þessari möppu.",
    "Repeat search in all folders" : "Endurtaka leit í öllum möppum",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bókamerktir tenglar eru yfirfarnir reglulega og þeir sem ekki tekst að rekja eru taldir upp hér.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Þú getur deilt bókamerkjamöppu með öðrum. Allar möppur sem deilt er með þér birtast hér.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Eitt bókamerki getur verið samtímis í mörgum möppum. Sé það uppfært uppfærast öll afrit þess. Öll tvítekin bókamerki eru talin upp hér til hagræðis.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valdi %n bókamerki","Valdi %n bókamerki"],
    "_Selected %n folder_::_Selected %n folders_" : ["Valin %n mappa","Valdar %n möppur"],
    "Do you really want to delete these items?" : "Ertu viss um að þú viljir eyða þessum atriðum?",
    "Open all selected" : "Opna allt valið",
    "Move selection" : "Færa valið",
    "Edit tags of selection" : "Breyta merkjum í vali",
    "Delete selection" : "Eyða vali",
    "Select all" : "Select all",
    "Cancel selection" : "Hætta við val",
    "Sort by created date" : "Sort by created date",
    "Sort by last modified" : "Raða eftir þegar var síðast breytt",
    "Sort by title" : "Raða eftir titli",
    "Sort by click count" : "Raða eftir fjölda smella",
    "Sort by manual order" : "Raða eftir handvirkri röð",
    "Sort by URL" : "Raða eftir slóð",
    "RSS feed copied" : "RSS-fréttastreymi afritað",
    "Trash Bin" : "Rusl",
    "Go back" : "Fara til baka",
    "Share folder" : "Deila möppu",
    "Open folder details" : "Opna nánari upplýsingar um möppu",
    "Select one or more tags" : "Veldu eitt eða fleiri merki",
    "New" : "Nýtt",
    "New bookmark" : "Nýtt bókamerki",
    "New folder" : "Ný mappa",
    "Change to grid view" : "Skipta í reitasýn",
    "Change to list view" : "Skipta í listasýn",
    "Copy RSS Feed of current view" : "Afrita RSS-fréttastreymi fyrirliggjandi sýnar",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-fréttastreymið krefst auðkenningar með Nextcloud-auðkennum þínum",
    "Search" : "Search",
    "Empty trash bin" : "Tæma ruslið",
    "Enter a link" : "Settu inn slóð",
    "Enter a title" : "Settu inn titil",
    "No bookmarks found" : "Engin bókamerki fundust",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} möppur og {bookmarks} bókamerki",
    "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
    "Welcome to Bookmarks" : "Velkomin í bókamerkin",
    "Add a bookmark" : "Bæta við bókamerki",
    "Import bookmarks" : "Flytja inn bókamerki",
    "Sync with your browser" : "Samstilltu við vafrann þinn",
    "Do you really want to permanently delete this folder?" : "Viltu eyða þessari möppu endanlega?",
    "Select folder" : "Veldu möppu",
    "Enter folder title" : "Settu inn heiti möppu",
    "Shared by {user}" : "Deilt af {user}",
    "Rename folder" : "Endurnefna möppu",
    "Move folder" : "Færa möppu",
    "Put folder into trashbin" : "Setja möppu í ruslið",
    "Restore folder" : "Endurheimta möppu",
    "Delete folder permanently" : "Eyða möppu endanlega",
    "Choose folder" : "Veldu möppu",
    "Submit" : "Senda inn",
    "Cancel" : "Hætta við",
    "Deleting bookmarks" : "Eyði bókamerkjum",
    "Deleting selection" : "Eyði vali",
    "Importing bookmarks" : "Flyt inn bókamerki",
    "Moving selection" : "Færi valið",
    "Adding selection to folders" : "Bæti vali í möppur",
    "Emptying trashbin" : "Tæmi ruslið",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Færi %n möppu og einhver bókamerki","Færi %n möppur og einhver bókamerki"],
    "_Moving %n folder_::_Moving %n folders_" : ["Færi %n möppu","Færi %n möppur"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Færi %n bókamerki","Færi %n bókamerki"],
    "All bookmarks" : "Öll bókamerki",
    "Recent" : "Nýlegt",
    "Shared with you" : "Deilt með þér",
    "Files" : "Skrár",
    "Duplicates" : "Tvítekningar",
    "Broken links" : "Rofnir tenglar",
    "New tag" : "Nýtt merki",
    "Search tags" : "Leita að merkjum",
    "Delete" : "Eyða",
    "Untagged" : "Ómerkt",
    "{used} bookmarks of {available} available" : "{used} bókamerki af {available} tiltækum",
    "Bookmarks Settings" : "Stillingar bókamerkja",
    "No bookmarked files" : "Engar bókamerktar skrár",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bókamerki á skrár eins og ljósmyndir eða PDF-skrár verða sjálfkrafa vistuð í Nextcloud-skrárnar þínar, þannig að þú getir samt fundið þær þó svo tengillinn verði ónettengdur.",
    "Nothing found" : "Ekkert fannst",
    "Your search yielded no results in the current folder." : "Engar niðurstöður fundust með leitt í þessari möppu.",
    "No broken links" : "Engir rofnir tenglar",
    "No shared folders" : "Engar samnýttar möppur",
    "No duplicated bookmarks" : "Engin tvítekin bókamerki",
    "No deleted bookmarks" : "Engin eydd bókamerki",
    "You haven't deleted anything yet." : "Þú hefur ekki eytt neinu ennþá.",
    "No bookmarks here" : "Engin bókamerki hér",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Bættu við bókamerkjum handvirkt eða flyttu inn bókamerki úr HTML-skrá.",
    "Archive path" : "Slóð á safn",
    "Backup path" : "Slóð á öryggisafrit",
    "Please select \"Add to home screen\" in your browser menu" : "Veldu \"Bæta á upphafsskjá\" í valmynd vafrans þíns",
    "Bookmarks settings" : "Stillingar bókamerkja",
    "Import/Export" : "Inn-/útflutningur",
    "Export bookmarks" : "Flytja út bókamerki",
    "Auto-archiving" : "Sjálfvirk söfnun í skrá",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Bókamerkjaforritið getur tekið sjálfvirkt afrit af vefefni tengla sem þú hefur bókamerkt",
    "Enable archiving" : "Virkja söfnun",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Settu inn slóðina að möppu í skránum þínum þar sem geyma ætti bókamerkin þín.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Kerfisstjórinn þinn hefur gert aðgang forritsins að netinu óvirkan, sem er ástæðan fyrir því að sjálfvirk söfnun í skrár er óvirk í augnablikinu.",
    "Auto-Backup" : "Sjálfvirkt öryggisafrit",
    "Enable backups" : "Virkja öryggisafritun",
    "Enter the path of a folder in your Files where backups will be stored." : "Settu inn slóðina að möppu í skránum þínum þar sem geyma ætti öryggisafritin þín.",
    "Client apps" : "Biðlaraforrit",
    "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
    "Install web app" : "Setja upp vefforritið",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Þú getur sett þetta forrit á upphafsskjá snjalltækisins þíns til að komast beint í bókamerkin þín. Einfalt er að fjarlægja forritið ef það hentar þér ekki.",
    "Install on home screen" : "Bæta við á upphafsskjá",
    "Bookmarklet" : "Bókamerklingur",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Dragðu þetta yfir í bókamerkin í vafranum þínu og smelltu, ef þú vilt bæta við bókamerki fyrir þessa vefsíðu á fljótlegan hátt.",
    "Add to {instanceName}" : "Bæta við {instanceName}",
    "Need help?" : "Þarftu hjálp?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Ef þú lendir í vandræðum með bókamerkjaforritið eða hefur hugmyndir um hvernig hægt væri að bæta það, skaltu ekki hika við að hafa samband með því að smella hér.",
    "Support this project" : "Styrkja þetta verkefni",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Vinnan við þetta bókamerkjaforrit er fjármögnuð með valfrjálsu áskriftarlíkani. Ef þér finnst þetta þess virði, væri ánægjulegt ef þú sæir þér fært að styrkja verkefnið. Eins gætirðu íhugað að gefa forritinu umsögn í Nextcloud-forritaversluninni. Takk kærlega 💙 ",
    "Created {time} ago" : "Búið til fyrir {time} síðan",
    "Created on {date}" : "Búið til {date}",
    "(Empty title)" : "(auður titill)",
    "Title" : "Titill",
    "Link" : "Tengill",
    "Untitled folder" : "Ónefnd mappa",
    "Root folder" : "Rótarmappa",
    "Tags" : "Merki",
    "Select tags and create new ones" : "Veldu merki og búðu til ný",
    "Notes" : "Minnispunktar",
    "Notes for this bookmark …" : "Minnispunktur á þetta bókamerki …",
    "Archived file" : "Skrá í safni",
    "Open file" : "Opna skrá",
    "Download file" : "Sækja skrá",
    "Open file location" : "Opna staðsetningu skráar",
    "Link copied" : "Tengill afritaður",
    "Owner" : "Eigandi",
    "Sharing" : "Deiling",
    "Select a user or group" : "Veldu notanda eða hóp",
    "Share link" : "Deila tengli",
    "Reading allowed" : "Lestur heimilaður",
    "Copy RSS feed" : "Afrita RSS-fréttastreymi",
    "Delete link" : "Eyða tengli",
    "Create public link" : "Búa til opinberan tengil",
    "Resharing allowed" : "Endurdeiling er leyfð",
    "Editing allowed" : "Breytingar leyfðar",
    "Allow editing" : "Leyfa breytingar",
    "Allow resharing" : "Leyfa endurdeilingu",
    "Remove share" : "Fjarlægja sameign",
    "Leave a rating on the Nextcloud App Store" : "Settu einkunn inn á síðu Nextcloud forritaverslunar",
    "Failed to save settings" : "Mistókst að vista stillingar",
    "Failed to load settings" : "Mistókst að hlaða inn stillingum",
    "Privacy" : "Gagnaleynd",
    "The app will try to access web pages that you add to automatically add information about them." : "Bókamerkjaforritið mun reyna að fá aðgang að þeim síðum sem þú bætir við til að sækja sjálfvirkt upplýsingar um þær.",
    "Enable accessing and collecting information from the web pages you add" : "Virkja aðgang og söfnun upplýsinga af vefsíðunum sem þú bætir við",
    "Performance" : "Afköst",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Á uppsetningum með mikinn fjölda notenda getur verið skynsamlegt að takmarka fjölda bókamerkja á hvern notandaaðgang.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Leyfður hámarksföldi bókamerkja á hvern notandaaðgang. (0 fyrir engin takmörk; það er sjálfgefið)",
    "Previews" : "Forskoðun",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Til þess að birta raunverulegar skjámyndir af þeim vefsíðum sem þú bókamerkir, getur forritið notað þjónustu utanaðkomandi aðila til að útbúa forskoðanir.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Þú getur annað hvort skráð þig ókeypis á  screeenly.com eða sett upp þinn eigin þjón.",
    "Screeenly API URL" : "Slóð á API-forritsviðmót Screenly",
    "Screeenly API key" : "Screeenly API-lykill",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "API-lykill ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "API-slóð Webshot",
    "Generic screenshot API" : "Almennt API-viðmót skjámynda",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Nýskráðu þig hjá einhverjum þjónustum sem bjóða API-viðmót fyrir skjámyndir og settu inn slóðina á API-viðmótið hér fyrir neðan. Notaðu breytuna {url} aem frátökumerki fyrir slóðina sem á að taka skjámynd af. API-viðmótið má bara skila myndinni beint.",
    "Generic API URL" : "Slóð á almennt API-viðmót",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Settu einfaldlega upp Pageres CLI frá Sindre Sorhus á netþjóninum þínum og bókamerkjaforritið mun finna það. Þú getur eftir sem áður fóðrað fleiri ENV-umhverfisbreytur til pageres, t.d. eins og dæmi er um í frátökutákninu:",
    "Pageres ENV variables" : "Pageres ENV umhverfisbreytur",
    "This URL is already bookmarked! Overwrite?" : "Þessi slóð er þegar bókamerkt! Skrifa yfir?",
    "Enter bookmark title" : "Settu inn titil á bókamerki",
    "Enter bookmark URL" : "Settu inn slóð á bókamerki",
    "Folder" : "Mappa",
    "Root Folder" : "Rótarmappa",
    "Save" : "Vista",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Aðgangur að netkerfi er sjálfgefið óvirkur. Farðu í kerfisstjórnunarstillingar bókamerkjaforritsins til að leyfa að sækja forskoðanir og auðkennistákn.",
    "What's new?" : "Hvað er nýtt á döfinni?",
    "What" : "Hvað",
    "Failed to count unavailable bookmarks" : "Mistókst að telja óaðgengileg bókamerki",
    "Failed to count archived bookmarks" : "Mistókst að telja bókamerki sem sett hafa verið í safn",
    "Failed to count duplicated bookmarks" : "Mistókst að telja tvítekin bókamerki",
    "Failed to load bookmark" : "Mistókst að hlaða inn bókamerki",
    "Failed to find existing bookmark" : "Mistókst að finna fyrirliggjandi bókamerki",
    "Failed to create bookmark" : "Mistókst að búa til bókamerki",
    "Failed to save bookmark" : "Mistókst að vista bókamerki",
    "Failed to move bookmark" : "Mistókst að færa bókamerki",
    "Failed to copy bookmark" : "Mistókst að afrita bókamerki",
    "Failed to delete bookmark" : "Mistókst að eyða bókamerki",
    "Import successful" : "Innflutningur tókst",
    "Failed to rename tag" : "Mistókst að endurnefna merki",
    "Failed to load tags" : "Mistókst að hlaða inn merkjum",
    "Failed to load folders" : "Mistókst að hlaða inn möppum",
    "Failed to load deleted folders" : "Mistókst að hlaða inn eyddum möppum",
    "Failed to load deleted bookmarks" : "Mistókst að hlaða inn eyddum bókamerkjum",
    "Failed to delete folder" : "Mistókst að eyða möppu",
    "Failed to move folder" : "Mistókst að færa möppu",
    "Failed to create folder" : "Mistókst að búa til möppu",
    "Failed to move parts of selection" : "Mistókst að færa hluta af völdu",
    "Failed to delete parts of selection" : "Mistókst að eyða hluta af völdu",
    "Failed to fetch bookmarks." : "Ekki tókst að sækja bókamerki.",
    "Failed to store setting" : "Mistókst að geyma stillingu",
    "Failed to load setting {key}" : "Mistókst að hlaða inn {key} stillingunni",
    "Failed to update share {shareId}" : "Mistókst að uppfæra sameignina {shareId}",
    "Failed to delete share {shareId}" : "Mistókst að eyða sameigninni {shareId}",
    "Create bookmarks for mentioned links" : "Búa til bókamerki fyrir tengla sem minnst er á",
    "No links found in this message" : "Engir tenglar fundust í þessum skilaboðum",
    "Bookmarks feed" : "Bókamerkjastreymi"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
