<?php
$TRANSLATIONS = array(
"Bookmarks" => "Bookmarks",
"Bookm." => "Bookm.",
"No file provided for import" => "No file provided for import",
"Unsupported file type for import" => "Unsupported file type for import",
"Some Error happened." => "Some Error happened.",
"Error" => "Error",
"Tags" => "Tags",
"Filter by tag" => "Filter by tag",
"Are you sure you want to remove this bookmark?" => "Are you sure you want to remove this bookmark?",
"Warning" => "Warning",
"Are you sure you want to remove this tag from every entry?" => "Are you sure you want to remove this tag from every entry?",
"Import error" => "Import error",
"Import completed successfully." => "Import completed successfully.",
"Uploading..." => "Uploading...",
"Add a bookmark" => "Add a bookmark",
"This URL is already bookmarked! Overwrite?" => "This URL is already bookmarked! Overwrite?",
"The title of the page" => "The title of the page",
"The address of the page" => "The address of the page",
"Description of the page" => "Description of the page",
"Save" => "Save",
"Delete" => "Delete",
"Edit" => "Edit",
"Cancel" => "Cancel",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:",
"Add to ownCloud" => "Add to ownCloud",
"Address" => "Address",
"Filterable Tags" => "Filterable Tags",
"You have no bookmarks" => "You have no bookmarks",
"You can also import a bookmark file" => "You can also import a bookmark file",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Export & Import",
"Export" => "Export",
"Import" => "Import"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
