<?php
$TRANSLATIONS = array(
"Save" => "Speichern",
"Delete" => "Löschen",
"Edit" => "Bearbeiten",
"Cancel" => "Abbrechen",
"Settings" => "Einstellungen",
"Import" => "Importieren"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
