<?php
$TRANSLATIONS = array(
"Bookmarks" => "Marcadores",
"Bookm." => "Marc.",
"No file provided for import" => "Não foi indicado qualquer ficheiro para importar",
"Unsupported file type for import" => "Tipo de ficheiro não suportado para importar",
"Some Error happened." => "Ocorreu algum tipo erro.",
"Error" => "Erro",
"Tags" => "Etiquetas",
"Filter by tag" => "Filtrar por etiqueta",
"Are you sure you want to remove this bookmark?" => "Tem a certeza que deseja remover este marcador?",
"Warning" => "Aviso",
"Are you sure you want to remove this tag from every entry?" => "Tem a certeza que deseja remover esta etiqueta de cada entrada?",
"Import error" => "Erro de importação",
"Import completed successfully." => "Importação bem sucedida.",
"Uploading..." => "A enviar...",
"Add a bookmark" => "Adicionar um marcador",
"This URL is already bookmarked! Overwrite?" => "Este URL já existe nos marcadores! Deseja Substituir?",
"The title of the page" => "O titulo da página",
"The address of the page" => "O endereço da página",
"Description of the page" => "Descrição da página",
"Save" => "Guardar",
"Delete" => "Eliminar",
"Edit" => "Editar",
"Cancel" => "Cancelar",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Arraste isto para os marcadores do seu navegador e clique nele quando quiser marcar uma página da Web rapidamente:",
"Add to ownCloud" => "Adicionar à ownCloud",
"Address" => "Endereço",
"Filterable Tags" => "Etiquetas Filtráveis",
"You have no bookmarks" => "Não tem marcadores",
"You can also import a bookmark file" => "Também pode importar um ficheiro de marcadores",
"Bookmarklet" => "Marcador de JavaScript",
"Export & Import" => "Exportar & Importar",
"Export" => "Exportar",
"Import" => "Importar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
