<?php
$TRANSLATIONS = array(
"Bookmarks" => "Favorits",
"Bookm." => "Fav.",
"No file provided for import" => "Cap de fichièr pas provesit per l'importacion",
"Unsupported file type for import" => "Tipe de fichièr pas pres en carga a l'importacion",
"Some Error happened." => "Una error s'es produsida.",
"Error" => "Error",
"Tags" => "Etiquetas",
"Filter by tag" => "Filtrar per etiqueta",
"Are you sure you want to remove this bookmark?" => "Sètz segur que volètz suprimir aqueste favorit ?",
"Warning" => "Atencion",
"Are you sure you want to remove this tag from every entry?" => "Sètz segur que volètz levar aquesta etiqueta de cada entrada ?",
"Import error" => "Error d'importacion",
"Import completed successfully." => "L'importacion s'es acabada amb succès.",
"Uploading..." => "Mandadís en cors…",
"Add a bookmark" => "Apondre un favorit",
"This URL is already bookmarked! Overwrite?" => "Aqueste URL es ja en favorit ! Lo reescriure ?",
"The title of the page" => "Lo títol de la pagina",
"The address of the page" => "L'adreça de la pagina",
"Description of the page" => "Descripcion de la pagina",
"Save" => "Salvar",
"Delete" => "Suprimir",
"Edit" => "Modificar",
"Cancel" => "Anullar",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Lisatz aquò dins los marcapaginas de vòstre navigador e clicatz dessús per apondre la pagina correnta a vòstres favorits :",
"Add to ownCloud" => "Apondre a ownCloud",
"Address" => "Adreça",
"Filterable Tags" => "Etiquetas filtrablas",
"You have no bookmarks" => "Avètz pas cap de favorit",
"You can also import a bookmark file" => "Tanben podètz importar un fichièr de favorits",
"Bookmarklet" => "Applisignet",
"Export & Import" => "Importar e exportar",
"Export" => "Exportar",
"Import" => "Importar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
