OC.L10N.register(
    "bookmarks",
    {
    "Details" : "ព័ត៌មាន​លម្អិត",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "Copy link" : "ចម្លងតំណ",
    "Move" : "Move",
    "New" : "ថ្មី",
    "New folder" : "ថត​ថ្មី",
    "Search" : "ស្វែងរក",
    "Rename folder" : "ប្ដូរ​ឈ្មោះ​ថត",
    "Cancel" : "បោះបង់",
    "Shared with you" : "Shared with you",
    "Files" : "ឯកសារ",
    "Delete" : "លុប",
    "Title" : "ចំណងជើង",
    "Link" : "Link",
    "Tags" : "ស្លាក",
    "Notes" : "កំណត់​ចំណាំ",
    "Owner" : "Owner",
    "Sharing" : "ការ​ចែក​រំលែក",
    "Share link" : "Share link",
    "Allow resharing" : "អនុញ្ញាត​ការ​ចែក​រំលែក​ម្ដង​ទៀត",
    "Folder" : "ថត",
    "Save" : "រក្សាទុក"
},
"nplurals=1; plural=0;");
