<?php

namespace Marcelklehr\LinkPreview\Exceptions;

/**
 * Class MalformedUrlException
 * @package Marcelklehr\LinkPreview\Exceptions
 * @codeCoverageIgnore
 */
class MalformedUrlException extends \Exception
{

}
