<?php
$TRANSLATIONS = array(
"Bookmarks" => "Nodau tudalen",
"Bookm." => "Nodtud.",
"No file provided for import" => "Dim ffeil i'w fewnforio",
"Unsupported file type for import" => "Dim cefnogaeth i fewnforio'r math hwn o ffeil",
"Error" => "Gwall",
"Tags" => "Tagiau",
"Filter by tag" => "Hidlo yn ôl tag",
"Warning" => "Rhybudd",
"Are you sure you want to remove this tag from every entry?" => "Ydych chi'n siwr eich bod am waredu'r tag hwn o bob cofnod?",
"Import error" => "Gwall mewnforio",
"Import completed successfully." => "Mewnforiwyd yn llwyddiannus.",
"Uploading..." => "Yn llwytho i fyny...",
"Add a bookmark" => "Ychwanegu nod tudalen",
"The title of the page" => "Teitl y dudalen",
"The address of the page" => "Cyfeiriad y dudalen",
"Description of the page" => "Disgrifiad o'r dudalen",
"Save" => "Cadw",
"Delete" => "Dileu",
"Edit" => "Golygu",
"Cancel" => "Diddymu",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Llusgwch hwn i nodau tudalen eich porwr a'i glicio pan fyddwch eisiau gosod nod tudalen gwe'n gyflym.",
"Address" => "Cyfeiriad",
"You have no bookmarks" => "Nid oes nodau tudalen gennych",
"Bookmarklet" => "Nod tudalen gweithredol",
"Export & Import" => "Allforio & Mewnforio",
"Export" => "Allforio",
"Import" => "Mewnforio"
);
$PLURAL_FORMS = "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;";
