<?php
$TRANSLATIONS = array(
"Bookmarks" => "Zaznamki",
"Bookm." => "Zaznam.",
"No file provided for import" => "Ni navedene datoteke za uvoz",
"Unsupported file type for import" => "Vrsta datoteke ni podprta za uvoz",
"Some Error happened." => "Prišlo je do napake.",
"Error" => "Napaka",
"Tags" => "Oznake",
"Filter by tag" => "Razvrsti po oznakah",
"Are you sure you want to remove this bookmark?" => "Ali ste prepričani, da želite izbrisati zaznamek?",
"Warning" => "Opozorilo",
"Are you sure you want to remove this tag from every entry?" => "Ali res želite odstraniti te oznake iz vsakega vnosa?",
"Import error" => "Napaka med uvozom",
"Import completed successfully." => "Uvoz je uspešno zaključen.",
"Uploading..." => "Poteka pošiljanje ...",
"Add a bookmark" => "Dodaj zaznamek",
"This URL is already bookmarked! Overwrite?" => "Spletni naslov je že dodan med zaznamke. Ali ga želite prepisati?",
"The title of the page" => "Naziv strani",
"The address of the page" => "Naslov strani",
"Description of the page" => "Opis strani",
"Save" => "Shrani",
"Delete" => "Izbriši",
"Edit" => "Uredi",
"Cancel" => "Prekliči",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Povlecite gumb med zaznamke in kliknite nanj, kadar želite obiskano spletno stran hitro dodati med svoje zaznamke:",
"Add to ownCloud" => "Dodaj v oblak ownCloud",
"Address" => "Naslov",
"Filterable Tags" => "Oznake, ki jih je mogoče filtrirati",
"You have no bookmarks" => "Ni shranjenih zaznamkov",
"You can also import a bookmark file" => "Uvoziti je mogoče tudi datoteko zaznamkov",
"Bookmarklet" => "Vstavek za zaznamke",
"Export & Import" => "Izvoz in uvoz",
"Export" => "Izvozi",
"Import" => "Uvozi"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";
