OC.L10N.register(
    "bookmarks",
    {
    "Rename" : "Namakan",
    "Move" : "Move",
    "New" : "Baru",
    "Search" : "Search",
    "Cancel" : "Batal",
    "Shared with you" : "Shared with you",
    "Files" : "Fail",
    "Delete" : "Padam",
    "Title" : "Judul",
    "Link" : "Link",
    "Notes" : "Nota",
    "Open file" : "Buka fail",
    "Owner" : "Owner",
    "Share link" : "Share link",
    "Folder" : "Folder",
    "Save" : "Simpan"
},
"nplurals=1; plural=0;");
