<?php
$TRANSLATIONS = array(
"Bookmarks" => "Marcadores",
"Failed to import one bookmark, because: " => "Falha ao exportar um marcador, porque:",
"Bookm." => "Marc.",
"No file provided for import" => "Arquivo para importação não fornecido",
"Unsupported file type for import" => "Arquivo para importação não suportado",
"Some Error happened." => "Algum Erro aconteceu.",
"Error" => "Erro",
"Tags" => "Tags",
"Filter by tag" => "Filtrar por tag",
"Are you sure you want to remove this bookmark?" => "Tem certeza que deseja remover este  marcador?",
"Warning" => "Aviso",
"Are you sure you want to remove this tag from every entry?" => "Tem certeza que deseja remover esta tag de todas as entradas?",
"Import error" => "Error ao Importar",
"Import completed successfully." => "Importação completada com sucesso",
"Uploading..." => "Enviando...",
"Add a bookmark" => "Adicionar um marcador",
"This URL is already bookmarked! Overwrite?" => "A URL já está marcada! Sobrescrever?",
"The title of the page" => "O título da página",
"The address of the page" => "O endereço da página",
"Description of the page" => "Descrição da página",
"Save" => "Salvar",
"Delete" => "Excluir",
"Edit" => "Editar",
"Cancel" => "Cancelar",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Arraste isso para os favoritos do seu navegador web e clique nele quando você quiser marcar/favoritar uma página rapidamente:",
"Add to ownCloud" => "Adicionar ao ownCloud",
"Address" => "Endereço",
"Filterable Tags" => "Etiquetas Filtráveis",
"You have no bookmarks" => "Você não tem marcadores",
"You can also import a bookmark file" => "Você pode também importar um arquivo de marcadores",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Exportar e Importar",
"Export" => "Exportar",
"Import" => "Importar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
