<?php
$TRANSLATIONS = array(
"Unsupported file type for import" => "ආයාත කරන ගොනුව රුචි නොවේ",
"Bookmarks" => "පිටු සළකුනු",
"Tags" => "ටැග",
"Filter by tag" => "ටැගය ආධාරයෙන් පෙරන්න",
"Edit bookmark" => "පිටු සළකුනු සකසන්න",
"Are you sure you want to remove this tag from every entry?" => "මෙම ටැගය සියළු ඇතුලත් කිරීමකින් ඉවත් කරන බව ඔබට සහතිකද",
"Warning" => "අනතුරු ඇඟවිම",
"Import completed successfully." => "ආයාත කිරීම සාර්ථකයි",
"Uploading..." => "උඩුගත කෙරේ...",
"Bookm." => "පිටුසන",
"Add a bookmark" => "පිටු සළකුනක් එක් කරන්න",
"Close" => "වසන්න",
"The title of the page" => "පිටුවේ මාතෘකාව",
"The address of the page" => "පිටුවේ ලිපිනය",
"Description of the page" => "පිටුවේ විස්තර",
"Save" => "සුරකින්න",
"Delete" => "මකන්න",
"Edit" => "සකසන්න",
"Cancel" => "එපා",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "මෙම වෙබ් පිටුව ඉක්මනින් පිටු සළකුනක් ලෙස සටහන් කිරීමට, එය බ්‍රවුසරයේ පිටු සළකුනු මතට ඇද ක්ලික් කරන්න:",
"Address" => "ලිපිනය",
"Add" => "එකතු කරන්න",
"Related Tags" => "අදාළ ටැගයන්",
"Settings" => "සිටුවම්",
"You have no bookmarks" => "පිටු සළකුනු නොමැත",
"You can also try to import a bookmark file" => "පිටුසන අඩංගු ගොනුවක් ආයාත කිරීමට උත්සහ කළ හැක",
"Export & Import" => "ආයාත හා නිර්යාත",
"Export" => "නිර්යාත කරන්න",
"Import" => "ආයාත කරන්න"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
