<?php
$TRANSLATIONS = array(
"Bookmarks" => "Laster-markak",
"Bookm." => "Lasterm.",
"No file provided for import" => "Ez da inportatzeko fitxategirik zehaztu",
"Unsupported file type for import" => "Fitxategi mota hau ez da onartzen inportatzeko.",
"Error" => "Errorea",
"Tags" => "Etiketak",
"Filter by tag" => "Iragazi etiketaren arabera",
"Warning" => "Abisua",
"Are you sure you want to remove this tag from every entry?" => "Ziur zaude etiketa hau sarrera guztietatik ezabatu nahi duzula?",
"Import error" => "Inportazio errorea",
"Import completed successfully." => "Inportazioa ongi egin da.",
"Uploading..." => "Igotzen...",
"Add a bookmark" => "Gehitu laster-marka",
"The title of the page" => "Orriaren izenburua",
"The address of the page" => "Orriaren helbidea",
"Description of the page" => "Orriaren deskribapena",
"Save" => "Gorde",
"Delete" => "Ezabatu",
"Edit" => "Editatu",
"Cancel" => "Ezeztatu",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Web orri bat laster-marketara azkar gehitzeko, arrastratu hau zure arakatzailearen laster-marketara eta klikatu bertan:",
"Add to ownCloud" => "Gehitu ownCloud-era",
"Address" => "Helbidea",
"You have no bookmarks" => "Ez duzu laster-markarik",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Exportatu eta inportatu",
"Export" => "Exportatu",
"Import" => "Inportatu"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
