OC.L10N.register(
    "bookmarks",
    {
    "Details" : "รายละเอียด",
    "Rename" : "เปลี่ยนชื่อ",
    "Copy link" : "คัดลอกลิงก์",
    "Move" : "ย้าย",
    "Select all" : "เลือกทั้งหมด",
    "Go back" : "กลับไป",
    "Share folder" : "แชร์โฟลเดอร์",
    "New" : "ใหม่",
    "New folder" : "โฟลเดอร์ใหม่",
    "Search" : "ค้นหา",
    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
    "_%n folder_::_%n folders_" : ["%n โฟลเดอร์"],
    "Rename folder" : "เปลี่ยนชื่อโฟลเดอร์",
    "Submit" : "ส่ง",
    "Cancel" : "ยกเลิก",
    "Recent" : "ล่าสุด",
    "Shared with you" : "แชร์กับคุณ",
    "Files" : "ไฟล์",
    "Delete" : "ลบ",
    "Need help?" : "ต้องการความช่วยเหลือ?",
    "Title" : "ชื่อเรื่อง",
    "Link" : "ลิงก์",
    "Tags" : "แท็ก",
    "Notes" : "โน้ต",
    "Open file" : "เปิดไฟล์",
    "Download file" : "ดาวน์โหลดไฟล์",
    "Link copied" : "คัดลอกลิงก์แล้ว",
    "Owner" : "เจ้าของ",
    "Sharing" : "การแชร์",
    "Share link" : "แชร์ลิงก์",
    "Create public link" : "สร้างลิงค์สาธารณะ",
    "Allow editing" : "อนุญาตให้แก้ไข",
    "Allow resharing" : "อนุญาตให้แชร์ซ้ำ",
    "Failed to save settings" : "ไม่สามารถบันทึกการตั้งค่าได้",
    "Failed to load settings" : "ไม่สามารถโหลดการตั้งค่าได้",
    "Privacy" : "ความเป็นส่วนตัว",
    "Folder" : "โฟลเดอร์",
    "Save" : "บันทึก",
    "What's new?" : "มีอะไรใหม่บ้าง?"
},
"nplurals=1; plural=0;");
