<?php
$TRANSLATIONS = array(
"Bookmarks" => "Obeleživači",
"Bookm." => "Obel.",
"No file provided for import" => "Nema fajla za uvoz",
"Unsupported file type for import" => "Nepodržan tip fajla za uvoz",
"Some Error happened." => "Desila se neka greška.",
"Error" => "Greška",
"Tags" => "Oznake",
"Filter by tag" => "Filtriraj po oznaci",
"Are you sure you want to remove this bookmark?" => "Želite li zaista da uklonite ovaj obeleživač?",
"Warning" => "Upozorenje",
"Are you sure you want to remove this tag from every entry?" => "Želite li zaista da uklonite ovu oznaku iz svakog unosa?",
"Import error" => "Greška uvoza",
"Import completed successfully." => "Uvoz je uspešno završen.",
"Uploading..." => "Otpremam…",
"Add a bookmark" => "Dodaj obeleživač",
"This URL is already bookmarked! Overwrite?" => "Ovaj URL je već obeležen! Da prebrišem?",
"The title of the page" => "Naslov stranice",
"The address of the page" => "Adresa stranice",
"Description of the page" => "Opis stranice",
"Save" => "Sačuvaj",
"Delete" => "Obriši",
"Edit" => "Uredi",
"Cancel" => "Odustani",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Prevucite ovo u obeleživače pregledača i kliknite ako na brzinu želite da obeležite veb stranicu:",
"Add to ownCloud" => "Dodaj u ownCloud",
"Address" => "Adresa",
"Filterable Tags" => "Filtrirajuće oznake",
"You have no bookmarks" => "Nemate obeleživača",
"You can also import a bookmark file" => "Možete i da uvezete fajl obeleživača",
"Bookmarklet" => "Aplet obeleživača",
"Export & Import" => "Izvoz i uvoz",
"Export" => "Izvezi",
"Import" => "Uvezi"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
