<?php
$TRANSLATIONS = array(
"Bookmarks" => "Đánh dấu",
"Bookm." => "Bookm.",
"No file provided for import" => "Không có tập tin nào để nhập vào",
"Unsupported file type for import" => "Loại tập tin không được hỗ trợ để nhập vào",
"Some Error happened." => "Một số lỗi xảy ra.",
"Error" => "Lỗi",
"Tags" => "Tags",
"Filter by tag" => "Lọc theo tag",
"Are you sure you want to remove this bookmark?" => "Bạn có chắc chắn muốn xóa dấu trang này?",
"Warning" => "Cảnh báo",
"Are you sure you want to remove this tag from every entry?" => "Bạn có chắc chắn bạn muốn loại bỏ tags này ?",
"Import error" => "Lỗi khi nhập",
"Import completed successfully." => "Nhập vào thành công",
"Uploading..." => "tải lên...",
"Add a bookmark" => " Thêm bookmark",
"This URL is already bookmarked! Overwrite?" => "URL này đã được đánh dấu! Ghi đè lên?",
"The title of the page" => "Tiêu đề trang",
"The address of the page" => "Địa chỉ trang",
"Description of the page" => "Mô tả trang",
"Save" => "Lưu",
"Delete" => "Xóa",
"Edit" => "Sửa",
"Cancel" => "Hủy",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Kéo vào trình duyệt làm bookmark ,khi bạn muốn đánh dấu một trang web một cách nhanh chóng:",
"Add to ownCloud" => "Thêm vào ownCloud",
"Address" => "Địa chỉ",
"Filterable Tags" => "Lọc theo tag",
"You have no bookmarks" => "Bạn chưa có bookmark nào",
"You can also import a bookmark file" => "Bạn cũng có thể thử nhập vào một tập tin bookmark",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Xuất ra & Nhập vào",
"Export" => "Xuất ra",
"Import" => "Nhập vào"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
