<?php
$TRANSLATIONS = array(
"Bookmarks" => "Zakładki",
"Bookm." => "Zakładka",
"No file provided for import" => "Nie wybrano plików do importu",
"Unsupported file type for import" => "Nieobsługiwany typ pliku do importu",
"Some Error happened." => "Wystąpił błąd.",
"Error" => "Błąd",
"Tags" => "Tagi",
"Filter by tag" => "Filtruj po tagach",
"Are you sure you want to remove this bookmark?" => "Usunąć tę zakładkę?",
"Warning" => "Ostrzeżenie",
"Are you sure you want to remove this tag from every entry?" => "Czy na pewno chcesz usunąć ten tag z każdego wpisu?",
"Import error" => "Błąd importu",
"Import completed successfully." => "Importowanie zostało pomyślnie ukończone.",
"Uploading..." => "Wgrywanie....",
"Add a bookmark" => "Dodaj zakładkę",
"This URL is already bookmarked! Overwrite?" => "Istnieje już zakładka dla tego adresu URL! Zastąpić ją?",
"The title of the page" => "Tytuł strony",
"The address of the page" => "Adres strony",
"Description of the page" => "Opis strony",
"Save" => "Zapisz",
"Delete" => "Usuń",
"Edit" => "Edytuj",
"Cancel" => "Anuluj",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Przeciągnij to do zakładek w przeglądarce i kliknij, jeśli chcesz szybko dodać stronę do zakładek:",
"Add to ownCloud" => "Dodaj do ownCloud",
"Address" => "Adres",
"Filterable Tags" => "Tagi możliwe do przefiltrowania",
"You have no bookmarks" => "Nie masz żadnych zakładek",
"You can also import a bookmark file" => "Możesz również zaimportować plik z zakładkami",
"Bookmarklet" => "Zakładka",
"Export & Import" => "Eksportuj i Importuj",
"Export" => "Export",
"Import" => "Import"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
