<?php
$TRANSLATIONS = array(
"Bookmarks" => "Záložky",
"Bookm." => "Zál.",
"No file provided for import" => "Žiadny súbor na import",
"Unsupported file type for import" => "Nepodporovaný typ súboru pre import",
"Some Error happened." => "Stala sa nejaká chyba",
"Error" => "Chyba",
"Tags" => "Značky",
"Filter by tag" => "Filtrovať podľa značky",
"Are you sure you want to remove this bookmark?" => "Naozaj chcete odstrániť túto záložku?",
"Warning" => "Upozornenie",
"Are you sure you want to remove this tag from every entry?" => "Naozaj ste si istý, že chcete odstrániť túto značku z každého záznamu?",
"Import error" => "Chyba importu",
"Import completed successfully." => "Import prebehol úspešne.",
"Uploading..." => "Odosielanie...",
"Add a bookmark" => "Pridať záložku",
"This URL is already bookmarked! Overwrite?" => "Táto URL už je medzi záložkami! Prepísať?",
"The title of the page" => "Názov stránky",
"The address of the page" => "Adresa stránky",
"Description of the page" => "Popis stránky",
"Save" => "Uložiť",
"Delete" => "Zmazať",
"Edit" => "Upraviť",
"Cancel" => "Zrušiť",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Presuňte toto do vášho prehliadača a kliknite ak chcete aktuálnu stránku uložiť do záložiek.",
"Add to ownCloud" => "Pridať do ownCloudu",
"Address" => "Adresa",
"Filterable Tags" => "Filtrovateľné značky",
"You have no bookmarks" => "Nemáte žiadne záložky",
"You can also import a bookmark file" => "Môžete tiež importovať súbor so záložkami",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Export & Import",
"Export" => "Export",
"Import" => "Import"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;";
