<?php
$TRANSLATIONS = array(
"Bookmarks" => "Záložky",
"Failed to import one bookmark, because: " => "Selhal import jedné záložky z důvodu:",
"Bookm." => "Zál.",
"No file provided for import" => "Nebyl vybrán soubor k importu",
"Unsupported file type for import" => "Nepodporovaný typ souboru pro import",
"Some Error happened." => "Došlo k chybě.",
"Error" => "Chyba",
"Tags" => "Značky",
"Filter by tag" => "Filtrovat podle značky",
"Are you sure you want to remove this bookmark?" => "Opravdu chcete odstranit tuto záložku?",
"Warning" => "Varování",
"Are you sure you want to remove this tag from every entry?" => "Opravdu jste si jisti, že si přejete odstranit tuto značku z každého záznamu?",
"Import error" => "Chyba při importu",
"Import completed successfully." => "Import úspěšně dokončen.",
"Uploading..." => "Odesílám...",
"Add a bookmark" => "Přidat záložku",
"This URL is already bookmarked! Overwrite?" => "Adresa URL je již mezi záložkami! Přepsat?",
"The title of the page" => "Název stránky",
"The address of the page" => "Adresa stránky",
"Description of the page" => "Popis stránky",
"Save" => "Uložit",
"Delete" => "Smazat",
"Edit" => "Upravit",
"Cancel" => "Zrušit",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Přetáhněte do Vašeho prohlížeče a klikněte, pokud si přejete rychle uložit stránku do záložek:",
"Add to ownCloud" => "Přidat do ownCloudu",
"Address" => "Adresa",
"Filterable Tags" => "Filtrovatelné tagy",
"You have no bookmarks" => "Nemáte žádné záložky",
"You can also import a bookmark file" => "Můžete také importovat soubor záložek",
"Bookmarklet" => "Rutina pro záložky",
"Export & Import" => "Export a import",
"Export" => "Exportovat",
"Import" => "Importovat"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;";
