<?php
$TRANSLATIONS = array(
"Bookmarks" => "ブックマーク",
"Bookm." => "ブックマーク",
"No file provided for import" => "インポートするファイルが指定されていません",
"Unsupported file type for import" => "インポートでは未サポートのファイルタイプ",
"Some Error happened." => "エラーが発生しました。",
"Error" => "エラー",
"Tags" => "タグ",
"Filter by tag" => "タグによるフィルター",
"Are you sure you want to remove this bookmark?" => "このブックマークを削除してもよろしいですか？",
"Warning" => "警告",
"Are you sure you want to remove this tag from every entry?" => "すべてのエントリからこのタグを削除してもよろしいですか？",
"Import error" => "インポートエラー",
"Import completed successfully." => "インポートは正常に完了しました。",
"Uploading..." => "アップロード中...",
"Add a bookmark" => "ブックマークを追加",
"This URL is already bookmarked! Overwrite?" => "このURLはすでにブックマークされています！上書きしますか？",
"The title of the page" => "ページのタイトル",
"The address of the page" => "ページのアドレス",
"Description of the page" => "ページの説明",
"Save" => "保存",
"Delete" => "削除",
"Edit" => "編集",
"Cancel" => "キャンセル",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Webページをすぐにブックマークしたい場合は、これをブラウザーのブックマークにドラッグし、クリックしてください:",
"Add to ownCloud" => "ownCloud に追加",
"Address" => "アドレス",
"Filterable Tags" => "絞り込み可能なタグ",
"You have no bookmarks" => "ブックマークがありません",
"You can also import a bookmark file" => "ブックマークファイルをインポートすることもできます。",
"Bookmarklet" => "ブックマークレット",
"Export & Import" => "エクスポートとインポート",
"Export" => "エクスポート",
"Import" => "インポート"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
