OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Lesezeichen",
    "You bookmarked \"%s\"" : "Du hast \"%s\" als Lesezeichen hinzugefügt",
    "%1$s bookmarked \"%2$s\"" : "%1$s hat \"%2$s\" als Lesezeichen hinzugefügt",
    "Someone bookmarked \"%s\"" : "Jemand hat \"%s\" als Lesezeichen hinzugefügt",
    "You deleted \"%s\"" : "Du hast \"%s\" gelöscht",
    "%1$s deleted \"%2$s\"" : "%1$s hat \"%2$s\" gelöscht",
    "Someone deleted \"%s\"" : "Jemand hat \"%s\" gelöscht",
    "You created folder \"%s\"" : "Du hast den Ordner \"%s\" erstellt",
    "%1$s created folder \"%2$s\"" : "%1$s hat den Ordner \"%2$s\" erstellt",
    "Someone created folder \"%s\"" : "Jemand hat den Ordner \"%s\" erstellt",
    "You moved folder \"%s\"" : "Du hast den Ordner \"%s\" verschoben",
    "%1$s moved folder \"%2$s\"" : "%1$s hat den Ordner \"%2$s\" verschoben",
    "Someone moved folder \"%s\"" : "Jemand hat den Ordner \"%s\" verschoben",
    "You deleted folder \"%s\"" : "Du hast den Ordner \"%s\" gelöscht",
    "%1$s deleted folder \"%2$s\"" : "%1$s hat den Ordner \"%2$s\" gelöscht",
    "Someone deleted folder \"%s\"" : "Jemand hat den Ordner \"%s\" gelöscht",
    "You shared folder \"%1$s\" with %2$s" : "Du hast den Ordner \"%1$s\" mit %2$s geteilt",
    "You shared folder \"%s\" with someone" : "Du hast den Ordner \"%s\" mit jemanden geteilt",
    "%1$s shared folder \"%2$s\" with you" : "%1$s hat den Ordner \"%2$s\" mit dir geteilt",
    "Someone shared folder \"%s\" with you" : "Jemand hat den Ordner \"%s\" mit dir geteilt",
    "You unshared folder \"%1$s\" with %2$s" : "Du hast die Freigabe des Ordners \"%1$s\" für %2$s aufgehoben",
    "You unshared folder \"%s\" with someone" : "Du hast die Freigabe des Ordners \"%s\" für jemanden aufgehoben",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s hat die Freigabe des Ordners \"%2$s\" aufgehoben",
    "Someone unshared folder \"%s\" with you" : "Jemand hat die Freigabe des Ordners \"%s\" aufgehoben",
    "No file provided for import" : "Keine Datei zum Importieren ausgewählt",
    "Failed to upload file" : "Datei konnte nicht hochgeladen werden",
    "Unsupported file type for import: " : "Import von Dateien dieses Typs wird nicht unterstützt:",
    "Bookmarks shared by %s" : "Lesezeichen geteilt von %s",
    "Frequent bookmarks" : "Häufige Lesezeichen",
    "Recent bookmarks" : "Neueste Lesezeichen",
    "Bookmark" : "Lesezeichen",
    "Bookmark deleted" : "Lesezeichen gelöscht",
    "Bookmark created" : "Lesezeichen erstellt",
    "Bookmark moved" : "Lesezeichen verschoben",
    "Bookmark updated" : "Lesezeichen aktualisiert",
    "Create bookmark" : "Lesezeichen erstellen",
    "Takes a link and adds it to your collection of bookmarks." : "Nimmt einen Link und fügt ihn deiner Lesezeichen-Sammlung hinzu.",
    "Bookmarks Backups" : "Lesezeichen-Sicherungekopien",
    "Collect and manage bookmarks, synced with all your devices" : "Lesezeichen sammeln und verwalten, die mit mit all deinen Geräten synchronisiert werden",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Lesezeichen in Ordnern sortieren\n- 🏷 Tags und persönliche Notizen hinzufügen\n- ☠ Finde defekte Links und Duplikate\n- 📲 Synchronisiere mit allen deinen Browsern und Geräten\n- 📔 Speichere archivierte Versionen deiner Links für den Fall, dass sie nicht mehr veröffentlicht werden\n- 🔍 Volltextsuche im Inhalt der Website\n- 👪 Teile Lesezeichen mit anderen Benutzern, Gruppen und Teams oder über öffentliche Links\n- ⚛ Erzeugen von RSS-Feeds für deine Sammlungen\n- 📈 Statistiken darüber, wie oft du auf welche Links zugreifst\n- 🔒 Automatische Backups deiner Lesezeichensammlung\n- 💼 Eingebaute Dashboard-Widgets für häufige und aktuelle Links\n\nVoraussetzungen:\n - PHP-Erweiterungen:\n   - intl: *\n   - mbstring: *\n - wenn du MySQL verwendest, verwende mindestens Version 8.0",
    "Do you really want to delete this bookmark?" : "Soll dieses Lesezeichen gelöscht werden?",
    "Link copied to clipboard" : "Link in die Zwischenablage kopiert",
    "Enter new title" : "Neuen Titel eingeben",
    "Select bookmark" : "Lesezeichen wählen",
    "You have never clicked this link" : "Du hast diesen Link noch nie angeklickt.",
    "You have clicked this link {count} times" : "Du hast diesen Link {count} Mal angeklickt.",
    "Details" : "Details",
    "Rename" : "Umbenennen",
    "Copy link" : "Link kopieren",
    "Move" : "Verschieben",
    "Add to folders" : "Zu Ordnern hinzufügen",
    "Put bookmark into trash bin" : "Lesezeichen in den Papierkorb verschieben",
    "Restore bookmark" : "Lesezeichen wiederherstellen",
    "Delete bookmark permanently" : "Lesezeichen endgültig löschen",
    "Content pending" : "Inhalt noch ausstehend",
    "This content is being downloaded for offline use. Please check back later." : "Dieser Inhalt wird zur Offline-Verwendung heruntergeladen. Bitte versuche es später erneut.",
    "Bookmarked {time} ago" : "Lesezeichen vor {time} erstellt",
    "Bookmarked on {date}" : "Lesezeichen am {date} erstellt",
    "These are your deleted items. Items will be deleted permanently after two months." : "Dies sind deine gelöschten Elemente. Diese werden nach zwei Monaten dauerhaft gelöscht.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Lesezeichen für Dateien wie Fotos oder PDFs werden automatisch als Dateien in deiner Nextcloud gespeichert, sodass du sie auch dann finden kannst, wenn der Link nicht mehr erreichbar ist.",
    "Searching in the current folder only." : "Suche nur im aktuellen Ordner",
    "Repeat search in all folders" : "Suche in allen Ordnern wiederholen",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Links in den Lesezeichen werden regelmäßig überprüft und diejenigen, die nicht erreicht werden können, werden hier aufgelistet.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Du kannst Lesezeichenordner mit anderen teilen. Hier werden alle für dich freigegebenen Ordner aufgelistet.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Ein Lesezeichen kann sich gleichzeitig in mehreren Ordnern befinden. Durch die Aktualisierung werden alle Kopien aktualisiert. Alle duplizierten Lesezeichen werden hier der Einfachheit halber aufgelistet.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} Ordner und {bookmarks} Lesezeichen ausgewählt",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n Lesezeichen ausgewählt","%n Lesezeichen ausgewählt"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n Ordner gewählt","%n Ordner gewählt"],
    "Do you really want to delete these items?" : "Sollen diese Elemente wirklich gelöscht werden?",
    "Open all selected" : "Alle ausgewählten öffnen",
    "Move selection" : "Auswahl verschieben",
    "Edit tags of selection" : "Ausgewählte Schlagworte bearbeiten",
    "Delete selection" : "Auswahl löschen",
    "Select all" : "Alle auswählen",
    "Cancel selection" : "Auswahl abbrechen",
    "Sort by created date" : "Nach Erstellungsdatum sortieren",
    "Sort by last modified" : "Nach letzter Änderung sortieren",
    "Sort by title" : "Nach Titel sortieren",
    "Sort by click count" : "Nach Klickanzahl sortieren",
    "Sort by manual order" : "Nach manueller Reihenfolge sortieren",
    "Sort by URL" : "Nach URL sortieren",
    "RSS feed copied" : "RSS-Feed kopiert",
    "Trash Bin" : "Papierkorb",
    "Go back" : "Zurückgehen",
    "Share folder" : "Ordner teilen",
    "Open folder details" : "Ordnerdetails öffnen",
    "Select one or more tags" : "Ein oder mehrere Schlagworte auswählen",
    "New" : "Neu",
    "New bookmark" : "Neues Lesezeichen",
    "New folder" : "Neuer Ordner",
    "Change to grid view" : "Zur Rasteransicht wechseln",
    "Change to list view" : "Zur Listenansicht wechseln",
    "Copy RSS Feed of current view" : "RSS-Feed der aktuellen Ansicht kopieren",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Der RSS-Feed erfordert eine Anmeldung mit deinen Nextcloud-Zugangsdaten",
    "Search" : "Suchen",
    "Empty trash bin" : "Papierkorb leeren",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["%n Lesezeichen dem neuen Ordner hinzugefügt","%n Lesezeichen dem neuen Ordner hinzugefügt"],
    "Enter a link" : "Link eingeben",
    "Enter a title" : "Titel eingeben",
    "No bookmarks found" : "Keine Lesezeichen gefunden",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} Ordner und {bookmarks} Lesezeichen",
    "_%n bookmark_::_%n bookmarks_" : ["%n Lesezeichen","%n Lesezeichen"],
    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
    "Welcome to Bookmarks" : "Willkommen bei Bookmarks",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Mit dieser App kannst du Links zu deinen Lieblingsorten im Internet verwalten. Sortiere deine Lesezeichen in Ordner, kennzeichne sie mit Schlagworten und teile sie mit anderen! Die App überprüft regelmäßig alle deine Links auf Verfügbarkeit und zeigt nicht erreichbare Links an. Wenn du einen Link zu einer Datei im Web hinzufügen, wird die Datei automatisch in deine Nextcloud-Dateien heruntergeladen. Du kannst mit dieser App auch Lesezeichen importieren, die aus anderen Diensten exportiert wurden, oder Lesezeichen mit deinem Browsern direkt synchronisieren.",
    "Add a bookmark" : "Lesezeichen hinzufügen",
    "Import bookmarks" : "Lesezeichen importieren",
    "Sync with your browser" : "Mit deinem Browser synchronisieren",
    "Do you really want to permanently delete this folder?" : "Möchtest du diesen Ordner endgültig löschen?",
    "Select folder" : "Ordner wählen",
    "Enter folder title" : "Ordnernamen eingeben",
    "Shared by {user}" : "Geteilt von {user}",
    "Rename folder" : "Ordner umbenennen",
    "Move folder" : "Ordner verschieben",
    "Put folder into trashbin" : "Ordner in den Parpierkorb verschieben",
    "Restore folder" : "Ordner wiederherstellen",
    "Delete folder permanently" : "Ordner endgültig löschen",
    "Choose folder" : "Ordner auswählen",
    "Submit" : "Übermitteln",
    "Cancel" : "Abbrechen",
    "Deleting bookmarks" : "Lesezeichen löschen",
    "Deleting selection" : "Auswahl löschen",
    "Importing bookmarks" : "Lesezeichen importieren",
    "Moving selection" : "Auswahl verschieben",
    "Adding selection to folders" : "Auswahl zu Ordnern hinzufügen",
    "Emptying trashbin" : "Papierkorb wird geleert.",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Verschiebe %n Ordner und einige Lesezeichen","Verschiebe %n Ordner und einige Lesezeichen"],
    "_Moving %n folder_::_Moving %n folders_" : ["Verschiebe %n Ordner","Verschiebe %n Ordner"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Verschiebe %n Lesezeichen","Verschiebe %n Lesezeichen"],
    "All bookmarks" : "Alle Lesezeichen",
    "Recent" : "Neueste",
    "Frequently clicked" : "Häufig angeklickt",
    "Shared with you" : "Mit dir geteilt",
    "Files" : "Dateien",
    "Duplicates" : "Duplikate",
    "Broken links" : "Ungültige Links",
    "New tag" : "Neues Schlagwort",
    "Search tags" : "Schlagworte suchen",
    "Delete" : "Löschen",
    "Untagged" : "Kein Schlagwort",
    "{used} bookmarks of {available} available" : "{used} Lesezeichen von {available} verfügbaren",
    "Bookmarks Settings" : "Lesezeichen-Einstellungen",
    "No bookmarked files" : "Keine Lesezeichen für Dateien vorhanden",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Lesezeichen für Dateien, wie Fotos oder PDFs, werden automatisch in deinen Nextcloud-Dateien gespeichert, sodass du sie auch dann finden kannst, wenn der Link nicht mehr verfügbar ist.",
    "Nothing found" : "Nichts gefunden",
    "Your search yielded no results in the current folder." : "Deine Suche hat in dem aktuellen Ordner kein Ergebnis gefunden.",
    "No broken links" : "Keine ungültige Links",
    "No shared folders" : "Keine geteilten Ordner",
    "No duplicated bookmarks" : "Keine doppelten Lesezeichen",
    "No deleted bookmarks" : "Keine gelöschten Lesezeichen",
    "You haven't deleted anything yet." : "Du hast bislang noch nichts gelöscht.",
    "No bookmarks here" : "Keine Lesezeichen vorhanden",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Lesezeichen manuell hinzufügen oder aus einer HTML-Datei importieren",
    "Archive path" : "Archiv-Pfad",
    "Backup path" : "Pfad für Sicherungekopien",
    "Please select \"Add to home screen\" in your browser menu" : "Bitte \"Zum Startbildschirm hinzufügen\" im Browsermenü auswählen",
    "Bookmarks settings" : "Lesezeichen-Einstellungen",
    "Import/Export" : "Import/Export",
    "Export bookmarks" : "Lesezeichen exportieren",
    "Auto-archiving" : "Automatische Archivierungen",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Die Lesezeichen-App kann automatisch den Webinhalt, der von dir gespeicherten Lesezeichen, archivieren.",
    "Enable archiving" : "Archivierung aktivieren",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Den Pfad eines Ordners in deinen Dateien eingeben, in dem mit Lesezeichen versehene Dateien gespeichert werden sollen.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Deine Administration hat aktuell den Netzwerkzugriff für diese App deaktiviert, daher ist die automatische Archivierung momentan deaktiviert.",
    "Auto-Backup" : "Automatische Sicherungekopien",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Die Lesezeichen-App kann täglich automatisch deine Lesezeichen sichern, um Datenverlust beim synchronisieren mit Geräten zu verhindern.",
    "Enable backups" : "Sicherungekopien aktivieren",
    "Enter the path of a folder in your Files where backups will be stored." : "Gib den Pfad eines Ordners in deinen Dateien ein, in dem deine Sicherungskopien gespeichert werden sollen.",
    "Context Chat integration" : "Kontext-Chat-Einbindung",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Die Lesezeichen-App kann die Textinhalte der von dir mit Lesezeichen versehenen Websites automatisch für den Kontext-Chat verfügbar machen, sodass du Fragen zu diesen Inhalten stellen und Antworten darauf erhalten kannst. Diese Funktion ist nur verfügbar, wenn die automatische Archivierung aktiviert ist.",
    "Context chat is currently not installed, but is required for this feature." : "Der Kontext-Chat ist derzeit nicht installiert, wird jedoch für diese Funktion benötigt.",
    "Enable Context Chat integration" : "Kontext-Chat-Einbindung aktivieren",
    "Client apps" : "Client-Apps",
    "Also check out the collection of client apps that integrate with this app: " : "Sieh dir auch die Sammlung von Client-Apps an, die diese App integrieren:",
    "Install web app" : "Web-App installieren",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Du kannst diese App auf dem Startbildschirm deines Geräts installieren, um schnell auf deine Lesezeichen auf dem Smartphone zuzugreifen. Du kannst die App ganz einfach wieder von deinem Startbildschirm entfernen, wenn sie dir nicht gefällt.",
    "Install on home screen" : "Auf Startbildschirm installieren",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Ziehe dies in deine Browser-Lesezeichen und klicke darauf, um schnell ein Lesezeichen für eine Webseite zu setzen.",
    "Add to {instanceName}" : "Hinzufügen zu {instanceName}",
    "Need help?" : "Benötigst du Hilfe?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Wenn du Probleme mit dieser Lesezeichen-App oder einen Verbesserungsvorschlag hast, nimm Kontakt zu uns auf, indem du hier klickst.",
    "Support this project" : "Dieses Projekt unterstützen",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Meine Arbeit an dieser Bookmarks-App wird durch ein freiwilliges Abonnementmodell finanziert. Wenn du meinst, dass meine Arbeit lohnenswert ist, unterstütze mich bitte. Bitte denke auch daran, die App im Nextcloud-App-Store zu bewerten. Vielen Dank 💙",
    "Created {time} ago" : "Erstellt vor {time}",
    "Created on {date}" : "Erstellt am {date}",
    "(Empty title)" : "(Leerer Titel)",
    "Title" : "Titel",
    "Link" : "Link",
    "Untitled folder" : "Unbenannter Ordner",
    "Root folder" : "Root-Ordner",
    "Tags" : "Schlagworte",
    "Select tags and create new ones" : "Schlagworte wählen und erstellen",
    "Notes" : "Notizen",
    "Notes for this bookmark …" : "Notizen für dieses Lesezeichen …",
    "Archived file" : "Archivierte Datei",
    "Open file" : "Datei öffnen",
    "Download file" : "Datei herunterladen",
    "Open file location" : "Dateispeicherort öffnen",
    "Link copied" : "Link kopiert",
    "Owner" : "Besitzer",
    "Sharing" : "Teilen",
    "Select a user or group" : "Benutzer oder Gruppe auswählen",
    "Share link" : "Link teilen",
    "Reading allowed" : "Lesen zugelassen",
    "Copy RSS feed" : "RSS-Feed kopieren",
    "Delete link" : "Link löschen",
    "Create public link" : "Öffentlichen Link erstellen",
    "Resharing allowed" : "Weiterteilen ist erlaubt",
    "Editing allowed" : "Bearbeitung zugelassen",
    "Allow editing" : "Bearbeitung erlauben",
    "Allow resharing" : "Weiterteilen erlauben",
    "Remove share" : "Freigabe entfernen",
    "Would you like to support this project?" : "Möchtest du dieses Projekt unterstützen?",
    "Leave a rating on the Nextcloud App Store" : "Hinterlasse eine Bewertung im Nextcloud App Store",
    "Failed to save settings" : "Einstellungen konnten nicht gespeichert werden",
    "Failed to load settings" : "Einstellungen konnten nicht geladen werden",
    "Privacy" : "Datenschutz",
    "The app will try to access web pages that you add to automatically add information about them." : "Die App versucht, auf die hinzugefügten Webseiten zuzugreifen, um automatisch Informationen über die Seiten hinzuzufügen.",
    "Enable accessing and collecting information from the web pages you add" : "Aktiviere den Zugriff auf und das Sammeln von Informationen über die von dir hinzugefügten Webseiten",
    "Performance" : "Leistung",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Bei einer Installation mit vielen Benutzern kann es hilfreich sein, die Anzahl der Lesezeichen pro Konto zu beschränken.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximal zulässige Anzahl von Lesezeichen pro Konto. (0 für kein Limit; Standard ist kein Limit)",
    "Previews" : "Vorschau",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Um Screenshots deiner als Lesezeichen gespeicherten Websites anzuzeigen, kann die App Dienste von Drittanbietern zur Generierung von Vorschaubildern verwenden.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Du kannst dich entweder kostenlos bei screeenly.com anmelden oder deinen eigenen Server einrichten.",
    "Screeenly API URL" : "Screeenly-API-URL",
    "Screeenly API key" : "Screeenly-API-Key",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine-API-Key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot-API-URL",
    "Generic screenshot API" : "Generische Screenshot-API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Melde dich bei einem der Screenshot-API-Anbieter an und gib unten die API-URL ein. Verwende die Variable {url} als Platzhalter für die URL zum Screenshot. Die API darf nur das Bild direkt zurückgeben.",
    "Generic API URL" : "Generische API-URL",
    "Pageres CLI" : "Pageres-Komandozeile",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Installiere einfach die Pageres CLI von Sindre Sorhus auf deinem Server und Bookmarks wird sie erkennen. Du kannst noch weitere ENV-Variablen hinzufügen, die an Pageres weitergeleitet werden sollen, z. B. wie im Platzhalter angegeben:",
    "Pageres ENV variables" : "Pageres ENV-Variablen",
    "This URL is already bookmarked! Overwrite?" : "Diese URL ist bereits als Lesezeichen gespeichert! Überschreiben?",
    "Enter bookmark title" : "Lesezeichentitel eingeben",
    "Enter bookmark URL" : "Lesezeichen-URL eingeben",
    "Folder" : "Ordner",
    "Root Folder" : "Root-Ordner",
    "Save" : "Speichern",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Netzwerkzugriff ist standardmäßig deaktiviert. Gehe zu den Administrationseinstellungen für die Lesezeichen-App, um das Abrufen von Vorschauen und Favicons zu erlauben.",
    "What's new?" : "Was ist neu?",
    "What" : "Was",
    "Failed to count unavailable bookmarks" : "Die nicht verfügbare Lesezeichen konnten nicht gezählt werden",
    "Failed to count archived bookmarks" : "Archivierte Lesezeichen konnten nicht gezählt werden",
    "Failed to count deleted bookmarks" : "Gelöschte Lesezeichen konnten nicht gezählt werden",
    "Failed to count duplicated bookmarks" : "Doppelte Lesezeichen konnten nicht gezählt werden",
    "Failed to count bookmarks" : "Lesezeichen konnten nicht gezählt werden",
    "Failed to load bookmark" : "Lesezeichen konnte nicht geladen werden",
    "Failed to find existing bookmark" : "Existierendes Lesezeichen konnte nicht gefunden werden",
    "Failed to create bookmark" : "Lesezeichen konnte nicht erstellt werden",
    "Failed to save bookmark" : "Lesezeichen konnte nicht gespeichert werden",
    "Failed to move bookmark" : "Lesezeichen konnte nicht verschoben werden",
    "Failed to copy bookmark" : "Lesezeichen konnte nicht kopiert werden",
    "Failed to delete bookmark" : "Lesezeichen konnte nicht gelöscht werden",
    "Failed to restore bookmark" : "Lesezeichen konnte nicht wiederhergestellt werden",
    "Import successful" : "Import erfolgreich",
    "Failed to rename tag" : "Schlagwort konnte nicht umbenannt werden",
    "Failed to load tags" : "Schlagworte konnten nicht geladen werden",
    "Failed to load folders" : "Ordner konnten nicht geladen werden",
    "Failed to load deleted folders" : "Gelöschte Ordner konnten nicht geladen werden",
    "Failed to load deleted bookmarks" : "Gelöschte Lesezeichen konnten nicht geladen werden",
    "Failed to delete folder" : "Ordner konnte nicht gelöscht werden",
    "Failed to move folder" : "Ordner konnte nicht verschoben werden.",
    "Failed to restore folder" : "Ordner konnte nicht wiederhergestellt werden",
    "Failed to create folder" : "Ordner konnte nicht erstellt werden",
    "Failed to load children order" : "Reihenfolge der untergeordneten Elemente konnte nicht geladen werden",
    "Failed to move parts of selection" : "Ein Teil der Auswahl konnte nicht verschoben werden",
    "Failed to copy parts of selection" : "Teile der Auswahl konnten nicht kopiert werden",
    "Failed to delete parts of selection" : "Ein Teil der Auswahl konnte nicht gelöscht werden",
    "Failed to tag parts of selection" : "Teile der Auswahl konnten nicht markiert werden",
    "Failed to fetch bookmarks." : "Lesezeichen konnten nicht abgerufen werden.",
    "Failed to store setting" : "Einstellungen konnten nicht gespeichert werden.",
    "Failed to load setting {key}" : "Einstellung konnte nicht geladen werden {key}",
    "Failed to create share for folder {folderId}" : "Freigabe für Ordner {folderId} konnte nicht erstellt werden",
    "Failed to update share {shareId}" : "Aktualisierung der Freigabe fehlgeschlagen {shareId}",
    "Failed to delete share {shareId}" : "Freigabe konnte nicht gelöscht werden {shareId}",
    "Failed to create public link for folder {folderId}" : "Öffentliche Freigabe für Ordner {folderId} konnte nicht erstellt werden",
    "Failed to delete public link for folder {folderId}" : "Öffentliche Freigabe für Ordner {folderId} konnte nicht gelöscht werden",
    "Failed to permanently delete parts of trash bin" : "Ein Teil des Papierkorbes konnte nicht endgültig gelöscht werden",
    "Create bookmarks for mentioned links" : "Lesezeichen für erwähnte Links erstellen",
    "No links found in this message" : "Keine Links in dieser Nachricht gefunden",
    "Bookmarks feed" : "Lesezeichen-Feed"
},
"nplurals=2; plural=(n != 1);");
