<?php
$TRANSLATIONS = array(
"Bookmarks" => "Bokmerker",
"Bookm." => "Bokmrk.",
"No file provided for import" => "Ingen fil valgt for importering",
"Unsupported file type for import" => "Ikke støttet filtype for importering",
"Some Error happened." => "Det oppstod en feil.",
"Error" => "Feil",
"Tags" => "Merkelapper",
"Filter by tag" => "Filtrer ut fra merkelapp",
"Are you sure you want to remove this bookmark?" => "Er du sikker på at du vil fjerne dette bokmerket?",
"Warning" => "Advarsel",
"Are you sure you want to remove this tag from every entry?" => "Er du sikker på at du vil slette denne merkelappen fra alle oppføringene?",
"Import error" => "Importerings-feil",
"Import completed successfully." => "Importering fullførte vellykket.",
"Uploading..." => "Laster opp...",
"Add a bookmark" => "Legg til et bokmerke",
"This URL is already bookmarked! Overwrite?" => "Denne URL-en er allerede i et bokmerke. Overskrive?",
"The title of the page" => "Sidens tittel",
"The address of the page" => "Sidens adresse",
"Description of the page" => "Beskrivelse av siden",
"Save" => "Lagre",
"Delete" => "Slett",
"Edit" => "Endre",
"Cancel" => "Avbryt",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Dra denne til bokmerkene i nettleseren din og klikk på den når du ønsker å raskt legge til en nettside som bokmerke:",
"Add to ownCloud" => "Legg til i ownCloud",
"Address" => "Adresse",
"Filterable Tags" => "Filtrerbare merkelapper",
"You have no bookmarks" => "Du har ingen bokmerker",
"You can also import a bookmark file" => "Du kan også imortere en bokmerke-fil",
"Bookmarklet" => "Bokmerke-applet",
"Export & Import" => "Eksport og import",
"Export" => "Eksporter",
"Import" => "Importer"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
