<?php
$TRANSLATIONS = array(
"Bookmarks" => "Tanda",
"Warning" => "Amaran",
"Close" => "Tutup",
"Save" => "Simpan",
"Delete" => "Padam",
"Edit" => "Sunting",
"Cancel" => "Batal",
"Address" => "Alamat",
"Add" => "Tambah",
"Settings" => "Tetapan",
"Export" => "Export",
"Import" => "Import"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
