<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Brick\\Math\\BigDecimal' => $vendorDir . '/brick/math/src/BigDecimal.php',
    'Brick\\Math\\BigInteger' => $vendorDir . '/brick/math/src/BigInteger.php',
    'Brick\\Math\\BigNumber' => $vendorDir . '/brick/math/src/BigNumber.php',
    'Brick\\Math\\BigRational' => $vendorDir . '/brick/math/src/BigRational.php',
    'Brick\\Math\\Exception\\DivisionByZeroException' => $vendorDir . '/brick/math/src/Exception/DivisionByZeroException.php',
    'Brick\\Math\\Exception\\IntegerOverflowException' => $vendorDir . '/brick/math/src/Exception/IntegerOverflowException.php',
    'Brick\\Math\\Exception\\MathException' => $vendorDir . '/brick/math/src/Exception/MathException.php',
    'Brick\\Math\\Exception\\NegativeNumberException' => $vendorDir . '/brick/math/src/Exception/NegativeNumberException.php',
    'Brick\\Math\\Exception\\NumberFormatException' => $vendorDir . '/brick/math/src/Exception/NumberFormatException.php',
    'Brick\\Math\\Exception\\RoundingNecessaryException' => $vendorDir . '/brick/math/src/Exception/RoundingNecessaryException.php',
    'Brick\\Math\\Internal\\Calculator' => $vendorDir . '/brick/math/src/Internal/Calculator.php',
    'Brick\\Math\\Internal\\Calculator\\BcMathCalculator' => $vendorDir . '/brick/math/src/Internal/Calculator/BcMathCalculator.php',
    'Brick\\Math\\Internal\\Calculator\\GmpCalculator' => $vendorDir . '/brick/math/src/Internal/Calculator/GmpCalculator.php',
    'Brick\\Math\\Internal\\Calculator\\NativeCalculator' => $vendorDir . '/brick/math/src/Internal/Calculator/NativeCalculator.php',
    'Brick\\Math\\RoundingMode' => $vendorDir . '/brick/math/src/RoundingMode.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'Doctrine\\Common\\Inflector\\Inflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Common/Inflector/Inflector.php',
    'Doctrine\\Inflector\\CachedWordInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/CachedWordInflector.php',
    'Doctrine\\Inflector\\GenericLanguageInflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/GenericLanguageInflectorFactory.php',
    'Doctrine\\Inflector\\Inflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Inflector.php',
    'Doctrine\\Inflector\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/InflectorFactory.php',
    'Doctrine\\Inflector\\Language' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Language.php',
    'Doctrine\\Inflector\\LanguageInflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/LanguageInflectorFactory.php',
    'Doctrine\\Inflector\\NoopWordInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/NoopWordInflector.php',
    'Doctrine\\Inflector\\Rules\\English\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\English\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\English\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/Rules.php',
    'Doctrine\\Inflector\\Rules\\English\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\French\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\French\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\French\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/Rules.php',
    'Doctrine\\Inflector\\Rules\\French\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/Rules.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Pattern' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Pattern.php',
    'Doctrine\\Inflector\\Rules\\Patterns' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Patterns.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/Rules.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Ruleset' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Ruleset.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/Rules.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Substitution' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Substitution.php',
    'Doctrine\\Inflector\\Rules\\Substitutions' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Substitutions.php',
    'Doctrine\\Inflector\\Rules\\Transformation' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Transformation.php',
    'Doctrine\\Inflector\\Rules\\Transformations' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Transformations.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/Rules.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Word' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Word.php',
    'Doctrine\\Inflector\\RulesetInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/RulesetInflector.php',
    'Doctrine\\Inflector\\WordInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/WordInflector.php',
    'League\\Uri\\BaseUri' => $vendorDir . '/league/uri/BaseUri.php',
    'League\\Uri\\Contracts\\AuthorityInterface' => $vendorDir . '/league/uri-interfaces/Contracts/AuthorityInterface.php',
    'League\\Uri\\Contracts\\Conditionable' => $vendorDir . '/league/uri-interfaces/Contracts/Conditionable.php',
    'League\\Uri\\Contracts\\DataPathInterface' => $vendorDir . '/league/uri-interfaces/Contracts/DataPathInterface.php',
    'League\\Uri\\Contracts\\DomainHostInterface' => $vendorDir . '/league/uri-interfaces/Contracts/DomainHostInterface.php',
    'League\\Uri\\Contracts\\FragmentDirective' => $vendorDir . '/league/uri-interfaces/Contracts/FragmentDirective.php',
    'League\\Uri\\Contracts\\FragmentInterface' => $vendorDir . '/league/uri-interfaces/Contracts/FragmentInterface.php',
    'League\\Uri\\Contracts\\HostInterface' => $vendorDir . '/league/uri-interfaces/Contracts/HostInterface.php',
    'League\\Uri\\Contracts\\IpHostInterface' => $vendorDir . '/league/uri-interfaces/Contracts/IpHostInterface.php',
    'League\\Uri\\Contracts\\PathInterface' => $vendorDir . '/league/uri-interfaces/Contracts/PathInterface.php',
    'League\\Uri\\Contracts\\PortInterface' => $vendorDir . '/league/uri-interfaces/Contracts/PortInterface.php',
    'League\\Uri\\Contracts\\QueryInterface' => $vendorDir . '/league/uri-interfaces/Contracts/QueryInterface.php',
    'League\\Uri\\Contracts\\SegmentedPathInterface' => $vendorDir . '/league/uri-interfaces/Contracts/SegmentedPathInterface.php',
    'League\\Uri\\Contracts\\UriAccess' => $vendorDir . '/league/uri-interfaces/Contracts/UriAccess.php',
    'League\\Uri\\Contracts\\UriComponentInterface' => $vendorDir . '/league/uri-interfaces/Contracts/UriComponentInterface.php',
    'League\\Uri\\Contracts\\UriException' => $vendorDir . '/league/uri-interfaces/Contracts/UriException.php',
    'League\\Uri\\Contracts\\UriInterface' => $vendorDir . '/league/uri-interfaces/Contracts/UriInterface.php',
    'League\\Uri\\Contracts\\UserInfoInterface' => $vendorDir . '/league/uri-interfaces/Contracts/UserInfoInterface.php',
    'League\\Uri\\Encoder' => $vendorDir . '/league/uri-interfaces/Encoder.php',
    'League\\Uri\\Exceptions\\ConversionFailed' => $vendorDir . '/league/uri-interfaces/Exceptions/ConversionFailed.php',
    'League\\Uri\\Exceptions\\MissingFeature' => $vendorDir . '/league/uri-interfaces/Exceptions/MissingFeature.php',
    'League\\Uri\\Exceptions\\OffsetOutOfBounds' => $vendorDir . '/league/uri-interfaces/Exceptions/OffsetOutOfBounds.php',
    'League\\Uri\\Exceptions\\SyntaxError' => $vendorDir . '/league/uri-interfaces/Exceptions/SyntaxError.php',
    'League\\Uri\\FeatureDetection' => $vendorDir . '/league/uri-interfaces/FeatureDetection.php',
    'League\\Uri\\HostFormat' => $vendorDir . '/league/uri-interfaces/HostFormat.php',
    'League\\Uri\\HostRecord' => $vendorDir . '/league/uri-interfaces/HostRecord.php',
    'League\\Uri\\HostType' => $vendorDir . '/league/uri-interfaces/HostType.php',
    'League\\Uri\\Http' => $vendorDir . '/league/uri/Http.php',
    'League\\Uri\\HttpFactory' => $vendorDir . '/league/uri/HttpFactory.php',
    'League\\Uri\\IPv4\\BCMathCalculator' => $vendorDir . '/league/uri-interfaces/IPv4/BCMathCalculator.php',
    'League\\Uri\\IPv4\\Calculator' => $vendorDir . '/league/uri-interfaces/IPv4/Calculator.php',
    'League\\Uri\\IPv4\\Converter' => $vendorDir . '/league/uri-interfaces/IPv4/Converter.php',
    'League\\Uri\\IPv4\\GMPCalculator' => $vendorDir . '/league/uri-interfaces/IPv4/GMPCalculator.php',
    'League\\Uri\\IPv4\\NativeCalculator' => $vendorDir . '/league/uri-interfaces/IPv4/NativeCalculator.php',
    'League\\Uri\\IPv6\\Converter' => $vendorDir . '/league/uri-interfaces/IPv6/Converter.php',
    'League\\Uri\\Idna\\Converter' => $vendorDir . '/league/uri-interfaces/Idna/Converter.php',
    'League\\Uri\\Idna\\Error' => $vendorDir . '/league/uri-interfaces/Idna/Error.php',
    'League\\Uri\\Idna\\Option' => $vendorDir . '/league/uri-interfaces/Idna/Option.php',
    'League\\Uri\\Idna\\Result' => $vendorDir . '/league/uri-interfaces/Idna/Result.php',
    'League\\Uri\\KeyValuePair\\Converter' => $vendorDir . '/league/uri-interfaces/KeyValuePair/Converter.php',
    'League\\Uri\\QueryString' => $vendorDir . '/league/uri-interfaces/QueryString.php',
    'League\\Uri\\SchemeType' => $vendorDir . '/league/uri/SchemeType.php',
    'League\\Uri\\Uri' => $vendorDir . '/league/uri/Uri.php',
    'League\\Uri\\UriComparisonMode' => $vendorDir . '/league/uri-interfaces/UriComparisonMode.php',
    'League\\Uri\\UriInfo' => $vendorDir . '/league/uri/UriInfo.php',
    'League\\Uri\\UriResolver' => $vendorDir . '/league/uri/UriResolver.php',
    'League\\Uri\\UriScheme' => $vendorDir . '/league/uri/UriScheme.php',
    'League\\Uri\\UriString' => $vendorDir . '/league/uri-interfaces/UriString.php',
    'League\\Uri\\UriTemplate' => $vendorDir . '/league/uri/UriTemplate.php',
    'League\\Uri\\UriTemplate\\Expression' => $vendorDir . '/league/uri/UriTemplate/Expression.php',
    'League\\Uri\\UriTemplate\\Operator' => $vendorDir . '/league/uri/UriTemplate/Operator.php',
    'League\\Uri\\UriTemplate\\Template' => $vendorDir . '/league/uri/UriTemplate/Template.php',
    'League\\Uri\\UriTemplate\\TemplateCanNotBeExpanded' => $vendorDir . '/league/uri/UriTemplate/TemplateCanNotBeExpanded.php',
    'League\\Uri\\UriTemplate\\VarSpecifier' => $vendorDir . '/league/uri/UriTemplate/VarSpecifier.php',
    'League\\Uri\\UriTemplate\\VariableBag' => $vendorDir . '/league/uri/UriTemplate/VariableBag.php',
    'League\\Uri\\Urn' => $vendorDir . '/league/uri/Urn.php',
    'League\\Uri\\UrnComparisonMode' => $vendorDir . '/league/uri-interfaces/UrnComparisonMode.php',
    'Marcelklehr\\LinkPreview\\Client' => $vendorDir . '/marcelklehr/link-preview/src/Client.php',
    'Marcelklehr\\LinkPreview\\Contracts\\LinkInterface' => $vendorDir . '/marcelklehr/link-preview/src/Contracts/LinkInterface.php',
    'Marcelklehr\\LinkPreview\\Contracts\\ParserInterface' => $vendorDir . '/marcelklehr/link-preview/src/Contracts/ParserInterface.php',
    'Marcelklehr\\LinkPreview\\Contracts\\PreviewInterface' => $vendorDir . '/marcelklehr/link-preview/src/Contracts/PreviewInterface.php',
    'Marcelklehr\\LinkPreview\\Exceptions\\ConnectionErrorException' => $vendorDir . '/marcelklehr/link-preview/src/Exceptions/ConnectionErrorException.php',
    'Marcelklehr\\LinkPreview\\Exceptions\\MalformedUrlException' => $vendorDir . '/marcelklehr/link-preview/src/Exceptions/MalformedUrlException.php',
    'Marcelklehr\\LinkPreview\\Exceptions\\UnknownFieldException' => $vendorDir . '/marcelklehr/link-preview/src/Exceptions/UnknownFieldException.php',
    'Marcelklehr\\LinkPreview\\Exceptions\\UnknownParserException' => $vendorDir . '/marcelklehr/link-preview/src/Exceptions/UnknownParserException.php',
    'Marcelklehr\\LinkPreview\\Models\\Link' => $vendorDir . '/marcelklehr/link-preview/src/Models/Link.php',
    'Marcelklehr\\LinkPreview\\Models\\Preview' => $vendorDir . '/marcelklehr/link-preview/src/Models/Preview.php',
    'Marcelklehr\\LinkPreview\\Parsers\\HtmlParser' => $vendorDir . '/marcelklehr/link-preview/src/Parsers/HtmlParser.php',
    'Marcelklehr\\LinkPreview\\Parsers\\VimeoParser' => $vendorDir . '/marcelklehr/link-preview/src/Parsers/VimeoParser.php',
    'Marcelklehr\\LinkPreview\\Parsers\\YouTubeParser' => $vendorDir . '/marcelklehr/link-preview/src/Parsers/YouTubeParser.php',
    'Masterminds\\HTML5' => $vendorDir . '/masterminds/html5/src/HTML5.php',
    'Masterminds\\HTML5\\Elements' => $vendorDir . '/masterminds/html5/src/HTML5/Elements.php',
    'Masterminds\\HTML5\\Entities' => $vendorDir . '/masterminds/html5/src/HTML5/Entities.php',
    'Masterminds\\HTML5\\Exception' => $vendorDir . '/masterminds/html5/src/HTML5/Exception.php',
    'Masterminds\\HTML5\\InstructionProcessor' => $vendorDir . '/masterminds/html5/src/HTML5/InstructionProcessor.php',
    'Masterminds\\HTML5\\Parser\\CharacterReference' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/CharacterReference.php',
    'Masterminds\\HTML5\\Parser\\DOMTreeBuilder' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/DOMTreeBuilder.php',
    'Masterminds\\HTML5\\Parser\\EventHandler' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/EventHandler.php',
    'Masterminds\\HTML5\\Parser\\FileInputStream' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/FileInputStream.php',
    'Masterminds\\HTML5\\Parser\\InputStream' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/InputStream.php',
    'Masterminds\\HTML5\\Parser\\ParseError' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/ParseError.php',
    'Masterminds\\HTML5\\Parser\\Scanner' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/Scanner.php',
    'Masterminds\\HTML5\\Parser\\StringInputStream' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/StringInputStream.php',
    'Masterminds\\HTML5\\Parser\\Tokenizer' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/Tokenizer.php',
    'Masterminds\\HTML5\\Parser\\TreeBuildingRules' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/TreeBuildingRules.php',
    'Masterminds\\HTML5\\Parser\\UTF8Utils' => $vendorDir . '/masterminds/html5/src/HTML5/Parser/UTF8Utils.php',
    'Masterminds\\HTML5\\Serializer\\HTML5Entities' => $vendorDir . '/masterminds/html5/src/HTML5/Serializer/HTML5Entities.php',
    'Masterminds\\HTML5\\Serializer\\OutputRules' => $vendorDir . '/masterminds/html5/src/HTML5/Serializer/OutputRules.php',
    'Masterminds\\HTML5\\Serializer\\RulesInterface' => $vendorDir . '/masterminds/html5/src/HTML5/Serializer/RulesInterface.php',
    'Masterminds\\HTML5\\Serializer\\Traverser' => $vendorDir . '/masterminds/html5/src/HTML5/Serializer/Traverser.php',
    'Mimey\\MimeMappingBuilder' => $vendorDir . '/xantios/mimey/src/MimeMappingBuilder.php',
    'Mimey\\MimeMappingGenerator' => $vendorDir . '/xantios/mimey/src/MimeMappingGenerator.php',
    'Mimey\\MimeTypes' => $vendorDir . '/xantios/mimey/src/MimeTypes.php',
    'Mimey\\MimeTypesInterface' => $vendorDir . '/xantios/mimey/src/MimeTypesInterface.php',
    'Normalizer' => $vendorDir . '/symfony/polyfill-intl-normalizer/Resources/stubs/Normalizer.php',
    'OCA\\Bookmarks\\Activity\\ActivityPublisher' => $baseDir . '/lib/Activity/ActivityPublisher.php',
    'OCA\\Bookmarks\\Activity\\Filter' => $baseDir . '/lib/Activity/Filter.php',
    'OCA\\Bookmarks\\Activity\\Provider' => $baseDir . '/lib/Activity/Provider.php',
    'OCA\\Bookmarks\\Activity\\Setting' => $baseDir . '/lib/Activity/Setting.php',
    'OCA\\Bookmarks\\AppInfo\\Application' => $baseDir . '/lib/AppInfo/Application.php',
    'OCA\\Bookmarks\\AugmentedTemplateResponse' => $baseDir . '/lib/AugmentedTemplateResponse.php',
    'OCA\\Bookmarks\\BackgroundJobs\\BackupJob' => $baseDir . '/lib/BackgroundJobs/BackupJob.php',
    'OCA\\Bookmarks\\BackgroundJobs\\ContextChatIndexJob' => $baseDir . '/lib/BackgroundJobs/ContextChatIndexJob.php',
    'OCA\\Bookmarks\\BackgroundJobs\\CrawlJob' => $baseDir . '/lib/BackgroundJobs/CrawlJob.php',
    'OCA\\Bookmarks\\BackgroundJobs\\EmptyTrashbinJob' => $baseDir . '/lib/BackgroundJobs/EmptyTrashbinJob.php',
    'OCA\\Bookmarks\\BackgroundJobs\\FileCacheGCJob' => $baseDir . '/lib/BackgroundJobs/FileCacheGCJob.php',
    'OCA\\Bookmarks\\BackgroundJobs\\IndividualCrawlJob' => $baseDir . '/lib/BackgroundJobs/IndividualCrawlJob.php',
    'OCA\\Bookmarks\\Capabilities' => $baseDir . '/lib/Capabilities.php',
    'OCA\\Bookmarks\\Command\\ClearPreviews' => $baseDir . '/lib/Command/ClearPreviews.php',
    'OCA\\Bookmarks\\ContextChat\\ContextChatProvider' => $baseDir . '/lib/ContextChat/ContextChatProvider.php',
    'OCA\\Bookmarks\\Contract\\IBookmarkPreviewer' => $baseDir . '/lib/Contract/IBookmarkPreviewer.php',
    'OCA\\Bookmarks\\Contract\\IImage' => $baseDir . '/lib/Contract/IImage.php',
    'OCA\\Bookmarks\\Controller\\AdminController' => $baseDir . '/lib/Controller/AdminController.php',
    'OCA\\Bookmarks\\Controller\\BookmarkController' => $baseDir . '/lib/Controller/BookmarkController.php',
    'OCA\\Bookmarks\\Controller\\FoldersController' => $baseDir . '/lib/Controller/FoldersController.php',
    'OCA\\Bookmarks\\Controller\\InternalBookmarkController' => $baseDir . '/lib/Controller/InternalBookmarkController.php',
    'OCA\\Bookmarks\\Controller\\InternalFoldersController' => $baseDir . '/lib/Controller/InternalFoldersController.php',
    'OCA\\Bookmarks\\Controller\\InternalTagsController' => $baseDir . '/lib/Controller/InternalTagsController.php',
    'OCA\\Bookmarks\\Controller\\SettingsController' => $baseDir . '/lib/Controller/SettingsController.php',
    'OCA\\Bookmarks\\Controller\\TagsController' => $baseDir . '/lib/Controller/TagsController.php',
    'OCA\\Bookmarks\\Controller\\WebViewController' => $baseDir . '/lib/Controller/WebViewController.php',
    'OCA\\Bookmarks\\Dashboard\\Frequent' => $baseDir . '/lib/Dashboard/Frequent.php',
    'OCA\\Bookmarks\\Dashboard\\Recent' => $baseDir . '/lib/Dashboard/Recent.php',
    'OCA\\Bookmarks\\Db\\Bookmark' => $baseDir . '/lib/Db/Bookmark.php',
    'OCA\\Bookmarks\\Db\\BookmarkMapper' => $baseDir . '/lib/Db/BookmarkMapper.php',
    'OCA\\Bookmarks\\Db\\BookmarkWithTagsAndParent' => $baseDir . '/lib/Db/BookmarkWithTagsAndParent.php',
    'OCA\\Bookmarks\\Db\\Folder' => $baseDir . '/lib/Db/Folder.php',
    'OCA\\Bookmarks\\Db\\FolderMapper' => $baseDir . '/lib/Db/FolderMapper.php',
    'OCA\\Bookmarks\\Db\\PublicFolder' => $baseDir . '/lib/Db/PublicFolder.php',
    'OCA\\Bookmarks\\Db\\PublicFolderMapper' => $baseDir . '/lib/Db/PublicFolderMapper.php',
    'OCA\\Bookmarks\\Db\\Share' => $baseDir . '/lib/Db/Share.php',
    'OCA\\Bookmarks\\Db\\ShareMapper' => $baseDir . '/lib/Db/ShareMapper.php',
    'OCA\\Bookmarks\\Db\\SharedFolder' => $baseDir . '/lib/Db/SharedFolder.php',
    'OCA\\Bookmarks\\Db\\SharedFolderMapper' => $baseDir . '/lib/Db/SharedFolderMapper.php',
    'OCA\\Bookmarks\\Db\\TagMapper' => $baseDir . '/lib/Db/TagMapper.php',
    'OCA\\Bookmarks\\Db\\TreeMapper' => $baseDir . '/lib/Db/TreeMapper.php',
    'OCA\\Bookmarks\\Db\\Types' => $baseDir . '/lib/Db/Types.php',
    'OCA\\Bookmarks\\Events\\BeforeDeleteEvent' => $baseDir . '/lib/Events/BeforeDeleteEvent.php',
    'OCA\\Bookmarks\\Events\\BeforeSoftDeleteEvent' => $baseDir . '/lib/Events/BeforeSoftDeleteEvent.php',
    'OCA\\Bookmarks\\Events\\BeforeSoftUndeleteEvent' => $baseDir . '/lib/Events/BeforeSoftUndeleteEvent.php',
    'OCA\\Bookmarks\\Events\\ChangeEvent' => $baseDir . '/lib/Events/ChangeEvent.php',
    'OCA\\Bookmarks\\Events\\CreateEvent' => $baseDir . '/lib/Events/CreateEvent.php',
    'OCA\\Bookmarks\\Events\\InsertEvent' => $baseDir . '/lib/Events/InsertEvent.php',
    'OCA\\Bookmarks\\Events\\ManipulateEvent' => $baseDir . '/lib/Events/ManipulateEvent.php',
    'OCA\\Bookmarks\\Events\\MoveEvent' => $baseDir . '/lib/Events/MoveEvent.php',
    'OCA\\Bookmarks\\Events\\UpdateEvent' => $baseDir . '/lib/Events/UpdateEvent.php',
    'OCA\\Bookmarks\\Exception\\AlreadyExistsError' => $baseDir . '/lib/Exception/AlreadyExistsError.php',
    'OCA\\Bookmarks\\Exception\\ChildrenOrderValidationError' => $baseDir . '/lib/Exception/ChildrenOrderValidationError.php',
    'OCA\\Bookmarks\\Exception\\Exception' => $baseDir . '/lib/Exception/Exception.php',
    'OCA\\Bookmarks\\Exception\\HtmlParseError' => $baseDir . '/lib/Exception/HtmlParseError.php',
    'OCA\\Bookmarks\\Exception\\UnauthenticatedError' => $baseDir . '/lib/Exception/UnauthenticatedError.php',
    'OCA\\Bookmarks\\Exception\\UnauthorizedAccessError' => $baseDir . '/lib/Exception/UnauthorizedAccessError.php',
    'OCA\\Bookmarks\\Exception\\UnsupportedOperation' => $baseDir . '/lib/Exception/UnsupportedOperation.php',
    'OCA\\Bookmarks\\Exception\\UrlParseError' => $baseDir . '/lib/Exception/UrlParseError.php',
    'OCA\\Bookmarks\\Exception\\UserLimitExceededError' => $baseDir . '/lib/Exception/UserLimitExceededError.php',
    'OCA\\Bookmarks\\ExportResponse' => $baseDir . '/lib/ExportResponse.php',
    'OCA\\Bookmarks\\Flow\\Bookmark' => $baseDir . '/lib/Flow/Bookmark.php',
    'OCA\\Bookmarks\\Flow\\CreateBookmark' => $baseDir . '/lib/Flow/CreateBookmark.php',
    'OCA\\Bookmarks\\Helper' => $baseDir . '/lib/Helper.php',
    'OCA\\Bookmarks\\Hooks\\BeforeTemplateRenderedListener' => $baseDir . '/lib/Hooks/BeforeTemplateRenderedListener.php',
    'OCA\\Bookmarks\\Hooks\\UsersGroupsCirclesListener' => $baseDir . '/lib/Hooks/UsersGroupsCirclesListener.php',
    'OCA\\Bookmarks\\Http\\Client' => $baseDir . '/lib/Http/Client.php',
    'OCA\\Bookmarks\\Http\\RequestFactory' => $baseDir . '/lib/Http/RequestFactory.php',
    'OCA\\Bookmarks\\Image' => $baseDir . '/lib/Image.php',
    'OCA\\Bookmarks\\Middleware\\ExceptionMiddleware' => $baseDir . '/lib/Middleware/ExceptionMiddleware.php',
    'OCA\\Bookmarks\\Middleware\\TicketMiddleware' => $baseDir . '/lib/Middleware/TicketMiddleware.php',
    'OCA\\Bookmarks\\Migration\\DeduplicateSharedFoldersRepairStep' => $baseDir . '/lib/Migration/DeduplicateSharedFoldersRepairStep.php',
    'OCA\\Bookmarks\\Migration\\GroupSharesUpdateRepairStep' => $baseDir . '/lib/Migration/GroupSharesUpdateRepairStep.php',
    'OCA\\Bookmarks\\Migration\\OrphanedSharesRepairStep' => $baseDir . '/lib/Migration/OrphanedSharesRepairStep.php',
    'OCA\\Bookmarks\\Migration\\OrphanedTreeItemsRepairStep' => $baseDir . '/lib/Migration/OrphanedTreeItemsRepairStep.php',
    'OCA\\Bookmarks\\Migration\\SuperfluousSharedFoldersRepairStep' => $baseDir . '/lib/Migration/SuperfluousSharedFoldersRepairStep.php',
    'OCA\\Bookmarks\\Migration\\UninstallRepairStep' => $baseDir . '/lib/Migration/UninstallRepairStep.php',
    'OCA\\Bookmarks\\Migration\\Version000014000Date20181002094721' => $baseDir . '/lib/Migration/Version000014000Date20181002094721.php',
    'OCA\\Bookmarks\\Migration\\Version000014000Date20181029094721' => $baseDir . '/lib/Migration/Version000014000Date20181029094721.php',
    'OCA\\Bookmarks\\Migration\\Version000016005Date20190402094721' => $baseDir . '/lib/Migration/Version000016005Date20190402094721.php',
    'OCA\\Bookmarks\\Migration\\Version001000007Date20190721094721' => $baseDir . '/lib/Migration/Version001000007Date20190721094721.php',
    'OCA\\Bookmarks\\Migration\\Version003000000Date20191123094721' => $baseDir . '/lib/Migration/Version003000000Date20191123094721.php',
    'OCA\\Bookmarks\\Migration\\Version003000000Date20191129094721' => $baseDir . '/lib/Migration/Version003000000Date20191129094721.php',
    'OCA\\Bookmarks\\Migration\\Version003000009Date20200505094721' => $baseDir . '/lib/Migration/Version003000009Date20200505094721.php',
    'OCA\\Bookmarks\\Migration\\Version003001000Date20200526094721' => $baseDir . '/lib/Migration/Version003001000Date20200526094721.php',
    'OCA\\Bookmarks\\Migration\\Version003001000Date20200526124721' => $baseDir . '/lib/Migration/Version003001000Date20200526124721.php',
    'OCA\\Bookmarks\\Migration\\Version003004000Date20200807124721' => $baseDir . '/lib/Migration/Version003004000Date20200807124721.php',
    'OCA\\Bookmarks\\Migration\\Version003004000Date20200817124721' => $baseDir . '/lib/Migration/Version003004000Date20200817124721.php',
    'OCA\\Bookmarks\\Migration\\Version004002000Date20210208124721' => $baseDir . '/lib/Migration/Version004002000Date20210208124721.php',
    'OCA\\Bookmarks\\Migration\\Version004003000Date20210718124721' => $baseDir . '/lib/Migration/Version004003000Date20210718124721.php',
    'OCA\\Bookmarks\\Migration\\Version004003001Date20210723124721' => $baseDir . '/lib/Migration/Version004003001Date20210723124721.php',
    'OCA\\Bookmarks\\Migration\\Version004005000Date20210918124721' => $baseDir . '/lib/Migration/Version004005000Date20210918124721.php',
    'OCA\\Bookmarks\\Migration\\Version010002000Date20220319124721' => $baseDir . '/lib/Migration/Version010002000Date20220319124721.php',
    'OCA\\Bookmarks\\Migration\\Version014001000Date20240524124721' => $baseDir . '/lib/Migration/Version014001000Date20240524124721.php',
    'OCA\\Bookmarks\\Migration\\Version016002000Date20260201124723' => $baseDir . '/lib/Migration/Version016002000Date20260201124723.php',
    'OCA\\Bookmarks\\Migration\\Version016002000Date20260218124723' => $baseDir . '/lib/Migration/Version016002000Date20260218124723.php',
    'OCA\\Bookmarks\\Migration\\Version016002000Date20260218134723' => $baseDir . '/lib/Migration/Version016002000Date20260218134723.php',
    'OCA\\Bookmarks\\QueryParameters' => $baseDir . '/lib/QueryParameters.php',
    'OCA\\Bookmarks\\Reference\\BookmarkReferenceProvider' => $baseDir . '/lib/Reference/BookmarkReferenceProvider.php',
    'OCA\\Bookmarks\\Search\\Provider' => $baseDir . '/lib/Search/Provider.php',
    'OCA\\Bookmarks\\Search\\SearchResultEntry' => $baseDir . '/lib/Search/SearchResultEntry.php',
    'OCA\\Bookmarks\\Service\\Authorizer' => $baseDir . '/lib/Service/Authorizer.php',
    'OCA\\Bookmarks\\Service\\BackupManager' => $baseDir . '/lib/Service/BackupManager.php',
    'OCA\\Bookmarks\\Service\\BookmarkPreviewer' => $baseDir . '/lib/Service/BookmarkPreviewer.php',
    'OCA\\Bookmarks\\Service\\BookmarkService' => $baseDir . '/lib/Service/BookmarkService.php',
    'OCA\\Bookmarks\\Service\\BookmarksParser' => $baseDir . '/lib/Service/BookmarksParser.php',
    'OCA\\Bookmarks\\Service\\CirclesService' => $baseDir . '/lib/Service/CirclesService.php',
    'OCA\\Bookmarks\\Service\\CrawlService' => $baseDir . '/lib/Service/CrawlService.php',
    'OCA\\Bookmarks\\Service\\FaviconPreviewer' => $baseDir . '/lib/Service/FaviconPreviewer.php',
    'OCA\\Bookmarks\\Service\\FileCache' => $baseDir . '/lib/Service/FileCache.php',
    'OCA\\Bookmarks\\Service\\FolderService' => $baseDir . '/lib/Service/FolderService.php',
    'OCA\\Bookmarks\\Service\\HtmlExporter' => $baseDir . '/lib/Service/HtmlExporter.php',
    'OCA\\Bookmarks\\Service\\HtmlImporter' => $baseDir . '/lib/Service/HtmlImporter.php',
    'OCA\\Bookmarks\\Service\\LinkExplorer' => $baseDir . '/lib/Service/LinkExplorer.php',
    'OCA\\Bookmarks\\Service\\LockManager' => $baseDir . '/lib/Service/LockManager.php',
    'OCA\\Bookmarks\\Service\\Previewers\\DefaultBookmarkPreviewer' => $baseDir . '/lib/Service/Previewers/DefaultBookmarkPreviewer.php',
    'OCA\\Bookmarks\\Service\\Previewers\\GenericUrlBookmarkPreviewer' => $baseDir . '/lib/Service/Previewers/GenericUrlBookmarkPreviewer.php',
    'OCA\\Bookmarks\\Service\\Previewers\\PageresBookmarkPreviewer' => $baseDir . '/lib/Service/Previewers/PageresBookmarkPreviewer.php',
    'OCA\\Bookmarks\\Service\\Previewers\\ScreeenlyBookmarkPreviewer' => $baseDir . '/lib/Service/Previewers/ScreeenlyBookmarkPreviewer.php',
    'OCA\\Bookmarks\\Service\\Previewers\\ScreenshotMachineBookmarkPreviewer' => $baseDir . '/lib/Service/Previewers/ScreenshotMachineBookmarkPreviewer.php',
    'OCA\\Bookmarks\\Service\\Previewers\\WebshotBookmarkPreviewer' => $baseDir . '/lib/Service/Previewers/WebshotBookmarkPreviewer.php',
    'OCA\\Bookmarks\\Service\\SettingsService' => $baseDir . '/lib/Service/SettingsService.php',
    'OCA\\Bookmarks\\Service\\TreeCacheManager' => $baseDir . '/lib/Service/TreeCacheManager.php',
    'OCA\\Bookmarks\\Service\\UrlNormalizer' => $baseDir . '/lib/Service/UrlNormalizer.php',
    'OCA\\Bookmarks\\Service\\UserSettingsService' => $baseDir . '/lib/Service/UserSettingsService.php',
    'OCA\\Bookmarks\\Settings\\AdminSection' => $baseDir . '/lib/Settings/AdminSection.php',
    'OCA\\Bookmarks\\Settings\\AdminSettings' => $baseDir . '/lib/Settings/AdminSettings.php',
    'Psr\\Http\\Client\\ClientExceptionInterface' => $vendorDir . '/psr/http-client/src/ClientExceptionInterface.php',
    'Psr\\Http\\Client\\ClientInterface' => $vendorDir . '/psr/http-client/src/ClientInterface.php',
    'Psr\\Http\\Client\\NetworkExceptionInterface' => $vendorDir . '/psr/http-client/src/NetworkExceptionInterface.php',
    'Psr\\Http\\Client\\RequestExceptionInterface' => $vendorDir . '/psr/http-client/src/RequestExceptionInterface.php',
    'Psr\\Http\\Message\\MessageInterface' => $vendorDir . '/psr/http-message/src/MessageInterface.php',
    'Psr\\Http\\Message\\RequestFactoryInterface' => $vendorDir . '/psr/http-factory/src/RequestFactoryInterface.php',
    'Psr\\Http\\Message\\RequestInterface' => $vendorDir . '/psr/http-message/src/RequestInterface.php',
    'Psr\\Http\\Message\\ResponseFactoryInterface' => $vendorDir . '/psr/http-factory/src/ResponseFactoryInterface.php',
    'Psr\\Http\\Message\\ResponseInterface' => $vendorDir . '/psr/http-message/src/ResponseInterface.php',
    'Psr\\Http\\Message\\ServerRequestFactoryInterface' => $vendorDir . '/psr/http-factory/src/ServerRequestFactoryInterface.php',
    'Psr\\Http\\Message\\ServerRequestInterface' => $vendorDir . '/psr/http-message/src/ServerRequestInterface.php',
    'Psr\\Http\\Message\\StreamFactoryInterface' => $vendorDir . '/psr/http-factory/src/StreamFactoryInterface.php',
    'Psr\\Http\\Message\\StreamInterface' => $vendorDir . '/psr/http-message/src/StreamInterface.php',
    'Psr\\Http\\Message\\UploadedFileFactoryInterface' => $vendorDir . '/psr/http-factory/src/UploadedFileFactoryInterface.php',
    'Psr\\Http\\Message\\UploadedFileInterface' => $vendorDir . '/psr/http-message/src/UploadedFileInterface.php',
    'Psr\\Http\\Message\\UriFactoryInterface' => $vendorDir . '/psr/http-factory/src/UriFactoryInterface.php',
    'Psr\\Http\\Message\\UriInterface' => $vendorDir . '/psr/http-message/src/UriInterface.php',
    'Psr\\Log\\AbstractLogger' => $vendorDir . '/psr/log/src/AbstractLogger.php',
    'Psr\\Log\\InvalidArgumentException' => $vendorDir . '/psr/log/src/InvalidArgumentException.php',
    'Psr\\Log\\LogLevel' => $vendorDir . '/psr/log/src/LogLevel.php',
    'Psr\\Log\\LoggerAwareInterface' => $vendorDir . '/psr/log/src/LoggerAwareInterface.php',
    'Psr\\Log\\LoggerAwareTrait' => $vendorDir . '/psr/log/src/LoggerAwareTrait.php',
    'Psr\\Log\\LoggerInterface' => $vendorDir . '/psr/log/src/LoggerInterface.php',
    'Psr\\Log\\LoggerTrait' => $vendorDir . '/psr/log/src/LoggerTrait.php',
    'Psr\\Log\\NullLogger' => $vendorDir . '/psr/log/src/NullLogger.php',
    'Rowbot\\Idna\\CodePoint' => $vendorDir . '/rowbot/idna/src/CodePoint.php',
    'Rowbot\\Idna\\CodePointStatus' => $vendorDir . '/rowbot/idna/src/CodePointStatus.php',
    'Rowbot\\Idna\\DomainInfo' => $vendorDir . '/rowbot/idna/src/DomainInfo.php',
    'Rowbot\\Idna\\Idna' => $vendorDir . '/rowbot/idna/src/Idna.php',
    'Rowbot\\Idna\\IdnaResult' => $vendorDir . '/rowbot/idna/src/IdnaResult.php',
    'Rowbot\\Idna\\LabelValidator' => $vendorDir . '/rowbot/idna/src/LabelValidator.php',
    'Rowbot\\Idna\\Resource\\DisallowedRanges' => $vendorDir . '/rowbot/idna/resources/DisallowedRanges.php',
    'Rowbot\\Idna\\Resource\\Regex' => $vendorDir . '/rowbot/idna/resources/Regex.php',
    'Rowbot\\Punycode\\Exception\\InvalidInputException' => $vendorDir . '/rowbot/punycode/src/Exception/InvalidInputException.php',
    'Rowbot\\Punycode\\Exception\\OutputSizeExceededException' => $vendorDir . '/rowbot/punycode/src/Exception/OutputSizeExceededException.php',
    'Rowbot\\Punycode\\Exception\\OverflowException' => $vendorDir . '/rowbot/punycode/src/Exception/OverflowException.php',
    'Rowbot\\Punycode\\Exception\\PunycodeException' => $vendorDir . '/rowbot/punycode/src/Exception/PunycodeException.php',
    'Rowbot\\Punycode\\Punycode' => $vendorDir . '/rowbot/punycode/src/Punycode.php',
    'Rowbot\\URL\\APIParserErrorType' => $vendorDir . '/rowbot/url/src/APIParserErrorType.php',
    'Rowbot\\URL\\APIParserResult' => $vendorDir . '/rowbot/url/src/APIParserResult.php',
    'Rowbot\\URL\\BasicURLParser' => $vendorDir . '/rowbot/url/src/BasicURLParser.php',
    'Rowbot\\URL\\Component\\AbstractPath' => $vendorDir . '/rowbot/url/src/Component/AbstractPath.php',
    'Rowbot\\URL\\Component\\Host\\AbstractHost' => $vendorDir . '/rowbot/url/src/Component/Host/AbstractHost.php',
    'Rowbot\\URL\\Component\\Host\\HostInterface' => $vendorDir . '/rowbot/url/src/Component/Host/HostInterface.php',
    'Rowbot\\URL\\Component\\Host\\HostParser' => $vendorDir . '/rowbot/url/src/Component/Host/HostParser.php',
    'Rowbot\\URL\\Component\\Host\\IPv4Address' => $vendorDir . '/rowbot/url/src/Component/Host/IPv4Address.php',
    'Rowbot\\URL\\Component\\Host\\IPv4AddressParser' => $vendorDir . '/rowbot/url/src/Component/Host/IPv4AddressParser.php',
    'Rowbot\\URL\\Component\\Host\\IPv6Address' => $vendorDir . '/rowbot/url/src/Component/Host/IPv6Address.php',
    'Rowbot\\URL\\Component\\Host\\IPv6AddressParser' => $vendorDir . '/rowbot/url/src/Component/Host/IPv6AddressParser.php',
    'Rowbot\\URL\\Component\\Host\\Math\\BrickMathAdapter' => $vendorDir . '/rowbot/url/src/Component/Host/Math/BrickMathAdapter.php',
    'Rowbot\\URL\\Component\\Host\\Math\\Exception\\MathException' => $vendorDir . '/rowbot/url/src/Component/Host/Math/Exception/MathException.php',
    'Rowbot\\URL\\Component\\Host\\Math\\NativeIntAdapter' => $vendorDir . '/rowbot/url/src/Component/Host/Math/NativeIntAdapter.php',
    'Rowbot\\URL\\Component\\Host\\Math\\NumberFactory' => $vendorDir . '/rowbot/url/src/Component/Host/Math/NumberFactory.php',
    'Rowbot\\URL\\Component\\Host\\Math\\NumberInterface' => $vendorDir . '/rowbot/url/src/Component/Host/Math/NumberInterface.php',
    'Rowbot\\URL\\Component\\Host\\NullHost' => $vendorDir . '/rowbot/url/src/Component/Host/NullHost.php',
    'Rowbot\\URL\\Component\\Host\\Serializer\\HostSerializerInterface' => $vendorDir . '/rowbot/url/src/Component/Host/Serializer/HostSerializerInterface.php',
    'Rowbot\\URL\\Component\\Host\\Serializer\\IPv4AddressSerializer' => $vendorDir . '/rowbot/url/src/Component/Host/Serializer/IPv4AddressSerializer.php',
    'Rowbot\\URL\\Component\\Host\\Serializer\\IPv6AddressSerializer' => $vendorDir . '/rowbot/url/src/Component/Host/Serializer/IPv6AddressSerializer.php',
    'Rowbot\\URL\\Component\\Host\\Serializer\\StringHostSerializer' => $vendorDir . '/rowbot/url/src/Component/Host/Serializer/StringHostSerializer.php',
    'Rowbot\\URL\\Component\\Host\\StringHost' => $vendorDir . '/rowbot/url/src/Component/Host/StringHost.php',
    'Rowbot\\URL\\Component\\OpaqueOrigin' => $vendorDir . '/rowbot/url/src/Component/OpaqueOrigin.php',
    'Rowbot\\URL\\Component\\OpaquePath' => $vendorDir . '/rowbot/url/src/Component/OpaquePath.php',
    'Rowbot\\URL\\Component\\PathInterface' => $vendorDir . '/rowbot/url/src/Component/PathInterface.php',
    'Rowbot\\URL\\Component\\PathList' => $vendorDir . '/rowbot/url/src/Component/PathList.php',
    'Rowbot\\URL\\Component\\PathSegment' => $vendorDir . '/rowbot/url/src/Component/PathSegment.php',
    'Rowbot\\URL\\Component\\QueryList' => $vendorDir . '/rowbot/url/src/Component/QueryList.php',
    'Rowbot\\URL\\Component\\Scheme' => $vendorDir . '/rowbot/url/src/Component/Scheme.php',
    'Rowbot\\URL\\Component\\TupleOrigin' => $vendorDir . '/rowbot/url/src/Component/TupleOrigin.php',
    'Rowbot\\URL\\Exception\\TypeError' => $vendorDir . '/rowbot/url/src/Exception/TypeError.php',
    'Rowbot\\URL\\Exception\\URLException' => $vendorDir . '/rowbot/url/src/Exception/URLException.php',
    'Rowbot\\URL\\Exception\\UnsupportedOperationException' => $vendorDir . '/rowbot/url/src/Exception/UnsupportedOperationException.php',
    'Rowbot\\URL\\Origin' => $vendorDir . '/rowbot/url/src/Origin.php',
    'Rowbot\\URL\\ParserContext' => $vendorDir . '/rowbot/url/src/ParserContext.php',
    'Rowbot\\URL\\ParserState' => $vendorDir . '/rowbot/url/src/ParserState.php',
    'Rowbot\\URL\\State\\AbstractHostState' => $vendorDir . '/rowbot/url/src/State/AbstractHostState.php',
    'Rowbot\\URL\\State\\AuthorityState' => $vendorDir . '/rowbot/url/src/State/AuthorityState.php',
    'Rowbot\\URL\\State\\FileHostState' => $vendorDir . '/rowbot/url/src/State/FileHostState.php',
    'Rowbot\\URL\\State\\FileSlashState' => $vendorDir . '/rowbot/url/src/State/FileSlashState.php',
    'Rowbot\\URL\\State\\FileState' => $vendorDir . '/rowbot/url/src/State/FileState.php',
    'Rowbot\\URL\\State\\FragmentState' => $vendorDir . '/rowbot/url/src/State/FragmentState.php',
    'Rowbot\\URL\\State\\HostState' => $vendorDir . '/rowbot/url/src/State/HostState.php',
    'Rowbot\\URL\\State\\HostnameState' => $vendorDir . '/rowbot/url/src/State/HostnameState.php',
    'Rowbot\\URL\\State\\NoSchemeState' => $vendorDir . '/rowbot/url/src/State/NoSchemeState.php',
    'Rowbot\\URL\\State\\OpaquePathState' => $vendorDir . '/rowbot/url/src/State/OpaquePathState.php',
    'Rowbot\\URL\\State\\PathOrAuthorityState' => $vendorDir . '/rowbot/url/src/State/PathOrAuthorityState.php',
    'Rowbot\\URL\\State\\PathStartState' => $vendorDir . '/rowbot/url/src/State/PathStartState.php',
    'Rowbot\\URL\\State\\PathState' => $vendorDir . '/rowbot/url/src/State/PathState.php',
    'Rowbot\\URL\\State\\PortState' => $vendorDir . '/rowbot/url/src/State/PortState.php',
    'Rowbot\\URL\\State\\QueryState' => $vendorDir . '/rowbot/url/src/State/QueryState.php',
    'Rowbot\\URL\\State\\RelativeSlashState' => $vendorDir . '/rowbot/url/src/State/RelativeSlashState.php',
    'Rowbot\\URL\\State\\RelativeState' => $vendorDir . '/rowbot/url/src/State/RelativeState.php',
    'Rowbot\\URL\\State\\SchemeStartState' => $vendorDir . '/rowbot/url/src/State/SchemeStartState.php',
    'Rowbot\\URL\\State\\SchemeState' => $vendorDir . '/rowbot/url/src/State/SchemeState.php',
    'Rowbot\\URL\\State\\SpecialAuthorityIgnoreSlashesState' => $vendorDir . '/rowbot/url/src/State/SpecialAuthorityIgnoreSlashesState.php',
    'Rowbot\\URL\\State\\SpecialAuthoritySlashesState' => $vendorDir . '/rowbot/url/src/State/SpecialAuthoritySlashesState.php',
    'Rowbot\\URL\\State\\SpecialRelativeOrAuthorityState' => $vendorDir . '/rowbot/url/src/State/SpecialRelativeOrAuthorityState.php',
    'Rowbot\\URL\\State\\State' => $vendorDir . '/rowbot/url/src/State/State.php',
    'Rowbot\\URL\\State\\StatusCode' => $vendorDir . '/rowbot/url/src/State/StatusCode.php',
    'Rowbot\\URL\\String\\AbstractStringBuffer' => $vendorDir . '/rowbot/url/src/String/AbstractStringBuffer.php',
    'Rowbot\\URL\\String\\AbstractStringList' => $vendorDir . '/rowbot/url/src/String/AbstractStringList.php',
    'Rowbot\\URL\\String\\AbstractUSVString' => $vendorDir . '/rowbot/url/src/String/AbstractUSVString.php',
    'Rowbot\\URL\\String\\CodePoint' => $vendorDir . '/rowbot/url/src/String/CodePoint.php',
    'Rowbot\\URL\\String\\EncodeSet' => $vendorDir . '/rowbot/url/src/String/EncodeSet.php',
    'Rowbot\\URL\\String\\Exception\\EncodingException' => $vendorDir . '/rowbot/url/src/String/Exception/EncodingException.php',
    'Rowbot\\URL\\String\\Exception\\RegexException' => $vendorDir . '/rowbot/url/src/String/Exception/RegexException.php',
    'Rowbot\\URL\\String\\Exception\\UndefinedIndexException' => $vendorDir . '/rowbot/url/src/String/Exception/UndefinedIndexException.php',
    'Rowbot\\URL\\String\\PercentEncoder' => $vendorDir . '/rowbot/url/src/String/PercentEncoder.php',
    'Rowbot\\URL\\String\\StringBuffer' => $vendorDir . '/rowbot/url/src/String/StringBuffer.php',
    'Rowbot\\URL\\String\\StringBufferInterface' => $vendorDir . '/rowbot/url/src/String/StringBufferInterface.php',
    'Rowbot\\URL\\String\\StringIteratorInterface' => $vendorDir . '/rowbot/url/src/String/StringIteratorInterface.php',
    'Rowbot\\URL\\String\\StringList' => $vendorDir . '/rowbot/url/src/String/StringList.php',
    'Rowbot\\URL\\String\\StringListInterface' => $vendorDir . '/rowbot/url/src/String/StringListInterface.php',
    'Rowbot\\URL\\String\\USVStringInterface' => $vendorDir . '/rowbot/url/src/String/USVStringInterface.php',
    'Rowbot\\URL\\String\\Utf8String' => $vendorDir . '/rowbot/url/src/String/Utf8String.php',
    'Rowbot\\URL\\String\\Utf8StringIterator' => $vendorDir . '/rowbot/url/src/String/Utf8StringIterator.php',
    'Rowbot\\URL\\Support\\EncodingHelper' => $vendorDir . '/rowbot/url/src/Support/EncodingHelper.php',
    'Rowbot\\URL\\URL' => $vendorDir . '/rowbot/url/src/URL.php',
    'Rowbot\\URL\\URLRecord' => $vendorDir . '/rowbot/url/src/URLRecord.php',
    'Rowbot\\URL\\URLSearchParams' => $vendorDir . '/rowbot/url/src/URLSearchParams.php',
    'Symfony\\Component\\CssSelector\\CssSelectorConverter' => $vendorDir . '/symfony/css-selector/CssSelectorConverter.php',
    'Symfony\\Component\\CssSelector\\Exception\\ExceptionInterface' => $vendorDir . '/symfony/css-selector/Exception/ExceptionInterface.php',
    'Symfony\\Component\\CssSelector\\Exception\\ExpressionErrorException' => $vendorDir . '/symfony/css-selector/Exception/ExpressionErrorException.php',
    'Symfony\\Component\\CssSelector\\Exception\\InternalErrorException' => $vendorDir . '/symfony/css-selector/Exception/InternalErrorException.php',
    'Symfony\\Component\\CssSelector\\Exception\\ParseException' => $vendorDir . '/symfony/css-selector/Exception/ParseException.php',
    'Symfony\\Component\\CssSelector\\Exception\\SyntaxErrorException' => $vendorDir . '/symfony/css-selector/Exception/SyntaxErrorException.php',
    'Symfony\\Component\\CssSelector\\Node\\AbstractNode' => $vendorDir . '/symfony/css-selector/Node/AbstractNode.php',
    'Symfony\\Component\\CssSelector\\Node\\AttributeNode' => $vendorDir . '/symfony/css-selector/Node/AttributeNode.php',
    'Symfony\\Component\\CssSelector\\Node\\ClassNode' => $vendorDir . '/symfony/css-selector/Node/ClassNode.php',
    'Symfony\\Component\\CssSelector\\Node\\CombinedSelectorNode' => $vendorDir . '/symfony/css-selector/Node/CombinedSelectorNode.php',
    'Symfony\\Component\\CssSelector\\Node\\ElementNode' => $vendorDir . '/symfony/css-selector/Node/ElementNode.php',
    'Symfony\\Component\\CssSelector\\Node\\FunctionNode' => $vendorDir . '/symfony/css-selector/Node/FunctionNode.php',
    'Symfony\\Component\\CssSelector\\Node\\HashNode' => $vendorDir . '/symfony/css-selector/Node/HashNode.php',
    'Symfony\\Component\\CssSelector\\Node\\NegationNode' => $vendorDir . '/symfony/css-selector/Node/NegationNode.php',
    'Symfony\\Component\\CssSelector\\Node\\NodeInterface' => $vendorDir . '/symfony/css-selector/Node/NodeInterface.php',
    'Symfony\\Component\\CssSelector\\Node\\PseudoNode' => $vendorDir . '/symfony/css-selector/Node/PseudoNode.php',
    'Symfony\\Component\\CssSelector\\Node\\SelectorNode' => $vendorDir . '/symfony/css-selector/Node/SelectorNode.php',
    'Symfony\\Component\\CssSelector\\Node\\Specificity' => $vendorDir . '/symfony/css-selector/Node/Specificity.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\CommentHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/CommentHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\HandlerInterface' => $vendorDir . '/symfony/css-selector/Parser/Handler/HandlerInterface.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\HashHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/HashHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\IdentifierHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/IdentifierHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\NumberHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/NumberHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\StringHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/StringHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Handler\\WhitespaceHandler' => $vendorDir . '/symfony/css-selector/Parser/Handler/WhitespaceHandler.php',
    'Symfony\\Component\\CssSelector\\Parser\\Parser' => $vendorDir . '/symfony/css-selector/Parser/Parser.php',
    'Symfony\\Component\\CssSelector\\Parser\\ParserInterface' => $vendorDir . '/symfony/css-selector/Parser/ParserInterface.php',
    'Symfony\\Component\\CssSelector\\Parser\\Reader' => $vendorDir . '/symfony/css-selector/Parser/Reader.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\ClassParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/ClassParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\ElementParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/ElementParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\EmptyStringParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/EmptyStringParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Shortcut\\HashParser' => $vendorDir . '/symfony/css-selector/Parser/Shortcut/HashParser.php',
    'Symfony\\Component\\CssSelector\\Parser\\Token' => $vendorDir . '/symfony/css-selector/Parser/Token.php',
    'Symfony\\Component\\CssSelector\\Parser\\TokenStream' => $vendorDir . '/symfony/css-selector/Parser/TokenStream.php',
    'Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\Tokenizer' => $vendorDir . '/symfony/css-selector/Parser/Tokenizer/Tokenizer.php',
    'Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\TokenizerEscaping' => $vendorDir . '/symfony/css-selector/Parser/Tokenizer/TokenizerEscaping.php',
    'Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\TokenizerPatterns' => $vendorDir . '/symfony/css-selector/Parser/Tokenizer/TokenizerPatterns.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\AbstractExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/AbstractExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\AttributeMatchingExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/AttributeMatchingExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\CombinationExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/CombinationExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\ExtensionInterface' => $vendorDir . '/symfony/css-selector/XPath/Extension/ExtensionInterface.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\FunctionExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/FunctionExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\HtmlExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/HtmlExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\NodeExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/NodeExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Extension\\PseudoClassExtension' => $vendorDir . '/symfony/css-selector/XPath/Extension/PseudoClassExtension.php',
    'Symfony\\Component\\CssSelector\\XPath\\Translator' => $vendorDir . '/symfony/css-selector/XPath/Translator.php',
    'Symfony\\Component\\CssSelector\\XPath\\TranslatorInterface' => $vendorDir . '/symfony/css-selector/XPath/TranslatorInterface.php',
    'Symfony\\Component\\CssSelector\\XPath\\XPathExpr' => $vendorDir . '/symfony/css-selector/XPath/XPathExpr.php',
    'Symfony\\Component\\DomCrawler\\AbstractUriElement' => $vendorDir . '/symfony/dom-crawler/AbstractUriElement.php',
    'Symfony\\Component\\DomCrawler\\Crawler' => $vendorDir . '/symfony/dom-crawler/Crawler.php',
    'Symfony\\Component\\DomCrawler\\Field\\ChoiceFormField' => $vendorDir . '/symfony/dom-crawler/Field/ChoiceFormField.php',
    'Symfony\\Component\\DomCrawler\\Field\\FileFormField' => $vendorDir . '/symfony/dom-crawler/Field/FileFormField.php',
    'Symfony\\Component\\DomCrawler\\Field\\FormField' => $vendorDir . '/symfony/dom-crawler/Field/FormField.php',
    'Symfony\\Component\\DomCrawler\\Field\\InputFormField' => $vendorDir . '/symfony/dom-crawler/Field/InputFormField.php',
    'Symfony\\Component\\DomCrawler\\Field\\TextareaFormField' => $vendorDir . '/symfony/dom-crawler/Field/TextareaFormField.php',
    'Symfony\\Component\\DomCrawler\\Form' => $vendorDir . '/symfony/dom-crawler/Form.php',
    'Symfony\\Component\\DomCrawler\\FormFieldRegistry' => $vendorDir . '/symfony/dom-crawler/FormFieldRegistry.php',
    'Symfony\\Component\\DomCrawler\\Image' => $vendorDir . '/symfony/dom-crawler/Image.php',
    'Symfony\\Component\\DomCrawler\\Link' => $vendorDir . '/symfony/dom-crawler/Link.php',
    'Symfony\\Component\\DomCrawler\\Test\\Constraint\\CrawlerAnySelectorTextContains' => $vendorDir . '/symfony/dom-crawler/Test/Constraint/CrawlerAnySelectorTextContains.php',
    'Symfony\\Component\\DomCrawler\\Test\\Constraint\\CrawlerAnySelectorTextSame' => $vendorDir . '/symfony/dom-crawler/Test/Constraint/CrawlerAnySelectorTextSame.php',
    'Symfony\\Component\\DomCrawler\\Test\\Constraint\\CrawlerSelectorAttributeValueSame' => $vendorDir . '/symfony/dom-crawler/Test/Constraint/CrawlerSelectorAttributeValueSame.php',
    'Symfony\\Component\\DomCrawler\\Test\\Constraint\\CrawlerSelectorCount' => $vendorDir . '/symfony/dom-crawler/Test/Constraint/CrawlerSelectorCount.php',
    'Symfony\\Component\\DomCrawler\\Test\\Constraint\\CrawlerSelectorExists' => $vendorDir . '/symfony/dom-crawler/Test/Constraint/CrawlerSelectorExists.php',
    'Symfony\\Component\\DomCrawler\\Test\\Constraint\\CrawlerSelectorTextContains' => $vendorDir . '/symfony/dom-crawler/Test/Constraint/CrawlerSelectorTextContains.php',
    'Symfony\\Component\\DomCrawler\\Test\\Constraint\\CrawlerSelectorTextSame' => $vendorDir . '/symfony/dom-crawler/Test/Constraint/CrawlerSelectorTextSame.php',
    'Symfony\\Component\\DomCrawler\\UriResolver' => $vendorDir . '/symfony/dom-crawler/UriResolver.php',
    'Symfony\\Polyfill\\Ctype\\Ctype' => $vendorDir . '/symfony/polyfill-ctype/Ctype.php',
    'Symfony\\Polyfill\\Intl\\Normalizer\\Normalizer' => $vendorDir . '/symfony/polyfill-intl-normalizer/Normalizer.php',
    'Symfony\\Polyfill\\Mbstring\\Mbstring' => $vendorDir . '/symfony/polyfill-mbstring/Mbstring.php',
    'fivefilters\\Readability\\Configuration' => $vendorDir . '/fivefilters/readability.php/src/Configuration.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMAttr' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMAttr.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMCdataSection' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMCdataSection.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMCharacterData' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMCharacterData.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMComment' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMComment.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMDocument' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMDocument.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMDocumentFragment' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMDocumentFragment.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMDocumentType' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMDocumentType.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMElement' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMElement.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMEntity' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMEntity.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMEntityReference' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMEntityReference.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMNode' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMNode.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMNodeList' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMNodeList.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMNotation' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMNotation.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMProcessingInstruction' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMProcessingInstruction.php',
    'fivefilters\\Readability\\Nodes\\DOM\\DOMText' => $vendorDir . '/fivefilters/readability.php/src/Nodes/DOM/DOMText.php',
    'fivefilters\\Readability\\Nodes\\NodeTrait' => $vendorDir . '/fivefilters/readability.php/src/Nodes/NodeTrait.php',
    'fivefilters\\Readability\\Nodes\\NodeUtility' => $vendorDir . '/fivefilters/readability.php/src/Nodes/NodeUtility.php',
    'fivefilters\\Readability\\ParseException' => $vendorDir . '/fivefilters/readability.php/src/ParseException.php',
    'fivefilters\\Readability\\Readability' => $vendorDir . '/fivefilters/readability.php/src/Readability.php',
);
