OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Detalios",
    "Rename" : "Renominar",
    "Copy link" : "Copiar ligamine",
    "Move" : "Mover",
    "Select all" : "Selectionar toto",
    "Go back" : "Retornar",
    "New" : "Nove",
    "New folder" : "Nove dossier",
    "Search" : "Cercar",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "Rename folder" : "Renominar dossier",
    "Cancel" : "Cancellar",
    "Recent" : "Recente",
    "Shared with you" : "Compartite con te",
    "Files" : "Files",
    "Delete" : "Deler",
    "Title" : "Titulo",
    "Link" : "Ligamine",
    "Tags" : "Etiquettas",
    "Notes" : "Notas",
    "Open file" : "Aperir file",
    "Owner" : "Owner",
    "Sharing" : "Compartente",
    "Share link" : "Compartir ligamine",
    "Allow editing" : "Permitter modificar",
    "Folder" : "Dossier",
    "Save" : "Salveguardar"
},
"nplurals=2; plural=(n != 1);");
