OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Penanda",
    "You bookmarked \"%s\"" : "Anda menandai \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s menandai \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Seseorang menandai \"%s\"",
    "You deleted \"%s\"" : "Anda menghapus \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s menghapus \"%2$s\"",
    "Someone deleted \"%s\"" : "Seseorang menghapus \"%s\"",
    "You created folder \"%s\"" : "Anda membuat folder \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s membuat folder \"%2$s\"",
    "Someone created folder \"%s\"" : "Seseorang membuat folder \"%s\"",
    "You moved folder \"%s\"" : "Anda memindahkan folder \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s memindahkan folder \"%2$s\"",
    "Someone moved folder \"%s\"" : "Seseorang memindahkan folder \"%s\"",
    "You deleted folder \"%s\"" : "Anda menghapus folder \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s menghapus folder \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Seseorang menghapus folder \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Anda membagikan folder \"%1$s\" dengan %2$s",
    "You shared folder \"%s\" with someone" : "Anda membagikan folder \"%s\" dengan seseorang",
    "%1$s shared folder \"%2$s\" with you" : "%1$s membagikan folder \"%2$s\" dengan Anda",
    "Someone shared folder \"%s\" with you" : "Seseorang membagikan folder \"%s\" dengan Anda",
    "You unshared folder \"%1$s\" with %2$s" : "Anda berhenti membagikan folder \"%1$s\" dengan %2$s",
    "You unshared folder \"%s\" with someone" : "Anda berhenti membagikan folder \"%s\" dengan seseorang",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s berhenti membagikan folder \"%2$s\" dengan Anda",
    "Someone unshared folder \"%s\" with you" : "Seseorang berhenti membagikan folder \"%s\" dengan Anda",
    "No file provided for import" : "Berkas untuk impor tidak tersedia",
    "Failed to upload file" : "Gagal mengunggah berkas",
    "Unsupported file type for import: " : "Jenis berkas tidak didukung untuk impor: ",
    "Bookmarks shared by %s" : "Penanda dibagikan oleh %s",
    "Frequent bookmarks" : "Penanda sering digunakan",
    "Recent bookmarks" : "Penanda terkini",
    "Bookmark" : "Penanda",
    "Bookmark deleted" : "Penanda dihapus",
    "Bookmark created" : "Penanda dibuat",
    "Bookmark moved" : "Penanda dipindahkan",
    "Bookmark updated" : "Penanda diperbarui",
    "Create bookmark" : "Buat penanda",
    "Takes a link and adds it to your collection of bookmarks." : "Mengambil tautan dan menambahkannya ke koleksi penanda Anda.",
    "Bookmarks Backups" : "Cadangan Penanda",
    "Collect and manage bookmarks, synced with all your devices" : "Kumpulkan dan kelola penanda, disinkronkan dengan semua perangkat Anda",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Urutkan penanda ke dalam folder\n- 🏷 Tambahkan tag dan catatan pribadi\n- ☠ Temukan tautan rusak dan duplikat\n- 📲 Sinkronkan dengan semua peramban dan perangkat Anda\n- 📔 Simpan versi arsip tautan Anda jika tautan tersebut dihapus\n- 🔍 Pencarian teks lengkap pada konten situs\n- 👪 Bagikan penanda dengan pengguna, grup, dan tim lain atau melalui tautan publik\n- ⚛ Buat umpan RSS dari koleksi Anda\n- 📈 Statistik seberapa sering Anda mengakses tautan tertentu\n- 🔒 Cadangan otomatis koleksi penanda Anda\n- 💼 Widget Dasbor bawaan untuk tautan sering digunakan dan terkini\n\nPersyaratan:\n - Ekstensi PHP:\n   - intl: *\n   - mbstring: *\n - saat menggunakan MySQL, gunakan minimal v8.0",
    "Do you really want to delete this bookmark?" : "Apakah Anda benar-benar ingin menghapus penanda ini?",
    "Link copied to clipboard" : "Tautan disalin ke papan klip",
    "Enter new title" : "Masukkan judul baru",
    "Select bookmark" : "Pilih penanda",
    "You have never clicked this link" : "Anda belum pernah mengeklik tautan ini",
    "You have clicked this link {count} times" : "Anda telah mengeklik tautan ini {count} kali",
    "Details" : "Detil",
    "Rename" : "Ubah nama",
    "Copy link" : "Salin tautan",
    "Move" : "Pindah",
    "Add to folders" : "Tambahkan ke folder",
    "Put bookmark into trash bin" : "Masukkan penanda ke tempat sampah",
    "Restore bookmark" : "Pulihkan penanda",
    "Delete bookmark permanently" : "Hapus penanda secara permanen",
    "Content pending" : "Konten tertunda",
    "This content is being downloaded for offline use. Please check back later." : "Konten ini sedang diunduh untuk penggunaan luring. Silakan periksa kembali nanti.",
    "Bookmarked {time} ago" : "Ditandai {time} yang lalu",
    "Bookmarked on {date}" : "Ditandai pada {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Ini adalah item yang dihapus. Item akan dihapus secara permanen setelah dua bulan.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Penanda ke berkas di web seperti foto atau PDF akan otomatis disimpan ke berkas Nextcloud Anda, sehingga Anda masih dapat menemukannya meskipun tautan tidak lagi tersedia.",
    "Searching in the current folder only." : "Mencari hanya dalam folder saat ini.",
    "Repeat search in all folders" : "Ulangi pencarian di semua folder",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Tautan yang ditandai diperiksa secara berkala dan tautan yang tidak dapat dijangkau akan terdaftar di sini.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Anda dapat membagikan folder penanda dengan orang lain. Semua folder yang dibagikan dengan Anda terdaftar di sini.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Satu penanda dapat berada di beberapa folder sekaligus. Memperbaruinya akan memperbarui semua salinan. Semua penanda duplikat terdaftar di sini untuk kemudahan.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Dipilih {folders} folder dan {bookmarks} penanda",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Memilih %n penanda"],
    "_Selected %n folder_::_Selected %n folders_" : ["Memilih %n folder"],
    "Do you really want to delete these items?" : "Apakah Anda benar-benar ingin menghapus item ini?",
    "Open all selected" : "Buka semua pilihan",
    "Move selection" : "Pindah pilihan",
    "Edit tags of selection" : "Edit tag pilihan",
    "Delete selection" : "Hapus pilihan",
    "Select all" : "Pilih semua",
    "Cancel selection" : "Batalkan pilihan",
    "Sort by created date" : "Urutkan berdasarkan tanggal dibuat",
    "Sort by last modified" : "Urutkan berdasarkan terakhir diubah",
    "Sort by title" : "Urutkan berdasarkan judul",
    "Sort by click count" : "Urutkan berdasarkan jumlah klik",
    "Sort by manual order" : "Urutkan berdasarkan urutan manual",
    "Sort by URL" : "Urutkan berdasarkan URL",
    "RSS feed copied" : "Umpan RSS tersalin",
    "Trash Bin" : "Tempat Sampah",
    "Go back" : "Kembali",
    "Share folder" : "Bagikan folder",
    "Open folder details" : "Buka detail folder",
    "Select one or more tags" : "Pilih satu atau lebih tag",
    "New" : "Baru",
    "New bookmark" : "Penanda baru",
    "New folder" : "Folder baru",
    "Change to grid view" : "Ubah ke tampilan grid",
    "Change to list view" : "Ubah ke tampilan daftar",
    "Copy RSS Feed of current view" : "Salin Umpan RSS dari tampilan saat ini",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Umpan RSS memerlukan autentikasi dengan kredensial Nextcloud Anda",
    "Search" : "Cari",
    "Empty trash bin" : "Kosongkan tempat sampah",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Menambahkan %n penanda ke folder baru"],
    "Enter a link" : "Masukkan tautan",
    "Enter a title" : "Masukkan judul",
    "No bookmarks found" : "Tidak ada penanda ditemukan",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} folder dan {bookmarks} penanda",
    "_%n bookmark_::_%n bookmarks_" : ["%n penanda"],
    "_%n folder_::_%n folders_" : ["%n folder"],
    "Welcome to Bookmarks" : "Selamat datang di Penanda",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Aplikasi ini memungkinkan Anda mengelola tautan ke tempat favorit Anda di web. Urutkan penanda Anda ke dalam folder, beri label dengan tag, dan bagikan dengan orang lain! Aplikasi akan secara berkala memeriksa semua tautan Anda untuk ketersediaan dan menampilkan tautan yang tidak tersedia. Jika Anda menambahkan tautan ke berkas di web, berkas tersebut akan otomatis diunduh ke Berkas Nextcloud Anda. Anda juga dapat mengimpor penanda yang diekspor dari layanan lain atau langsung menyinkronkan penanda dari semua peramban Anda dengan aplikasi ini.",
    "Add a bookmark" : "Tambahkan penanda",
    "Import bookmarks" : "Impor penanda",
    "Sync with your browser" : "Sinkronkan dengan peramban Anda",
    "Do you really want to permanently delete this folder?" : "Apakah Anda benar-benar ingin menghapus folder ini secara permanen?",
    "Select folder" : "Pilih folder",
    "Enter folder title" : "Masukkan judul folder",
    "Shared by {user}" : "Dibagikan oleh {user}",
    "Rename folder" : "Ubah nama folder",
    "Move folder" : "Pindahkan folder",
    "Put folder into trashbin" : "Masukkan folder ke tempat sampah",
    "Restore folder" : "Pulihkan folder",
    "Delete folder permanently" : "Hapus folder secara permanen",
    "Choose folder" : "Pilih folder",
    "Submit" : "Kirim",
    "Cancel" : "Membatalkan",
    "Deleting bookmarks" : "Menghapus penanda",
    "Deleting selection" : "Menghapus pilihan",
    "Importing bookmarks" : "Mengimpor penanda",
    "Moving selection" : "Memindahkan pilihan",
    "Adding selection to folders" : "Menambahkan pilihan ke folder",
    "Emptying trashbin" : "Mengosongkan tempat sampah",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Memindahkan %n folder dan beberapa penanda"],
    "_Moving %n folder_::_Moving %n folders_" : ["Memindahkan %n folder"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Memindahkan %n penanda"],
    "All bookmarks" : "Semua penanda",
    "Recent" : "Terbaru",
    "Shared with you" : "Shared with you",
    "Files" : "Berkas",
    "Duplicates" : "Duplikat",
    "Broken links" : "Tautan rusak",
    "New tag" : "Tag baru",
    "Search tags" : "Cari tag",
    "Delete" : "Hapus",
    "Untagged" : "Belum ada tag",
    "{used} bookmarks of {available} available" : "{used} penanda dari {available} tersedia",
    "Bookmarks Settings" : "Pengaturan Penanda",
    "No bookmarked files" : "Tidak ada berkas yang ditandai",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Penanda ke berkas seperti foto atau PDF akan otomatis disimpan ke berkas Nextcloud Anda, sehingga Anda masih dapat menemukannya meskipun tautan tidak lagi tersedia.",
    "Nothing found" : "Tidak ada yang ditemukan",
    "Your search yielded no results in the current folder." : "Pencarian Anda tidak menghasilkan hasil di folder saat ini.",
    "No broken links" : "Tidak ada tautan rusak",
    "No shared folders" : "Tidak ada folder yang dibagikan",
    "No duplicated bookmarks" : "Tidak ada penanda duplikat",
    "No deleted bookmarks" : "Tidak ada penanda yang dihapus",
    "You haven't deleted anything yet." : "Anda belum menghapus apa pun.",
    "No bookmarks here" : "Tidak ada penanda di sini",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Tambahkan penanda secara manual atau impor penanda dari berkas HTML.",
    "Archive path" : "Jalur arsip",
    "Backup path" : "Jalur cadangan",
    "Please select \"Add to home screen\" in your browser menu" : "Silakan pilih \"Tambahkan ke layar utama\" di menu peramban Anda",
    "Bookmarks settings" : "Pengaturan penanda",
    "Import/Export" : "Impor/Ekspor",
    "Export bookmarks" : "Ekspor penanda",
    "Auto-archiving" : "Pengarsipan otomatis",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Aplikasi penanda dapat secara otomatis mengarsipkan konten web dari tautan yang telah Anda tandai",
    "Enable archiving" : "Aktifkan pengarsipan",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Masukkan jalur folder di Berkas Anda tempat berkas yang ditandai akan disimpan.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Saat ini administrator Anda telah menonaktifkan akses jaringan untuk aplikasi ini, sehingga Pengarsipan Otomatis dinonaktifkan untuk sementara.",
    "Auto-Backup" : "Cadangan Otomatis",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Aplikasi penanda dapat secara otomatis mencadangkan penanda Anda setiap hari untuk mencegah kehilangan data saat menyinkronkan penanda di berbagai perangkat.",
    "Enable backups" : "Aktifkan cadangan",
    "Enter the path of a folder in your Files where backups will be stored." : "Masukkan jalur folder di Berkas Anda tempat cadangan akan disimpan.",
    "Context Chat integration" : "Integrasi Obrolan Konteks",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Aplikasi penanda dapat secara otomatis menyediakan konten tekstual dari situs web yang Anda tandai ke Obrolan Konteks, yang memungkinkan pengajuan pertanyaan dan mendapatkan jawaban berdasarkan konten tersebut. Ini hanya tersedia jika pengarsipan otomatis diaktifkan.",
    "Context chat is currently not installed, but is required for this feature." : "Obrolan konteks saat ini tidak terpasang, tetapi diperlukan untuk fitur ini.",
    "Enable Context Chat integration" : "Aktifkan integrasi Obrolan Konteks",
    "Client apps" : "Aplikasi klien",
    "Also check out the collection of client apps that integrate with this app: " : "Lihat juga koleksi aplikasi klien yang terintegrasi dengan aplikasi ini: ",
    "Install web app" : "Pasang aplikasi web",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Anda dapat memasang aplikasi ini di layar utama perangkat Anda untuk mengakses penanda Anda dengan cepat di ponsel. Anda dapat dengan mudah menghapus aplikasi dari layar utama Anda lagi, jika Anda tidak menyukainya.",
    "Install on home screen" : "Pasang di layar utama",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Seret ini ke penanda peramban Anda dan klik untuk menandai halaman web dengan cepat.",
    "Add to {instanceName}" : "Tambahkan ke {instanceName}",
    "Need help?" : "Butuh bantuan?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Jika Anda mengalami masalah dengan aplikasi Penanda ini atau memiliki ide tentang apa yang bisa ditingkatkan, jangan ragu untuk menghubungi dengan mengklik di sini.",
    "Support this project" : "Dukung proyek ini",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Pekerjaan saya pada aplikasi Penanda ini didukung oleh model langganan sukarela. Jika Anda merasa apa yang saya lakukan bermanfaat, saya akan senang jika Anda dapat mendukung pekerjaan saya. Selain itu, pertimbangkan untuk memberikan ulasan aplikasi di toko aplikasi Nextcloud. Terima kasih 💙 ",
    "Created {time} ago" : "Dibuat {time} yang lalu",
    "Created on {date}" : "Terbuat pada {date}",
    "(Empty title)" : "(Judul kosong)",
    "Title" : "Judul",
    "Link" : "Tautan",
    "Untitled folder" : "Folder tanpa judul",
    "Root folder" : "Folder akar",
    "Tags" : "Tag",
    "Select tags and create new ones" : "Pilih tag dan buat yang baru",
    "Notes" : "Catatan",
    "Notes for this bookmark …" : "Catatan untuk penanda ini …",
    "Archived file" : "Berkas terarsip",
    "Open file" : "Buka file",
    "Download file" : "Unduh berkas",
    "Open file location" : "Buka lokasi berkas",
    "Link copied" : "Link tersalin",
    "Owner" : "Owner",
    "Sharing" : "Berbagi",
    "Select a user or group" : "Pilih pengguna atau grup",
    "Share link" : "Bagikan tautan",
    "Reading allowed" : "Membaca diizinkan",
    "Copy RSS feed" : "Salin umpan RSS",
    "Delete link" : "Hapus tautan",
    "Create public link" : "Buat tautan publik",
    "Resharing allowed" : "Membagikan ulang diizinkan",
    "Editing allowed" : "Mengedit diizinkan",
    "Allow editing" : "Izinkan penyuntingan",
    "Allow resharing" : "Izinkan pembagian ulang",
    "Remove share" : "Hapus berbagi",
    "Leave a rating on the Nextcloud App Store" : "Beri penilaian di Toko Aplikasi Nextcloud",
    "Failed to save settings" : "Gagal simpan setelan",
    "Failed to load settings" : "Gagal memuat pengaturan",
    "Privacy" : "Privasi",
    "The app will try to access web pages that you add to automatically add information about them." : "Aplikasi akan mencoba mengakses halaman web yang Anda tambahkan untuk secara otomatis menambahkan informasi tentang halaman tersebut.",
    "Enable accessing and collecting information from the web pages you add" : "Aktifkan akses dan pengumpulan informasi dari halaman web yang Anda tambahkan",
    "Performance" : "Performa",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Dalam instalasi dengan banyak pengguna, mungkin berguna untuk membatasi jumlah penanda per akun.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Jumlah maksimum penanda yang diizinkan per akun. (0 untuk tanpa batas; standar adalah tanpa batas)",
    "Previews" : "Pratinjau",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Untuk menampilkan tangkapan layar asli dari situs web yang Anda tandai, aplikasi dapat menggunakan layanan pihak ketiga untuk menghasilkan pratinjau.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Anda dapat mendaftar gratis di screeenly.com atau menyiapkan server Anda sendiri.",
    "Screeenly API URL" : "URL API Screeenly",
    "Screeenly API key" : "Kunci API Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Kunci API ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL API Webshot",
    "Generic screenshot API" : "API tangkapan layar generik",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Daftar dengan salah satu penyedia API tangkapan layar dan masukkan URL API di bawah. Gunakan variabel {url} sebagai penampung untuk URL yang akan ditangkap layarnya. API harus mengembalikan hanya gambar secara langsung.",
    "Generic API URL" : "URL API Generik",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Cukup pasang Pageres CLI oleh Sindre Sorhus di server Anda dan Penanda akan menemukannya. Anda masih dapat menambahkan variabel ENV tambahan untuk diberikan ke pageres, misalnya seperti yang ditunjukkan pada penampung:",
    "Pageres ENV variables" : "Variabel ENV Pageres",
    "This URL is already bookmarked! Overwrite?" : "URL ini sudah ditandai! Timpa?",
    "Enter bookmark title" : "Tulis judul penanda",
    "Enter bookmark URL" : "Tulis URL penanda",
    "Folder" : "Folder",
    "Root Folder" : "Folder Akar",
    "Save" : "Simpan",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Akses jaringan dinonaktifkan secara standar. Buka pengaturan administrator untuk aplikasi penanda untuk mengizinkan pengambilan pratinjau dan favicon.",
    "What's new?" : "Apa yang baru?",
    "What" : "Apa",
    "Failed to count unavailable bookmarks" : "Gagal menghitung penanda yang tidak tersedia",
    "Failed to count archived bookmarks" : "Gagal menghitung penanda yang diarsipkan",
    "Failed to count duplicated bookmarks" : "Gagal menghitung penanda duplikat",
    "Failed to count bookmarks" : "Gagal menghitung penanda",
    "Failed to load bookmark" : "Gagal memuat penanda",
    "Failed to find existing bookmark" : "Gagal mencari penanda eksis",
    "Failed to create bookmark" : "Gagal membuat penanda",
    "Failed to save bookmark" : "Gagal menyimpan penanda",
    "Failed to move bookmark" : "Gagal memindahkan penanda",
    "Failed to copy bookmark" : "Gagal menyalin penanda",
    "Failed to delete bookmark" : "Gagal menghapus penanda",
    "Failed to restore bookmark" : "Gagal memulihkan penanda",
    "Import successful" : "Impor berhasil",
    "Failed to rename tag" : "Gagal mengganti nama tag",
    "Failed to load tags" : "Gagal memuat tag",
    "Failed to load folders" : "Gagal memuat folder",
    "Failed to load deleted folders" : "Gagal memuat folder yang dihapus",
    "Failed to load deleted bookmarks" : "Gagal memuat penanda yang dihapus",
    "Failed to delete folder" : "Gagal menghapus folder",
    "Failed to move folder" : "Gagal memindahkan folder",
    "Failed to restore folder" : "Gagal memulihkan folder",
    "Failed to create folder" : "Gagal membuat folder",
    "Failed to load children order" : "Gagal memuat urutan anak",
    "Failed to move parts of selection" : "Gagal memindahkan sebagai pilihan",
    "Failed to copy parts of selection" : "Gagal menyalin bagian dari pilihan",
    "Failed to delete parts of selection" : "Gagal menghapus sebagian pilihan",
    "Failed to tag parts of selection" : "Gagal menandai bagian dari pilihan",
    "Failed to fetch bookmarks." : "Gagal menampilkan penanda",
    "Failed to store setting" : "Gagal menyimpan pengaturan",
    "Failed to load setting {key}" : "Gagal memuat setelan {key}",
    "Failed to create share for folder {folderId}" : "Gagal membuat berbagi untuk folder {folderId}",
    "Failed to update share {shareId}" : "Gagal memperbarui berbagi {shareId}",
    "Failed to delete share {shareId}" : "Gagal menghapus berbagi {shareId}",
    "Failed to create public link for folder {folderId}" : "Gagal membuat tautan publik untuk folder {folderId}",
    "Failed to delete public link for folder {folderId}" : "Gagal menghapus tautan publik untuk folder {folderId}",
    "Failed to permanently delete parts of trash bin" : "Gagal menghapus secara permanen bagian dari tempat sampah",
    "Create bookmarks for mentioned links" : "Buat penanda untuk tautan yang disebutkan",
    "No links found in this message" : "Tidak ada tautan ditemukan dalam pesan ini",
    "Bookmarks feed" : "Umpan penanda"
},
"nplurals=1; plural=0;");
