OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Մանրամասներ",
    "Rename" : "Վերանվանել",
    "Copy link" : "Պատճենել հղումը",
    "Move" : "Move",
    "Select all" : "Նշել բոլորը",
    "New" : "Նոր",
    "New folder" : "Նոր պանակ",
    "Search" : "Search",
    "_%n folder_::_%n folders_" : ["%n պանակ","%n պանակ"],
    "Cancel" : "ընդհատել",
    "Shared with you" : "Shared with you",
    "Files" : "Ֆայլեր",
    "Delete" : "հեռացնել",
    "Title" : "Վերնագիր",
    "Link" : "Հղում",
    "Notes" : "Notes",
    "Owner" : "Owner",
    "Share link" : "Կիսվել հղմամբ",
    "Allow editing" : "Թույլատրել խմբագրումը",
    "Folder" : "Պանակ",
    "Save" : "Պահպանել"
},
"nplurals=2; plural=(n != 1);");
