<?php
$TRANSLATIONS = array(
"Bookmarks" => "பக்க அடையாளங்கள்",
"Bookm." => "பக்க அடையாளங்கள்",
"Unsupported file type for import" => "இறக்குமதிக்கு ஆதரவளிக்காத கோப்பு வகை",
"Error" => "வழு",
"Tags" => "சீட்டுகள்",
"Filter by tag" => "சீட்டுகளால் வடிகட்டுக",
"Warning" => "எச்சரிக்கை",
"Are you sure you want to remove this tag from every entry?" => "ஒவ்வொரு நுழைவின் போதும் இந்த சீட்டை கட்டாயம் அகற்ற வேண்டுமா?",
"Import completed successfully." => "இறக்குமதி வெற்றிகரமாக நிறைவேற்றப்பட்டது.",
"Uploading..." => "பதிவேற்றல்...",
"Add a bookmark" => "பக்க அடையாளம் ஒன்றை சேர்க்க",
"The title of the page" => "பக்கத்தி்ன் தலைப்பு",
"The address of the page" => "பக்கத்தின் முகவரி",
"Description of the page" => "பக்கத்தின் விவரிப்பு",
"Save" => "சேமிக்க",
"Delete" => "அழிக்க",
"Edit" => "தொகுக்க",
"Cancel" => "இரத்து செய்க",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "உங்களுக்கு ஒரு வலைய பக்கத்தை விரைவாக பக்க அடையாளப்படுத்துவதற்கு அதை உங்களுடைய உலாவியின் பக்க அடையாளங்களில் இழுத்து விட்டு சொடக்குக",
"Address" => "முகவரி",
"You have no bookmarks" => "உங்களிடம் பக்க அடையாளங்கள் இல்லை ",
"Bookmarklet" => "பக்க அடையாளங்கள்",
"Export & Import" => "ஏற்றுமதி மற்றும் இறக்குமதி",
"Export" => "ஏற்றுமதி",
"Import" => "இறக்குமதி"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
