OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "书签",
    "You bookmarked \"%s\"" : "您添加了书签 \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s 添加了书签 \"%2$s\"",
    "Someone bookmarked \"%s\"" : "有人添加了书签 \"%s\"",
    "You deleted \"%s\"" : "您删除了 \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s 删除了 \"%2$s\"",
    "Someone deleted \"%s\"" : "有人删除了 \"%s\"",
    "You created folder \"%s\"" : "您已创建文件夹 \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s已创建文件夹 \"%2$s\"",
    "Someone created folder \"%s\"" : "有人已创建文件夹 \"%s\"",
    "You moved folder \"%s\"" : "您已移动文件夹 \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s 已移动文件夹 \"%2$s\"",
    "Someone moved folder \"%s\"" : "有人已移动文件夹 \"%s\"",
    "You deleted folder \"%s\"" : "您已删除文件夹 \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s 已删除文件夹 \"%2$s\"",
    "Someone deleted folder \"%s\"" : "有人已删除文件夹 \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "您已将文件夹 \"%1$s\" 共享给 %2$s",
    "You shared folder \"%s\" with someone" : "您已将文件夹 \"%s\" 共享给其他人",
    "%1$s shared folder \"%2$s\" with you" : "%1$s已共享文件夹 \"%2$s\" 给您",
    "Someone shared folder \"%s\" with you" : "有人共享文件夹 \"%s\" 给您",
    "You unshared folder \"%1$s\" with %2$s" : "您已取消开放给 %2$s的%1$s文件夹共享",
    "You unshared folder \"%s\" with someone" : "您已取消%s文件夹的共享",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s取消了开放给您的%2$s文件夹共享",
    "Someone unshared folder \"%s\" with you" : "有人取消了开放给您的%s文件夹共享",
    "No file provided for import" : "未提供导入文件",
    "Failed to upload file" : "无法上传文件",
    "Unsupported file type for import: " : "不支持导入的文件类型：",
    "Bookmarks shared by %s" : "由 %s 共享的书签",
    "Frequent bookmarks" : "常用书签",
    "Recent bookmarks" : "近期书签",
    "Bookmark" : "书签",
    "Bookmark deleted" : "书签已删除",
    "Bookmark created" : "书签已创建",
    "Bookmark moved" : "书签已移除",
    "Bookmark updated" : "书签已更新",
    "Create bookmark" : "创建书签",
    "Takes a link and adds it to your collection of bookmarks." : "获取一个链接并将其添加到您的书签中。",
    "Bookmarks Backups" : "书签备份",
    "Collect and manage bookmarks, synced with all your devices" : "收集和管理书签，与您的全部设备同步",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 将书签整理到文件夹中\n- 🏷 添加标签和个人备注\n- ☠ 查找损坏的链接和重复项\n- 📲 与所有浏览器和设备同步\n- 📔 保存链接的归档版本，以防它们被取消发布\n- 🔍 网站内容全文搜索\n- 👪 与其他用户、群组和团队或通过公开链接分享书签\n- ⚛ 为您的收藏集生成 RSS 源\n- 📈 统计您访问哪些链接的频率\n- 🔒 自动备份书签收藏集\n- 💼 内置仪表盘微件，用于最常用和最近的链接\n\n要求：\n - PHP 扩展：\n   - intl: *\n   - mbstring: *\n - 使用 MySQL 时，至少使用 v8.0",
    "Do you really want to delete this bookmark?" : "你真想删除这个书签吗？",
    "Link copied to clipboard" : "链接已复制到剪贴板",
    "Enter new title" : "输入新标题",
    "Select bookmark" : "选择书签",
    "You have never clicked this link" : "您从未点击过此链接",
    "You have clicked this link {count} times" : "您已点击此链接 {count} 次",
    "Details" : "详情",
    "Rename" : "重命名",
    "Copy link" : "复制链接",
    "Move" : "移动",
    "Add to folders" : "添加到文件夹",
    "Put bookmark into trash bin" : "将书签放入回收站",
    "Restore bookmark" : "恢复书签",
    "Delete bookmark permanently" : "永久删除书签",
    "Content pending" : "内容待定",
    "This content is being downloaded for offline use. Please check back later." : "此内容正被下载以供离线使用。请稍后再来查看。 ",
    "Bookmarked {time} ago" : "{time} 前加入书签",
    "Bookmarked on {date}" : "于 {date} 加入书签",
    "These are your deleted items. Items will be deleted permanently after two months." : "这些是您已删除的项目，将在两个月后永久删除项目。",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "网络上的文件，类似照片或 PDF 等的书签会被自动保存到你的Nextcloud 文件中，这样即使链接的文件消失，你仍然可以找到它们。",
    "Searching in the current folder only." : "仅在当前文件夹中搜索。",
    "Repeat search in all folders" : "在所有文件夹中重复搜索",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "已添加书签的链接会定期检查，无法访问的链接会显示在这里",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "您可以与其他人分享书签文件夹。所有与您分享的文件夹会显示在这里。",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "一个书签可以同时在多个文件夹中。更新它将会更新所有副本。为了方便起见，这里列出了所有重复的书签。",
    "Selected {folders} folders and {bookmarks} bookmarks" : "已选择文件夹 {folders} 和书签 {bookmarks} ",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["已选择 %n 个书签"],
    "_Selected %n folder_::_Selected %n folders_" : ["已选择 %n 个文件夹"],
    "Do you really want to delete these items?" : "你真想删除这些项目吗？",
    "Open all selected" : "打开所选",
    "Move selection" : "移动所选项",
    "Edit tags of selection" : "编辑所选标签",
    "Delete selection" : "删除所选项",
    "Select all" : "全部选择",
    "Cancel selection" : "取消选择",
    "Sort by created date" : "按创建日期排序 ",
    "Sort by last modified" : "按最后更改排序",
    "Sort by title" : "按标题排序",
    "Sort by click count" : "按点击次数排序",
    "Sort by manual order" : "按手动顺序排序",
    "Sort by URL" : "按 URL 排序",
    "RSS feed copied" : "RSS提要已复制",
    "Trash Bin" : "回收站",
    "Go back" : "返回",
    "Share folder" : "分享文件夹",
    "Open folder details" : "打开文件夹详情",
    "Select one or more tags" : "选择一个或多个标签",
    "New" : "新建",
    "New bookmark" : "新建书签",
    "New folder" : "新建文件夹",
    "Change to grid view" : "变为网格视图",
    "Change to list view" : "变为列表视图",
    "Copy RSS Feed of current view" : "复制当前视图的 RSS 订阅源",
    "The RSS feed requires authentication with your Nextcloud credentials" : "此 RSS 订阅源需要使用 Nextcloud 凭据进行身份验证",
    "Search" : "搜索",
    "Empty trash bin" : "清空回收站",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["正在将 %n 个书签添加到新文件夹"],
    "Enter a link" : "输入一个链接",
    "Enter a title" : "输入标题",
    "No bookmarks found" : "未找到书签",
    "{folders} folders and {bookmarks} bookmarks" : "{folders}个文件夹和{bookmarks}枚书签",
    "_%n bookmark_::_%n bookmarks_" : ["%n 个书签"],
    "_%n folder_::_%n folders_" : ["%n 个文件夹"],
    "Welcome to Bookmarks" : "欢迎使用书签",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "此应用可让您管理网络上您喜爱位置的链接。将您的书签分类到文件夹中，使用标签标记，并与他人分享！此应用会定期检查所有链接的可用性，并显示不可用的链接。如果您添加指向网络上某个文件的链接，该文件将自动下载到您的 Nextcloud Files 中。您还可以使用此应用导入从其他服务导出的书签，或直接同步所有浏览器中的书签。",
    "Add a bookmark" : "添加书签",
    "Import bookmarks" : "导入标签",
    "Sync with your browser" : "与你的浏览器同步",
    "Do you really want to permanently delete this folder?" : "是否确定要永久删除此文件夹？",
    "Select folder" : "选择文件夹",
    "Enter folder title" : "输入文件夹标题",
    "Shared by {user}" : "由{user} 共享",
    "Rename folder" : "重命名文件夹",
    "Move folder" : "移动文件夹",
    "Put folder into trashbin" : "将文件夹放入回收站",
    "Restore folder" : "恢复文件夹",
    "Delete folder permanently" : "永久删除文件夹",
    "Choose folder" : "选择文件夹",
    "Submit" : "提交",
    "Cancel" : "取消",
    "Deleting bookmarks" : "正在删除书签",
    "Deleting selection" : "正在删除所选项",
    "Importing bookmarks" : "正在导入书签",
    "Moving selection" : "正在移动所选项",
    "Adding selection to folders" : "正在将所选项添加到文件夹",
    "Emptying trashbin" : "正在清空回收站",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移动 %n 个文件夹和一些书签"],
    "_Moving %n folder_::_Moving %n folders_" : ["正在移动 %n 个文件夹"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移动 %n 个书签"],
    "All bookmarks" : "全部书签",
    "Recent" : "最近",
    "Frequently clicked" : "经常点击",
    "Shared with you" : "已共享给您",
    "Files" : "文件",
    "Duplicates" : "重复",
    "Broken links" : "失效的链接",
    "New tag" : "新标签",
    "Search tags" : "搜索标签",
    "Delete" : "删除",
    "Untagged" : "无标签",
    "{used} bookmarks of {available} available" : " {available}书签可用，已用{used}",
    "Bookmarks Settings" : "书签设置",
    "No bookmarked files" : "无已添加书签的文件",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等文件的书签会被自动保存到你的Nextcloud文件中，因此即使链接离线，你仍然可以找到它们。",
    "Nothing found" : "未找到任何内容",
    "Your search yielded no results in the current folder." : "您的搜索在当前文件夹中没有结果。",
    "No broken links" : "没有失效的链接",
    "No shared folders" : "没有共享的文件夹",
    "No duplicated bookmarks" : "没有重复的书签",
    "No deleted bookmarks" : "没有已删除的书签",
    "You haven't deleted anything yet." : "您尚未删除任何内容。",
    "No bookmarks here" : "无书签",
    "Add bookmarks manually or import bookmarks from a HTML file." : "手动添加书签或从HTML文件中导入书签。",
    "Archive path" : "归档路径",
    "Backup path" : "备份路径",
    "Please select \"Add to home screen\" in your browser menu" : "请点击浏览器菜单中的“添加到主屏幕”",
    "Bookmarks settings" : "书签设置",
    "Import/Export" : "导入/导出",
    "Export bookmarks" : "导出书签",
    "Auto-archiving" : "自动归档",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "书签应用可以自动归档您已加入书签的链接的网络内容",
    "Enable archiving" : "启用归档",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "输入一个文件夹路径，加书签的文件会被存储至该文件夹",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "目前，您的管理员禁用了此应用的网络访问，但这就是目前禁用自动归档的原因。",
    "Auto-Backup" : "自动备份",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "书签应用可以每天自动备份您的书签，以防在跨设备同步书签时丢失数据。",
    "Enable backups" : "启用备份",
    "Enter the path of a folder in your Files where backups will be stored." : "输入一个存储备份的文件夹的路径。",
    "Context Chat integration" : "上下文聊天集成",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "书签应用可以自动将您书签网站文本内容添加到“上下文聊天”中，以便用户根据这些内容提问并获得解答。此功能仅在启用自动存档功能后可用。",
    "Context chat is currently not installed, but is required for this feature." : "当前未安装上下文聊天，但此功能需要上下文聊天。",
    "Enable Context Chat integration" : "启用上下文聊天集成",
    "Client apps" : "客户端应用",
    "Also check out the collection of client apps that integrate with this app: " : "还可以查看与此应用集成的客户端应用集合：",
    "Install web app" : "安装 Web 应用",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "你可以在你的设备主屏幕上安装这个应用程序来快速访问你手机上的书签。如果你不喜欢它，你可以很容易地从主屏幕上删除它。",
    "Install on home screen" : "安装到主屏幕",
    "Bookmarklet" : "小书签",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "将此拖到浏览器书签中，并单击它可快速将网页添加为书签。",
    "Add to {instanceName}" : "添加到 {instanceName}",
    "Need help?" : "需要帮助？",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "如果您在使用此书签应用时遇到问题，或者对改进之处有想法，请随时点击此处与我们联系。",
    "Support this project" : "支持此项目",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "我在这个书签应用上的工作是由自愿订阅模式推动的。如果您认为我所做的事情值得，我很高兴您能支持我的工作。此外，请考虑在 Nextcloud 应用商店中给此应用评论。谢谢 💙 ",
    "Created {time} ago" : "创建于 {time} 前",
    "Created on {date}" : "创建于 {date}",
    "(Empty title)" : "（标题为空）",
    "Title" : "标题",
    "Link" : "链接",
    "Untitled folder" : "未命名文件夹",
    "Root folder" : "根文件夹",
    "Tags" : "标签",
    "Select tags and create new ones" : "选择标签和创建新标签",
    "Notes" : "笔记",
    "Notes for this bookmark …" : "标签的注释",
    "Archived file" : "已归档的文件",
    "Open file" : "打开文件 ",
    "Download file" : "下载文件",
    "Open file location" : "打开文件位置 ",
    "Link copied" : "已复制链接",
    "Owner" : "所有者",
    "Sharing" : "正在共享",
    "Select a user or group" : "选择用户或分组",
    "Share link" : "共享链接",
    "Reading allowed" : "已允许读取",
    "Copy RSS feed" : "复制RSS提要",
    "Delete link" : "删除链接",
    "Create public link" : "创建公开链接",
    "Resharing allowed" : "不允许重新分享 ",
    "Editing allowed" : "已允许编辑",
    "Allow editing" : "允许编辑",
    "Allow resharing" : "允许重新分享",
    "Remove share" : "移除共享",
    "Would you like to support this project?" : "您愿意支持这个项目吗？",
    "Leave a rating on the Nextcloud App Store" : "在 Nextcloud 应用商店留下评价",
    "Failed to save settings" : "无法保存设置",
    "Failed to load settings" : "无法加载设置",
    "Privacy" : "隐私",
    "The app will try to access web pages that you add to automatically add information about them." : "此应用将尝试访问您添加的网页，以自动添加有关它们的信息。",
    "Enable accessing and collecting information from the web pages you add" : "启用从您添加的网页访问和搜集信息的功能",
    "Performance" : "性能",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在有很多用户的安装中，限制每个账号的书签数量可能很有用。",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每个账号允许的最大书签数量。（0 表示无限制；默认为无限制）",
    "Previews" : "预览",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "为了显示您加入书签的网站的真实屏幕截图，此应用使用第三方服务生成预览。",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "您既可以在 screeenly.com 免费注册，也可以搭建您自己的服务器。",
    "Screeenly API URL" : "Screenly API 地址",
    "Screeenly API key" : "Screenly API 密钥",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "通用屏幕截图 API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "注册任何屏幕截图 API 提供者并在下方输入 API URL。使用变量 {url} 作为要屏幕截图的 URL 的占位符。API 必须仅直接返回图像。",
    "Generic API URL" : "通用 API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "只需在您的服务器上安装 Sindre Sorhus 开发的 Pageres CLI，书签就会找到它。您仍然可以添加其他 ENV 变量来提供给 pageres，例如占位符中所示：",
    "Pageres ENV variables" : "Pageres ENV 变量",
    "This URL is already bookmarked! Overwrite?" : "此链接已加入书签！是否覆盖？",
    "Enter bookmark title" : "输入书签标题",
    "Enter bookmark URL" : "输入书签网址",
    "Folder" : "文件夹",
    "Root Folder" : "根目录",
    "Save" : "保存",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "网络访问默认关闭。进入书签应用的管理员设置，允许获取预览和书签图标。 ",
    "What's new?" : "有哪些更新？",
    "What" : "是什么",
    "Failed to count unavailable bookmarks" : "无法统计不可用书签",
    "Failed to count archived bookmarks" : "无法统计已归档书签",
    "Failed to count deleted bookmarks" : "无法统计已删除书签",
    "Failed to count duplicated bookmarks" : "无法统计重复书签",
    "Failed to count bookmarks" : "无法统计书签",
    "Failed to load bookmark" : "无法加载书签",
    "Failed to find existing bookmark" : "无法找到现有书签",
    "Failed to create bookmark" : "无法创建书签",
    "Failed to save bookmark" : "无法保存书签",
    "Failed to move bookmark" : "无法移动书签",
    "Failed to copy bookmark" : "无法复制书签",
    "Failed to delete bookmark" : "无法删除书签",
    "Failed to restore bookmark" : "无法恢复书签",
    "Import successful" : "导入成功",
    "Failed to rename tag" : "无法重命名标签",
    "Failed to load tags" : "无法加载标签",
    "Failed to load folders" : "无法加载文件夹",
    "Failed to load deleted folders" : "无法加载已删除的文件夹",
    "Failed to load deleted bookmarks" : "无法加载已删除的书签",
    "Failed to delete folder" : "无法删除文件夹",
    "Failed to move folder" : "无法移动文件夹",
    "Failed to restore folder" : "无法恢复文件夹",
    "Failed to create folder" : "无法创建文件夹",
    "Failed to load children order" : "无法加载子项排序",
    "Failed to move parts of selection" : "无法移动部分所选项",
    "Failed to copy parts of selection" : "无法复制部分所选项",
    "Failed to delete parts of selection" : "无法删除部分所选项",
    "Failed to tag parts of selection" : "无法为部分所选项添加标签",
    "Failed to fetch bookmarks." : "无法获取书签。",
    "Failed to store setting" : "无法存储设置",
    "Failed to load setting {key}" : "无法加载设置 {key}",
    "Failed to create share for folder {folderId}" : "无法为文件夹 {folderId} 创建共享",
    "Failed to update share {shareId}" : "无法更新共享 {shareId}",
    "Failed to delete share {shareId}" : "无法删除共享 {shareId}",
    "Failed to create public link for folder {folderId}" : "无法为文件夹 {folderId} 创建公开链接",
    "Failed to delete public link for folder {folderId}" : "无法删除文件夹 {folderId} 的公开链接",
    "Failed to permanently delete parts of trash bin" : "无法永久删除回收站部分内容",
    "Create bookmarks for mentioned links" : "为提到的链接创建书签",
    "No links found in this message" : "消息中没有找到链接",
    "Bookmarks feed" : "书签订阅源"
},
"nplurals=1; plural=0;");
