OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Leabharmharcanna",
    "You bookmarked \"%s\"" : "Chuir tú leabharmharcáil \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s leabharmharcáilte \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Leabharmharcáil duine éigin \"%s\"",
    "You deleted \"%s\"" : "Scrios tú \"%s\"",
    "%1$s deleted \"%2$s\"" : "Scriosadh %1$s \"%2$s\"",
    "Someone deleted \"%s\"" : "Scrios duine éigin \"%s\"",
    "You created folder \"%s\"" : "Chruthaigh tú fillteán \"%s\"",
    "%1$s created folder \"%2$s\"" : "Chruthaigh %1$s fillteán \"%2$s\"",
    "Someone created folder \"%s\"" : "Chruthaigh duine éigin fillteán \"%s\"",
    "You moved folder \"%s\"" : "Bhog tú fillteán \"%s\"",
    "%1$s moved folder \"%2$s\"" : "Bogadh %1$s fillteán \"%2$s\"",
    "Someone moved folder \"%s\"" : "Bhog duine éigin fillteán \"%s\"",
    "You deleted folder \"%s\"" : "Scrios tú fillteán \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "Scriosadh %1$s fillteán \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Scrios duine éigin fillteán \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Roinn tú fillteán \"%1$s\" le %2$s",
    "You shared folder \"%s\" with someone" : "Roinn tú fillteán \"%s\" le duine éigin",
    "%1$s shared folder \"%2$s\" with you" : "%1$s fillteán roinnte \"%2$s\" leat",
    "Someone shared folder \"%s\" with you" : "Roinn duine éigin fillteán \"%s\" leat",
    "You unshared folder \"%1$s\" with %2$s" : "Dhíroinn tú fillteán \"%1$s\" le %2$s",
    "You unshared folder \"%s\" with someone" : "Dhíroinn tú fillteán \"%s\" le duine éigin",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s fillteán neamhroinnte \"%2$s\" leat",
    "Someone unshared folder \"%s\" with you" : "Dhíroinnte duine éigin fillteán \"%s\" leat",
    "No file provided for import" : "Níor soláthraíodh aon chomhad le hiompórtáil",
    "Failed to upload file" : "Theip ar uaslódáil an chomhaid",
    "Unsupported file type for import: " : "Cineál comhaid nach dtacaítear leis le haghaidh iompórtáil:",
    "Bookmarks shared by %s" : "Leabharmharcanna roinnte ag %s",
    "Frequent bookmarks" : "Leabharmharcanna go minic",
    "Recent bookmarks" : "Leabharmharcanna le déanaí",
    "Bookmark" : "Leabharmharc",
    "Bookmark deleted" : "Leabharmharc scriosta",
    "Bookmark created" : "Leabharmharc cruthaithe",
    "Bookmark moved" : "Bogadh an leabharmharc",
    "Bookmark updated" : "Leabharmharc nuashonraithe",
    "Create bookmark" : "Cruthaigh leabharmharc",
    "Takes a link and adds it to your collection of bookmarks." : "Glacann sé nasc agus cuireann sé le do bhailiúchán leabharmharcanna é.",
    "Bookmarks Backups" : "Leabharmharcanna Cúltaca",
    "Collect and manage bookmarks, synced with all your devices" : "Bailigh agus bainistigh leabharmharcanna, sioncronaithe le do ghléasanna go léir",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Sórtáil leabharmharcanna ina bhfillteáin\n- 🏷 Cuir clibeanna agus nótaí pearsanta leis\n- ☠ Aimsigh naisc briste agus dúblaigh\n- 📲 Sioncrónaigh le do brabhsálaithe agus gléasanna go léir\n- 📔 Stóráil leaganacha cartlainne de do naisc ar eagla go ndífhoilsítear iad\n- 🔍 Cuardach lántéacs ar inneachar an tsuímh\n- 👪 Roinn leabharmharcanna le húsáideoirí, grúpaí agus foirne eile nó trí naisc phoiblí\n- ⚛ Gin fothaí RSS de do bhailiúcháin\n- 📈 Staitisticí maidir le cé chomh minic is a fhaigheann tú rochtain ar na naisc\n- 🔒 Cúltaca uathoibríocha de do bhailiúchán leabharmharcanna\n- 💼 Giuirléidí Deais ionsuite le haghaidh naisc rialta agus le déanaí\n\nRiachtanais:\n- Eisínteachtaí PHP:\n- intl:*\n- mbstring: *\n- agus MySQL á úsáid agat, bain úsáid as v8.0 ar a laghad",
    "Do you really want to delete this bookmark?" : "An bhfuil tú cinnte gur mhaith leat an leabharmharc seo a scriosadh?",
    "Link copied to clipboard" : "Cóipeáladh an nasc chuig an ngearrthaisce",
    "Enter new title" : "Cuir isteach teideal nua",
    "Select bookmark" : "Roghnaigh leabharmharc",
    "You have never clicked this link" : "Níor chliceáil tú an nasc seo riamh",
    "You have clicked this link {count} times" : "Tá tú cliceáil ar an nasc seo {count} uair",
    "Details" : "Sonraí",
    "Rename" : "Athainmnigh",
    "Copy link" : "Cóipeáil an nasc",
    "Move" : "Bog",
    "Add to folders" : "Cuir le fillteáin",
    "Put bookmark into trash bin" : "Cuir leabharmharc sa bhosca bruscair",
    "Restore bookmark" : "Athchóirigh leabharmharc",
    "Delete bookmark permanently" : "Scrios leabharmharc go buan",
    "Content pending" : "Ábhar ar feitheamh",
    "This content is being downloaded for offline use. Please check back later." : "Tá an t-ábhar seo á íoslódáil le haghaidh úsáide as líne. Seiceáil ar ais ar ball le do thoil.",
    "Bookmarked {time} ago" : "Leabharmharcáilte {time} ó shin",
    "Bookmarked on {date}" : "Leabharmharcáilte ar {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Seo iad do chuid míreanna scriosta. Scriosfar na míreanna go buan tar éis dhá mhí.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Sábhálfar leabharmharcanna chuig comhaid ar an ngréasán cosúil le grianghraif nó PDFanna go huathoibríoch chuig do chomhaid Nextcloud, ionas gur féidir leat iad a aimsiú fiú nuair a théann an nasc as líne.",
    "Searching in the current folder only." : "Ag cuardach san fhillteán reatha amháin.",
    "Repeat search in all folders" : "Déan cuardach arís i ngach fillteán",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Seiceáiltear naisc leabharmharcáilte go rialta agus liostaítear na cinn nach féidir a bhaint amach anseo.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Is féidir leat fillteáin leabharmharc a roinnt le daoine eile. Tá gach fillteán a roinntear leat liostaithe anseo.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Is féidir le leabharmharc amháin a bheith i bhfillteáin iolracha ag an am céanna. Nuashonrófar gach cóip dá nuashonrú. Tá na leabharmharcanna dúblacha go léir liostaithe anseo mar áis.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Roghnaíodh {fillteáin} fillteáin agus leabharmharcanna {leabharmharcanna}",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Roghnaíodh %n leabharmharc","Roghnaíodh %n leabharmharcanna","Roghnaíodh %n leabharmharcanna","Roghnaíodh %n leabharmharcanna","Roghnaíodh %n leabharmharcanna"],
    "_Selected %n folder_::_Selected %n folders_" : ["Roghnaíodh %n fillteán","Roghnaíodh %n fillteáin","Roghnaíodh %n fillteáin","Roghnaíodh %n fillteáin","Roghnaíodh %n fillteáin"],
    "Do you really want to delete these items?" : "An bhfuil tú cinnte gur mhaith leat na míreanna seo a scriosadh?",
    "Open all selected" : "Oscail gach roghnaithe",
    "Move selection" : "Bog roghnú",
    "Edit tags of selection" : "Cuir clibeanna roghnúcháin in eagar",
    "Delete selection" : "Scrios an roghnúchán",
    "Select all" : "Roghnú go léir",
    "Cancel selection" : "Cealaigh an roghnúchán",
    "Sort by created date" : "Sórtáil de réir dáta cruthaithe",
    "Sort by last modified" : "Sórtáil de réir mionathraithe",
    "Sort by title" : "Sórtáil de réir teidil",
    "Sort by click count" : "Sórtáil de réir comhaireamh cliceáil",
    "Sort by manual order" : "Sórtáil de réir ordú láimhe",
    "Sort by URL" : "Sórtáil de réir URL",
    "RSS feed copied" : "Cóipeáladh fotha RSS",
    "Trash Bin" : "Bruscar",
    "Go back" : "Dul ar ais",
    "Share folder" : "Comhroinn fillteán",
    "Open folder details" : "Oscail sonraí fillteáin",
    "Select one or more tags" : "Roghnaigh clib amháin nó níos mó",
    "New" : "Nua",
    "New bookmark" : "Leabharmharc nua",
    "New folder" : "Fillteán nua",
    "Change to grid view" : "Athrú go radharc greille",
    "Change to list view" : "Athraigh go hamharc liosta",
    "Copy RSS Feed of current view" : "Cóipeáil Fotha RSS den radharc reatha",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Teastaíonn fíordheimhniú ón bhfotha RSS le do dhintiúir Nextcloud",
    "Search" : "Cuardach",
    "Empty trash bin" : "Bruscar folamh",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["%n leabharmharc á chur le fillteán nua","%n leabharmharcanna á gcur le fillteán nua","%n leabharmharcanna á gcur le fillteán nua","%n leabharmharcanna á gcur le fillteán nua","%n leabharmharcanna á gcur le fillteán nua"],
    "Enter a link" : "Cuir isteach nasc",
    "Enter a title" : "Cuir isteach teideal",
    "No bookmarks found" : "Níor aimsíodh leabharmharcanna",
    "{folders} folders and {bookmarks} bookmarks" : "{fillteáin} fillteán agus {leabharmharcanna} leabharmharcanna",
    "_%n bookmark_::_%n bookmarks_" : ["%n leabharmharc","%n leabharmharcanna","%n leabharmharcanna","%n leabharmharcanna","%n leabharmharcanna"],
    "_%n folder_::_%n folders_" : ["%n fillteán","%n fillteáin","%n fillteáin","%n fillteáin","%n fillteáin"],
    "Welcome to Bookmarks" : "Fáilte go Leabharmharcanna",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Ligeann an aip seo duit naisc chuig na háiteanna is fearr leat ar an ngréasán a bhainistiú. Sórtáil do leabharmharcanna i bhfillteáin, lipéadaigh iad le clibeanna agus roinn le daoine eile iad! Seiceálfaidh an aip do naisc go léir go rialta le haghaidh infhaighteachta agus taispeánfar naisc nach bhfuil ar fáil. Má chuireann tú nasc le comhad ar an ngréasán, déanfar an comhad a íoslódáil go huathoibríoch chuig do Chomhaid Nextcloud. Is féidir leat leabharmharcanna arna n-easpórtáil ó sheirbhísí eile a allmhairiú freisin nó leabharmharcanna a shioncronú go díreach ó do bhrabhsálaithe go léir leis an aip seo.",
    "Add a bookmark" : "Cuir leabharmharc leis",
    "Import bookmarks" : "Iompórtáil leabharmharcanna",
    "Sync with your browser" : "Sioncrónaigh le do bhrabhsálaí",
    "Do you really want to permanently delete this folder?" : "Ar mhaith leat an fillteán seo a scriosadh go buan?",
    "Select folder" : "Roghnaigh fillteán",
    "Enter folder title" : "Cuir isteach teideal an fhillteáin",
    "Shared by {user}" : "Roinnte ag {user}",
    "Rename folder" : "Athainmnigh fillteán",
    "Move folder" : "Bog fillteán",
    "Put folder into trashbin" : "Cuir fillteán isteach sa bhruscar",
    "Restore folder" : "Athchóirigh fillteán",
    "Delete folder permanently" : "Scrios fillteán go buan",
    "Choose folder" : "Roghnaigh fillteán",
    "Submit" : "Cuir isteach",
    "Cancel" : "Cealaigh",
    "Deleting bookmarks" : "Leabharmharcanna á scriosadh",
    "Deleting selection" : "Roghnú á scriosadh",
    "Importing bookmarks" : "Leabharmharcanna á n-iompórtáil",
    "Moving selection" : "Roghnú ag bogadh",
    "Adding selection to folders" : "Roghnú á chur le fillteáin",
    "Emptying trashbin" : "Bruscar á fholmhú",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Fillteán %n agus roinnt leabharmharc á mbogadh","Ag bogadh %n fillteán agus roinnt leabharmharcanna","Ag bogadh %n fillteán agus roinnt leabharmharcanna","Ag bogadh %n fillteán agus roinnt leabharmharcanna","Ag bogadh %n fillteán agus roinnt leabharmharcanna"],
    "_Moving %n folder_::_Moving %n folders_" : ["fillteán %n á bhogadh","%n fillteán á mbogadh","%n fillteán á mbogadh","%n fillteán á mbogadh","%n fillteán á mbogadh"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n leabharmharc á bhogadh","%n leabharmharcanna á mbogadh","%n leabharmharcanna á mbogadh","%n leabharmharcanna á mbogadh","%n leabharmharcanna á mbogadh"],
    "All bookmarks" : "Gach leabharmharc",
    "Recent" : "le déanaí",
    "Frequently clicked" : "Cliceáilte go minic",
    "Shared with you" : "Roinnte leat",
    "Files" : "Comhaid",
    "Duplicates" : "Dúblaigh",
    "Broken links" : "Naisc briste",
    "New tag" : "Clib nua",
    "Search tags" : "Cuardaigh clibeanna",
    "Delete" : "Scrios",
    "Untagged" : "Gan chlib",
    "{used} bookmarks of {available} available" : "leabharmharcanna {úsáidte} de {ar fáil} ar fáil",
    "Bookmarks Settings" : "Socruithe Leabharmharcanna",
    "No bookmarked files" : "Níl aon chomhaid leabharmharcáilte",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Sábhálfar leabharmharcanna chuig comhaid ar nós grianghraif nó PDFanna go huathoibríoch chuig do chomhaid Nextcloud, ionas gur féidir leat iad a aimsiú fiú nuair a théann an nasc as líne.",
    "Nothing found" : "Ní bhfuarthas aon rud",
    "Your search yielded no results in the current folder." : "Níor tháinig aon toradh ar do chuardach san fhillteán reatha.",
    "No broken links" : "Gan naisc briste",
    "No shared folders" : "Níl aon fhillteán roinnte",
    "No duplicated bookmarks" : "Gan leabharmharcanna dúblacha",
    "No deleted bookmarks" : "Níl aon leabharmharcanna scriosta",
    "You haven't deleted anything yet." : "Níl aon rud scriosta agat fós.",
    "No bookmarks here" : "Níl aon leabharmharcanna anseo",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Cuir leabharmharcanna leis de láimh nó iompórtáil leabharmharcanna ó chomhad HTML.",
    "Archive path" : "Conair cartlainne",
    "Backup path" : "Cosán cúltaca",
    "Please select \"Add to home screen\" in your browser menu" : "Roghnaigh \"Cuir leis an scáileán baile\" i roghchlár do bhrabhsálaí le do thoil",
    "Bookmarks settings" : "Socruithe leabharmharcanna",
    "Import/Export" : "Iompórtáil/Easpórtáil",
    "Export bookmarks" : "Easpórtáil leabharmharcanna",
    "Auto-archiving" : "Uath-cartlannú",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Is féidir leis an aip leabharmharcanna inneachar gréasáin na naisc atá leabharmharcáilte agat a chartlannú go huathoibríoch",
    "Enable archiving" : "Cumasaigh cartlannú",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Cuir isteach conair an fhillteáin i do Chomhaid inar cheart comhaid leabharmharcáilte a stóráil.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Tá rochtain líonra díchumasaithe ag do riarthóir don aip seo faoi láthair, áfach, agus is é sin an fáth go bhfuil Uath-cartlannú díchumasaithe faoi láthair.",
    "Auto-Backup" : "Auto-Cúltaca",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Is féidir leis an aip leabharmharcanna cúltaca uathoibríoch a dhéanamh de do leabharmharcanna ar bhonn laethúil chun caillteanas sonraí a chosc agus leabharmharcanna á sioncronú thar ghléasanna.",
    "Enable backups" : "Cumasaigh cúltacaí",
    "Enter the path of a folder in your Files where backups will be stored." : "Cuir isteach an cosán ar fhillteán i do Comhaid áit a mbeidh cúltacaí a stóráil.",
    "Context Chat integration" : "Comhtháthú Comhrá Comhthéacsúil",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Is féidir leis an aip leabharmharcanna ábhar téacsúil na suíomhanna gréasáin a bhfuil leabharmharcanna agat orthu a chur ar fáil go huathoibríoch do Chomhrá Comhthéacsúil, rud a ligeann duit ceisteanna a chur fúthu agus freagraí a fháil bunaithe ar an ábhar sin. Níl sé seo ar fáil ach amháin má tá uath-chartlannú cumasaithe.",
    "Context chat is currently not installed, but is required for this feature." : "Níl comhrá comhthéacsúil suiteáilte faoi láthair, ach tá sé riachtanach don ghné seo.",
    "Enable Context Chat integration" : "Cumasaigh comhtháthú Comhrá Comhthéacsúil",
    "Client apps" : "Aipeanna cliant",
    "Also check out the collection of client apps that integrate with this app: " : "Seiceáil freisin an bailiúchán d'aipeanna cliaint a chomhtháthaíonn leis an aip seo:",
    "Install web app" : "Suiteáil aip gréasáin",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Is féidir leat an aip seo a shuiteáil ar scáileán baile do ghléis chun rochtain tapa a fháil ar do leabharmharcanna ar do ghuthán. Is féidir leat an aip a bhaint go héasca ó do scáileán baile arís, mura dtaitníonn sé leat.",
    "Install on home screen" : "Suiteáil ar an scáileán sa bhaile",
    "Bookmarklet" : "Leabharmharclann",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Tarraing é seo chuig leabharmharcanna do bhrabhsálaí agus cliceáil air chun leathanach gréasáin a leabharmharcáil go tapa.",
    "Add to {instanceName}" : "Cuir le {instanceName}",
    "Need help?" : "Teastaionn Cabhair?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Má tá fadhbanna agat leis an aip Leabharmharcanna seo nó má tá tuairim agat cad a d’fhéadfaí a fheabhsú, ná bíodh leisce ort teagmháil a dhéanamh trí chliceáil anseo.",
    "Support this project" : "Tacaigh leis an tionscadal seo",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Tá mo chuid oibre ar an aip Bookmarks seo bunaithe ar shíntiús deonach. Má cheapann tú gur fiú an méid a dhéanfaidh mé, bheinn sásta dá bhféadfá tacú le mo chuid oibre. Chomh maith leis sin, smaoinigh le do thoil ar athbhreithniú a thabhairt don aip ar an siopa aip Nextcloud. Go raibh maith agat 💙",
    "Created {time} ago" : "Cruthaithe {time} ó shin",
    "Created on {date}" : "Cruthaithe ar {date}",
    "(Empty title)" : "(Teideal folamh)",
    "Title" : "Teideal",
    "Link" : "Nasc",
    "Untitled folder" : "Fillteán gan teideal",
    "Root folder" : "Fillteán fréimhe",
    "Tags" : "Clibeanna",
    "Select tags and create new ones" : "Roghnaigh clibeanna agus cruthaigh cinn nua",
    "Notes" : "Nótaí",
    "Notes for this bookmark …" : "Nótaí don leabharmharc seo…",
    "Archived file" : "Comhad cartlainne",
    "Open file" : "Oscail comhad",
    "Download file" : "Íoslódáil an comhad",
    "Open file location" : "Oscail suíomh comhaid",
    "Link copied" : "Cóipeáladh an nasc",
    "Owner" : "Úinéir",
    "Sharing" : "Roinnt",
    "Select a user or group" : "Roghnaigh úsáideoir nó grúpa",
    "Share link" : "Comhroinn nasc",
    "Reading allowed" : "Léitheoireacht ceadaithe",
    "Copy RSS feed" : "Cóipeáil fotha RSS",
    "Delete link" : "Scrios an nasc",
    "Create public link" : "Cruthaigh nasc poiblí",
    "Resharing allowed" : "Ceadaíodh athroinnt",
    "Editing allowed" : "Ceadaíodh eagarthóireacht",
    "Allow editing" : "Ceadaigh eagarthóireacht",
    "Allow resharing" : "Ceadaigh athroinnt",
    "Remove share" : "Bain sciar",
    "Would you like to support this project?" : "Ar mhaith leat tacú leis an tionscadal seo?",
    "Leave a rating on the Nextcloud App Store" : "Fág rátáil ar an  Siopa Aip Nextcloud",
    "Failed to save settings" : "Theip ar na socruithe a shábháil",
    "Failed to load settings" : "Theip ar lódáil na socruithe",
    "Privacy" : "Príobháideacht",
    "The app will try to access web pages that you add to automatically add information about them." : "Déanfaidh an aip iarracht teacht ar leathanaigh ghréasáin a chuireann tú leis chun faisnéis fúthu a chur leis go huathoibríoch.",
    "Enable accessing and collecting information from the web pages you add" : "Cumasaigh rochtain agus bailiú faisnéise ó na leathanaigh ghréasáin a chuireann tú leis",
    "Performance" : "Feidhmíocht",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I suiteáil ina bhfuil go leor úsáideoirí b’fhéidir go mbeadh sé úsáideach líon na leabharmharcanna in aghaidh an chuntais a shrianadh.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "An líon uasta leabharmharcanna in aghaidh an chuntais. (0 gan teorainn; níl aon teorainn leis an réamhshocrú)",
    "Previews" : "Réamhamhairc",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "D’fhonn fíor-scáileáin de do shuíomhanna gréasáin leabharmharcáilte a thaispeáint, is féidir leis an aip seirbhísí tríú páirtí a úsáid chun réamhamhairc a ghiniúint.",
    "Screeenly" : "Go scáileáin",
    "You can either sign up for free at screeenly.com or setup your own server." : "Is féidir leat clárú saor in aisce ag screeenly.com nó do fhreastalaí féin a shocrú.",
    "Screeenly API URL" : "URL API go scáileáin",
    "Screeenly API key" : "Eochair API go scáileán",
    "ScreenshotMachine" : "Meaisín gabháil scáileáin",
    "ScreenshotMachine API key" : "Eochair API ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL Webshot API",
    "Generic screenshot API" : "API screenshot cineálach",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Cláraigh le haon cheann de na soláthraithe API scáileáin agus cuir an URL API thíos. Bain úsáid as an athróg {url} mar áitshealbhóir don URL chun gabháil scáileáin. Ní mór don API ach an íomhá a thabhairt ar ais go díreach.",
    "Generic API URL" : "URL API cineálach",
    "Pageres CLI" : "Leathanaigh CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Níl ort ach an Pageres CLI le Sindre Sorhus a shuiteáil ar do fhreastalaí agus gheobhaidh Leabharmharcanna é. Is féidir leat vars ENV breise a chur leis fós le beathú le leathanaigh, e.g. mar a léirítear sa sealbhóir:",
    "Pageres ENV variables" : "Athróga Pageres ENV",
    "This URL is already bookmarked! Overwrite?" : "Tá an URL seo leabharmharcáilte cheana féin! Forscríobh?",
    "Enter bookmark title" : "Cuir isteach teideal leabharmharc",
    "Enter bookmark URL" : "Cuir isteach URL leabharmharc",
    "Folder" : "Fillteán",
    "Root Folder" : "Fillteán Fréamh",
    "Save" : "Sábháil",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Díchumasaítear rochtain líonra de réir réamhshocraithe. Téigh chuig socruithe riarthóra don aip leabharmharcanna chun réamhamhairc agus favicons a fháil.",
    "What's new?" : "Cad atá nua?",
    "What" : "Cad",
    "Failed to count unavailable bookmarks" : "Theip ar leabharmharcanna nach bhfuil ar fáil a chomhaireamh",
    "Failed to count archived bookmarks" : "Níorbh fhéidir leabharmharcanna cartlainne a chomhaireamh",
    "Failed to count deleted bookmarks" : "Theip ar chomhaireamh leabharmharcanna scriosta",
    "Failed to count duplicated bookmarks" : "Theip ar leabharmharcanna dúblacha a chomhaireamh",
    "Failed to count bookmarks" : "Theip ar chomhaireamh leabharmharcanna",
    "Failed to load bookmark" : "Theip ar lódáil leabharmharc",
    "Failed to find existing bookmark" : "Theip ar an leabharmharc reatha a aimsiú",
    "Failed to create bookmark" : "Theip ar leabharmharc a chruthú",
    "Failed to save bookmark" : "Theip ar shábháil leabharmharc",
    "Failed to move bookmark" : "Theip ar an leabharmharc a bhogadh",
    "Failed to copy bookmark" : "Theip ar an leabharmharc a chóipeáil",
    "Failed to delete bookmark" : "Theip ar leabharmharc a scriosadh",
    "Failed to restore bookmark" : "Theip ar an leabharmharc a athbhunú",
    "Import successful" : "Iompórtáil rathúil",
    "Failed to rename tag" : "Theip ar an gclib a athainmniú",
    "Failed to load tags" : "Theip ar lódáil clibeanna",
    "Failed to load folders" : "Theip ar lódáil fillteáin",
    "Failed to load deleted folders" : "Theip ar lódáil fillteáin scriosta",
    "Failed to load deleted bookmarks" : "Theip ar lódáil leabharmharcanna scriosta",
    "Failed to delete folder" : "Theip ar scriosadh an fhillteáin",
    "Failed to move folder" : "Theip ar bhogadh fillteán",
    "Failed to restore folder" : "Theip ar an bhfillteán a athchóiriú",
    "Failed to create folder" : "Theip ar chruthú fillteán",
    "Failed to load children order" : "Theip ar ordú na bpáistí a lódáil",
    "Failed to move parts of selection" : "Theip ar chodanna den roghnúchán a bhogadh",
    "Failed to copy parts of selection" : "Theip ar chodanna den roghnúchán a chóipeáil",
    "Failed to delete parts of selection" : "Theip ar chodanna den roghnú a scriosadh",
    "Failed to tag parts of selection" : "Theip ar chodanna den roghnú a chlibeáil",
    "Failed to fetch bookmarks." : "Theip ar leabharmharcanna a fháil.",
    "Failed to store setting" : "Theip ar an socrú a stóráil",
    "Failed to load setting {key}" : "Theip ar an socrú {key} a lódáil",
    "Failed to create share for folder {folderId}" : "Theip ar chomhroinnt a chruthú don fhillteán {folderId}",
    "Failed to update share {shareId}" : "Theip ar roinnt {shareId} a nuashonrú",
    "Failed to delete share {shareId}" : "Theip ar roinnt {shareId} a scriosadh",
    "Failed to create public link for folder {folderId}" : "Theip ar nasc poiblí a chruthú don fhillteán {folderId}",
    "Failed to delete public link for folder {folderId}" : "Theip ar an nasc poiblí don fhillteán {folderId} a scriosadh",
    "Failed to permanently delete parts of trash bin" : "Theip ar chodanna den bhosca bruscair a scriosadh go buan",
    "Create bookmarks for mentioned links" : "Cruthaigh leabharmharcanna do naisc luaite",
    "No links found in this message" : "Níor aimsíodh aon nasc sa teachtaireacht seo",
    "Bookmarks feed" : "Fotha leabharmharcanna"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
