<?php
$TRANSLATIONS = array(
"Bookmarks" => "Σελιδοδείκτες",
"Failed to import one bookmark, because: " => "Απέτυχε η εισαγωγή ενός σελιδοδείκτη, διότι:",
"Bookm." => "Σελιδοδεικτ.",
"No file provided for import" => "Δεν δόθηκε αρχείο για εισαγωγή",
"Unsupported file type for import" => "Δεν υποστηρίζεται o τύπος αρχείου για εισαγωγή",
"Some Error happened." => "Συνέβη κάποιο σφάλμα.",
"Error" => "Σφάλμα",
"Tags" => "Ετικέτες",
"Filter by tag" => "Φιλτράρισμα βάσει ετικέτας",
"Are you sure you want to remove this bookmark?" => "Είστε σίγουρος πως θέλετε να διαγράψετε τον σελοδοδείκτη;",
"Warning" => "Προειδοποίηση",
"Are you sure you want to remove this tag from every entry?" => "Είστε σίγουροι για την αφαίρεση αυτής της ετικέτας από κάθε καταχώρηση;",
"Import error" => "Σφάλμα εισαγωγής",
"Import completed successfully." => "Η εισαγωγή ολοκληρώθηκε επιτυχώς.",
"Uploading..." => "Μεταφόρτωση...",
"Add a bookmark" => "Προσθήκη σελιδοδείκτη",
"This URL is already bookmarked! Overwrite?" => "Αυτή η διεύθυνση έχει καταχωρηθεί ήδη στους σελιδοδείκτες. Αντικατάσταση;",
"The title of the page" => "Τίτλος της σελίδας",
"The address of the page" => "Διεύθυνση της σελίδας",
"Description of the page" => "Περιγραφή της σελίδας",
"Save" => "Αποθήκευση",
"Delete" => "Διαγραφή",
"Edit" => "Επεξεργασία",
"Cancel" => "Ακύρωση",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Σύρετε αυτό στους σελιδοδείκτες του περιηγητή σας και κάντε κλικ επάνω του, όταν θέλετε να προσθέσετε γρήγορα μια ιστοσελίδα ως σελιδοδείκτη:",
"Add to ownCloud" => "Προσθήκη στο ownCloud",
"Address" => "Διεύθυνση",
"Filterable Tags" => "Φιλτραρισμένες ετικέτες.",
"You have no bookmarks" => "Δεν έχετε σελιδοδείκτες",
"You can also import a bookmark file" => "Μπορείτε επίσης να εισάγετε αρχείο σελιδοδεικτών",
"Bookmarklet" => "Εφαρμογίδιο Σελιδοδεικτών",
"Export & Import" => "Εξαγωγή & Εισαγωγή",
"Export" => "Εξαγωγή",
"Import" => "Εισαγωγή"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
