<?php

/*
 * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
 *
 * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
 */

namespace OCA\Bookmarks\Contract;

use OCA\Bookmarks\Db\Bookmark;

interface IBookmarkPreviewer {
	/**
	 * @param Bookmark $bookmark
	 * @return IImage|null
	 */
	public function getImage($bookmark, $cacheOnly = false): ?IImage;
}
