<?php

namespace Marcelklehr\LinkPreview\Exceptions;

/**
 * Class UnknownFieldException
 * @package Marcelklehr\LinkPreview\Exceptions
 * @codeCoverageIgnore
 */
class UnknownFieldException extends \Exception
{
}
