OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Yer imleri",
    "You bookmarked \"%s\"" : "\"%s\" yer imini eklediniz",
    "%1$s bookmarked \"%2$s\"" : "%1$s, \"%2$s\" yer imini ekledi",
    "Someone bookmarked \"%s\"" : "Biri \"%s\" yer imini ekledi",
    "You deleted \"%s\"" : "\"%s\" yer imini sildiniz",
    "%1$s deleted \"%2$s\"" : "%1$s, \"%2$s\" yer imini sildi",
    "Someone deleted \"%s\"" : "Biri \"%s\" yer imini sildi",
    "You created folder \"%s\"" : "\"%s\" klasörünü eklediniz",
    "%1$s created folder \"%2$s\"" : "%1$s, \"%2$s\" klasörünü ekledi",
    "Someone created folder \"%s\"" : "Biri \"%s\" klasörünü ekledi",
    "You moved folder \"%s\"" : "\"%s\" klasörünü taşıdınız",
    "%1$s moved folder \"%2$s\"" : "%1$s, \"%2$s\" klasörünü taşıdı",
    "Someone moved folder \"%s\"" : "Biri \"%s\" klasörünü taşıdı",
    "You deleted folder \"%s\"" : "\"%s\" klasörünü sildiniz",
    "%1$s deleted folder \"%2$s\"" : "%1$s, \"%2$s\" klasörünü sildi",
    "Someone deleted folder \"%s\"" : "Biri \"%s\" klasörünü sildi",
    "You shared folder \"%1$s\" with %2$s" : "\"%1$s\" klasörünü %2$s ile paylaştınız",
    "You shared folder \"%s\" with someone" : "\"%s\" klasörünü birisi ile paylaştınız",
    "%1$s shared folder \"%2$s\" with you" : "%1$s, \"%2$s\" klasörünü sizinle paylaştı",
    "Someone shared folder \"%s\" with you" : "Biri \"%s\" klasörünü sizinle paylaştı",
    "You unshared folder \"%1$s\" with %2$s" : "\"%1$s\" klasörünün %2$s ile paylaşımını kaldırdınız",
    "You unshared folder \"%s\" with someone" : "\"%s\" klasörünün biri ile paylaşımını kaldırdınız",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s, \"%2$s\" klasörünün sizinle paylaşımını kaldırdı",
    "Someone unshared folder \"%s\" with you" : "Biri \"%s\" klasörünün sizinle paylaşımını kaldırdı",
    "No file provided for import" : "İçe aktarılacak bir dosya seçilmemiş",
    "Failed to upload file" : "Dosya yüklenemedi",
    "Unsupported file type for import: " : "İçe aktarılacak dosya türü desteklenmiyor:",
    "Bookmarks shared by %s" : "%s tarafından paylaşılan yer imleri",
    "Frequent bookmarks" : "Sık kullanılan yer imleri",
    "Recent bookmarks" : "Son kullanılan yer imleri",
    "Bookmark" : "Yer imi",
    "Bookmark deleted" : "Yer imi silindi",
    "Bookmark created" : "Yer imi eklendi",
    "Bookmark moved" : "Yer imi taşındı",
    "Bookmark updated" : "Yer imi güncellendi",
    "Create bookmark" : "Yer imi ekle",
    "Takes a link and adds it to your collection of bookmarks." : "Bir bağlantıyı alarak yer imlerinize ekler.",
    "Bookmarks Backups" : "Yer imi yedekleri",
    "Collect and manage bookmarks, synced with all your devices" : "Yer imlerini toplayın ve yönetin, tüm aygıtlarınızla eşitleyin",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Yer imlerini klasörlerle düzenleyin\n- 🏷 Etiketler ve kişisel notlar ekleyin\n- ☠ Bozuk ve yinelenen bağlantıları bulun\n- 📲 Tüm tarayıcılarınız ve aygıtlarınızla eşitleyin\n- 📔 Bağlantılarınız yayından kaldırılırsa arşivlenmiş sürümlerini tutun\n- 🔍 Site içeriklerinde tam yazı araması yapın\n- 👪 Yer imlerini diğer kullanıcılar, gruplar, takımlar veya herkese açık bağlantılar ile paylaşın\n- ⚛ Derlemeleriniz için RSS akışları oluşturun\n- 📈 Hangi bağlantılara ne sıklıkla eriştiğiniz hakkında istatistikler görün\n- 🔒 Yer imleri derlemenizi otomatik olarak yedekleyin\n- 💼 Sık ve son kullanılan bağlantılar için hazır pano bileşenlerini kullanın\n\nGereksinimler:\n- PHP eklentileri:\n- intl: *\n- mbstring: *\n- MySQL için en az 8.0 sürümünü kullanın",
    "Do you really want to delete this bookmark?" : "Bu yer imini silmek istediğinize emin misiniz?",
    "Link copied to clipboard" : "Bağlantı panoya kopyalandı",
    "Enter new title" : "Yeni başlığı yazın",
    "Select bookmark" : "Yer imi seçin",
    "You have never clicked this link" : "Bu bağlantıya hiç tıklamadınız",
    "You have clicked this link {count} times" : "Bu bağlantıya {count} kez tıkladınız",
    "Details" : "Ayrıntılar",
    "Rename" : "Yeniden adlandır",
    "Copy link" : "Bağlantıyı kopyala",
    "Move" : "Taşı",
    "Add to folders" : "Klasörlere ekle",
    "Put bookmark into trash bin" : "Yer imini çöpe at",
    "Restore bookmark" : "Yer imini geri yükle",
    "Delete bookmark permanently" : "Yer imini kalıcı olarak sil",
    "Content pending" : "İçerik bekliyor",
    "This content is being downloaded for offline use. Please check back later." : "İçerik çevrim dışı kullanım için indirildi. Lütfen bir süre sonra yeniden deneyin.",
    "Bookmarked {time} ago" : "{time} önce yer imlerine eklenmiş",
    "Bookmarked on {date}" : "{date} tarihinde yer imlerine eklenmiş",
    "These are your deleted items. Items will be deleted permanently after two months." : "Burada silinmiş ögelerinizi görebilirsiniz. Bunlar iki ay sonra kalıcı olarak silinir.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Fotoğraf ya da PDF gibi internet üzerindeki dosyaların yer imleri otomatik olarak Nextcloud dosyalarınıza kaydedilir. Böylece bağlantı çevrim dışı olsa bile bu dosyalara erişebilirsiniz.",
    "Searching in the current folder only." : "Yalnızca geçerli klasörde aranıyor.",
    "Repeat search in all folders" : "Aramayı tüm klasörlerde yinele",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Yer imi bağlantıları düzenli olarak denetlenir ve erişilemeyen bağlantılar burada görüntülenir.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Yer imi klasörlerini başkalarıyla paylaşabilirsiniz. Sizinle paylaşılan tüm klasörler burada görüntülenir.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Bir yer imi aynı anda birden fazla klasörde bulunabilir. Biri güncellendiğinde tüm kopyalar güncellenir. Tüm yer imi kopyaları kolaylık sağlamak için burada listelenmiştir.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} klasör ve {bookmarks} yer imi seçilmiş",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n yer imi seçilmiş","%n yer imi seçilmiş"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n klasör seçilmiş","%n klasör seçilmiş"],
    "Do you really want to delete these items?" : "Bu ögeleri silmek istediğinize emin misiniz?",
    "Open all selected" : "Tüm seçilmişleri aç",
    "Move selection" : "Seçilmişleri taşı",
    "Edit tags of selection" : "Seçimin etiketlerini düzenle",
    "Delete selection" : "Seçilmişleri sil",
    "Select all" : "Tümünü seç",
    "Cancel selection" : "Seçimi iptal et",
    "Sort by created date" : "Eklenme tarihine göre sırala",
    "Sort by last modified" : "Değişiklik tarihine göre sırala",
    "Sort by title" : "Başlığa göre sırala",
    "Sort by click count" : "Tıklanma sayısına göre sırala",
    "Sort by manual order" : "El ile belirtilen sıralamaya göre sırala",
    "Sort by URL" : "Adrese göre sırala",
    "RSS feed copied" : "RSS akışı kopyalandı",
    "Trash Bin" : "Çöp",
    "Go back" : "Geri dön",
    "Share folder" : "Klasör paylaş",
    "Open folder details" : "Klasör bilgilerini aç",
    "Select one or more tags" : "Bir ya da bir kaç etiket seçin",
    "New" : "Yeni",
    "New bookmark" : "Yeni yer imi",
    "New folder" : "Yeni klasör",
    "Change to grid view" : "Tablo görünümüne geç",
    "Change to list view" : "Liste görünümüne geç",
    "Copy RSS Feed of current view" : "Geçerli görünümün RSS akışını kopyala",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS akışı için Nextcloud kimlik doğrulama bilgilerinizi yazmanız gerekiyor",
    "Search" : "Arama",
    "Empty trash bin" : "Çöp kutusunu boşalt",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Yeni klasöre %n yer imi ekleniyor","Yeni klasöre %n yer imi ekleniyor"],
    "Enter a link" : "Bir bağlantı yazın",
    "Enter a title" : "Bir başlık yazın",
    "No bookmarks found" : "Herhangi bir yer imi bulunamadı",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} klasör ve {bookmarks} yer imi",
    "_%n bookmark_::_%n bookmarks_" : ["%n yer imi","%n yer imi"],
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "Welcome to Bookmarks" : "Yer imlerine hoş geldiniz",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Bu uygulama sık kullandığınız site bağlantılarını yönetmenizi sağlar. Yer imlerinizi klasörlere ayırabilir, etiketleyebilir ve başkalarıyla paylaşabilirsiniz! Uygulama, düzenli olarak tüm bağlantılarınızın kullanılabilir olduğunu denetler ve kullanılamayan bağlantıları gösterir İnternet üzerindeki bir dosyaya bağlantı eklerseniz, dosya otomatik olarak Nextcloud Dosyalar uygulamanıza indirilir. Ayrıca, diğer hizmetlerden dışa aktarılmış yer imlerini içe aktarabilir ya da bu uygulama ile doğrudan tüm tarayıcılarınızdaki yer imlerini eşitleyebilirsiniz.",
    "Add a bookmark" : "Yer imi ekle",
    "Import bookmarks" : "Yer imlerini içe aktar",
    "Sync with your browser" : "Tarayıcınızla eşitleyin",
    "Do you really want to permanently delete this folder?" : "Bu klasörü kalıcı olarak silmek istediğinize emin misiniz?",
    "Select folder" : "Klasör seçin",
    "Enter folder title" : "Klasör başlığını yazın",
    "Shared by {user}" : "{user} tarafından paylaşıldı",
    "Rename folder" : "Klasörü yeniden adlandır",
    "Move folder" : "Klasörü taşı",
    "Put folder into trashbin" : "Klasörü çöpe at",
    "Restore folder" : "Klasörü geri yükle",
    "Delete folder permanently" : "Klasörü kalıcı olarak sil",
    "Choose folder" : "Klasör seçin",
    "Submit" : "Gönder",
    "Cancel" : "İptal",
    "Deleting bookmarks" : "Yer imleri siliniyor",
    "Deleting selection" : "Seçim siliniyor",
    "Importing bookmarks" : "Yer imleri içe aktarılıyor",
    "Moving selection" : "Seçim taşınıyor",
    "Adding selection to folders" : "Seçim klasörlere ekleniyor",
    "Emptying trashbin" : "Çöp kutusu boşaltılıyor",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n klasör ve bazı yer imleri taşınıyor","%n klasör ve bazı yer imleri taşınıyor"],
    "_Moving %n folder_::_Moving %n folders_" : ["%n klasör taşınıyor","%n klasör taşınıyor"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n yer imi taşınıyor","%n yer imi taşınıyor"],
    "All bookmarks" : "Tüm yer imleri",
    "Recent" : "Son",
    "Frequently clicked" : "Sık tıklanan",
    "Shared with you" : "Sizinle paylaşılan",
    "Files" : "Dosyalar",
    "Duplicates" : "Kopyalar",
    "Broken links" : "Kopuk bağlantılar",
    "New tag" : "Etiket ekle",
    "Search tags" : "Etiket arama",
    "Delete" : "Sil",
    "Untagged" : "Etiketlenmemiş",
    "{used} bookmarks of {available} available" : "{used} yer imi {available} kullanılabilir",
    "Bookmarks Settings" : "Yer imleri ayarları",
    "No bookmarked files" : "Yer imlerine eklenmiş bir dosya yok",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Fotoğraf ya da PDF gibi dosyaların yer imleri otomatik olarak Nextcloud dosyalarınıza kaydedilir. Böylece bağlantı çevrim dışı olsa bile bu dosyalara erişebilirsiniz.",
    "Nothing found" : "Herhangi bir şey bulunamadı",
    "Your search yielded no results in the current folder." : "Aramanız sonucunda geçerli klasörde bir sonuç bulunamadı.",
    "No broken links" : "Çalışmayan bir bağlantı yok",
    "No shared folders" : "Paylaşılmış bir klasör yok",
    "No duplicated bookmarks" : "Henüz çoğaltılmış bir yer imi yok",
    "No deleted bookmarks" : "Henüz silinmiş bir yer imi yok",
    "You haven't deleted anything yet." : "Henüz bir şey silmemişsiniz.",
    "No bookmarks here" : "Burada herhangi bir yer imi yok",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Yer imlerini el ile ekleyin ya da bir HTML dosyasından içe aktarın.",
    "Archive path" : "Arşiv yolu",
    "Backup path" : "Yedekleme yolu",
    "Please select \"Add to home screen\" in your browser menu" : "Lütfen tarayıcınızın menüsünden \"Girişe ekle\" seçin",
    "Bookmarks settings" : "Yer imi ayarları",
    "Import/Export" : "İçe/Dışa aktar",
    "Export bookmarks" : "Yer imlerini dışa aktar",
    "Auto-archiving" : "Otomatik arşivleme",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Yer imleri uygulaması, yer imlerine eklediğiniz bağlantıların içeriğini otomatik olarak arşivleyebilir",
    "Enable archiving" : "Arşivleme kullanılsın",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Dosyalar uygulamasında, yer imlerine eklenmiş dosyaların kaydedileceği klasörün yolunu yazın",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Yöneticiniz bu uygulamanın ağ erişimini kapatmış. Bu nedenle otomatik arşivleme kullanılamaz.",
    "Auto-Backup" : "Otomatik yedekleme",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Yer imleri uygulaması, yer imlerini aygıtlar arasında eşitlerken veri kaybını önlemek için yer imlerinizi her gün otomatik olarak yedekleyebilir.",
    "Enable backups" : "Yedekleme kullanılsın",
    "Enter the path of a folder in your Files where backups will be stored." : "Dosyalar uygulamasında, yedeklerin kaydedileceği klasörün yolunu yazın.",
    "Context Chat integration" : "Context Chat bütünleştirmesi",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Yer imleri uygulaması, Context Chat yer imlerine eklediğiniz sitelerin yazı içeriklerini otomatik olarak kullanılabilir. Böylece, bu içerikler ile ilgili sorular sorabilir ve bunlara göre yanıtlar alabilirsiniz. Bu özellik yalnızca otomatik arşivleme açıldığında kullanılabilir.",
    "Context chat is currently not installed, but is required for this feature." : "Context Chat kurulu değil. Bu özelliğin kullanılabilmesi için kurulmalıdır.",
    "Enable Context Chat integration" : "Context Chat bütünleştirmesi kullanılsın",
    "Client apps" : "İstemci uygulamaları",
    "Also check out the collection of client apps that integrate with this app: " : "Ayrıca bu uygulama ile birlikte çalışan istemci uygulamalarına da bakın:",
    "Install web app" : "Web uygulaması kur",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Telefonunuzdaki yer imlerinize hızlı bir şekilde erişmek için bu uygulamayı aygıtınızın ana ekranına kurabilirsiniz. Beğenmezseniz uygulamayı ana ekranınızdan kolayca kaldırabilirsiniz.",
    "Install on home screen" : "Ana sayfaya kur",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Bunu sürükleyip tarayıcınızın yer imleri bölümüne bırakın ve bir site sayfasını kolayca yer imlerine eklemek için üzerine tıklayın.",
    "Add to {instanceName}" : "{instanceName} üzerine ekle",
    "Need help?" : "Yardım gerekiyor mu?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Bu Yer imleri uygulamasıyla ilgili sorun yaşıyorsanız veya neyin geliştirilebileceği konusunda bir fikriniz varsa, buraya tıklayarak bizimle görüşmeye çekinmeyin.",
    "Support this project" : "Bu projeyi destekleyin",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Yer imleri uygulamasındaki çalışmam gönüllü abonelik modeliyle destekleniyor. Yaptığım şeyin değerli olduğunu düşünüyorsanız, çalışmamı desteklerseniz mutlu olurum. Ayrıca, lütfen Nextcloud uygulama mağazasında uygulamaya bir değerlendirme yazmayı düşünün. Teşekkürler 💙",
    "Created {time} ago" : "{time} önce oluşturulmuş",
    "Created on {date}" : "{date} tarihinde oluşturulmuş",
    "(Empty title)" : "(Başlıksız)",
    "Title" : "Başlık",
    "Link" : "Bağlantı",
    "Untitled folder" : "Adlandırılmamış klasör",
    "Root folder" : "Kök klasör",
    "Tags" : "İşaretler",
    "Select tags and create new ones" : "Etiketleri seçin ve yenilerini ekleyin",
    "Notes" : "Notlar",
    "Notes for this bookmark …" : "Bu yer imi için notlar ...",
    "Archived file" : "Arşivlenmiş dosya",
    "Open file" : "Dosyayı aç",
    "Download file" : "Dosyayı indir",
    "Open file location" : "Dosya konumunu aç",
    "Link copied" : "Bağlantı kopyalandı",
    "Owner" : "Sahibi",
    "Sharing" : "Paylaşım",
    "Select a user or group" : "Bir kullanıcı ya da grup seçin",
    "Share link" : "Paylaşım bağlantısı",
    "Reading allowed" : "Okunabilir",
    "Copy RSS feed" : "RSS akışını kopyala",
    "Delete link" : "Bağlantıyı sil",
    "Create public link" : "Herkese açık bağlantı ekle",
    "Resharing allowed" : "Yeniden paylaşılabilir",
    "Editing allowed" : "Düzenlenebilir",
    "Allow editing" : "Düzenlenebilsin",
    "Allow resharing" : "Yeniden paylaşılabilsin",
    "Remove share" : "Paylaşımı kaldır",
    "Would you like to support this project?" : "Bu projeyi desteklemek ister misiniz?",
    "Leave a rating on the Nextcloud App Store" : "Nextcloud uygulama mağazasında değerlendirin",
    "Failed to save settings" : "Ayarlar kaydedilemedi",
    "Failed to load settings" : "Ayarlar yüklenemedi",
    "Privacy" : "Gizlilik",
    "The app will try to access web pages that you add to automatically add information about them." : "Bu uygulama eklediğiniz siteler ile ilgili bilgileri otomatik olarak eklemeyi dener.",
    "Enable accessing and collecting information from the web pages you add" : "Eklediğiniz site sayfaları ile ilgili bilgi erişimi ve derlemesi kullanılsın",
    "Performance" : "Başarım",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Çok sayıda kullanıcının bulunduğu kurulumlarda, her hesap için yer imi sayısını sınırlamak yararlı olabilir.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Bir hesaba eklenebilecek yer imi sayısı (0 sınırsız, varsayılan olarak sınırlama yoktur).",
    "Previews" : "Ön izlemeler",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Uygulama, yer imlerine eklenmiş sitelere ait gerçek ekran görüntülerini gösterebilmek için 3. taraf hizmetleri kullanabilir.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Screeenly.com sitesinde bir hesap açabilir ya da kendi sunucunuzu kurabilirsiniz.",
    "Screeenly API URL" : "Screeenly API adresi",
    "Screeenly API key" : "Screeenly API anahtarı",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API anahtarı",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API adresi",
    "Generic screenshot API" : "Genel ekran görüntüsü API uygulaması",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Ekran görüntüsü API hizmeti sağlayıcılarından birinde hesap açın ve API adreisni aşağıya yazın. Ekran görüntüsü için adresin yer belirticisi olarak {url} değişkenini kullanın. API yalnızca doğrudan görüntüyü döndürmelidir.",
    "Generic API URL" : "Genel API adresi",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Sindre Sorhus tarafından geliştirilen Pageres CLI paketini sunucunuza kurmanız yeterlidir; Yer imleri uygulaması onu bulur. Yine de, yer belirticide belirtildiği gibi pageres üzerine aktarılacak ek ENV değişkenleri ekleyebilirsiniz:",
    "Pageres ENV variables" : "Pageres ENV değişkenleri",
    "This URL is already bookmarked! Overwrite?" : "Bu adres zaten yer imlerine eklenmiş! Üzerine yazılsın mı?",
    "Enter bookmark title" : "Yer iminin başlığını yazın",
    "Enter bookmark URL" : "Yer imi adresini yazın",
    "Folder" : "Klasör",
    "Root Folder" : "Kök klasör",
    "Save" : "Kaydet",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Ağ erişimi varsayılan olarak kapalıdır. Yer imleri uygulamasının yönetici ayarlarına giderek, ön izleme ve favicon görsellerini alma seçeneğini açın.",
    "What's new?" : "Yenilikler neler?",
    "What" : "Ne",
    "Failed to count unavailable bookmarks" : "Kullanılamayan yer imlerinin sayısı hesaplanamadı",
    "Failed to count archived bookmarks" : "Arşivlenmiş yer imlerinin sayısı hesaplanamadı",
    "Failed to count deleted bookmarks" : "Silinmiş yer imlerinin sayısı belirlenemedi",
    "Failed to count duplicated bookmarks" : "Çoğaltılmış yer imlerinin sayısı hesaplanamadı",
    "Failed to count bookmarks" : "Yer imlerinin sayısı belirlenemedi",
    "Failed to load bookmark" : "Yer imi yüklenemedi",
    "Failed to find existing bookmark" : "Var olan yer imi bulunamadı",
    "Failed to create bookmark" : "Yer imi eklenemedi",
    "Failed to save bookmark" : "Yer imi kaydedilemedi",
    "Failed to move bookmark" : "Yer imi taşınamadı",
    "Failed to copy bookmark" : "Yer imi kopyalanamadı",
    "Failed to delete bookmark" : "Yer imi silinemedi",
    "Failed to restore bookmark" : "Yer imi geri yüklenemedi",
    "Import successful" : "İçe aktarma işlemi tamamlandı",
    "Failed to rename tag" : "Etiket yeniden adlandırılamadı",
    "Failed to load tags" : "Etiketler yüklenemedi",
    "Failed to load folders" : "Klasörler yüklenemedi",
    "Failed to load deleted folders" : "Silinmiş klasörler yüklenemedi",
    "Failed to load deleted bookmarks" : "Silinmiş yer imleri yüklenemedi",
    "Failed to delete folder" : "Klasör silinemedi",
    "Failed to move folder" : "Klasör taşınamadı",
    "Failed to restore folder" : "Klasör geri yüklenemedi",
    "Failed to create folder" : "Klasör eklenemedi",
    "Failed to load children order" : "Alt öge sıralaması yüklenemedi",
    "Failed to move parts of selection" : "Seçilmişlerin bir bölümü taşınamadı",
    "Failed to copy parts of selection" : "Seçilmişlerin bir bölümü kopyalanamadı",
    "Failed to delete parts of selection" : "Seçilmişlerin bir bölümü silinemedi",
    "Failed to tag parts of selection" : "Seçilmişlerin bir bölümü etiketlenemedi",
    "Failed to fetch bookmarks." : "Yer imleri alınamadı.",
    "Failed to store setting" : "Ayar kaydedilemedi",
    "Failed to load setting {key}" : "{key} ayarı yüklenemedi",
    "Failed to create share for folder {folderId}" : "{folderId} klasörü için paylaşım oluşturulamadı",
    "Failed to update share {shareId}" : "{shareId} paylaşımı güncellenemedi",
    "Failed to delete share {shareId}" : "{shareId} paylaşımı silinemedi",
    "Failed to create public link for folder {folderId}" : "{folderId} klasörü için herkese açık bağlantı oluşturulamadı",
    "Failed to delete public link for folder {folderId}" : "{folderId} klasörü için herkese açık bağlantı silinemedi",
    "Failed to permanently delete parts of trash bin" : "Çöp kutusunun bir bölümü kalıcı olarak silinemedi",
    "Create bookmarks for mentioned links" : "Anılan bağlantılar için yer imleri oluşturulsun",
    "No links found in this message" : "Bu iletide herhangi bir bağlantı bulunamadı",
    "Bookmarks feed" : "Yer imleri akışı"
},
"nplurals=2; plural=(n > 1);");
