<?php
$TRANSLATIONS = array(
"Bookmarks" => "Yer İmleri",
"Failed to import one bookmark, because: " => "Bir yer imi bu nedenle içe aktarılamadı:",
"Bookm." => "Yer imi",
"No file provided for import" => "İçe aktarılacak dosya yok",
"Unsupported file type for import" => "İçe aktarmak için desteklenmeyen dosya türü",
"Some Error happened." => "Bir hata meydana geldi.",
"Error" => "Hata",
"Tags" => "Etiketler",
"Filter by tag" => "Etikete göre süz",
"Are you sure you want to remove this bookmark?" => "Bu yer imini silmek istediğinizden emin misiniz?",
"Warning" => "Uyarı",
"Are you sure you want to remove this tag from every entry?" => "Bu etiketi tüm girdilerden silmek istediğinizden emin misiniz?",
"Import error" => "İçeri aktarım hatası",
"Import completed successfully." => "İçe aktarım başarıyla tamamlandı.",
"Uploading..." => "Yükleniyor...",
"Add a bookmark" => "Bir yer imi ekle",
"This URL is already bookmarked! Overwrite?" => "Bu URL zaten yer imlerinde! Üzerine yazılsın mı?",
"The title of the page" => "Sayfanın başlığı",
"The address of the page" => "Sayfanın adresi",
"Description of the page" => "Sayfa açıklaması",
"Save" => "Kaydet",
"Delete" => "Sil",
"Edit" => "Düzenle",
"Cancel" => "İptal",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Bunu tarayıcınızın yer imlerine sürükleyin ve bir web sayfasını hızlıca yer imlerine eklemek istediğinizde tıklayın:",
"Add to ownCloud" => "ownCloud'a Ekle",
"Address" => "Adres",
"Filterable Tags" => "Süzülebilir Etiketler",
"You have no bookmarks" => "Hiç yer iminiz yok",
"You can also import a bookmark file" => "Ayrıca bir yer imi dosyasını içe aktarabilirsiniz",
"Bookmarklet" => "Yer İmi Ekleyici",
"Export & Import" => "Dışa ve İçe Aktarma",
"Export" => "Dışa aktar",
"Import" => "İçe aktar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
