OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Details",
    "Rename" : "Nomini o'zgartirish",
    "Copy link" : "Havolani nusxalash",
    "Move" : "Move",
    "Select all" : "Select all",
    "New" : "New",
    "New folder" : "New folder",
    "Search" : "Qidirish",
    "Empty trash bin" : "Axlat qutisini bo'shatish",
    "_%n folder_::_%n folders_" : ["%n papkalar"],
    "Select folder" : "Jildni tanlang",
    "Submit" : "Submit",
    "Cancel" : "Bekor qilish",
    "Recent" : "Recent",
    "Shared with you" : "Shared with you",
    "Files" : "Fayllar",
    "Delete" : "O'chirish",
    "Add to {instanceName}" : " {instanceName}ni qo`shish",
    "Need help?" : "Need help?",
    "Title" : "Sarlavha",
    "Link" : "Link",
    "Tags" : "Tags",
    "Notes" : "Notes",
    "Download file" : "Download file",
    "Link copied" : "Havola nusxalandi",
    "Owner" : "Owner",
    "Sharing" : "Ulashish",
    "Share link" : "Share link",
    "Allow editing" : "Allow editing",
    "Allow resharing" : "Qayta almashishga ruxsat bering",
    "Failed to save settings" : "Sozlamalarni saqlab bo'lmadi",
    "Failed to load settings" : "Sozlamalarni yuklab bo'lmadi",
    "Save" : "Saqlash"
},
"nplurals=1; plural=0;");
