<?php
$TRANSLATIONS = array(
"Bookmarks" => "รายการโปรด",
"Bookm." => "รายการโปรด",
"No file provided for import" => "ไม่พบไฟล์สำหรับการนำเข้าข้อมูล",
"Unsupported file type for import" => "ประเภทของไฟล์ที่ต้องการนำเข้าไม่ได้รับการรองรับให้ใช้งาน",
"Some Error happened." => "มีข้อผิดพลาดเกิดขึ้น",
"Error" => "ข้อผิดพลาด",
"Tags" => "ป้ายกำกับ",
"Filter by tag" => "แสดงข้อมูลตามป้ายกำกับ",
"Are you sure you want to remove this bookmark?" => "คุณแน่ใจแล้วหรือว่าต้องการลบรายการโปรดนี้",
"Warning" => "คำเตือน",
"Are you sure you want to remove this tag from every entry?" => "คุณแน่ใจแล้วหรือว่าต้องการลบป้ายกำกับนี้ออกจากทุกๆรายการ",
"Import error" => "นำเข้าข้อมูลผิดพลาด",
"Import completed successfully." => "นำเข้าข้อมูลเสร็จเรียบร้อยแล้ว",
"Uploading..." => "กำลังอัพโหลด...",
"Add a bookmark" => "เพิ่มรายการโปรด",
"This URL is already bookmarked! Overwrite?" => "URL นี้มีอยู่แล้วในบุ๊คมาร์ค! ให้เขียนทับ?",
"The title of the page" => "ชื่อของหน้า",
"The address of the page" => "ที่อยู่ของหน้า",
"Description of the page" => "คำอธิบายเกี่ยวกับหน้า",
"Save" => "บันทึก",
"Delete" => "ลบ",
"Edit" => "แก้ไข",
"Cancel" => "ยกเลิก",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "ลากสิ่งนี้ไปไว้ที่รายการโปรดในโปรแกรมบราวเซอร์ของคุณ แล้วคลิกที่นั่น, เมื่อคุณต้องการเก็บหน้าเว็บเพจเข้าไปไว้ในรายการโปรดอย่างรวดเร็ว",
"Add to ownCloud" => "เพิ่มใน ownCloud",
"Address" => "ที่อยู่",
"Filterable Tags" => "กรองแท็ก",
"You have no bookmarks" => "คุณยังไม่มีรายการโปรด",
"You can also import a bookmark file" => "นอกจากนี้คุณยังสามารถนำเข้าไฟล์รายการโปรด",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "ส่งออก & นำเข้า",
"Export" => "ส่งออก",
"Import" => "นำเข้า"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
