<?php
$TRANSLATIONS = array(
"Bookmarks" => "دڵخوازه‌کان",
"Tags" => "تاگه‌کان",
"Warning" => "ئاگاداری",
"Bookm." => "نیشانکردن",
"Close" => "داخستن",
"Save" => "پاشکه‌وتکردن",
"Edit" => "دەسکاریکردن",
"Cancel" => "لابردن",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "رابکێشه‌ ئه‌مه بۆ دڵخوازه‌کان له‌ وێبگه‌ڕه‌که‌ت وه‌ کرته‌ بکه‌ لێی، کاتێك ده‌ته‌وێت ماڵپه‌ڕێك دڵخواز بکه‌ی به‌خێرای:",
"Address" => "ناونیشان",
"Add" => "زیادکردن",
"Settings" => "ده‌ستكاری",
"You have no bookmarks" => "تۆ دڵخوازت نیه",
"Export" => "هه‌ناردن",
"Import" => "هێنان"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
