OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Detallar",
    "Rename" : "Adı dəyiş",
    "Copy link" : "linki nüsxələ",
    "Move" : "Move",
    "Select all" : "Hamısıı seç",
    "New" : "Yeni",
    "New folder" : "Yeni qovluq",
    "Search" : "Axtarış",
    "_%n folder_::_%n folders_" : ["%n qovluq","%n qovluqlar"],
    "Welcome to Bookmarks" : "Əlfəcinlərə xoş gəlmisiniz",
    "Rename folder" : "Qovluğun adını dəyiş",
    "Cancel" : "Dayandır",
    "Shared with you" : "Shared with you",
    "Files" : "Fayllar",
    "Delete" : "Sil",
    "Title" : "Başlıq",
    "Link" : "Link",
    "Tags" : "Işarələr",
    "Notes" : "Qeydlər",
    "Link copied" : "Link kopyalandı",
    "Owner" : "Owner",
    "Sharing" : "Paylaşılır",
    "Share link" : "Linki yayımla",
    "Allow resharing" : "Yenidən paylaşıma izin",
    "Folder" : "Qovluq",
    "Save" : "Saxla"
},
"nplurals=2; plural=(n != 1);");
