OC.L10N.register(
    "bookmarks",
    {
    "You unshared folder \"%1$s\" with %2$s" : "Вы скасавалі абагульванне папкі \"%1$s\" з %2$s",
    "You unshared folder \"%s\" with someone" : "Вы скасавалі абагульванне папкі \"%s\" з кімсьці",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s скасаваў(-ла) абагульванне папкі \"%2$s\" з вамі",
    "Someone unshared folder \"%s\" with you" : "Хтосьці скасаваў абагульванне папкі \"%s\" з вамі",
    "Link copied to clipboard" : "Спасылка скапіявана ў буфер абмену",
    "Details" : "Падрабязнасці",
    "Rename" : "Перайменаваць",
    "Copy link" : "Скапіяваць спасылку",
    "Move" : "Перамясціць",
    "Delete selection" : "Выдаліць выбранае",
    "Select all" : "Выбраць усе",
    "Go back" : "Назад",
    "New" : "Новы",
    "New folder" : "Новая папка",
    "Search" : "Пошук",
    "_%n folder_::_%n folders_" : ["%n папка","%n папкі","%n папак","%n папак"],
    "Select folder" : "Выберыце папку",
    "Shared by {user}" : "Абагуліў(-ла) {user}",
    "Rename folder" : "Перайменаваць папку",
    "Move folder" : "Перамясціць папку",
    "Submit" : "Адправіць",
    "Cancel" : "Скасаваць",
    "Recent" : "Нядаўнія",
    "Shared with you" : "Абагулена з вамі",
    "Files" : "Файлы",
    "Delete" : "Выдаліць",
    "Add to {instanceName}" : "Дадаць у {instanceName}",
    "Need help?" : "Патрэбна дапамога?",
    "Title" : "Загаловак",
    "Link" : "Спасылка",
    "Root folder" : "Каранёвая папка",
    "Tags" : "Тэгі",
    "Notes" : "Нататкі",
    "Archived file" : "Архіваваны файл",
    "Open file" : "Адкрыць файл",
    "Download file" : "Спампаваць файл",
    "Open file location" : "Адкрыць размяшчэнне файла",
    "Link copied" : "Спасылка скапіявана",
    "Owner" : "Уладальнік",
    "Sharing" : "Абагульванне",
    "Select a user or group" : "Выберыце карыстальніка або групу",
    "Share link" : "Абагуліць спасылку",
    "Copy RSS feed" : "Скапіяваць стужку RSS",
    "Delete link" : "Выдаліць спасылку",
    "Create public link" : "Стварыць публічную спасылку",
    "Allow editing" : "Дазволіць рэдагаванне",
    "Failed to save settings" : "Не ўдалося захаваць налады",
    "Privacy" : "Прыватнасць",
    "Performance" : "Прадукцыйнасць",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Вы можаце зарэгістравацца бясплатна на сайце screeenly.com або наладзіць свой уласны сервер.",
    "Screeenly API URL" : "URL-адрас API Screeenly",
    "Screeenly API key" : "Ключ API Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Ключ API ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL-адрас API Webshot",
    "Folder" : "Папка",
    "Root Folder" : "Каранёвая папка",
    "Save" : "Захаваць",
    "Failed to load tags" : "Не ўдалося загрузіць тэгі"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
