<?php
$TRANSLATIONS = array(
"Bookmarks" => "סימניות",
"Failed to import one bookmark, because: " => "נכשל ביבוא סימנייה אחת, מהסיבה:",
"Bookm." => "סימניה.",
"No file provided for import" => "לא סופק קובץ לייבוא",
"Unsupported file type for import" => "סוג הקובץ אינו ניתן לייבוא",
"Some Error happened." => "אירעו מספר שגיאות.",
"Error" => "שגיאה",
"Tags" => "תגיות",
"Filter by tag" => "סנן לפי תגית",
"Are you sure you want to remove this bookmark?" => "האם באמת להסיר סימנייה זו?",
"Warning" => "אזהרה",
"Are you sure you want to remove this tag from every entry?" => "האם אתה בטוח שברצונך להסיר את התגית מכל הרשומות?",
"Import error" => "שגיאת יבוא",
"Import completed successfully." => "ייבוא הושלם בהצלחה.",
"Uploading..." => "העלאה...",
"Add a bookmark" => "הוסף סימניה",
"This URL is already bookmarked! Overwrite?" => "כתובת אינטרנט זו כבר סומנה כסימנייה! האם לדרוס?",
"The title of the page" => "כותרת הדף",
"The address of the page" => "כתובת הדף",
"Description of the page" => "תיאור הדף",
"Save" => "שמירה",
"Delete" => "מחיקה",
"Edit" => "עריכה",
"Cancel" => "ביטול",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "ניתן לגרור את הקישור הזה אל סרגל הסימניות בדפדפן שלך וללחוץ עליו כאשר מעוניינים ליצור סימניה לאתר במהירות.",
"Add to ownCloud" => "הוסף לownCloud",
"Address" => "כתובת",
"Filterable Tags" => "תגיות סינון",
"You have no bookmarks" => "אין ברשותך סימניות",
"You can also import a bookmark file" => "ניתן גם ליבא קובץ סימניות",
"Bookmarklet" => "יישומון סימנייה",
"Export & Import" => "ייבוא וייצוא",
"Export" => "יצוא",
"Import" => "יבא"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
