OC.L10N.register(
    "bookmarks",
    {
    "Details" : "විස්තර",
    "Rename" : "නැවත නම් කරන්න",
    "Copy link" : "සබැඳිය පිටපත් කරන්න",
    "Select all" : "සියල්ල තෝරන්න",
    "Cancel selection" : "තේරීම අවලංගු කරන්න",
    "Go back" : "ආපසු යන්න",
    "New" : "නව",
    "New folder" : "නව බහාලුම",
    "Search" : "සොයන්න",
    "Enter a link" : "සබැඳියක් ඇතුළත් කරන්න",
    "_%n folder_::_%n folders_" : ["බහාලුම් %1$d","බහාලුම් %1$d"],
    "Select folder" : "බහාලුම තෝරන්න",
    "Cancel" : "අවලංගු කරන්න",
    "Files" : "ගොනු",
    "Install web app" : "වියමන යෙදුම ස්ථාපනය කරන්න",
    "Need help?" : "උපකාරයක් අවශ්‍යයද?",
    "Link" : "සබැඳිය",
    "Notes" : "සටහන්",
    "Open file" : "ගොනුව විවෘත කරන්න",
    "Download file" : "ගොනුව බාගන්න",
    "Link copied" : "සබැඳිය පිටපත් කළා",
    "Owner" : "හිමිකරු",
    "Select a user or group" : "පරිශීලකයෙකු හෝ සමූහයක් තෝරන්න",
    "Allow editing" : "සංස්කරණයට ඉඩ දෙන්න",
    "Allow resharing" : "නැවත බෙදා ගැනීමට ඉඩ දෙන්න",
    "Privacy" : "පෞද්ගලිකත්වය",
    "Folder" : "බහාලුම",
    "Save" : "සුරකින්න"
},
"nplurals=2; plural=(n != 1);");
