OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "You bookmarked \"%s\"" : "Añadió \"%s\" a los marcadores",
    "%1$s bookmarked \"%2$s\"" : "%1$s añadió \"%2$s\" a los marcadores",
    "Someone bookmarked \"%s\"" : "Alguien añadió \"%s\" a los marcadores",
    "You deleted \"%s\"" : "Ha eliminado \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s eliminó \"%2$s\"",
    "Someone deleted \"%s\"" : "Alguien eliminó \"%s\"",
    "You created folder \"%s\"" : "Ha creado la carpeta \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s creó la carpeta \"%2$s\"",
    "Someone created folder \"%s\"" : "Alguien creó la carpeta \"%s\"",
    "You moved folder \"%s\"" : "Ha movido la carpeta \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s movió la carpeta \"%2$s\"",
    "Someone moved folder \"%s\"" : "Alguien movió la carpeta \"%s\"",
    "You deleted folder \"%s\"" : "Ha eliminado la carpeta \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s eliminó la carpeta \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Alguien eliminó la carpeta \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Ha compartido la carpeta \"%1$s\" con %2$s",
    "You shared folder \"%s\" with someone" : "Ha compartido la carpeta \"%s\" con alguien",
    "%1$s shared folder \"%2$s\" with you" : "%1$s le ha compartido la carpeta \"%2$s\"",
    "Someone shared folder \"%s\" with you" : "Alguien le ha compartido la carpeta \"%s\"",
    "You unshared folder \"%1$s\" with %2$s" : "Ha dejado de compartir la carpeta \"%1$s\" con %2$s",
    "You unshared folder \"%s\" with someone" : "Ha dejado de compartir la carpeta \"%s\" con alguien",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s le ha dejado de compartir la carpeta \"%2$s\"",
    "Someone unshared folder \"%s\" with you" : "Alguien le ha dejado de compartir la carpeta \"%s\"",
    "No file provided for import" : "No se especificó un archivo para importar",
    "Bookmarks shared by %s" : "Marcadores compartidos por %s ",
    "Frequent bookmarks" : "Marcadores frecuentes",
    "Recent bookmarks" : "Marcadores recientes",
    "Bookmark" : "Marcador",
    "Bookmark deleted" : "Marcador eliminado",
    "Bookmark created" : "Marcador creado",
    "Bookmark moved" : "Marcador movido",
    "Bookmark updated" : "Marcador actualizado",
    "Create bookmark" : "Crear marcador",
    "Takes a link and adds it to your collection of bookmarks." : "Toma un enlace y lo añade a su colección de marcadores.",
    "Bookmarks Backups" : "Respaldo de marcadores",
    "Collect and manage bookmarks, synced with all your devices" : "Recolectar y administrar marcadores, sincronizados con todos sus dispositivos",
    "Do you really want to delete this bookmark?" : "¿Realmente desea eliminar este marcador?",
    "Link copied to clipboard" : "Enlace copiado al portapapeles",
    "Enter new title" : "Ingrese un nuevo título",
    "Select bookmark" : "Seleccionar marcador",
    "You have never clicked this link" : "Nunca ha hecho clic en este enlace",
    "You have clicked this link {count} times" : "Ha hecho clic en este enlace {count}vez",
    "Details" : "Detalles",
    "Rename" : "Renombrar",
    "Copy link" : "Copiar liga",
    "Move" : "Mover",
    "Add to folders" : "Añadir a carpetas",
    "Put bookmark into trash bin" : "Mover marcador a la papelera",
    "Restore bookmark" : "Restaurar marcador",
    "Delete bookmark permanently" : "Eliminar marcador permanentemente",
    "Content pending" : "Contenido pendiente",
    "This content is being downloaded for offline use. Please check back later." : "Este contenido se está descargando para su uso sin conexión. Por favor, compruebe más tarde.",
    "Bookmarked {time} ago" : "Se agregó como marcador hace {time}",
    "Bookmarked on {date}" : "Se agregó como marcador el {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Estos son sus elementos eliminados. Los elementos serán eliminados permanentemente después de dos meses.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Los marcadores de archivos en la web, como fotos o PDFs, se guardarán automáticamente en sus archivos de Nextcloud, por lo que aún puede encontrarlos incluso cuando el enlace no esté disponible.",
    "Searching in the current folder only." : "Buscando únicamente en la carpeta actual.",
    "Repeat search in all folders" : "Repetir la búsqueda en todas las carpetas",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Los marcadores se comprueban regularmente y se listan aquellos que no se pueden alcanzar.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Puede compartir carpetas de marcadores con otros. Todas las carpetas que le han compartido se listan aquí.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Un marcador puede estar en múltiples carpetas a la vez. Al actualizarlo, se actualizarán todas las copias también. Todos los marcadores duplicados se listan aquí para mayor comodidad.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Seleccionados {folders} carpetas y {bookmarks} marcadores",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Seleccionado %n marcador","Seleccionados %n marcadores","Seleccionados %n marcadores"],
    "_Selected %n folder_::_Selected %n folders_" : ["Seleccionada%n carpeta","Seleccionadas %n carpetas","Seleccionadas %n carpetas"],
    "Do you really want to delete these items?" : "¿Realmente desea eliminar estos elementos?",
    "Open all selected" : "Abrir todos los seleccionados",
    "Move selection" : "Mover selección",
    "Edit tags of selection" : "Editar las etiquetas de la selección",
    "Delete selection" : "Borrar selección",
    "Select all" : "Seleccionar todo",
    "Cancel selection" : "Cancelar selección",
    "Sort by created date" : "Ordenar por fecha de creación",
    "Sort by last modified" : "Ordenar por última modificación",
    "Sort by title" : "Ordenar por título",
    "Sort by click count" : "Ordenar por número de clics",
    "Sort by manual order" : "Ordenar manualmente",
    "Sort by URL" : "Ordenar por URL",
    "RSS feed copied" : "Fuente RSS copiada",
    "Trash Bin" : "Papelera",
    "Go back" : "Regresar",
    "Share folder" : "Compartir carpeta",
    "Open folder details" : "Abrir detalles de la carpeta",
    "Select one or more tags" : "Seleccione una o más etiquetas",
    "New" : "Nuevo",
    "New bookmark" : "Nuevo marcador",
    "New folder" : "Carpeta nueva ",
    "Change to grid view" : "Cambiar a la vista de cuadrícula",
    "Change to list view" : "Cambiar a la vista de lista",
    "Copy RSS Feed of current view" : "Copiar la fuente RSS de la vista actual",
    "The RSS feed requires authentication with your Nextcloud credentials" : "La fuente RSS requiere autentificarse con sus credenciales de Nextcloud",
    "Search" : "Buscar",
    "Empty trash bin" : "Vaciar la papelera de reciclaje",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Añadiendo %n marcador a la nueva carpeta","Añadiendo %n marcadores a la nueva carpeta","Añadiendo %n marcadores a la nueva carpeta"],
    "Enter a link" : "Ingrese un enlace",
    "Enter a title" : "Ingrese un título",
    "No bookmarks found" : "No se encontraron marcadores",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} carpetas y {bookmarks} marcadores",
    "_%n bookmark_::_%n bookmarks_" : ["%n marcador","%n marcadores","%n marcadores"],
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
    "Welcome to Bookmarks" : "Bienvenido a marcadores",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Esta aplicación le permite gestionar enlaces a sus lugares favoritos en la web. ¡Organice sus marcadores en carpetas, agregue etiquetas y comparta con otros! La aplicación comprobará regularmente todos sus enlaces para ver si están disponibles y mostrará los enlaces no disponibles. Si agrega un enlace a un archivo en la web, el archivo se descargará automáticamente a sus archivos de Nextcloud. También puede importar marcadores exportados desde otros servicios o sincronizar directamente los marcadores de todos sus navegadores con esta aplicación.",
    "Add a bookmark" : "Agregar un marcador",
    "Import bookmarks" : "Importar marcadores",
    "Sync with your browser" : "Sincronizar con su navegador",
    "Do you really want to permanently delete this folder?" : "¿Realmente desea eliminar esta carpeta permanentemente?",
    "Select folder" : "Seleccionar carpeta",
    "Enter folder title" : "Ingrese el título de la carpeta",
    "Shared by {user}" : "Compartido por {user}",
    "Rename folder" : "Renombrar carpeta",
    "Move folder" : "Mover carpeta",
    "Put folder into trashbin" : "Mover carpeta a la papelera",
    "Restore folder" : "Restaurar carpeta",
    "Delete folder permanently" : "Eliminar carpeta permanentemente",
    "Choose folder" : "Seleccioanr carpeta",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Deleting bookmarks" : "Eliminando marcadores",
    "Deleting selection" : "Eliminando selección",
    "Importing bookmarks" : "Importando marcadores",
    "Moving selection" : "Moviendo selección",
    "Adding selection to folders" : "Añadiendo selección a carpetas",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Moviendo %n carpeta y algunos marcadores","Moviendo %n carpetas y algunos marcadores","Moviendo %n carpetas y algunos marcadores"],
    "_Moving %n folder_::_Moving %n folders_" : ["Moviendo %n carpeta","Moviendo %n carpetas","Moviendo %n carpetas"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Moviendo %n marcador","Moviendo %n marcadores","Moviendo %n marcadores"],
    "All bookmarks" : "Todos los marcadores",
    "Recent" : "Reciente",
    "Shared with you" : "Compartido con usted",
    "Files" : "Archivos",
    "Duplicates" : "Duplicados",
    "Broken links" : "Enlaces rotos",
    "New tag" : "Nueva etiqueta",
    "Search tags" : "Buscar etiquetas",
    "Delete" : "Borrar",
    "Untagged" : "Sin etiquetar",
    "{used} bookmarks of {available} available" : "{used} marcadores de {available} disponibles",
    "Bookmarks Settings" : "Configuración de marcadores",
    "No bookmarked files" : "No hay archivos con marcadores",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Los marcadores a archivos como fotos o PDFs se guardarán automáticamente en sus archivos de Nextcloud, para que pueda encontrarlos incluso cuando el enlace esté fuera de línea.",
    "Nothing found" : "Nada encontrado",
    "Your search yielded no results in the current folder." : "Su búsqueda no arrojó resultados en la carpeta actual.",
    "No broken links" : "No hay enlaces rotos",
    "No shared folders" : "No hay carpetas compartidas",
    "No duplicated bookmarks" : "No hay marcadores duplicados",
    "No deleted bookmarks" : "No hay marcadores eliminados",
    "You haven't deleted anything yet." : "No ha eliminado nada aún.",
    "No bookmarks here" : "No hay marcadores aquí",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Agregue marcadores manualmente o importe marcadores desde un archivo HTML.",
    "Archive path" : "Ruta del archivo",
    "Backup path" : "Ruta del respaldo",
    "Please select \"Add to home screen\" in your browser menu" : "Por favor, seleccione \"Añadir a la pantalla de inicio\" en el menú de su navegador",
    "Bookmarks settings" : "Configuración de marcadores",
    "Import/Export" : "Importar/exportar",
    "Export bookmarks" : "Exportar marcadores",
    "Auto-archiving" : "Archivando automáticamente",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "La aplicación de marcadores puede archivar automáticamente el contenido web de los enlaces que haya marcado",
    "Enable archiving" : "Habilitar el archivado",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Ingrese la ruta de una carpeta en sus archivos donde se deban almacenar los archivos marcados.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Actualmente, su administrador ha desactivado el acceso a la red para esta aplicación, es por ello que el auto archivado está deshabilitado por el momento.",
    "Auto-Backup" : "Respaldar automáticamente",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "La aplicación de marcadores puede respaldar automáticamente sus marcadores diariamente para prevenir pérdida de información al sincronizar marcadores entre dispositivos.",
    "Enable backups" : "Habilitar los respaldos",
    "Enter the path of a folder in your Files where backups will be stored." : "Ingrese la ruta de una carpeta en sus archivos donde se deban almacenar los respaldos.",
    "Client apps" : "Aplicaciones de cliente",
    "Also check out the collection of client apps that integrate with this app: " : "Vea también la colección de aplicaciones de cliente que se integran con esta aplicación:",
    "Install web app" : "Instalar la aplicación web",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Puede instalar esta aplicación en la pantalla de inicio de su dispositivo para acceder rápidamente a sus marcadores en su teléfono. Puede eliminar fácilmente la aplicación de su pantalla de inicio, en caso de que no le agrade.",
    "Install on home screen" : "Instalar en la pantalla de inicio",
    "Bookmarklet" : "Marcador a código ",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Arrastre esto a los marcadores de su navegador y haga clic en él para marcar rápidamente una página web.",
    "Add to {instanceName}" : "Añadir a {instanceName}",
    "Need help?" : "¿Necesitas ayuda?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Si tiene problemas con la aplicación de Marcadores o tiene una idea de cómo se podría mejorar, no dude en ponerse en contacto haciendo clic aquí.",
    "Support this project" : "Apoye este proyecto",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Mi trabajo en esta aplicación de Marcadores está impulsado por un modelo de suscripción voluntario. Si cree que lo que hago vale la pena, me haría muy feliz si pudiera apoyar mi trabajo. Además, por favor considere dejar una opinión sobre la misma en la tienda de aplicaciones de Nextcloud. Gracias 💙",
    "Created {time} ago" : "Creado hace {time}",
    "Created on {date}" : "Creado el {date}",
    "(Empty title)" : "(Título vacío)",
    "Title" : "Título",
    "Link" : "Liga",
    "Untitled folder" : "Carpeta sin título",
    "Root folder" : "Carpeta raíz",
    "Tags" : "Etiquetas",
    "Select tags and create new ones" : "Seleccionar etiquetas y crear nuevas",
    "Notes" : "Notas",
    "Notes for this bookmark …" : "Notas para este marcador ...",
    "Archived file" : "Archivo archivado",
    "Open file" : "Abrir archivo",
    "Download file" : "Descargar archivo",
    "Open file location" : "Abrir la ubicación del archivo",
    "Link copied" : "Vinculo copiado",
    "Owner" : "Dueño",
    "Sharing" : "Compartiendo",
    "Select a user or group" : "Seleccionar un usuario o grupo",
    "Share link" : "Compartir liga",
    "Reading allowed" : "Lectura permitida",
    "Copy RSS feed" : "Copiar fuente RSS",
    "Delete link" : "Eliminar enlace",
    "Create public link" : "Crear enlace público",
    "Resharing allowed" : "Volver a compartir permitido",
    "Editing allowed" : "Edición permitida",
    "Allow editing" : "Permitir edición",
    "Allow resharing" : "Permitir volver a compartir",
    "Remove share" : "Eliminar el recurso compartido",
    "Leave a rating on the Nextcloud App Store" : "Deje una calificación en la tienda de aplicaciones de Nextcloud",
    "Failed to save settings" : "No se pudo guardar la configuración",
    "Failed to load settings" : "No se pudo cargar la configuración",
    "Privacy" : "Privacidad",
    "The app will try to access web pages that you add to automatically add information about them." : "La aplicación intentará acceder a las páginas web que añada para incorporar automáticamente información sobre ellas.",
    "Enable accessing and collecting information from the web pages you add" : "Habilitar el acceso y la recopilación de información de las páginas web que agregue",
    "Performance" : "Desempeño",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "En una instalación con un gran número de usuarios, puede ser útil limitar el número de marcadores por cuenta.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Número máximo de marcadores permitidos por cuenta. (0 para sin límite; el valor predeterminado es sin límite)",
    "Previews" : "Vistas previas",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Para poder mostrar capturas de pantalla reales de sus sitios web marcados, la aplicación puede utilizar servicios de terceros para generar las vistas previas.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Puedes registrarse gratuitamente en screeenly.com o configurar su propio servidor.",
    "Screeenly API URL" : "URL de la API de Screeenly",
    "Screeenly API key" : "Llave de API de Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clave de la API de ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL de la API de Webshot",
    "Generic screenshot API" : "API de captura de pantalla genérica",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Inicie sesión con cualquiera de los proveedores de API de capturas de pantalla y ponga la URL de la API debajo. Use la variable {url}como marcador de posición de la URL a sacar captura de pantalla. La API debe regresar únicamente la imagen directamente.",
    "Generic API URL" : "URL de la API genérica",
    "Pageres CLI" : "Línea de comandos de Pageres",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Simplemente instale la línea de comandos de Pageres por Sindre Sorhus en su servidor y Marcadores lo encontrará. Aún puede agregar variables de entorno adicionales que se pasarán a pageres, por ejemplo, como se indica en el marcador de posición:",
    "Pageres ENV variables" : "Variables de entorno de Pageres",
    "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
    "Enter bookmark title" : "Ingrese el título del marcador",
    "Enter bookmark URL" : "Ingrese la URL del marcador",
    "Folder" : "Carpeta",
    "Root Folder" : "Carpeta raíz",
    "Save" : "Guardar",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "El acceso a la red está desactivado de forma predeterminada. Vaya a la configuración de administración de la aplicación de marcadores para permitir la obtención de vistas previas y favicons.",
    "What's new?" : "¿Qué hay de nuevo?",
    "What" : "Qué",
    "Failed to count unavailable bookmarks" : "Error al contar los marcadores no disponibles",
    "Failed to count archived bookmarks" : "Error al contar los marcadores archivados",
    "Failed to count duplicated bookmarks" : "Error al contar los marcadores duplicados",
    "Failed to load bookmark" : "Error al cargar el marcador",
    "Failed to find existing bookmark" : "Error al encontrar el marcador existente",
    "Failed to create bookmark" : "Error al crear el marcador",
    "Failed to save bookmark" : "Error al guardar el marcador",
    "Failed to move bookmark" : "Error al mover el marcador",
    "Failed to copy bookmark" : "Error al copiar el marcador",
    "Failed to delete bookmark" : "Error al borrar el marcador",
    "Failed to rename tag" : "Error al renombrar la etiqueta",
    "Failed to load tags" : "No se pudieron cargar las etiquetas",
    "Failed to load folders" : "Error al cargar las carpetas",
    "Failed to load deleted folders" : "No se pudieron cargar las carpetas eliminadas",
    "Failed to load deleted bookmarks" : "No se pudieron cargar los marcadores eliminados",
    "Failed to delete folder" : "Error al eliminar la carpeta",
    "Failed to move folder" : "No se pudo mover la carpeta",
    "Failed to create folder" : "Error al crear la carpeta",
    "Failed to fetch bookmarks." : "Error al obtener los marcadores.",
    "Failed to store setting" : "No se pudo guardar la configuración",
    "Failed to load setting {key}" : "No se pudo cargar la configuración {key}",
    "Failed to update share {shareId}" : "No se pudo actualizar el recurso compartido {shareId}",
    "Failed to delete share {shareId}" : "No se pudo eliminar el recurso compartido {shareId}",
    "Create bookmarks for mentioned links" : "Crear marcadores para los enlaces mencionados",
    "No links found in this message" : "No se encontraron enlaces en este mensaje",
    "Bookmarks feed" : "Fuente de marcadores"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
