<?php
$TRANSLATIONS = array(
"Bookmarks" => "Marcatores de libro",
"Bookm." => "Marcat.",
"No file provided for import" => "Il non ha alcun file de importar",
"Unsupported file type for import" => "Typo de file non supportate per importation",
"Some Error happened." => "Un error ha occurrite.",
"Error" => "Error",
"Tags" => "Etiquettas",
"Filter by tag" => "Filtra per etiquetta",
"Are you sure you want to remove this bookmark?" => "Es tu secur de voler remover iste marcator?",
"Warning" => "Aviso",
"Are you sure you want to remove this tag from every entry?" => "Tu es secur que tu vole remover iste etiquetta ex omne entratas?",
"Import error" => "Error de importation",
"Import completed successfully." => "Importation completate con successo.",
"Uploading..." => "Incargante...",
"Add a bookmark" => "Adde un marcator de libro",
"This URL is already bookmarked! Overwrite?" => "Iste URL es jam inter le marcatores! Superscriber?",
"The title of the page" => "Le titulo del pagina",
"The address of the page" => "Le adresse del pagina",
"Description of the page" => "Description del pagina",
"Save" => "Salveguardar",
"Delete" => "Deler",
"Edit" => "Modificar",
"Cancel" => "Cancellar",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Trahe isto in tu marcatores de libro de navigator e pulsa, quando tu vole memorar un pagina web rapidemente:",
"Add to ownCloud" => "Adde a ownCloud",
"Address" => "Adresse",
"Filterable Tags" => "Etiquettas filtrabile",
"You have no bookmarks" => "Tu non ha marcatores de libro",
"You can also import a bookmark file" => "Tu pote etiam importar un file de marcatores de libro",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Exportation & Importation",
"Export" => "Exportar",
"Import" => "Importar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
