OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bokmerker",
    "You bookmarked \"%s\"" : "Du bokmerket \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s bokmerket \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Noen bookmerket \"%s\"",
    "You deleted \"%s\"" : "Du slettet \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s slettet \"%2$s\"",
    "Someone deleted \"%s\"" : "Noen slettet \"%s\"",
    "You created folder \"%s\"" : "Du opprettet mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s opprettet mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "Noen opprettet mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttet mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttet mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "Noen flyttet mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du slettet mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s slettet mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Noen slettet mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delte mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du delte mappen \"%s\" med noen",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delte mappen \"%2$s\" med deg",
    "Someone shared folder \"%s\" with you" : "Noen delte mappen \"%s\" med deg",
    "You unshared folder \"%1$s\" with %2$s" : "Du stoppet å dele mappen \"%1$s\" med %2$s",
    "You unshared folder \"%s\" with someone" : "Du stoppet å dele mappen \"%s\" med noen",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s stoppet å dele mappen \"%2$s\" med deg",
    "Someone unshared folder \"%s\" with you" : "Noen stoppet å dele mappen \"%s\" med deg",
    "No file provided for import" : "Ingen fil valgt for import",
    "Bookmarks shared by %s" : "Bokmerker delt av %s",
    "Frequent bookmarks" : "Hyppige bokmerker",
    "Recent bookmarks" : "Nylige bokmerker",
    "Bookmark" : "Legg til som bokmerke",
    "Bookmark deleted" : "Bokmerke slettet",
    "Bookmark created" : "Bokmerke opprettet",
    "Bookmark moved" : "Bokmerke flyttet",
    "Bookmark updated" : "Bokmerke oppdatert",
    "Create bookmark" : "Opprett bokmerke",
    "Takes a link and adds it to your collection of bookmarks." : "Tar en lenke å legger den til i den i bokmerke-samlingen din.",
    "Bookmarks Backups" : "Sikkerhetskopi av bokmerker",
    "Collect and manage bookmarks, synced with all your devices" : "Samle og administrer bokmerker, synkronisert med alle enhetene dine",
    "Do you really want to delete this bookmark?" : "Er du sikker på at du vil slette dette bokmerket?",
    "Link copied to clipboard" : "Lenke kopiert til utklippstavlen",
    "Enter new title" : "Skriv inn en ny tittel",
    "Select bookmark" : "Velg bokmerke",
    "You have never clicked this link" : "Du har aldri klikket på denne koblingen",
    "You have clicked this link {count} times" : "Du har klikket på denne koblingen {count} ganger",
    "Details" : "Detaljer",
    "Rename" : "Gi nytt navn",
    "Copy link" : "Kopier lenke",
    "Move" : "Flytt",
    "Add to folders" : "Legg i mapper",
    "Put bookmark into trash bin" : "Legg bokmerket i papirkurven",
    "Restore bookmark" : "Gjenopprett bokmerke",
    "Delete bookmark permanently" : "Slett bokmerke permanent",
    "Content pending" : "Ventende innhold",
    "This content is being downloaded for offline use. Please check back later." : "Dette innholdet lastes ned for frakoblet bruk. Kom tilbake senere.",
    "Bookmarked {time} ago" : "Bokmerke lagt til {time} siden",
    "Bookmarked on {date}" : "Bokmerket den {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Dette er de slettede elementene dine. Elementer slettes permanent etter to måneder.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmerker til filer på nettet som bilder eller PDF-filer lagres automatisk i Nextcloud-filene dine, slik at du fortsatt kan finne dem selv når lenken går i frakoblet modus.",
    "Searching in the current folder only." : "Søker kun i den gjeldende mappen.",
    "Repeat search in all folders" : "Gjenta søk i alle mapper",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bokmerkede lenker kontrolleres regelmessig, og de som ikke kan nås, er oppført her.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Du kan dele bokmerkemapper med andre. Alle mapper delt med deg er oppført her.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Ett bokmerke kan være i flere mapper samtidig. Oppdatering av den vil oppdatere alle kopier. Alle dupliserte bokmerker er oppført her for enkelhets skyld.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valgte {folders} mapper og {bookmarks} bokmerker",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valgt %n bokmerke","Valgte %n bokmerker"],
    "_Selected %n folder_::_Selected %n folders_" : ["Valgt %n mappe","Valgte %n mapper"],
    "Do you really want to delete these items?" : "Ønsker du virkelig å slette disse elementene?",
    "Open all selected" : "Åpne alle valgte",
    "Move selection" : "Flytt utvalg",
    "Edit tags of selection" : "Rediger merker til utvalg",
    "Delete selection" : "Slett utvalg",
    "Select all" : "Velg alle",
    "Cancel selection" : "Avbryt utvalg",
    "Sort by created date" : "Sorter etter opprettelsesdato",
    "Sort by last modified" : "Sorter etter sist endret",
    "Sort by title" : "Sorter etter tittel",
    "Sort by click count" : "Sorter etter antall klikk",
    "Sort by manual order" : "Sorter etter manuell rekkefølge",
    "Sort by URL" : "Sorter etter URL",
    "RSS feed copied" : "RSS-strøm kopiert",
    "Trash Bin" : "Papirkurv",
    "Go back" : "Gå tilbake",
    "Share folder" : "Del mappe",
    "Open folder details" : "Åpne mappedetaljer",
    "Select one or more tags" : "Velg en eller flere merkelapper",
    "New" : "Ny",
    "New bookmark" : "Nytt bokmerke",
    "New folder" : "Ny mappe",
    "Change to grid view" : "Bytt til rutenettvisning",
    "Change to list view" : "Bytt til listevisning",
    "Copy RSS Feed of current view" : "Kopier RSS-strømmen til gjeldende visning",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-strømmen krever godkjenning med Nextcloud-legitimasjonen din",
    "Search" : "Søk",
    "Empty trash bin" : "Tøm papirkurv",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Legger til %n bokmerke til ny mappe","Legger til %n bokmerker til ny mappe"],
    "Enter a link" : "Skriv inn et lenke",
    "Enter a title" : "Angi en tittel",
    "No bookmarks found" : "Ingen bokmerker funnet",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} mapper og {bookmarks} bokmerker",
    "_%n bookmark_::_%n bookmarks_" : ["%n bokmerke","%n bokmerker"],
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "Welcome to Bookmarks" : "Velkommen til Bokmerker",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Denne appen lar deg administrere lenker til favorittstedene dine på nettet. Sorter bokmerkene dine i mapper, merk dem med etiketter og del dem med andre! Appen vil regelmessig sjekke alle koblingene dine for tilgjengelighet og vise utilgjengelige lenker. Hvis du legger til en lenke til en fil på nettet, blir filen automatisk lastet ned til Nextcloud-filene dine. Du kan også importere bokmerker eksportert fra andre tjenester eller direkte synkronisere bokmerker fra alle nettleserne dine med denne appen.",
    "Add a bookmark" : "Legg til bokmerke",
    "Import bookmarks" : "Importer bokmerker",
    "Sync with your browser" : "Synkroniser med nettleseren din",
    "Do you really want to permanently delete this folder?" : "Vil du virkelig slette denne mappen permanent?",
    "Select folder" : "Velg mappe",
    "Enter folder title" : "Skriv inn tittel",
    "Shared by {user}" : "Delt av {user}",
    "Rename folder" : "Gi mappen nytt navn",
    "Move folder" : "Flytt mappe",
    "Put folder into trashbin" : "Legg mappe i papirkurven",
    "Restore folder" : "Gjenopprett mappe",
    "Delete folder permanently" : "Slett mappe permanent",
    "Choose folder" : "Velg mappe",
    "Submit" : "Send inn",
    "Cancel" : "Avbryt",
    "Deleting bookmarks" : "Sletter bokmerker",
    "Deleting selection" : "Sletter utvalg",
    "Importing bookmarks" : "Importerer bokmerker",
    "Moving selection" : "Flytter utvalg",
    "Adding selection to folders" : "Legger utvalg til mapper",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flytter %n mappe og noen bokmerker","Flytter %n mapper og noen bokmerker"],
    "_Moving %n folder_::_Moving %n folders_" : ["Flytter %n mappe","Flytter %n mapper"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flytter %n bokmerke","Flytter %n bokmerker"],
    "All bookmarks" : "Alle bokmerker",
    "Recent" : "Nylig",
    "Shared with you" : "Delt med deg",
    "Files" : "Filer",
    "Duplicates" : "Duplikater",
    "Broken links" : "Brutte koblinger",
    "New tag" : "Ny merkelapp",
    "Search tags" : "Søk i merkelapper",
    "Delete" : "Slett",
    "Untagged" : "Ikke merket",
    "{used} bookmarks of {available} available" : "{used} bokmerker av {available} tilgjengelige",
    "Bookmarks Settings" : "Innstillinger for bokmerker",
    "No bookmarked files" : "Ingen bokmerkede filer",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmerker til filer som bilder eller PDF-filer lagres automatisk i Nextcloud-filene dine, slik at du fortsatt kan finne dem selv når lenken går i frakoblet modus.",
    "Nothing found" : "Ingenting funnet",
    "Your search yielded no results in the current folder." : "Søket ditt ga ingen resultater i gjeldende mappe.",
    "No broken links" : "Ingen brutte koblinger",
    "No shared folders" : "Ingen delte mapper",
    "No duplicated bookmarks" : "Ingen dupliserte bokmerker",
    "No deleted bookmarks" : "Ingen slettede bokmerker",
    "You haven't deleted anything yet." : "Du har ikke slettet noe enda.",
    "No bookmarks here" : "Ingen bokmerker her",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Legg til bokmerker manuelt eller importer bokmerker fra en HTML-fil.",
    "Archive path" : "Arkivsti",
    "Backup path" : "Sikkerhetskopisti",
    "Please select \"Add to home screen\" in your browser menu" : "Velg \"Legg til på startskjermen\" i nettlesermenyen",
    "Bookmarks settings" : "Innstillinger for bokmerker",
    "Import/Export" : "Import/Eksport",
    "Export bookmarks" : "Eksporter bokmerker",
    "Auto-archiving" : "Automatisk arkivering",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Bokmerke-appen kan automatisk arkivere nettinnholdet til lenker du har bokmerket",
    "Enable archiving" : "Aktiver arkivering",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Skriv inn banen til en mappe i filene dine der bokmerkede filer skal lagres.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "For øyeblikket har administratoren din deaktivert nettverkstilgang for denne appen, og det er grunnen til at automatisk arkivering er deaktivert for øyeblikket.",
    "Auto-Backup" : "Automatisk sikkerhetskopiering",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Bokmerke-appen kan automatisk sikkerhetskopiere bokmerkene dine daglig for å forhindre tap av data når du synkroniserer bokmerker på tvers av enheter.",
    "Enable backups" : "Aktiver sikkerhetskopier",
    "Enter the path of a folder in your Files where backups will be stored." : "Skriv inn banen til en mappe i filene dine der sikkerhetskopier skal lagres.",
    "Client apps" : "Klient-apper",
    "Also check out the collection of client apps that integrate with this app: " : "Sjekk også ut samlingen av klientapper som integreres med denne appen:",
    "Install web app" : "Installer webapp",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Du kan installere denne appen på enhetens startskjerm for raskt å få tilgang til bokmerkene dine på telefonen. Du kan enkelt fjerne appen fra startskjermen igjen, hvis du ikke liker den.",
    "Install on home screen" : "Installer på hjemskjerm",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Dra dette til nettleserbokmerkene dine og klikk på det for raskt å bokmerke en nettside.",
    "Add to {instanceName}" : "Legg til {instanceName}",
    "Need help?" : "Trenger du hjelp?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Hvis du har problemer med denne bokmerkeappen eller har en ide om hva som kan forbedres, ikke nøl med å ta kontakt ved å klikke her.",
    "Support this project" : "Støtt dette prosjektet",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Arbeidet mitt med denne bokmerkeappen drives av en frivillig abonnementsmodell. Hvis du tror det jeg gjør er verdt din oppmerksomhet, ville jeg være glad hvis du kunne støtte mitt arbeid. Vurder også å gi appen en anmeldelse i Nextcloud App Store. Takk 💙 ",
    "Created {time} ago" : "Opprettet {time} siden",
    "Created on {date}" : "Opprettet den {date}",
    "(Empty title)" : "(tom tittel)",
    "Title" : "Tittel",
    "Link" : "Lenke",
    "Untitled folder" : "Ikke navngitt mappe",
    "Root folder" : "Hovedmappe",
    "Tags" : "Merkelapper",
    "Select tags and create new ones" : "Velg merkelapper og opprett nye",
    "Notes" : "Notater",
    "Notes for this bookmark …" : "Notater for dette bokmerket...",
    "Archived file" : "Arkivert fil",
    "Open file" : "Åpne fil",
    "Download file" : "Last ned fil",
    "Open file location" : "Åpne filplassering",
    "Link copied" : "Lenke kopiert",
    "Owner" : "Eier",
    "Sharing" : "Deling",
    "Select a user or group" : "Velg en bruker eller gruppe",
    "Share link" : "Del lenke",
    "Reading allowed" : "Lesing er tillatt",
    "Copy RSS feed" : "Kopier RSS-strøm",
    "Delete link" : "Slett kobling",
    "Create public link" : "Opprett offentlig kobling",
    "Resharing allowed" : "Deling på nytt tillatt",
    "Editing allowed" : "Redigering tillatt",
    "Allow editing" : "Tillat redigering",
    "Allow resharing" : "TIllat videre deling",
    "Remove share" : "Fjern deling",
    "Leave a rating on the Nextcloud App Store" : "Legg igjen en vurdering på Nextcloud App Store",
    "Failed to save settings" : "Klarte ikke å lagre innstillinger",
    "Failed to load settings" : "Klarte ikke å laste inn innstillinger",
    "Privacy" : "Personvern",
    "The app will try to access web pages that you add to automatically add information about them." : "Appen vil prøve å få tilgang til nettsider du legger til, for automatisk å legge til informasjon om dem.",
    "Enable accessing and collecting information from the web pages you add" : "Aktiver tilgang til og innsamling av informasjon fra nettsidene du legger til",
    "Performance" : "Ytelse",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installasjon med mange brukere kan det være nyttig å begrense antall bokmerker per konto.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimalt tillatt antall bokmerker per konto. (0 for ingen grense; standard er ingen grense)",
    "Previews" : "Forhåndsvisning",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "For å vise ekte skjermbilder av dine bokmerkede nettsteder, kan appen bruke tredjepartstjenester til å generere forhåndsvisninger.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Du kan enten registrere deg gratis på screeenly.com eller sette opp din egen server.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API-nøkkel",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API-nøkkel",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Generisk skjermbilde API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Registrer deg hos en av skjermbilde-API-leverandørene og legg API-URL-en nedenfor. Bruk variabelen {url} som en plassholder for URL-adressen til skjermbilde. API-en må bare returnere bildet direkte.",
    "Generic API URL" : "Generisk API-URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Bare installer Pageres CLI av Sindre Sorhus på serveren din, så finner Bokmerker den. Du kan fortsatt legge til flere ENV-variabler som skal mates til Pageres, f.eks. som angitt i plassholderen:",
    "Pageres ENV variables" : "Pageres ENV-variabler",
    "This URL is already bookmarked! Overwrite?" : "Denne lenken eksisterer allerede, ønsker du overskrive?",
    "Enter bookmark title" : "Skriv inn tittel",
    "Enter bookmark URL" : "Angi bokmerke-URL",
    "Folder" : "Mappe",
    "Root Folder" : "Rotmappe",
    "Save" : "Lagre",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Nettverkstilgang er deaktivert som standard. Gå til administratorinnstillinger for bokmerkeappen for å tillate henting av forhåndsvisninger og favorittikoner.",
    "What's new?" : "Hva er nytt?",
    "What" : "Hva",
    "Failed to count unavailable bookmarks" : "Telling av utilgjengelige bokmerker feilet",
    "Failed to count archived bookmarks" : "Telling av arkiverte bokmerker feilet",
    "Failed to count duplicated bookmarks" : "Telling av dupliserte bokmerker feilet",
    "Failed to load bookmark" : "Lasting av bokmerke feilet",
    "Failed to find existing bookmark" : "Kunne ikke finne eksisterende bokmerke",
    "Failed to create bookmark" : "Klarte ikke å opprette bokmerke",
    "Failed to save bookmark" : "Lagring av bokmerke feilet",
    "Failed to move bookmark" : "Flytting av bokmerke feilet",
    "Failed to copy bookmark" : "Kopiering av bokmerke feilet",
    "Failed to delete bookmark" : "Sletting av bokmerke feilet",
    "Import successful" : "Import vellykket",
    "Failed to rename tag" : "Omdøping av merkelapp feilet",
    "Failed to load tags" : "Lasting av merkelapper feilet",
    "Failed to load folders" : "Lasting av mapper feilet",
    "Failed to load deleted folders" : "Lasting av slettede mapper feilet",
    "Failed to load deleted bookmarks" : "Lasting av slettede bokmerker feilet",
    "Failed to delete folder" : "Sletting av mappe feilet",
    "Failed to move folder" : "Flytting av mappen feilet",
    "Failed to create folder" : "Oppretting av mappe feilet",
    "Failed to fetch bookmarks." : "Henting av bokmerker feilet",
    "Failed to store setting" : "Lagring av innstilling feilet",
    "Failed to load setting {key}" : "Lasting av innstilling {key} feilet",
    "Failed to update share {shareId}" : "Oppdatering av delt ressurs feilet {shareId}",
    "Failed to delete share {shareId}" : "Sletting av delt ressurs feilet {shareId}",
    "Create bookmarks for mentioned links" : "Opprett bokmerker for nevnte koblinger",
    "No links found in this message" : "Ingen koblinger funnet i denne meldingen",
    "Bookmarks feed" : "Bokmerker-strøm"
},
"nplurals=2; plural=(n != 1);");
