OC.L10N.register(
    "bookmarks",
    {
    "Details" : "বিসতারিত",
    "Rename" : "পূনঃনামকরণ",
    "Copy link" : "লিঙ্ক কপি করো",
    "Move" : "Move",
    "Go back" : "ফিরে যাও",
    "New" : "নতুন",
    "New folder" : "নতুন ফোল্ডার",
    "Search" : "Search",
    "Rename folder" : "ফোল্ডার পূনঃনামকরণ কর",
    "Cancel" : "বাতির",
    "Recent" : "সাম্প্রতিক",
    "Shared with you" : "Shared with you",
    "Files" : "ফাইল",
    "Delete" : "মুছে",
    "Title" : "শিরোনাম",
    "Link" : "Link",
    "Tags" : "ট্যাগ",
    "Notes" : "নোট",
    "Open file" : "খোলা ফাইল",
    "Owner" : "Owner",
    "Sharing" : "ভাগাভাগিরত",
    "Share link" : "লিংক ভাগাভাগি করেন",
    "Folder" : "ফোল্ডার",
    "Save" : "সংরক্ষণ"
},
"nplurals=2; plural=(n != 1);");
