OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "–¢—ç–º–¥—ç–≥–ª—ç–∂ –∞–≤–∞—Ö",
    "You bookmarked \"%s\"" : "–¢—ç–º–¥—ç–≥–ª—ç–∂ –∞–≤–ª–∞–∞ \"%s\"",
    "You deleted \"%s\"" : "\"%s\"-–∏–π–≥ —Ç–∞ —É—Å—Ç–≥–∞–ª–∞–∞",
    "%1$s deleted \"%2$s\"" : "\"%2$s\"-–∏–π–≥ %1$s —É—Å—Ç–≥–∞–ª–∞–∞ ",
    "Someone deleted \"%s\"" : "\"%s\" —É—Å—Ç–≥–∞–≥–¥–ª–∞–∞",
    "You created folder \"%s\"" : "–¢–∞ \"%s\" —Ñ–æ–ª–¥–µ—Ä—ã–≥ “Ø“Ø—Å–≥—ç–ª—ç—ç",
    "%1$s created folder \"%2$s\"" : "\"%2$s\" —Ñ–æ–ª–¥–µ—Ä—ã–≥ %1$s —à–∏–Ω—ç—ç—Ä “Ø“Ø—Å–≥—ç–ª—ç—ç",
    "Someone created folder \"%s\"" : "\"%s\" —Ñ–æ–ª–¥–µ—Ä—ã–≥ —à–∏–Ω—ç—ç—Ä “Ø“Ø—Å–≥—ç–ª—ç—ç",
    "You moved folder \"%s\"" : "–¢–∞ \"%s\" —Ñ–æ–ª–¥–µ—Ä—ã–≥  —Ö”©–¥”©–ª–≥”©–ª”©”©",
    "%1$s moved folder \"%2$s\"" : "\"%2$s\" —Ñ–æ–ª–¥–µ—Ä—ã–≥ %1$s —Ö”©–¥”©–ª–≥”©–ª”©”©",
    "Link copied to clipboard" : "Холбоос санах ойд хуулагдсан",
    "Details" : "–î—ç–ª–≥—ç—Ä—ç–Ω–≥“Ø–π",
    "Rename" : "–ù—ç—Ä–ª—ç–Ω—ç “Ø“Ø",
    "Copy link" : "–•–æ–ª–±–æ–æ—Å —Ö—É—É–ª–∞—Ö",
    "Move" : "–ó”©”©—Ö",
    "Delete selection" : "Сонголтыг устгах",
    "Select all" : "–±“Ø–≥–¥–∏–π–≥ —Å–æ–Ω–≥–æ—Ö",
    "Sort by title" : "Гарчигаар эрэмбэлэх",
    "Go back" : "–ë—É—Ü–∞—Ö",
    "Share folder" : "Хавтас хуваалцах",
    "New" : "–®–∏–Ω—ç",
    "New folder" : "–®–∏–Ω—ç —Ö–∞–≤—Ç–∞—Å",
    "Search" : "–•–∞–π—Ö",
    "Empty trash bin" : "Хогийн савыг хоослох",
    "_%n folder_::_%n folders_" : ["%n —Ö–∞–≤—Ç–∞—Å","%n —Ö–∞–≤—Ç–∞—Å"],
    "Shared by {user}" : "{user}-р хуваалцсан",
    "Move folder" : "Хавтас зөөх",
    "Choose folder" : "–•–∞–≤—Ç–∞—Å —Å–æ–Ω–≥–æ–≥–æ —É—É",
    "Submit" : "–º—ç–¥—ç–≥–¥—ç—Ö",
    "Cancel" : "–±–æ–ª–∏—É–ª–∞—Ö",
    "Recent" : "–°“Ø“Ø–ª–∏–π–Ω “Ø–µ–∏–π–Ω",
    "Shared with you" : "—Ç–∞–Ω—Ç–∞–π —Ö—É–≤–∞–∞–ª—Ü—Å–∞–Ω",
    "Files" : "—Ñ–∞–π–ª—É—É–¥",
    "Delete" : "–£—Å—Ç–≥–∞—Ö",
    "Context Chat integration" : "Context Chat нэгтгэл",
    "Add to {instanceName}" : "{instanceName}-т нэмэх",
    "Need help?" : "Тусламж хэрэгтэй юу?",
    "Title" : "–¶–æ–ª/–ê–ª–±–∞–Ω —Ç—É—à–∞–∞–ª",
    "Link" : "–•–æ–ª–±–æ–æ—Å",
    "Tags" : "Tag-“Ø“Ø–¥",
    "Notes" : "–®–∏–Ω—ç ",
    "Open file" : "–§–∞–π–ª¬†–æ–Ω–≥–æ–π–ª–≥–æ—Ö",
    "Download file" : "Файл татах",
    "Link copied" : "Холбоос хуулагдсан",
    "Owner" : "–≠–∑—ç–º—à–∏–≥—á",
    "Sharing" : "–¢“Ø–≥—ç—ç—Ö",
    "Select a user or group" : "Хэрэглэгч эсвэл бүлэг сонгох",
    "Share link" : "–•–æ–ª–±–æ–æ—Å —Ö—É–≤–∞–∞–ª—Ü–∞—Ö",
    "Create public link" : "Нийтийн холбоос үүсгэх",
    "Allow editing" : "–ó–∞—Å–≤–∞—Ä–ª–∞—Ö—ã–≥ –∑”©–≤—à”©”©—Ä”©—Ö",
    "Allow resharing" : "Дахин хуваалцахыг зөвшөөрөх",
    "Failed to save settings" : "Тохиргоог хадгалж чадсангүй",
    "Privacy" : "–•—É–≤–∏–π–Ω –Ω—É—É—Ü",
    "Performance" : "Гүйцэтгэл",
    "Folder" : "–•–∞–≤—Ç–∞—Å",
    "Save" : "–•–∞–¥–≥–∞–ª–∞—Ö",
    "What's new?" : "Шинэ юу байна?",
    "Failed to load tags" : "Тагуудыг ачаалж чадсангүй"
},
"nplurals=2; plural=(n != 1);");
