OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Segnalibri",
    "You bookmarked \"%s\"" : "Hai aggiunto un segnalibro di \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s ha aggiunto un segnalibro di \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Qualcuno ha aggiunto un segnalibro di \"%s\"",
    "You deleted \"%s\"" : "Hai eliminato \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s ha eliminato \"%2$s\"",
    "Someone deleted \"%s\"" : "Qualcuno ha eliminato \"%s\"",
    "You created folder \"%s\"" : "Hai creato la cartella \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s ha creato la cartella \"%2$s\"",
    "Someone created folder \"%s\"" : "Qualcuno ha creato la cartella \"%s\"",
    "You moved folder \"%s\"" : "Hai spostato la cartella \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s ha spostato la cartella \"%2$s\"",
    "Someone moved folder \"%s\"" : "Qualcuno ha spostato la cartella \"%s\"",
    "You deleted folder \"%s\"" : "Hai eliminato la cartella \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s ha eliminato la cartella \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Qualcuno ha eliminato la cartella \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Hai condiviso la cartella \"%1$s\" con %2$s",
    "You shared folder \"%s\" with someone" : "Hai condiviso la cartella \"%s\" con qualcuno",
    "%1$s shared folder \"%2$s\" with you" : "%1$s ha condiviso la cartella \"%2$s\" con te",
    "Someone shared folder \"%s\" with you" : "Qualcuno ha condiviso la cartella \"%s\" con te",
    "You unshared folder \"%1$s\" with %2$s" : "Hai rimosso la condivisione della cartella \"%1$s\" con %2$s",
    "You unshared folder \"%s\" with someone" : "Hai rimosso la condivisione della cartella \"%s\" con qualcuno",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s ha rimosso la condivisione della cartella \"%2$s\" con te",
    "Someone unshared folder \"%s\" with you" : "Qualcuno ha rimosso la condivisione della cartella \"%s\" con te",
    "No file provided for import" : "Nessun file fornito per l'importazione",
    "Failed to upload file" : "Invio del file non riuscito",
    "Unsupported file type for import: " : "Tipo di file non supportato per l'importazione:",
    "Bookmarks shared by %s" : "Segnalibri condivisi da %s",
    "Frequent bookmarks" : "Segnalibri frequenti",
    "Recent bookmarks" : "Segnalibri recenti",
    "Bookmark" : "Segnalibro",
    "Bookmark deleted" : "Segnalibro eliminato",
    "Bookmark created" : "Segnalibro creato",
    "Bookmark moved" : "Segnalibro spostato",
    "Bookmark updated" : "Segnalibro aggiornato",
    "Create bookmark" : "Crea segnalibro",
    "Takes a link and adds it to your collection of bookmarks." : "Prende un collegamento e lo aggiunge alla tua raccolta di segnalibri.",
    "Bookmarks Backups" : "Backup dei segnalibri",
    "Do you really want to delete this bookmark?" : "Vuoi davvero eliminare questo segnalibro?",
    "Link copied to clipboard" : "Collegamento copiato negli appunti",
    "Enter new title" : "Digita un nuovo titolo",
    "Select bookmark" : "Seleziona segnalibro",
    "Details" : "Dettagli",
    "Rename" : "Rinomina",
    "Copy link" : "Copia colleg.",
    "Move" : "Sposta",
    "Add to folders" : "Aggiungi a cartelle",
    "Delete bookmark permanently" : "Elimina definitivamente il segnalibro",
    "Content pending" : "Contenuti in sospeso",
    "This content is being downloaded for offline use. Please check back later." : "Questo contenuto è in scaricamento per l'utilizzo non in linea. Torna più tardi.",
    "Bookmarked {time} ago" : "Aggiunto ai segnalibri {time} fa",
    "Bookmarked on {date}" : "Aggiunto ai segnalibri il {date}",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "I segnalibri per file sul web come foto o PDF saranno automaticamente salvati nei tuoi file di Nextcloud, in modo che tu possa trovarli anche quando il collegamento non sarà disponibile.",
    "Searching in the current folder only." : "Cerca solo nella cartella corrente",
    "Repeat search in all folders" : "Ripeti la ricerca in tutte le cartelle",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "I segnalibri vengono controllati regolarmente e quelli che non possono essere raggiunti sono elencati qui.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Puoi condividere le cartelle con i segnalibri con gli altri.\nTutte le cartelle condivise con te sono elencante qui.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Un segnalibro può trovarsi in più cartelle contemporaneamente. L'aggiornamento aggiornerà tutte le copie. Tutti i segnalibri duplicati sono elencati qui per comodità.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Selezionate {folders} cartelle e {bookmarks} segnalibri",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Selezionato %n segnalibro","Selezionati %n segnalibri","Selezionati %n segnalibri"],
    "_Selected %n folder_::_Selected %n folders_" : ["Selezionata %n cartella","Selezionate %n cartelle","Selezionate %n cartelle"],
    "Do you really want to delete these items?" : "Vuoi davvero eliminare questi elementi?",
    "Open all selected" : "Apri tutti i selezionati",
    "Move selection" : "Sposta selezione",
    "Edit tags of selection" : "Modifica le etichette della selezione",
    "Delete selection" : "Elimina selezione",
    "Select all" : "Seleziona tutto",
    "Cancel selection" : "Annulla la selezione",
    "Sort by created date" : "Ordina per data di creazione",
    "Sort by last modified" : "Ordina per ultima modifica",
    "Sort by title" : "Ordina per titolo",
    "Sort by click count" : "Ordina per numero di clic",
    "Sort by manual order" : "Ordina manualmente",
    "Sort by URL" : "Ordina per URL",
    "RSS feed copied" : "Fonte RSS copiata",
    "Trash Bin" : "Cestino",
    "Go back" : "Indietro",
    "Share folder" : "Condividi cartella",
    "Select one or more tags" : "Seleziona una o più etichette",
    "New" : "Nuovo",
    "New bookmark" : "Nuovo segnalibro",
    "New folder" : "Nuova cartella",
    "Change to grid view" : "Mostra visuale a griglia",
    "Change to list view" : "Mostra visuale a elenco",
    "Copy RSS Feed of current view" : "Copia la fonte RSS della vista attuale",
    "The RSS feed requires authentication with your Nextcloud credentials" : "La fonte RSS richiede l'autenticazione con le tue credenziali Nextcloud",
    "Search" : "Cerca",
    "Empty trash bin" : "Svuota cestino",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Aggiunta di %n segnalibro alla nuova cartella","Aggiunta di %n segnalibri alla nuova cartella","Aggiunta di %n segnalibri alla nuova cartella"],
    "Enter a link" : "Digita un collegamento",
    "Enter a title" : "Digita un titolo",
    "No bookmarks found" : "Nessun segnalibro trovato",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} cartelle e {bookmarks} segnalibri",
    "_%n bookmark_::_%n bookmarks_" : ["%n segnalibro","%n segnalibri","%n segnalibri"],
    "_%n folder_::_%n folders_" : ["1%n cartella","%n cartelle","%n cartelle"],
    "Welcome to Bookmarks" : "Benvenuto in segnalibri",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Questa applicazione ti consente di gestire i collegamenti ai tuoi posti preferiti sul web. Organizza i tuoi segnalibri in cartelle, etichettali e condividili con gli altri! L'applicazione verifica regolarmente la disponibilità di tutti i tuoi collegamenti e visualizza i collegamenti non disponibili. Se aggiungi un collegamento a un file sul web, il file sarà scaricato automaticamente nei tuoi file Nextcloud. Puoi anche importare i segnalibri esportati da altri servizi o sincronizzare direttamente i segnalibri da tutti i tuoi browser con questa applicazioni.",
    "Add a bookmark" : "Aggiungi un segnalibro",
    "Import bookmarks" : "Importa segnalibri",
    "Sync with your browser" : "Sincronizza con il tuo browser",
    "Select folder" : "Seleziona cartella",
    "Enter folder title" : "Digita titolo della cartella",
    "Shared by {user}" : "Condiviso da {user}",
    "Rename folder" : "Rinomina cartella",
    "Move folder" : "Sposta cartella",
    "Restore folder" : "Ripristina cartella",
    "Choose folder" : "Scegli cartella",
    "Submit" : "Invia",
    "Cancel" : "Annulla",
    "Deleting bookmarks" : "Eliminazione segnalibri",
    "Deleting selection" : "Eliminazione selezione",
    "Importing bookmarks" : "Importazione segnalibri",
    "Moving selection" : "Spostamento selezione",
    "Adding selection to folders" : "Aggiunta della selezione alle cartelle",
    "Emptying trashbin" : "Svuotamento del cestino",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Spostamento di %n cartella e di alcuni segnalibri","Spostamento di %n cartelle e alcuni segnalibri","Spostamento di %n cartelle e alcuni segnalibri"],
    "_Moving %n folder_::_Moving %n folders_" : ["Spostamento di %n cartella","Spostamento di %n cartelle","Spostamento di %n cartelle"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Spostamento di %n segnalibro","Spostamento di %n segnalibri","Spostamento di %n segnalibri"],
    "All bookmarks" : "Tutti i segnalibri",
    "Recent" : "Recenti",
    "Shared with you" : "Condivisi con te",
    "Files" : "File",
    "Duplicates" : "Duplicati",
    "Broken links" : "Collegamenti interrotti",
    "New tag" : "Nuova etichetta",
    "Search tags" : "Cerca etichette",
    "Delete" : "Elimina",
    "Untagged" : "Non etichettati",
    "{used} bookmarks of {available} available" : "{used} segnalibri di {available} disponibili",
    "Bookmarks Settings" : "Impostazioni segnalibri",
    "No bookmarked files" : "Nessun file come segnalibro",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "I segnalibri per file come foto o PDF saranno automaticamente salvati nei tuoi file di Nextcloud, in modo che tu possa trovarli anche quando non sei in linea.",
    "Nothing found" : "Nessun risultato",
    "Your search yielded no results in the current folder." : "Nessun risultato trovato nella cartella corrente",
    "No broken links" : "Nessun collegamento interrotto",
    "No shared folders" : "Nessuna cartella condivisa",
    "No duplicated bookmarks" : "Nessun segnalibro duplicato",
    "No deleted bookmarks" : "Nessun segnalibro eliminato",
    "No bookmarks here" : "Nessun segnalibro qui",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Aggiungi i segnalibri manualmente o importa i segnalibri da un file HTML.",
    "Archive path" : "Percorso dell'archivio",
    "Backup path" : "Percorso di backup",
    "Please select \"Add to home screen\" in your browser menu" : "Seleziona \"Aggiungi alla schermata principale\" nel menu del tuo browser",
    "Bookmarks settings" : "Impostazioni dei segnalibri",
    "Import/Export" : "Importa/Esporta",
    "Export bookmarks" : "Esporta segnalibri",
    "Auto-archiving" : "Archiviazione automatica",
    "Enable archiving" : "Abilita archiviazione",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Inserisci il percorso di una cartella nei tuoi File dove conservare i file con segnalibro.",
    "Auto-Backup" : "Backup automatico",
    "Enable backups" : "Abilita backup",
    "Enter the path of a folder in your Files where backups will be stored." : "Inserisci il percorso di una cartella di File in cui saranno archiviati i backup.",
    "Client apps" : "Applicazioni client",
    "Also check out the collection of client apps that integrate with this app: " : "Controlla inoltre l'elenco delle applicazioni client che si integrano con questa applicazione:",
    "Install web app" : "Installazione l'applicazione web",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Puoi installare questa applicazione sulla schermata iniziale del tuo dispositivo per accedere rapidamente ai tuoi segnalibri sul telefono. Puoi rimuovere facilmente di nuovo l'applicazione dalla schermata iniziale, se non ti piace. ",
    "Install on home screen" : "Installa sulla schermata principale",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Trascinalo nei segnalibri del tuo browser e fai clic per creare rapidamente un segnalibro di una pagina web.",
    "Add to {instanceName}" : "Aggiungi a {instanceName} ",
    "Need help?" : "Ti serve aiuto?",
    "Created {time} ago" : "Creato {time} fa",
    "Created on {date}" : "Creato il {date}",
    "(Empty title)" : "(Titolo vuoto)",
    "Title" : "Titolo",
    "Link" : "Collegamento",
    "Untitled folder" : "Cartella senza nome",
    "Root folder" : "Cartella radice",
    "Tags" : "Etichette",
    "Select tags and create new ones" : "Seleziona le etichette o creane di nuove",
    "Notes" : "Note",
    "Notes for this bookmark …" : "Note per questo segnalibro...",
    "Archived file" : "File archiviato",
    "Open file" : "Apri file",
    "Download file" : "Scarica il file",
    "Open file location" : "Apri percorso file",
    "Link copied" : "Collegamento copiato",
    "Owner" : "Proprietario",
    "Sharing" : "Condivisione",
    "Select a user or group" : "Seleziona un utente o gruppo",
    "Share link" : "Condividi collegamento",
    "Reading allowed" : "Lettura consentita",
    "Copy RSS feed" : "Copia fonte RSS",
    "Delete link" : "Elimina collegamento",
    "Create public link" : "Crea collegamento pubblico",
    "Resharing allowed" : "Ri-condivisione consentita",
    "Editing allowed" : "Modifica consentita",
    "Allow editing" : "Consenti la modifica",
    "Allow resharing" : "Consenti la ri-condivisione",
    "Remove share" : "Rimuovi condivisione",
    "Would you like to support this project?" : "Vuoi supportare questo progetto?",
    "Failed to save settings" : "Salvataggio impostazioni non riuscito",
    "Failed to load settings" : "Caricamento impostazioni non riuscito",
    "Privacy" : "Riservatezza",
    "Enable accessing and collecting information from the web pages you add" : "Abilita l'accesso e la raccolta di informazioni dalle pagine web che aggiungi",
    "Performance" : "Prestazioni",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "In un'installazione con molti utenti, potrebbe essere utile limitare il numero di segnalibri per account.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Numero massimo consentito di segnalibri per account. (0 per nessun limite; predefinito nessun limite)",
    "Previews" : "Anteprime",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Puoi registrarti gratuitamente su screeenly.com o configurare il tuo server.",
    "Screeenly API URL" : "URL API di Screeenly",
    "Screeenly API key" : "Chiave API di Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Chiave API ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "API URL Webshot",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Variabili Pageres ENV",
    "This URL is already bookmarked! Overwrite?" : "Questo URL è già un segnalibro! Vuoi sovrascriverlo?",
    "Enter bookmark title" : "Digita titolo del segnalibro",
    "Enter bookmark URL" : "Digita URL del segnalibro",
    "Folder" : "Cartella",
    "Root Folder" : "Cartella radice",
    "Save" : "Salva",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "L'accesso alla rete è disattivato in modo predefinito. Vai alle impostazioni amministratore dell'applicazione Segnalibri per consentire il reperimento di anteprime e favicon.",
    "What's new?" : "Cosa c'è di nuovo?",
    "What" : "Cosa",
    "Failed to count unavailable bookmarks" : "Conteggio dei segnalibri non disponibili non riuscito",
    "Failed to count archived bookmarks" : "Conteggio dei segnalibri archiviati non riuscito",
    "Failed to count duplicated bookmarks" : "Impossibile contare i segnalibri duplicati",
    "Failed to load bookmark" : "Caricamento dei segnalibri non riuscito",
    "Failed to find existing bookmark" : "Recupero segnalibri esistenti non riuscito",
    "Failed to create bookmark" : "Creazione segnalibro non riuscita",
    "Failed to save bookmark" : "Salvataggio segnalibro non riuscito",
    "Failed to move bookmark" : "Spostamento segnalibro non riuscito",
    "Failed to copy bookmark" : "Copia del segnalibro fallita",
    "Failed to delete bookmark" : "Eliminazione segnalibro non riuscita",
    "Import successful" : "Importazione avvenuta",
    "Failed to rename tag" : "Rinomina dell'etichetta non riuscita",
    "Failed to load tags" : "Caricamento etichette non riuscito",
    "Failed to load folders" : "Caricamento cartelle non riuscito",
    "Failed to delete folder" : "Eliminazione cartelle non riuscita",
    "Failed to restore folder" : "Ripristino cartella non riuscito",
    "Failed to create folder" : "Creazione cartella non riuscita",
    "Failed to move parts of selection" : "Spostamento di parte della selezione non riuscito",
    "Failed to copy parts of selection" : "Copia di parte della selezione non riuscita",
    "Failed to delete parts of selection" : "Eliminazione di parte della selezione non riuscita",
    "Failed to fetch bookmarks." : "Recupero segnalibri non riuscito.",
    "Failed to store setting" : "Salvataggio impostazioni non riuscito",
    "Failed to load setting {key}" : "Caricamento dell'impostazione {key} non riuscito",
    "Failed to update share {shareId}" : "Aggiornamento della condivisione {shareId} non riuscito",
    "Failed to delete share {shareId}" : "Eliminazione della condivisione {shareId} non riuscita",
    "Create bookmarks for mentioned links" : "Crea segnalibri per i collegamenti menzionati",
    "No links found in this message" : "Nessun collegamento trovato in questo messaggio",
    "Bookmarks feed" : "Fonte dei segnalibri"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
