<?php
$TRANSLATIONS = array(
"Bookmarks" => "Обележувачи",
"Bookm." => "Обел.",
"No file provided for import" => "Не е дадена датотека за увоз",
"Unsupported file type for import" => "Неподржнан тип на датотека за внес",
"Some Error happened." => "Се случи некоја грешка.",
"Error" => "Грешка",
"Tags" => "Ознаки",
"Filter by tag" => "Филтрирај по ознака",
"Are you sure you want to remove this bookmark?" => "Дали сте сигурни дека сакате да го отстраните овој обележувач?",
"Warning" => "Предупредување",
"Are you sure you want to remove this tag from every entry?" => "Дали сте сигурни дека сакате да ја отстраните оваа ознака од секој внес?",
"Import error" => "Грешка при увоз",
"Import completed successfully." => "Увозот заврши успешно",
"Uploading..." => "Подигнувам...",
"Add a bookmark" => "Додади обележувач",
"This URL is already bookmarked! Overwrite?" => "URL-то е веќе обележано. Да го пребришам?",
"The title of the page" => "Насловот на страницата",
"The address of the page" => "Адресата на страницата",
"Description of the page" => "Опис на страницата",
"Save" => "Сними",
"Delete" => "Избриши",
"Edit" => "Уреди",
"Cancel" => "Откажи",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Повлечете го ова во папката со обележувачи во Вашиот прелистувач и кликнете го кога сакате брзо да направите обележувач:",
"Add to ownCloud" => "Додади во ownCloud",
"Address" => "Адреса",
"Filterable Tags" => "Филтрирачки ознаки",
"You have no bookmarks" => "Немате обележувачи",
"You can also import a bookmark file" => "Можете исто така да увезете и датотека за обележувачи ",
"Bookmarklet" => "Обележувач",
"Export & Import" => "Извези и увези",
"Export" => "Извези",
"Import" => "Внеси"
);
$PLURAL_FORMS = "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;";
