<?php
$TRANSLATIONS = array(
"Bookmarks" => "書籤",
"Bookm." => "書籤",
"No file provided for import" => "沒有提供匯入用的檔案",
"Unsupported file type for import" => "不支援這種檔案類型的匯入",
"Some Error happened." => "發生了一些錯誤",
"Error" => "錯誤",
"Tags" => "標籤",
"Filter by tag" => "依標籤篩選",
"Are you sure you want to remove this bookmark?" => "你確定你要移除此書籤？",
"Warning" => "警告",
"Are you sure you want to remove this tag from every entry?" => "您確定要從每個項目中移除這個標籤嗎？",
"Import error" => "匯入錯誤",
"Import completed successfully." => "匯入成功完成。",
"Uploading..." => "上傳中...",
"Add a bookmark" => "新增書籤",
"This URL is already bookmarked! Overwrite?" => "此網址已經存在書籤中，確定要複寫？",
"The title of the page" => "頁面標題",
"The address of the page" => "頁面的位址",
"Description of the page" => "頁面說明",
"Save" => "儲存",
"Delete" => "刪除",
"Edit" => "編輯",
"Cancel" => "取消",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "把這個拖曳至瀏覽器的書籤列，下次您想要將某個頁面加至書籤時，點一下書籤列上面的這個項目即可。",
"Add to ownCloud" => "新增至ownCloud",
"Address" => "網址",
"Filterable Tags" => "可篩選的標記",
"You have no bookmarks" => "您還沒有任何書籤",
"You can also import a bookmark file" => "你也可以匯入書籤檔案",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "匯出與匯入",
"Export" => "匯出",
"Import" => "匯入"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
