OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Detalii",
    "Rename" : "Redenumire",
    "Copy link" : "Copiază link",
    "Move" : "Mută",
    "Select all" : "Selectează tot",
    "Go back" : "Înapoi",
    "Share folder" : "Distribuie dosar",
    "New" : "Nou",
    "New folder" : "Director nou",
    "Search" : "Caută",
    "Empty trash bin" : "Golește coșul de gunoi",
    "_%n folder_::_%n folders_" : ["%n director","%n directoare","%n directoare"],
    "Rename folder" : "Redenumește dosar",
    "Submit" : "Trimite",
    "Cancel" : "Anulează",
    "Recent" : "Recente",
    "Shared with you" : "Partajat cu tine",
    "Files" : "Fișiere",
    "Delete" : "Șterge",
    "Need help?" : "Ai nevoie de ajutor?",
    "Created on {date}" : "Creat la {date}",
    "Title" : "Titlu",
    "Link" : "Legătură",
    "Root folder" : "Folder principal",
    "Tags" : "Etichete",
    "Notes" : "Notițe",
    "Open file" : "Deschide fișier",
    "Download file" : "Descarcă fișier",
    "Link copied" : "Link copiat",
    "Owner" : "Proprietar",
    "Sharing" : "Partajare",
    "Share link" : "Partajează link-ul",
    "Allow editing" : "Permite editarea",
    "Allow resharing" : "Permite repartajarea",
    "Privacy" : "Confidențialitate",
    "Performance" : "Performanța",
    "Folder" : "Director",
    "Save" : "Salvează",
    "What's new?" : "Ce este nou?"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
