OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Details",
    "Rename" : "Rename",
    "Copy link" : "Copy link",
    "Move" : "Move",
    "Select all" : "Select all",
    "Go back" : "Go back",
    "Share folder" : "საქაღალდის გაზიარება",
    "New" : "New",
    "New folder" : "New folder",
    "Search" : "Search",
    "Empty trash bin" : "Empty trash bin",
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "Submit" : "Submit",
    "Cancel" : "Cancel",
    "Recent" : "Recent",
    "Shared with you" : "Shared with you",
    "Files" : "ფაილები",
    "Delete" : "Delete",
    "Bookmarklet" : "Bookmarklet",
    "Need help?" : "Need help?",
    "Link" : "Link",
    "Tags" : "Tags",
    "Notes" : "Notes",
    "Link copied" : "Link copied",
    "Owner" : "Owner",
    "Sharing" : "Sharing",
    "Select a user or group" : "Select a user or group",
    "Share link" : "Share link",
    "Allow editing" : "Allow editing",
    "Allow resharing" : "Allow resharing",
    "Failed to save settings" : "Failed to save settings",
    "Privacy" : "Privacy",
    "Performance" : "Performance",
    "Folder" : "Folder",
    "Save" : "Save",
    "What's new?" : "What's new?",
    "Failed to load tags" : "Failed to load tags"
},
"nplurals=2; plural=(n!=1);");
