OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "סימניות",
    "You bookmarked \"%s\"" : "הוספת את „%s” לסימניות",
    "%1$s bookmarked \"%2$s\"" : "„%2$s” התווסף לסימניות על ידי %1$s",
    "Someone bookmarked \"%s\"" : "מישהו הוסיף את „%s” לסימניות",
    "You deleted \"%s\"" : "מחקת את „%s”",
    "%1$s deleted \"%2$s\"" : "„%2$s” נמחק על ידי %1$s",
    "Someone deleted \"%s\"" : "מישהו מחק את „%s”",
    "You created folder \"%s\"" : "יצרת את התיקייה „%s”",
    "%1$s created folder \"%2$s\"" : "התיקייה „%2$s” נוצרה על ידי %1$s",
    "Someone created folder \"%s\"" : "התיקייה „%s” נוצרה על ידי מישהו",
    "You moved folder \"%s\"" : "העברת את התיקייה „%s”",
    "%1$s moved folder \"%2$s\"" : "התיקייה „%2$s” הועברה על ידי %1$s",
    "Someone moved folder \"%s\"" : "התיקייה „%s” הועברה על ידי מישהו",
    "You deleted folder \"%s\"" : "מחקת את התיקייה „%s”",
    "No file provided for import" : "לא סופק קובץ לייבוא",
    "Failed to upload file" : "כשלון בהעלאת קובץ",
    "Bookmarks shared by %s" : "סימניות שמשותפות על ידי %s",
    "Bookmark" : "סימנייה",
    "Bookmark deleted" : "סימנייה נמחקה",
    "Bookmark created" : "סימנייה נוצרה",
    "Bookmark moved" : "סימנייה הועברה",
    "Bookmark updated" : "סימנייה עודכנה",
    "Create bookmark" : "יצירת סימנייה",
    "Takes a link and adds it to your collection of bookmarks." : "לוקח קישור ומוסיף אותו לאוסף הסימניות שלך.",
    "Link copied to clipboard" : "הקישור הועתק ללוח הגזירים",
    "Enter new title" : "נא למלא כותרת חדשה",
    "Select bookmark" : "בחירת סימנייה",
    "Details" : "פרטים",
    "Rename" : "שינוי שם",
    "Copy link" : "העתקת קישור",
    "Move" : "העברה",
    "Selected {folders} folders and {bookmarks} bookmarks" : "נבחרו {folders} תיקיות ו־{bookmarks} סימניות",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו"],
    "_Selected %n folder_::_Selected %n folders_" : ["נבחרה תיקייה %n","נבחרו %n תיקיות","נבחרו %n תיקיות","נבחרו %n תיקיות"],
    "Do you really want to delete these items?" : "למחוק את הפריטים האלה?",
    "Open all selected" : "לפתוח את כל הנבחרים",
    "Move selection" : "העברת בחירה",
    "Delete selection" : "מחיקת בחירה",
    "Select all" : "בחר הכל",
    "Cancel selection" : "ביטול בחירה",
    "Go back" : "חזרה",
    "Select one or more tags" : "יש לבחור תגית אחת או יותר",
    "New" : "חדש",
    "New bookmark" : "סימנייה חדשה",
    "New folder" : "תיקייה חדשה",
    "Search" : "חיפוש",
    "Empty trash bin" : "פינוי סל האשפה",
    "Enter a link" : "נא למלא קישור",
    "Enter a title" : "נא למלא כותרת",
    "No bookmarks found" : "לא נמצאו סימניות",
    "_%n folder_::_%n folders_" : ["%n תיקייה","%n תיקיות","%n תיקיות","%n תיקיות"],
    "Add a bookmark" : "הוספת סימנייה",
    "Sync with your browser" : "סנכרון עם הדפדפן שלך",
    "Select folder" : "בחירת תיקייה",
    "Enter folder title" : "נא למלא כותרת לתיקייה",
    "Shared by {user}" : "שותפה על ידי {user}",
    "Rename folder" : "שינוי שם תיקייה",
    "Choose folder" : "בחירת תיקייה",
    "Submit" : "שליחה",
    "Cancel" : "ביטול",
    "Deleting bookmarks" : "הסימניות נמחקות",
    "Deleting selection" : "הבחירה נמחקת",
    "Importing bookmarks" : "סימניות מיובאות",
    "Moving selection" : "הבחירה מועברת",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["תיקייה אחת ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות"],
    "_Moving %n folder_::_Moving %n folders_" : ["תיקייה אחת מועברת","%n תיקיות מועברות","%n תיקיות מועברות","%n תיקיות מועברות"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["סימנייה אחת מועברת","%n סימניות מועברות","%n סימניות מועברות","%n סימניות מועברות"],
    "All bookmarks" : "כל הסימניות",
    "Recent" : "אחרונים",
    "Shared with you" : "משותף אתך",
    "Files" : "קבצים",
    "Broken links" : "קישורים פגומים",
    "Delete" : "מחיקה",
    "Untagged" : "ללא תגית",
    "{used} bookmarks of {available} available" : "{used} סימניות מתוך {available} זמינות",
    "No bookmarks here" : "אין כאן סימניות",
    "Archive path" : "נתיב הארכיון",
    "Please select \"Add to home screen\" in your browser menu" : "נא לבחור באפשרות „הוספה למסך הבית” בתפריט הדפדפן שלך",
    "Client apps" : "יישומוני לקוח",
    "Also check out the collection of client apps that integrate with this app: " : "כדאי להציץ באוסף יישומוני הלקוח שמשתלבים עם היישומון הזה:",
    "Install web app" : "התקנת יישומון דפדפן",
    "Install on home screen" : "התקנה על מסך הבית",
    "Bookmarklet" : "יישומון סימנייה",
    "Add to {instanceName}" : "הוספה אל {instanceName}",
    "Need help?" : "עזרה נזקקת?",
    "Created {time} ago" : "נוצר לפני {time}",
    "Created on {date}" : "נוצר ב־{date}",
    "Title" : "תפקיד",
    "Link" : "קישור",
    "Root folder" : "תיקיית בסיס",
    "Tags" : "תגיות",
    "Select tags and create new ones" : "בחירת תגיות ויצירת חדשות",
    "Notes" : "הערות",
    "Open file" : "פתיחת קובץ",
    "Download file" : "הורדת קובץ",
    "Link copied" : "הקישור הועתק",
    "Owner" : "בעלות",
    "Sharing" : "שיתוף",
    "Select a user or group" : "נא לבחור משתמש או קבוצה",
    "Share link" : "קישור שיתוף",
    "Delete link" : "מחיקת קישור",
    "Create public link" : "יצירת קישור ציבורי",
    "Allow editing" : "לאפשר עריכה",
    "Allow resharing" : "לאפשר שיתוף מחדש",
    "Remove share" : "הסרת שיתוף",
    "Failed to save settings" : "שמירת ההגדרות נכשלה",
    "Failed to load settings" : "טעינת ההגדרות נכשלה",
    "Privacy" : "פרטיות",
    "Enable accessing and collecting information from the web pages you add" : "הפעלת גישה ואיסוף של מידע מהאתרים שהוספת.",
    "Performance" : "ביצועים",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "כמות הסימניות המרבית לחשבון. (0 ללא הגבלה וזאת גם בררת המחדל)",
    "Previews" : "תצוגות מקדימות",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "ניתן להירשם בחינם בכתובת screeenly.com או להקים שרת משלך.",
    "Screeenly API URL" : "כתובת ה־API של Screeenly",
    "Screeenly API key" : "מפתח ה־API של Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "מפתח ה־API של ScreenshotMachine",
    "This URL is already bookmarked! Overwrite?" : "כתובת זו כבר נשמרה בסימניות! לשכתב?",
    "Enter bookmark title" : "נא להקליד כותרת לסימנייה",
    "Enter bookmark URL" : "נא למלא כתובת סימנייה",
    "Folder" : "תיקייה",
    "Save" : "שמירה",
    "What's new?" : "מה חדש?",
    "Failed to load bookmark" : "טעינת הסימנייה נכשלה",
    "Failed to find existing bookmark" : "איתור סימנייה קיימת נכשל",
    "Failed to create bookmark" : "יצירת סימנייה נכשלה",
    "Failed to save bookmark" : "שמירת סימנייה נכשלה",
    "Failed to move bookmark" : "העברת סימנייה נכשלה",
    "Failed to delete bookmark" : "מחיקת הסימנייה נכשלה",
    "Import successful" : "הייבוא הצליח",
    "Failed to rename tag" : "שינוי שם התגית נכשל",
    "Failed to load tags" : "טעינת התגיות נכשלה",
    "Failed to load folders" : "טעינת התיקיות נכשלה",
    "Failed to delete folder" : "מחיקת התיקייה נכשלה",
    "Failed to create folder" : "יצירת התיקייה נכשלה",
    "Failed to move parts of selection" : "העברת חלקים מהבחירה נכשלה",
    "Failed to delete parts of selection" : "מחיקת חלקים מהבחירה נכשלה",
    "Failed to fetch bookmarks." : "קבלת הסימניות נכשלה.",
    "Failed to load setting {key}" : "טעינת ההגדרה {key} נכשלה",
    "Failed to update share {shareId}" : "עדכון השיתוף {shareId} נכשל",
    "Failed to delete share {shareId}" : "מחיקת השיתוף {shareId} נכשלה",
    "Bookmarks feed" : "ערוץ סימניות"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
