OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bokmärken",
    "You bookmarked \"%s\"" : "Du sparade \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s sparade \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Någon sparade %s",
    "You deleted \"%s\"" : "Du raderade \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s raderade \"%2$s\"",
    "Someone deleted \"%s\"" : "Någon raderade \"%s\"",
    "You created folder \"%s\"" : "Du skapade mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s skapade mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "Någon skapade mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttade mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttade mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "Någon flyttade mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du raderade mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s raderade mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Någon raderade mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delade mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du delade mappen \"%s\" med någon",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delade mappen \"%2$s\" med dig",
    "Someone shared folder \"%s\" with you" : "Någon delade mappen \"%s\" med dig",
    "You unshared folder \"%1$s\" with %2$s" : "Du slutade dela mappen \"%1$s\" med %2$s",
    "You unshared folder \"%s\" with someone" : "Du slutade dela mappen \"%s\" med någon",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s slutade dela mappen \"%2$s\" med dig",
    "Someone unshared folder \"%s\" with you" : "Någon slutade  dela mappen \"%s\" med dig",
    "No file provided for import" : "Inga filer given för importering",
    "Failed to upload file" : "Kunde inte ladda upp filen",
    "Unsupported file type for import: " : "Ogiltig filtyp för import: ",
    "Bookmarks shared by %s" : "Bokmärken delas av %s",
    "Frequent bookmarks" : "Vanliga bokmärken",
    "Recent bookmarks" : "Senaste bokmärken",
    "Bookmark" : "Bokmärke",
    "Bookmark deleted" : "Bokmärke raderat",
    "Bookmark created" : "Bokmärke skapat",
    "Bookmark moved" : "Bokmärke flyttat",
    "Bookmark updated" : "Bokmärke uppdaterat",
    "Create bookmark" : "Skapa bokmärke",
    "Takes a link and adds it to your collection of bookmarks." : "Tar en länk och lägger till den i dina bokmärken.",
    "Bookmarks Backups" : "Bokmärken säkerhetskopior",
    "Collect and manage bookmarks, synced with all your devices" : "Samla och hantera bokmärken, synkroniserade med alla dina enheter",
    "Do you really want to delete this bookmark?" : "Är du säker att du vill ta bort detta bokmärket?",
    "Link copied to clipboard" : "Länken kopierad till urklipp",
    "Enter new title" : "Ange ny titel",
    "Select bookmark" : "Välj bokmärke",
    "You have never clicked this link" : "Du har aldrig klickat på den här länken",
    "You have clicked this link {count} times" : "Du har klickat på den här länken {count} gånger",
    "Details" : "Detaljer",
    "Rename" : "Byt namn",
    "Copy link" : "Kopiera länk",
    "Move" : "Flytta",
    "Add to folders" : "Lägg till i mappar",
    "Put bookmark into trash bin" : "Lägg bokmärket i papperskorgen",
    "Restore bookmark" : "Återställ bokmärke",
    "Delete bookmark permanently" : "Ta bort bokmärke permanent",
    "Content pending" : "Väntar på innehåll",
    "This content is being downloaded for offline use. Please check back later." : "Detta innehåll laddas ner för offlineanvändning. Vänligen försök igen senare.",
    "Bookmarked {time} ago" : "Sparad för {time} sedan",
    "Bookmarked on {date}" : "Sparad den {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Det här är dina raderade objekt. Objekt kommer att raderas permanent efter två månader.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer på webben som foton eller PDF-filer sparas automatiskt till dina Nextcloud-filer, så att du fortfarande kan hitta dem även när länken går offline.",
    "Searching in the current folder only." : "Söker endast i nuvarande mappen.",
    "Repeat search in all folders" : "Upprepa sökning i alla mappar",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bokmärkta länkar kontrolleras regelbundet och de som inte kan nås listas här.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Du kan dela bokmärkesmappar med andra. Alla mappar som delas med dig listas här.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Ett bokmärke kan finnas i flera mappar samtidigt. Om du uppdaterar en, uppdateras alla kopior. Alla dubbletter av bokmärken listas här.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valde {folders} mappar och {bookmarks} bokmärken",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valde %n bokmärke","Valde %n bokmärken"],
    "_Selected %n folder_::_Selected %n folders_" : ["Valde %n mapp","Valde %n mappar"],
    "Do you really want to delete these items?" : "Är du säker att du vill ta bort dessa objekt?",
    "Open all selected" : "Öppna alla markerade",
    "Move selection" : "Flytta urval",
    "Edit tags of selection" : "Ändra taggar för urval",
    "Delete selection" : "Ta bort urval",
    "Select all" : "Välj alla",
    "Cancel selection" : "Avbryt markering",
    "Sort by created date" : "Sortera efter skapat datum",
    "Sort by last modified" : "Sortera efter senast modifierad",
    "Sort by title" : "Sortera efter titel",
    "Sort by click count" : "Sortera efter antal klicks",
    "Sort by manual order" : "Sortera efter manuell ordning",
    "Sort by URL" : "Sortera efter URL",
    "RSS feed copied" : "Kopierade RSS flöde",
    "Trash Bin" : "Papperskorg",
    "Go back" : "Gå tillbaks",
    "Share folder" : "Dela mapp",
    "Open folder details" : "Öppna mappinformation",
    "Select one or more tags" : "Välj en eller flera taggar",
    "New" : "Nytt",
    "New bookmark" : "Nytt bokmärke",
    "New folder" : "Ny mapp",
    "Change to grid view" : "Växla till rutnätsvy",
    "Change to list view" : "Växla till listvy",
    "Copy RSS Feed of current view" : "Kopiera RSS-flöde för aktuella vyn",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-flödet kräver autentisering med dina Nextcloud-uppgifter",
    "Search" : "Sök",
    "Empty trash bin" : "Töm papperskorgen",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Lägger till %n bokmärke i ny mapp","Lägger till %n bokmärken i ny mapp"],
    "Enter a link" : "Ange en länk",
    "Enter a title" : "Ange en titel",
    "No bookmarks found" : "Inga bokmärken hittades",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} mappar och {bookmarks} bokmärken",
    "_%n bookmark_::_%n bookmarks_" : ["%n bokmärke","%n bokmärken"],
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "Welcome to Bookmarks" : "Välkommen till Bokmärken",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Denna app låter dig hantera länkar till dina favoritplatser på webben. Sortera dina bokmärken i mappar, märk dem med taggar och dela dem med andra! Appen kontrollerar regelbundet alla dina länkar för tillgänglighet och visar otillgängliga länkar. Om du lägger till en länk till en fil på webben kommer filen automatiskt att laddas ner till dina Nextcloud-filer. Du kan också importera bokmärken som exporterats från andra tjänster eller direkt synkronisera bokmärken från alla dina webbläsare med denna app.",
    "Add a bookmark" : "Lägg till ett bokmärke",
    "Import bookmarks" : "Importera bokmärken",
    "Sync with your browser" : "Synkronisera med din webbläsare",
    "Do you really want to permanently delete this folder?" : "Vill du verkligen ta bort den här mappen permanent?",
    "Select folder" : "Välj mapp",
    "Enter folder title" : "Ange titel",
    "Shared by {user}" : "Delad av {user}",
    "Rename folder" : "Byt namn på mapp",
    "Move folder" : "Flytta mapp",
    "Put folder into trashbin" : "Lägg mappen i papperskorgen",
    "Restore folder" : "Återställ mapp",
    "Delete folder permanently" : "Ta bort mapp permanent",
    "Choose folder" : "Välj mapp",
    "Submit" : "Skicka",
    "Cancel" : "Avbryt",
    "Deleting bookmarks" : "Tar bort bokmärken",
    "Deleting selection" : "Tar bort urval",
    "Importing bookmarks" : "Importerar bokmärken",
    "Moving selection" : "Flyttar urval",
    "Adding selection to folders" : "Lägger till urval i mappar",
    "Emptying trashbin" : "Tömmer papperskorgen",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flyttar %n mapp och några bokmärken","Flyttar %n mappar och några bokmärken"],
    "_Moving %n folder_::_Moving %n folders_" : ["Flyttar %n mapp","Flyttar %n mappar"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flyttar %n bokmärke","Flyttar %n bokmärken"],
    "All bookmarks" : "Alla bokmärken",
    "Recent" : "Nya",
    "Shared with you" : "Delat med dig",
    "Files" : "Filer",
    "Duplicates" : "Dubbletter",
    "Broken links" : "Brutna länkar",
    "New tag" : "Ny tagg",
    "Search tags" : "Sök taggar",
    "Delete" : "Ta bort",
    "Untagged" : "Inte taggad",
    "{used} bookmarks of {available} available" : "{used} bokmärken av {available} tillgängliga",
    "Bookmarks Settings" : "Bokmärkesinställningar",
    "No bookmarked files" : "Inga bokmärkta filer",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer som foton eller PDF-filer sparas automatiskt i ditt Nextcloud så att du fortfarande kan hitta dem även när länken går offline.",
    "Nothing found" : "Inget hittades",
    "Your search yielded no results in the current folder." : "Din sökning gav inga resultat i den nuvarande mappen.",
    "No broken links" : "Inga trasiga länkar",
    "No shared folders" : "Inga delade mappar",
    "No duplicated bookmarks" : "Inga dubblerade bokmärken",
    "No deleted bookmarks" : "Inga borttagna bokmärken",
    "You haven't deleted anything yet." : "Du har inte tagit bort något ännu.",
    "No bookmarks here" : "Inga bokmärken här",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Lägg till bokmärken manuellt eller importera bokmärken från en HTML-fil.",
    "Archive path" : "Sökväg till arkiv",
    "Backup path" : "Sökväg till säkerhetskopior",
    "Please select \"Add to home screen\" in your browser menu" : "Vänligen välj \"Lägg till hemskärm\" i din webbläsarmeny",
    "Bookmarks settings" : "Bokmärkesinställningar",
    "Import/Export" : "Import/Export",
    "Export bookmarks" : "Exportera bokmärken",
    "Auto-archiving" : "Auto-arkivering",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Bokmärkesappen kan automatiskt arkivera webbinnehållet för länkar du har bokmärkt.",
    "Enable archiving" : "Aktivera arkivering",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Ange sökvägen till en mapp i dina filer där bokmärkta filer ska lagras.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "För närvarande har din administratör inaktiverat nätverksåtkomst för den här appen, vilket är anledningen till att automatisk arkivering är inaktiverad för tillfället.",
    "Auto-Backup" : "Automatisk säkerhetskopiering",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Bokmärkesappen kan automatiskt säkerhetskopiera dina bokmärken dagligen för att förhindra dataförlust när du synkroniserar bokmärken mellan enheter.",
    "Enable backups" : "Aktivera säkerhetskopiering",
    "Enter the path of a folder in your Files where backups will be stored." : "Ange sökvägen till en mapp i dina filer där säkerhetskopior kommer att lagras.",
    "Context Chat integration" : "Integration med kontextchatt",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Bokmärkesappen kan automatiskt göra det textuella innehållet på de webbplatser du bokmärker tillgängligt för Kontextchatt, vilket gör att du kan ställa frågor om och få svar baserade på det innehållet. Detta är endast tillgängligt om autoarkivering är aktiverad.",
    "Context chat is currently not installed, but is required for this feature." : "Kontextchatt är för närvarande inte installerad, men krävs för denna funktion.",
    "Enable Context Chat integration" : "Aktivera integration med kontextchatt",
    "Client apps" : "Klientappar",
    "Also check out the collection of client apps that integrate with this app: " : "Kolla också in samlingen av klientappar som integrerar med den här appen: ",
    "Install web app" : "Installera webbapp",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Du kan installera denna appen på hemskärmen av din enhet för att snabbt komma åt dina bokmärken från din mobil. Du kan enkelt ta bort appen från hemskärmen igen ifall du inte gillar det.",
    "Install on home screen" : "Installera på hemskärmen",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Dra till webbläsarens bokmärken och klicka på den för att snabbt bokmärka en webbplats.",
    "Add to {instanceName}" : "Lägg till {instanceName}",
    "Need help?" : "Behövs hjälp?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Om du har problem med denna bokmärkesapp eller har en idé om vad som kan förbättras, tveka inte att höra av dig genom att klicka här.",
    "Support this project" : "Stöd detta projekt",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Mitt arbete med den här bokmärkesappen drivs av en frivillig prenumerationsmodell. Om du tycker att det jag gör är värt besväret skulle jag bli glad om du kunde stödja mitt arbete. Överväg också att ge appen en recension i Nextclouds appbutik. Tack 💙 ",
    "Created {time} ago" : "Skapad för {time} sedan",
    "Created on {date}" : "Skapades {date}",
    "(Empty title)" : "(Tom titel)",
    "Title" : "Titel",
    "Link" : "Länk",
    "Untitled folder" : "Namnlös mapp",
    "Root folder" : "Topp-mapp",
    "Tags" : "Taggar",
    "Select tags and create new ones" : "Välj taggar och skapa nya",
    "Notes" : "Anteckning",
    "Notes for this bookmark …" : "Anteckningar för detta bokmärket …",
    "Archived file" : "Arkiverad fil",
    "Open file" : "Öppna fil",
    "Download file" : "Hämta fil",
    "Open file location" : "Öppna filsökväg",
    "Link copied" : "Länk kopierad",
    "Owner" : "Ägare",
    "Sharing" : "Delning",
    "Select a user or group" : "Välj en användare eller grupp",
    "Share link" : "Dela länk",
    "Reading allowed" : "Läsning tillåten",
    "Copy RSS feed" : "Kopiera RSS-flöde",
    "Delete link" : "Ta bort länk",
    "Create public link" : "Skapa offentlig länk",
    "Resharing allowed" : "Vidaredelning tillåten",
    "Editing allowed" : "Redigering tillåten",
    "Allow editing" : "Tillåt redigering",
    "Allow resharing" : "Tillåt vidaredelning",
    "Remove share" : "Ta bort delning",
    "Leave a rating on the Nextcloud App Store" : "Lämna ett omdöme på Nextcloud App Store",
    "Failed to save settings" : "Kunde inte spara inställningarna",
    "Failed to load settings" : "Kunde inte läsa in inställningar",
    "Privacy" : "Integritet",
    "The app will try to access web pages that you add to automatically add information about them." : "Appen kommer försöka komma åt webbsidor som du lägger till för att automatiskt lägga till information om dem.",
    "Enable accessing and collecting information from the web pages you add" : "Aktivera åtkomst till och samla information från webbsidorna du lägger till",
    "Performance" : "Prestanda",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installation med många användare kan det vara nödvändigt att begränsa antalet bokmärken per konto.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximalt tillåtet antal bokmärken per konto. (0 för ingen gräns; standard är ingen gräns)",
    "Previews" : "Förhandsvisningar",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "För att visa riktiga skärmdumpar av dina bokmärkta webbplatser kan appen använda tredjepartstjänster för att generera förhandsvisningar.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Du kan antingen registrera dig gratis på screeenly.com eller sätta upp en egen server.",
    "Screeenly API URL" : "Screeenly API-webbadress",
    "Screeenly API key" : "Screeenly API-nyckel",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API nyckel",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Generisk skärmdump API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Registrera dig hos någon av API-leverantörerna för skärmdumpar och ange API-URL nedan. Använd variabeln {url} som platshållare för webbadressen för skärmdump. API:t måste endast returnera bilden direkt.",
    "Generic API URL" : "Generisk API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Installera Pageres CLI av Sindre Sorhus på din server så hittar Bokmärken det. Du kan fortfarande lägga till ytterligare ENV-variabler som ska matas till Pageres, t.ex. som anges i platshållaren:",
    "Pageres ENV variables" : "Pageres ENV-variabler",
    "This URL is already bookmarked! Overwrite?" : "Den här webbadressen är redan bokmärkt! Skriva över?",
    "Enter bookmark title" : "Ange titel",
    "Enter bookmark URL" : "Ange bokmärkets webbadress",
    "Folder" : "Mapp",
    "Root Folder" : "Rot mapp",
    "Save" : "Spara",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Nätverkstillgång är inaktiv som standard. Gå till administratör-inställningarna för bokmärkesappen för att tillåta hämtning av förhandsvisningar och ikoner.",
    "What's new?" : "Vad är nytt?",
    "What" : "Vad",
    "Failed to count unavailable bookmarks" : "Det gick inte att räkna otillgängliga bokmärken",
    "Failed to count archived bookmarks" : "Det gick inte att räkna arkiverade bokmärken",
    "Failed to count duplicated bookmarks" : "Det gick inte att räkna dubblerade bokmärken",
    "Failed to count bookmarks" : "Kunde inte räkna bokmärken",
    "Failed to load bookmark" : "Det gick inte att läsa in bokmärket",
    "Failed to find existing bookmark" : "Kunde inte hitta befintligt bokmärke",
    "Failed to create bookmark" : "Kunde inte skapa bokmärke",
    "Failed to save bookmark" : "Kunde inte spara bokmärke",
    "Failed to move bookmark" : "Kunde inte flytta bokmärke",
    "Failed to copy bookmark" : "Kunde inte kopiera bokmärket",
    "Failed to delete bookmark" : "Kunde inte radera bokmärke",
    "Failed to restore bookmark" : "Kunde inte återställa bokmärke",
    "Import successful" : "Importen lyckades",
    "Failed to rename tag" : "Kunde inte döpa om tagg",
    "Failed to load tags" : "Kunde inte läsa in taggar",
    "Failed to load folders" : "Kunde inte läsa in mappar",
    "Failed to load deleted folders" : "Kunde inte läsa in borttagna mappar",
    "Failed to load deleted bookmarks" : "Kunde inte läsa in borttagna bokmärken",
    "Failed to delete folder" : "Kunde inte radera mapp",
    "Failed to move folder" : "Det gick inte att flytta mappen",
    "Failed to restore folder" : "Kunde inte återställa mapp",
    "Failed to create folder" : "Kunde inte skapa mapp",
    "Failed to load children order" : "Kunde inte läsa in underordnade objekt",
    "Failed to move parts of selection" : "Kunde inte flytta vissa delar av urvalet",
    "Failed to copy parts of selection" : "Kunde inte kopiera delar av markeringen",
    "Failed to delete parts of selection" : "Kunde inte ta bort delar av urvalet",
    "Failed to tag parts of selection" : "Kunde inte tagga delar av markeringen",
    "Failed to fetch bookmarks." : "Kunde inte hämta bokmärken.",
    "Failed to store setting" : "Kunde inte spara inställning",
    "Failed to load setting {key}" : "Det gick inte att läsa in inställningen {key}",
    "Failed to create share for folder {folderId}" : "Kunde inte skapa delning för mappen {folderId}",
    "Failed to update share {shareId}" : "Det gick inte att uppdatera delningen {shareId}",
    "Failed to delete share {shareId}" : "Det gick inte att radera delningen {shareId}",
    "Failed to create public link for folder {folderId}" : "Kunde inte skapa offentlig länk för mappen {folderId}",
    "Failed to delete public link for folder {folderId}" : "Kunde inte ta bort offentlig länk för mappen {folderId}",
    "Failed to permanently delete parts of trash bin" : "Kunde inte permanent ta bort delar av papperskorgen",
    "Create bookmarks for mentioned links" : "Skapa bokmärken för nämnda länkar",
    "No links found in this message" : "Inga länkar hittades i detta meddelande",
    "Bookmarks feed" : "Bokmärkesflöde"
},
"nplurals=2; plural=(n != 1);");
