OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Könyvjelzők",
    "You bookmarked \"%s\"" : "Elmentve a könyvjelzők közé: „%s”",
    "%1$s bookmarked \"%2$s\"" : "%1$s könyvjelzőzte ezt: „%2$s”",
    "Someone bookmarked \"%s\"" : "Valaki már könyvjelzőzte ezt: „%s”",
    "You deleted \"%s\"" : "„%s” törölve",
    "%1$s deleted \"%2$s\"" : "%1$s törölte ezt: „%2$s”",
    "Someone deleted \"%s\"" : "Valaki törölte ezt: „%s”",
    "You created folder \"%s\"" : "Létrehozta ezt a mappát: „%s”",
    "%1$s created folder \"%2$s\"" : "%1$s létrehozta a következő mappát: „%2$s”",
    "Someone created folder \"%s\"" : "Valaki létrehozta ezt a mappát: „%s”.",
    "You moved folder \"%s\"" : "Áthelyezte ezt a mappát: „%s”",
    "%1$s moved folder \"%2$s\"" : "%1$s áthelyezte ezt a mappát: „%2$s”",
    "Someone moved folder \"%s\"" : "Valaki áthelyezte ezt a mappát: „%s”",
    "You deleted folder \"%s\"" : "Törölte ezt a mappát: %s.",
    "%1$s deleted folder \"%2$s\"" : "%1$s törölte ezt a mappát: „%2$s”",
    "Someone deleted folder \"%s\"" : "Valaki törölte ezt a mappát: „%s”.",
    "You shared folder \"%1$s\" with %2$s" : "Megosztotta a(z) „%1$s mappát vele: %2$s",
    "You shared folder \"%s\" with someone" : "Megosztotta a(z) „%s” mappát valakivel",
    "%1$s shared folder \"%2$s\" with you" : "%1$s megosztotta Önnel a(z) „%2$s” mappát",
    "Someone shared folder \"%s\" with you" : "Valaki megosztotta Önnel a(z) „%s” mappát",
    "You unshared folder \"%1$s\" with %2$s" : "Megszüntette a(z) „%1$s” mappa megosztását vele: %2$s",
    "You unshared folder \"%s\" with someone" : "Megszüntette a(z) „%s” mappa megosztását valakivel",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s megszüntette a(z) „%2$s” mappa megosztását Önnel",
    "Someone unshared folder \"%s\" with you" : "Valaki megszüntette a(z) „%s” mappa megosztását Önnel",
    "No file provided for import" : "Nincs fájl megadva az importáláshoz",
    "Failed to upload file" : "A fájl feltöltése sikertelen",
    "Unsupported file type for import: " : "Ismeretlen fájltípus az importáláshoz:",
    "Bookmarks shared by %s" : "%s által megosztott könyvjelzők",
    "Frequent bookmarks" : "Gyakori könyvjelzők",
    "Recent bookmarks" : "Legújabb könyvjelzők",
    "Bookmark" : "Könyvjelző",
    "Bookmark deleted" : "Könyvjelző törölve",
    "Bookmark created" : "Könyvjelző létrehozva",
    "Bookmark moved" : "Könyvjelző áthelyezve",
    "Bookmark updated" : "Könyvjelző frissítve",
    "Create bookmark" : "Könyvjelző létrehozása",
    "Takes a link and adds it to your collection of bookmarks." : "Fog egy hivatkozást, és hozzáadja a könyvjelzők gyűjteményéhez.",
    "Bookmarks Backups" : "Könyvjelzők biztonsági mentése",
    "Collect and manage bookmarks, synced with all your devices" : "Könyvjelzők gyűjtése és kezelése, szinkronizálva az összes eszközével",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Könyvjelzők mappákba rendezése\n- 🏷 Címkék és személyes jegyzetek hozzáadása\n- ☠ Hibás hivatkozások és duplikátumok kiszűrése\n- 📲 Szinkronizálás az összes böngészővel és eszközzel\n- 📔 Hivatkozások archivált verzióinak tárolása, arra az esetre, ha leveszik az eredetit\n- 🔍 Teljes szöveges keresés az oldalak tartalmában\n- 👪 Könyvjelzők megosztása más felhasználókkal, csoportokkal vagy csapatokkal, vagy nyilvános hivatkozással\n- ⚛ RSS-hírforrások előállítása a gyűjteményekből\n- 📈 Statisztikák a hivatkozások eléréseiről\n- 🔒 Automatikus mentés a teljes gyűjteményről\n- 💼 Beépített Irányítópult modulok a gyakori és friss hivatkozásokkal\n\nKövetelmények:\n- PHP bővítmények:\n  - intl: *\n  - mbstring: *\n- MySQL esetén legalább v8.0",
    "Do you really want to delete this bookmark?" : "Biztos, hogy törli ezt a könyvjelzőt?",
    "Link copied to clipboard" : "Hivatkozás a vágólapra másolva",
    "Enter new title" : "Adja meg a címet",
    "Select bookmark" : "Válasszon könyvjelzőt",
    "You have never clicked this link" : "Még soha nem kattintott erre a hivatkozásra",
    "You have clicked this link {count} times" : "{count} alkalommal kattintott erre a hivatkozásra",
    "Details" : "Részletek",
    "Rename" : "Átnevezés",
    "Copy link" : "Hivatkozás másolása",
    "Move" : "Áthelyezés",
    "Add to folders" : "Hozzáadás a mappákhoz",
    "Put bookmark into trash bin" : "Könyvjelző kukába dobása",
    "Restore bookmark" : "Könyvjelző helyreállítása",
    "Delete bookmark permanently" : "Könyvjelző végleges törlése",
    "Content pending" : "Tartalom függőben",
    "This content is being downloaded for offline use. Please check back later." : "Ez a tartalom offline használatra töltődik le. Nézzen vissza később.",
    "Bookmarked {time} ago" : "Könyvjelzőzve ennyi ideje: {time}",
    "Bookmarked on {date}" : "Könyvjelzőzés dátuma: {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Ezek a törölt elemek. Két hónap után véglegesen törlődnek.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "A weben lévő fájlok, például a fényképek vagy a PDF-ek könyvjelzőit automatikusan menti az Ön Nextcloud fájljaiba, így akkor is megtalálhatja őket, ha a kapcsolat offline állapotban van.",
    "Searching in the current folder only." : "Keresés csak a jelenlegi mappában.",
    "Repeat search in all folders" : "Keresés megismétlése az összes mappában",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "A könyvjelzőzött hivatkozásokat rendszeresen ellenőrzi, és azok, melyek nem érhetők el, itt jelennek meg.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Megoszthatja másokkal a könyvjelzőmappákat. Az összes Önnel megosztott mappa itt jelenik meg.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Egy könyvjelző egyszerre több mappában is lehet. A frissítése az összes másolatot frissíti. A kényelem érdekében az összes ismételt könyvjelző itt jelenik.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} mappa és {bookmarks} könyvjelző kiválasztva",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n könyvjelző kiválasztva","%n könyvjelző kiválasztva"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n mappa kiválasztva","%n mappa kiválasztva"],
    "Do you really want to delete these items?" : "Biztos, hogy törli ezeket az elemeket?",
    "Open all selected" : "Az összes kiválasztott megnyitása",
    "Move selection" : "Kiválasztás áthelyezése",
    "Edit tags of selection" : "Kiválasztott címkék szerkesztése",
    "Delete selection" : "Kiválasztás törlése",
    "Select all" : "Összes kiválasztása",
    "Cancel selection" : "Kiválasztás elvetése",
    "Sort by created date" : "Rendezés létrehozás dátuma szerint",
    "Sort by last modified" : "Rendezés módosítás dátuma szerint",
    "Sort by title" : "Rendezés cím szerint",
    "Sort by click count" : "Rendezés kattintásszám szerint",
    "Sort by manual order" : "Rendezés kézi sorrend szerint",
    "Sort by URL" : "Rendezés webcím szerint",
    "RSS feed copied" : "Az RSS-csatorna másolva",
    "Trash Bin" : "Kuka",
    "Go back" : "Visszalépés",
    "Share folder" : "Mappa megosztása",
    "Open folder details" : "Mappa részletek megnyitása",
    "Select one or more tags" : "Válasszon egy vagy több címkét",
    "New" : "Új",
    "New bookmark" : "Új könyvjelző",
    "New folder" : "Új mappa",
    "Change to grid view" : "Váltás rácsnézetre",
    "Change to list view" : "Váltás listanézetre",
    "Copy RSS Feed of current view" : "Az aktuális nézet RSS-hírcsatornájának másolása",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Az RSS-hírcsatorna hitelesítést igényel a Nextcloud hitelesítő adataival",
    "Search" : "Keresés",
    "Empty trash bin" : "Kuka ürítése",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["%n könyvjelző hozzáadása az új mappához","%n könyvjelző hozzáadása az új mappához"],
    "Enter a link" : "Adja meg a hivatkozást",
    "Enter a title" : "Adja meg a címet",
    "No bookmarks found" : "Nem található könyvjelző",
    "{folders} folders and {bookmarks} bookmarks" : " {folders} mappa és {bookmarks} könyvjelző",
    "_%n bookmark_::_%n bookmarks_" : ["%n könyvjelző","%n könyvjelző"],
    "_%n folder_::_%n folders_" : ["%n mappa","%n mappa"],
    "Welcome to Bookmarks" : "Üdvözli a Könyvjelzők",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Az alkalmazás lehetővé teszi, hogy rendszerezze a kedvenc helyeit a weben. Rendezze mappákba a könyvjelzőit, címkézze fel őket, és ossza meg másokkal! Az alkalmazás rendszeresen ellenőrzi, hogy a hivatkozások elérhetők-e, és megjeleníti a nem elérhető hivatkozásokat. Ha hozzáad egy webes fájlhivatkozást, akkor az automatikus le lesz töltve a Nextcloud Fájlokba. Importálhatja is a más szolgáltatásokból származó könyvjelzőket, vagy közvetlenül szinkronizálhat az összes böngészőjéből az alkalmazással.",
    "Add a bookmark" : "Könyvjelző hozzáadása",
    "Import bookmarks" : "Könyvjelzők importálása",
    "Sync with your browser" : "Szinkronizálás a böngészővel",
    "Do you really want to permanently delete this folder?" : "Biztos, hogy végleg törli ezt a mappát?",
    "Select folder" : "Válasszon egy mappát",
    "Enter folder title" : "Adja meg a mappa nevét",
    "Shared by {user}" : "Megosztotta: {user}",
    "Rename folder" : "Mappa átnevezése",
    "Move folder" : "Mappa áthelyezése",
    "Put folder into trashbin" : "Mappa kukába dobása",
    "Restore folder" : "Mappa helyreállítása",
    "Delete folder permanently" : "Mappa végleges törlése",
    "Choose folder" : "Válasszon mappát",
    "Submit" : "Beküldés",
    "Cancel" : "Mégse",
    "Deleting bookmarks" : "Könyvjelzők törlése folyamatban",
    "Deleting selection" : "Kiválasztás törlése",
    "Importing bookmarks" : "Könyvjelzők importálása",
    "Moving selection" : "A kijelölés áthelyezése",
    "Adding selection to folders" : "Kijelölés hozzáadása a mappákhoz",
    "Emptying trashbin" : "Kuka ürítése",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n mappa és néhány könyvjelző áthelyezése","%n mappa és néhány könyvjelző áthelyezése"],
    "_Moving %n folder_::_Moving %n folders_" : ["%n mappa áthelyezése","%n mappa áthelyezése"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n könyvjelző áthelyezése","%n könyvjelző áthelyezése"],
    "All bookmarks" : "Minden könyvjelző",
    "Recent" : "Friss",
    "Frequently clicked" : "Gyakran rákattintva",
    "Shared with you" : "Megosztva Önnel",
    "Files" : "Fájlok",
    "Duplicates" : "Ismétlések",
    "Broken links" : "Megszakadt hivatkozások",
    "New tag" : "Új címke",
    "Search tags" : "Címkék keresése",
    "Delete" : "Törlés",
    "Untagged" : "Nem címkézett",
    "{used} bookmarks of {available} available" : "{used} könyvjelző / {available} elérhető",
    "Bookmarks Settings" : "Könyvjelzőbeállítások",
    "No bookmarked files" : "Nincsenek könyvjelzőzött fájlok",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "A fájlok, például a fényképek vagy a PDF-ek könyvjelzőit automatikusan menti az Ön Nextcloud fájljaiba, így akkor is megtalálhatja őket, ha a kapcsolat offline állapotban van.",
    "Nothing found" : "Semmi sem található",
    "Your search yielded no results in the current folder." : "Nincs találat a jelenlegi mappában.",
    "No broken links" : "Nincsenek törött hivatkozások",
    "No shared folders" : "Nincsenek megosztott mappák",
    "No duplicated bookmarks" : "Nincsenek ismételt könyvjelzők",
    "No deleted bookmarks" : "Nincsenek törölt könyvjelzők",
    "You haven't deleted anything yet." : "Még nem törölt semmit.",
    "No bookmarks here" : "Itt nincsenek könyvjelzők",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Adjon hozzá könyvjelzőket kézzel, vagy importálja egy HTML-fájlból.",
    "Archive path" : "Archívum elérési útvonala",
    "Backup path" : "Biztonsági mentés útvonala",
    "Please select \"Add to home screen\" in your browser menu" : "Válassza a böngésző menüjében a „Hozzáadás a kezdőképernyőhöz” lehetőséget",
    "Bookmarks settings" : "Könyvjelzőbeállítások",
    "Import/Export" : "Importálás/exportálás",
    "Export bookmarks" : "Könyvjelzők exportálása",
    "Auto-archiving" : "Automatikus archiválás",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "A Könyvjelzők alkalmazás képes automatikusan archiválni a mentett hivatkozások tartalmát",
    "Enable archiving" : "Archiválás engedélyezése",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Adja meg egy mappa elérési útját a Fájlokban, ahol a könyvjelzőket tárolni szeretné",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Jelenleg a Könyvjelzők alkalmazás internetelérését letiltotta a rendszergazda, ezért most nem lehet automatikusan archiválni a hivatkozások tartalmát.",
    "Auto-Backup" : "Automatikus biztonsági mentés",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "A Könyvjelzők alkalmazás képes naponta automatikus mentést készíteni a könyvjelző-gyűjteményről az adatvesztés megelőzése érdekében, ha esetleg a szinkronizálásnál valami hiba lép fel.",
    "Enable backups" : "Biztonsági mentés engedélyezése",
    "Enter the path of a folder in your Files where backups will be stored." : "Adjon meg egy mappaútvonalat a Fájlokból, ahol a biztonsági mentések lesznek tárolva.",
    "Context Chat integration" : "Context Chat integráció",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "A Könyvjelzők alkalmazás automatikusan elérhetővé tudja tenni a weboldalak szöveges tartamát a Környezeti csevegésben, így kérdéseket tehet fel és válaszokat kaphat a tartalom alapján. Ez csak akkor érhető el, ha az automatikus archiválás be van kapcsolva.",
    "Context chat is currently not installed, but is required for this feature." : "A Környezeti csevegés jelenleg nincs telepítve, de szükséges ehhez a funkcióhoz.",
    "Enable Context Chat integration" : "Környezeti csevegés integrációjának bekapcsolása",
    "Client apps" : "Kliensalkalmazások",
    "Also check out the collection of client apps that integrate with this app: " : "Nézze meg az alkalmazással integrált ügyfélalkalmazások gyűjteményét is: ",
    "Install web app" : "Webalkalmazás telepítése",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Telepítheti az alkalmazást az eszköze kezdőképernyőjére, hogy gyorsan elérje a könyvjelzőit a telefonján. Ha nem tetszik, akkor könnyedén el is távolítja az alkalmazást a kezdőképernyőjéről.",
    "Install on home screen" : "Telepítés a kezdőképernyőre",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Húzza ezt a böngésző könyvjelzőihez, és kattintson rá a weboldal gyors könyvjelzőzéséhez.",
    "Add to {instanceName}" : "Hozzáadás ehhez: {instanceName}",
    "Need help?" : "Segítségre van szüksége?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Ha valami problémája van a Könyvjelzők alkalmazással, vagy van egy ötlete, javaslata, ne habozzon kapcsolatba lépni velünk ezen a hivatkozáson.",
    "Support this project" : "Projekt támogatása",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "A Könyvjelzők alkalmazásba tett munkámat támogathatja egy önkéntes előfizetéssel. Amennyiben értékeli ezt a munkát, örülnék, ha megtenné. Plusz esetleg értékelje az alkalmazást a Nextcloud alkalmazástárában. Köszönöm! 💙",
    "Created {time} ago" : "Létrehozva ennyi ideje: {time}",
    "Created on {date}" : "Létrehozás dátuma: {date}",
    "(Empty title)" : "(Üres cím)",
    "Title" : "Cím",
    "Link" : "Hivatkozás",
    "Untitled folder" : "Névtelen mappa",
    "Root folder" : "Gyökérmappa",
    "Tags" : "Címkék",
    "Select tags and create new ones" : "Válasszon címkéket, vagy hozzon létre újakat",
    "Notes" : "Jegyzetek",
    "Notes for this bookmark …" : "Megjegyzések a könyvjelzőhöz…",
    "Archived file" : "Archivált fájl",
    "Open file" : "Fájl megnyitása",
    "Download file" : "Fájl letöltése",
    "Open file location" : "Fájl helyének megnyitása",
    "Link copied" : "Hivatkozás másolva",
    "Owner" : "Tulajdonos",
    "Sharing" : "Megosztás",
    "Select a user or group" : "Válasszon ki egy felhasználót vagy csoportot",
    "Share link" : "Hivatkozás megosztása",
    "Reading allowed" : "Az olvasás engedélyezett",
    "Copy RSS feed" : "Az RSS/Atom-hírcsatorna másolása",
    "Delete link" : "Hivatkozás törlése",
    "Create public link" : "Nyilvános hivatkozás létrehozása",
    "Resharing allowed" : "A továbbosztás engedélyezett",
    "Editing allowed" : "A Szerkesztés engedélyezett",
    "Allow editing" : "Szerkesztés engedélyezése",
    "Allow resharing" : "Továbbosztás engedélyezése",
    "Remove share" : "Megosztás eltávolítása",
    "Would you like to support this project?" : "Szeretné támogatni ezt a projektet?",
    "Leave a rating on the Nextcloud App Store" : "Adjon le értékelést a Nextcloud alkalmazástárban",
    "Failed to save settings" : "A beállítások mentése sikertelen",
    "Failed to load settings" : "A beállítások betöltése sikertelen",
    "Privacy" : "Adatvédelem",
    "The app will try to access web pages that you add to automatically add information about them." : "Az alkalmazás megpróbálja letölteni a hozzáadott weboldalakat, hogy automatikusan további információkkal egészítse ki őket.",
    "Enable accessing and collecting information from the web pages you add" : "Engedélyezze az információk elérését és összegyűjtését a hozzáadott weboldalakról",
    "Performance" : "Teljesítmény",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "S sok felhasználót tartalmazó példányokon célszerű a fiókonkénti könyvjelzők számát korlátozni.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "A fiókonként maximálisan engedélyezett könyvjelzők száma. (0: nincs korlátozás, ez az alapértelmezés)",
    "Previews" : "Előnézetek",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Hogy valódi képernyőképeket lehessen megjeleníteni a könyvjelzőzött weboldalakhoz, az alkalmazás külső szolgáltatást tud igénybe venni az előnézetek előállításához.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Ingyenesen regisztrálhat a screeenly.com weboldalon, vagy beállíthatja a saját kiszolgálóját.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API-kulcs",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API-kulcs",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Általános képernyőkép API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Regisztráljon valamelyik képernyőkép API szolgáltatónál, és adja meg alább az API webcímét. A webcímben a lefotózandó oldal címét az {url} változóval adhatja meg. Az API-nak közvetlenül a képernyőképet kell visszaadnia a válaszban.",
    "Generic API URL" : "Általános API webcíme",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Csak telepítse a Pageres CLI-t (Sindre Sorhus programja) a kiszolgálóra, és a Könyvjelzők meg fogja találni. További környezeti változókat is adhat meg a pageresnek, például ahogy a helykitöltő mutatja:",
    "Pageres ENV variables" : "Pageres környezeti változók",
    "This URL is already bookmarked! Overwrite?" : "Ez a cím már könyvjelzőzve van. Felülírja?",
    "Enter bookmark title" : "Adja meg a könyvjelző címét",
    "Enter bookmark URL" : "Adja meg a könyvjelző URL-jét",
    "Folder" : "Mappa",
    "Root Folder" : "Gyökérmappa",
    "Save" : "Mentés",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "A hálózati hozzáférés alapértelmezés szerint le van tiltva. Nyissa meg a könyvjelzők alkalmazás rendszergazdai beállításait, hogy engedélyezze az előnézetek és a kedvencek beolvasását.",
    "What's new?" : "Újdonságok",
    "What" : "Mit",
    "Failed to count unavailable bookmarks" : "Az elérhetetlen könyvjelzők megszámlálása sikertelen",
    "Failed to count archived bookmarks" : "Az archivált könyvjelzők megszámolása sikertelen",
    "Failed to count deleted bookmarks" : "Nem sikerült megszámolni a törölt könyvjelzőket",
    "Failed to count duplicated bookmarks" : "Az ismételt könyvjelzők megszámolása sikertelen",
    "Failed to count bookmarks" : "Nem sikerült megszámolni a könyvjelzőket",
    "Failed to load bookmark" : "A könyvjelző betöltése sikertelen",
    "Failed to find existing bookmark" : "A létező könyvjelző keresése sikertelen",
    "Failed to create bookmark" : "A könyvjelző létrehozása sikertelen",
    "Failed to save bookmark" : "A könyvjelző mentése sikertelen",
    "Failed to move bookmark" : "A könyvjelző áthelyezése sikertelen",
    "Failed to copy bookmark" : "A könyvjelző másolása sikertelen",
    "Failed to delete bookmark" : "A könyvjelző törlése sikertelen",
    "Failed to restore bookmark" : "Nem sikerült helyreállítani a könyvjelzőket",
    "Import successful" : "Sikeres importálás",
    "Failed to rename tag" : "A címke átnevezése sikertelen",
    "Failed to load tags" : "A könyvjelző címkéinek betöltése sikertelen",
    "Failed to load folders" : "A mappák betöltése sikertelen",
    "Failed to load deleted folders" : "Nem sikerült betölteni a törölt mappákat",
    "Failed to load deleted bookmarks" : "Nem sikerült betölteni a törölt konyvjelzőket",
    "Failed to delete folder" : "A mappa törlése sikertelen",
    "Failed to move folder" : "Nem sikerült áthelyezni a mappát",
    "Failed to restore folder" : "Nem sikerült helyreállítani a mappát",
    "Failed to create folder" : "A mappa létrehozása sikertelen",
    "Failed to load children order" : "Nem sikerült betölteni a gyermekek sorrendjét",
    "Failed to move parts of selection" : "Kiválasztás részeinek áthelyezése sikertelen",
    "Failed to copy parts of selection" : "Nem sikerült másolni a kijelölés egy részét",
    "Failed to delete parts of selection" : "Kiválasztás részeinek törlése sikertelen",
    "Failed to tag parts of selection" : "Nem sikerült címkézni a kijelölés egy részét",
    "Failed to fetch bookmarks." : "A könyvjelzők lekérése sikertelen.",
    "Failed to store setting" : "Nem sikerült tárolni a beállítást",
    "Failed to load setting {key}" : "A(z) {key} beállítás betöltése sikertelen",
    "Failed to create share for folder {folderId}" : "Nem sikerült megosztást létrehozni a(z) {folderId} mappához",
    "Failed to update share {shareId}" : "A megosztás frissítése sikertelen: {shareId}",
    "Failed to delete share {shareId}" : "A(z) {shareId} megosztás törlése sikertelen",
    "Failed to create public link for folder {folderId}" : "Nem sikerült nyilvános hivatkozást létrehozni a(z) {folderId} mappához",
    "Failed to delete public link for folder {folderId}" : "Nem sikerült törölni a(z) {folderId} mappa nyilvános hivatkozását",
    "Failed to permanently delete parts of trash bin" : "Nem sikerült a kuka részeinek végleges törlése",
    "Create bookmarks for mentioned links" : "Könyvjelzők létrehozása a megemlített hivatkozásokhoz",
    "No links found in this message" : "Nincs hivatkozás ehhez az üzenethez",
    "Bookmarks feed" : "Könyvjelzők hírfolyama"
},
"nplurals=2; plural=(n != 1);");
