<?php
$TRANSLATIONS = array(
"Bookmarks" => "نشانک‌ها",
"Bookm." => "Bookm",
"No file provided for import" => "هیچ فایلی وارد نشده است.",
"Unsupported file type for import" => "نوع فایل برای وارد کردن معتبر نیست",
"Some Error happened." => "یک خطا پیش آمد.",
"Error" => "خطا",
"Tags" => "برچسب‌ها",
"Filter by tag" => "فیلتر بر اساس برچسب",
"Are you sure you want to remove this bookmark?" => "آیا از حذف این نشانک اطمینان دارید ؟",
"Warning" => "اخطار",
"Are you sure you want to remove this tag from every entry?" => "آیا مطمئن هستید که میخواهید این برچسب را از هر مطلب حذف کنید؟",
"Import error" => "وارد کردن خطا",
"Import completed successfully." => "وارد کردن با موفقیت انجام شد",
"Uploading..." => "درحال بارگذاری...",
"Add a bookmark" => "اضافه کردن یک نشانک",
"This URL is already bookmarked! Overwrite?" => "این لینک قبلا نشانک گذاری شده است . آیا میخواهید بازنویسی کنید ؟",
"The title of the page" => "عنوان صفحه",
"The address of the page" => "آدرس صحفه",
"Description of the page" => "توضیحات صفحه",
"Save" => "ذخیره",
"Delete" => "حذف",
"Edit" => "ویرایش",
"Cancel" => "منصرف شدن",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "هنگامی که می‌خواهید کی صفحه‌ی اینترنتی را بسرعت نشان کنید، این را به نشانه‌های مرورگر خود بکشید و روی آن کلیک کنید.",
"Add to ownCloud" => "افزودن به ownCloud",
"Address" => "آدرس",
"Filterable Tags" => "برچسب های قابل فیلتر شدن",
"You have no bookmarks" => "شما هیچ نشانکی ندارید",
"You can also import a bookmark file" => "شما همچنین می توانید یک فایل نشانه دار را وارد نمایید .",
"Bookmarklet" => "بوکمارک لت",
"Export & Import" => "وارد کردن و خروجی گرفتن",
"Export" => "خروجی گرفتن",
"Import" => "وارد کردن"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
