OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "You bookmarked \"%s\"" : "Vde. engadiu «%s» aos marcadores",
    "%1$s bookmarked \"%2$s\"" : "%1$s engadiu «%2$s» aos marcadores",
    "Someone bookmarked \"%s\"" : "Vde. engadiu «%s» aos marcadores",
    "You deleted \"%s\"" : "Vde. eliminou «%s»",
    "%1$s deleted \"%2$s\"" : "%1$s eliminou «%2$s»",
    "Someone deleted \"%s\"" : "Alguén eliminou «%s»",
    "You created folder \"%s\"" : "Vde. creou o cartafol «%s»",
    "%1$s created folder \"%2$s\"" : "%1$s creou o cartafol «%2$s»",
    "Someone created folder \"%s\"" : "Alguén creou o cartafol «%s»",
    "You moved folder \"%s\"" : "Vde. moveu o cartafol «%s»",
    "%1$s moved folder \"%2$s\"" : "%1$s moveu o cartafol «%2$s»",
    "Someone moved folder \"%s\"" : "Alguén moveu o cartafol «%s»",
    "You deleted folder \"%s\"" : "Vde. eliminou o cartafol «%s»",
    "%1$s deleted folder \"%2$s\"" : "%1$s eliminou o cartafol «%2$s»",
    "Someone deleted folder \"%s\"" : "Alguén eliminou o cartafol «%s»",
    "You shared folder \"%1$s\" with %2$s" : "Vde. compartiu o cartafol «%1$s» con %2$s",
    "You shared folder \"%s\" with someone" : "Vde. compartiu o cartafol «%s» con alguén",
    "%1$s shared folder \"%2$s\" with you" : "%1$s compartiu o cartafol «%2$s» con Vde.",
    "Someone shared folder \"%s\" with you" : "Alguén compartiu o cartafol «%s» con Vde.",
    "You unshared folder \"%1$s\" with %2$s" : "Vde. deixou de compartir o cartafol «%1$s» con %2$s",
    "You unshared folder \"%s\" with someone" : "Vde. deixou de compartir o cartafol «%s» con alguén",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s deixou de compartir o cartafol «%2$s» con Vde.",
    "Someone unshared folder \"%s\" with you" : "Alguén deixou de compartir o cartafol «%s» con Vde.",
    "No file provided for import" : "Non forneceu ningún ficheiro para importar",
    "Failed to upload file" : "Produciuse un fallo ao enviar o ficheiro",
    "Unsupported file type for import: " : "Tipo de ficheiro non admitido para importar:",
    "Bookmarks shared by %s" : "Marcador compartido por %s",
    "Frequent bookmarks" : "Marcadores frecuentes",
    "Recent bookmarks" : "Marcadores recentes",
    "Bookmark" : "Marcador",
    "Bookmark deleted" : "Eliminouse o marcador",
    "Bookmark created" : "Creouse o marcador",
    "Bookmark moved" : "Moveuse o marcador",
    "Bookmark updated" : "Actualizouse o marcador",
    "Create bookmark" : "Crear un marcador",
    "Takes a link and adds it to your collection of bookmarks." : "Faga unha ligazón e engádaa á súa colección de marcadores",
    "Bookmarks Backups" : "Copia de seguranza dos marcadores",
    "Collect and manage bookmarks, synced with all your devices" : "Recompile e xestione os marcadores, sincronizados con todos os seus dispositivos",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Ordenar os marcadores en cartafoles\n- 🏷 Engadire etiquetas e notas persoais\n- ☠ Buscar ligazóns rachadas e duplicadas\n- 📲 Sincronizar con todos os seus navegadores e dispositivos\n- 📔 Almacenar as versións arquivadas das súas ligazóns no caso de que sexan eliminadas\n- 🔍 Buscas de texto completo no contido do sitio\n- 👪 Compartr os marcadores con outros usuarios, grupos e equipos ou a través de ligazóns públicas\n- ⚛ Xerar fontes RSS das úas coleccións\n- 📈 Estatísticas sobre a frecuencia con que accede a que ligazóns\n- 🔒 Copia de seguranza automática da súa colección de marcadores\n- 💼 Trebellos de Taboleiro integrados para ligazóns frecuentes e recentes\n\nRequisitos:\n - Extensións de PHP:\n   - intl: *\n   - mbstring: *\n - cando use MySQL, use polo menos a v8.0",
    "Do you really want to delete this bookmark?" : "Confirma que quere eliminar este marcador?",
    "Link copied to clipboard" : "A ligazón foi copiada no portapapeis.",
    "Enter new title" : "Introduza un novo título",
    "Select bookmark" : "Seleccionar marcador",
    "You have never clicked this link" : "Nunca premeu nesta ligazón",
    "You have clicked this link {count} times" : "Vde. premeu {count} veces nesta ligazón",
    "Details" : "Detalles",
    "Rename" : "Cambiar o nome",
    "Copy link" : "Copiar a ligazón",
    "Move" : "Mover",
    "Add to folders" : "Engadir aos cartafoles",
    "Put bookmark into trash bin" : "Poñer o marcador no lixo",
    "Restore bookmark" : "Restaurar o marcador",
    "Delete bookmark permanently" : "Eliminar o marcador de xeito permanente",
    "Content pending" : "Contido pendente",
    "This content is being downloaded for offline use. Please check back later." : "Este contido estase descargando para usar sen conexión. Volva comprobar máis tarde.",
    "Bookmarked {time} ago" : "Marcado como favorito hai {time}",
    "Bookmarked on {date}" : "Marcado como favorito o {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Estes son os elementos eliminados. Os elementos eliminaranse definitivamente após dous meses.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Os marcadores de ficheiros na web, como as fotos ou os PDF, gardaranse automaticamente nos seus ficheiros de Nextcloud, para que poida atopalos incluso cando a ligazón estea fóra de liña.",
    "Searching in the current folder only." : "Buscando só no cartafol actual.",
    "Repeat search in all folders" : "Repetir a busca en todos os cartafoles",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "As ligazóns marcadas compróbanse regularmente e aá que non se pode acceder están listadas aquí.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Pode compartir cartafoles de marcadores con outras persoas. Todos os cartafoles compartidos con Vde. amósanse aquí.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Un marcador pode estar en varios cartafoles á vez. Ao actualizar, actualizaranse todas as copias. Todos os marcadores duplicados están listados aquí por comodidade.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Seleccionados {folders} cartafoles e {bookmarks} marcadores",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Seleccionado %n marcador","Seleccionados %n marcadores"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n cartafol seleccionado","%n cartafoles seleccionados"],
    "Do you really want to delete these items?" : "Confirma que quere eliminar estes elementos?",
    "Open all selected" : "Abrir todos os seleccionados",
    "Move selection" : "Mover a selección",
    "Edit tags of selection" : "Editar as etiquetas de selección",
    "Delete selection" : "Eliminar a selección",
    "Select all" : "Seleccionar todo",
    "Cancel selection" : "Cancelar a selección",
    "Sort by created date" : "Ordenar pola data de creación.",
    "Sort by last modified" : "Ordenar pola última modificación",
    "Sort by title" : "Ordenar pola título",
    "Sort by click count" : "Ordenar por conta de clics",
    "Sort by manual order" : "Ordenar manualmente.",
    "Sort by URL" : "Ordenar polo URL",
    "RSS feed copied" : "Fonte RSS copiada",
    "Trash Bin" : "Cesto do lixo.",
    "Go back" : "Volver",
    "Share folder" : "Compartir cartafol",
    "Open folder details" : "Abrir os detalles do cartafol",
    "Select one or more tags" : "Seleccione unha ou máis etiquetas",
    "New" : "Novo",
    "New bookmark" : "Novo marcador",
    "New folder" : "Novo cartafol",
    "Change to grid view" : "Cambiar á vista de grade",
    "Change to list view" : "Cambiar á vista de lista",
    "Copy RSS Feed of current view" : "Copiar a fonte RSS da vista actual",
    "The RSS feed requires authentication with your Nextcloud credentials" : "A fonte RSS precisa a autenticación coas súas credenciais de Nextcloud",
    "Search" : "Buscar",
    "Empty trash bin" : "Baleirar o lixo",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Engadindo %n marcador nun novo cartafol","Engadindo %n marcadores nun novo cartafol"],
    "Enter a link" : "Introduza unha ligazón.",
    "Enter a title" : "Introduza o título",
    "No bookmarks found" : "Non se atopou ningún marcador",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} cartafoles e {bookmarks} marcadores",
    "_%n bookmark_::_%n bookmarks_" : ["%n marcador","%n marcadores"],
    "_%n folder_::_%n folders_" : ["%n cartafol","%n cartafoles"],
    "Welcome to Bookmarks" : "Dámoslle a benvida aos marcadores",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Esta aplicación permítelle xestionar ligazóns aos seus lugares favoritos na web. Ordenar os seus marcadores en cartafoles, etiquetalos con etiquetas e compártilos con outros! A aplicación comprobará regularmente a dispoñibilidade de todas as súas ligazóns e amosará as que non estean dispoñíbeis. Se engade unha ligazón a un ficheiro na web, o ficheiro descargarase automaticamente nos seus ficheiros de Nextcloud. Tamén pode importar marcadores exportados doutros servizos ou sincronizar directamente os marcadores de todos os seus navegadores con esta aplicación.",
    "Add a bookmark" : "Engadir un marcador",
    "Import bookmarks" : "Importar os marcadores",
    "Sync with your browser" : "Sincronizar co seu navegador",
    "Do you really want to permanently delete this folder?" : "Confirma que quere eliminar este cartafol de xeito permanente?",
    "Select folder" : "Seleccionar cartafol",
    "Enter folder title" : "Introduza o título do cartafol",
    "Shared by {user}" : "Compartido por {user}",
    "Rename folder" : "Cambiar o nome do cartafol",
    "Move folder" : "Mover o cartafol",
    "Put folder into trashbin" : "Poñer o cartafol no lixo",
    "Restore folder" : "Restaurar o cartafol",
    "Delete folder permanently" : "Eliminar o cartafol de xeito permanente",
    "Choose folder" : "Escoller cartafol",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Deleting bookmarks" : "Eliminando os marcadores",
    "Deleting selection" : "Eliminando a selección",
    "Importing bookmarks" : "Importando os marcadores",
    "Moving selection" : "Movendo a selección",
    "Adding selection to folders" : "Engadindo a selección aos cartafoles",
    "Emptying trashbin" : "Baleirando o cesto do lixo",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movendo %n cartafol e algúns marcadores","Movendo %n cartafoles e algúns marcadores"],
    "_Moving %n folder_::_Moving %n folders_" : ["Movendo %n cartafol","Movendo %n cartafoles"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movendo %n marcador","Movendo %n marcadores"],
    "All bookmarks" : "Todos os marcadores",
    "Recent" : "Recente",
    "Frequently clicked" : "Seleccionado con frecuencia",
    "Shared with you" : "Compartido con Vde.",
    "Files" : "Ficheiros",
    "Duplicates" : "Duplicados",
    "Broken links" : "Ligazóns rachadas",
    "New tag" : "Nova etiqueta",
    "Search tags" : "Etiquetas de busca",
    "Delete" : "Eliminar",
    "Untagged" : "Sen etiquetar",
    "{used} bookmarks of {available} available" : "{used} marcadores de {available} disponíbeis",
    "Bookmarks Settings" : "Axustes de marcadores",
    "No bookmarked files" : "Non hai ficheiros en marcadores",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Os marcadores de ficheiros como as fotos ou os PDF gardaranse automaticamente nos seus ficheiros de Nextcloud, para que poida atopalos incluso cando a ligazón estea fóra de liña.",
    "Nothing found" : "Non se atopou ren",
    "Your search yielded no results in the current folder." : "A súa busca non deu ningún resultado no cartafol actual.",
    "No broken links" : "Non hai ligazóns rachadas",
    "No shared folders" : "Non hai cartafoles compartidos",
    "No duplicated bookmarks" : "Non hai marcadores duplicados",
    "No deleted bookmarks" : "Non hai marcadores eliminados",
    "You haven't deleted anything yet." : "Aínda non eliminou ren.",
    "No bookmarks here" : "Aquí non hai marcadores. ",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Engadir marcadores manualmente ou importar os marcadores dun ficheiro HTML.",
    "Archive path" : "Ruta do arquivo",
    "Backup path" : "Ruta á copia de seguranza",
    "Please select \"Add to home screen\" in your browser menu" : "Seleccione «Engadir na pantalla de inicio» no menú do seu navegador",
    "Bookmarks settings" : "Axustes de marcadores",
    "Import/Export" : "Importación/exportación",
    "Export bookmarks" : "Exportar os marcadores",
    "Auto-archiving" : "Arquivamento automático",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "A aplicación de marcadores pode arquivar automaticamente o contido web das ligazóns que marcou",
    "Enable archiving" : "Activa o arquivamento",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Introduza a ruta dun cartafol en Ficheiros onde se debe almacenar os ficheiros marcados.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "A administración desta instancia desactivou o acceso á rede para esta aplicación, polo que o arquivado automático está desactivado neste momento.",
    "Auto-Backup" : "Copia de seguranza automática",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "A aplicación de marcadores pode facer unha copia de seguranza automática dos seus marcadores a diario para evitar a perda de datos ao sincronizar os marcadores entre os dispositivos.",
    "Enable backups" : "Activar as copias de seguranza",
    "Enter the path of a folder in your Files where backups will be stored." : "Introduza a ruta dun cartafol en Ficheiros onde se debe almacenar as copias de seguranza.",
    "Context Chat integration" : "Integración da Parola de contexto",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "A aplicación de marcadores pode poñer automaticamente a disposición da Parola de contexto o contido textual dos sitios web que marque como favoritos, o que lle permite facer preguntas e obter respostas baseadas neses contidos. Isto só está dispoñíbel se o arquivo automático está activado.",
    "Context chat is currently not installed, but is required for this feature." : "A Parola de contexto non está instalada actualmente, mais é necesaria para esta funcionalidade.",
    "Enable Context Chat integration" : "Activar a integración da Parola de contexto",
    "Client apps" : "Aplicacións cliente ",
    "Also check out the collection of client apps that integrate with this app: " : "Consulte tamén a colección de aplicacións de clientes que se integran con esta aplicación:",
    "Install web app" : "Instalar a aplicación web",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Pode instalar esta aplicación na pantalla de inicio do seu dispositivo para acceder rapidamente aos seus marcadores no seu teléfono. Pode retirar doadamente a aplicación da pantalla de inicio, se non lle gusta.",
    "Install on home screen" : "Instalar na pantalla de inicio",
    "Bookmarklet" : "Marcapáxinas",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Arrastre isto cara aos marcadores do seu navegador e prema para marcar rapidamente unha páxina web",
    "Add to {instanceName}" : "Engadir a {instanceName}",
    "Need help?" : "Precisa axuda?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Se ten problemas con esta aplicación de Marcadores ou ten unha idea sobre o que se pode mellorar, non dubide en poñerse en contacto connosco premendo aquí.",
    "Support this project" : "Apoie este proxecto",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "O meu traballo nesta aplicación de Marcadores nútrese dun modelo de subscrición voluntaria. Se pensa que o que fago paga a pena, estaría encantado de que apoiaras o meu traballo. Ademais, considere facer algunha consideración sobre a aplicación na tenda de aplicacións de Nextcloud. Grazas 💙",
    "Created {time} ago" : "Creado hai {time}",
    "Created on {date}" : "Creado o {date}",
    "(Empty title)" : "(Título baleiro)",
    "Title" : "Título",
    "Link" : "Ligazón",
    "Untitled folder" : "Cartafol sen título",
    "Root folder" : "Cartafol raíz",
    "Tags" : "Etiquetas",
    "Select tags and create new ones" : "Seleccionar etiquetas e crear outras novas",
    "Notes" : "Notas",
    "Notes for this bookmark …" : "Notas para este marcador…",
    "Archived file" : "Ficheiro arquivado",
    "Open file" : "Abrir ficheiro",
    "Download file" : "Descargar ficheiros",
    "Open file location" : "Abrir a localización do ficheiro",
    "Link copied" : "Ligazón copiada",
    "Owner" : "Propietario",
    "Sharing" : "Compartindo",
    "Select a user or group" : "Seleccionar un usuario ou grupo",
    "Share link" : "Ligazón para compartir",
    "Reading allowed" : "Permitida a lectura",
    "Copy RSS feed" : "Copiar a fonte RSS",
    "Delete link" : "Eliminar ligazón",
    "Create public link" : "Crear ligazón pública",
    "Resharing allowed" : "Permítese volver compartir",
    "Editing allowed" : "Permitido editar",
    "Allow editing" : "Permitir a edición",
    "Allow resharing" : "Permitir volver compartir",
    "Remove share" : "Retirar a compartición",
    "Would you like to support this project?" : "Quere apoiar este proxecto?",
    "Leave a rating on the Nextcloud App Store" : "Deixa unha valoración na tenda de aplicacións de Nextcloud",
    "Failed to save settings" : "Produciuse un fallo ao gardar os axustes",
    "Failed to load settings" : "Produciuse un fallo ao cargar os axustes",
    "Privacy" : "Privacidade",
    "The app will try to access web pages that you add to automatically add information about them." : "A aplicación tentará acceder ás páxinas web que engada para engadir automaticamente información sobre elas.",
    "Enable accessing and collecting information from the web pages you add" : "Activar o acceso e a recollida de información das páxinas web que engada",
    "Performance" : "Rendemento",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Nunha instalación con moitos usuarios pode ser útil restrinxir o número de marcadores por conta.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Número máximo de marcadores permitidos por conta. (0 sen límite; o predeterminado é sen límite)",
    "Previews" : "Vistas previas",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "A fin de amosar capturas de pantalla reais dos tsus sitios web marcados, a aplicación pode usar servizos de terceiros para xerar vistas previas.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Pode rexistrarse gratuitamente en screeenly.com ou configurar o seu propio servidor.",
    "Screeenly API URL" : "URL da API Screeenly",
    "Screeenly API key" : "Chave da API Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Chave da API do ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL da API do Webshot",
    "Generic screenshot API" : "API xenérica de capturas de pantalla",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Rexístrase con calquera dos provedores de API de capturas de pantalla e poña o URL da API a seguir. Use a variábel {url} como marcador de substitución para o URL para a captura de pantalla. A API debe devolver só a imaxe directamente.",
    "Generic API URL" : "URL xenérica da API",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Simplemente instale a CLI de Pageres de Sindre Sorhus no seu servidor e Marcadores atoparao. Aínda pode engadir variábeis ENV (de contorno) adicionais para alimentar a pageres, por exemplo. como se indica no marcador de substitución:",
    "Pageres ENV variables" : "Variábeis ENV (de contorno) de Pageres",
    "This URL is already bookmarked! Overwrite?" : "Este URL xa existe como marcador! Sobrescribilo?",
    "Enter bookmark title" : "Introduza o título do marcador",
    "Enter bookmark URL" : "Introduza o URL do marcador",
    "Folder" : "Cartafol",
    "Root Folder" : "Cartafol raíz",
    "Save" : "Gardar",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "O acceso á rede está desactivado de xeito predeterminado. Vaia aos axustes do administrador da aplicación de marcadores para permitir a recuperación de vistas previas e favicons.",
    "What's new?" : "Que hai de novo?",
    "What" : "Que",
    "Failed to count unavailable bookmarks" : "Produciuse un fallo ao contar os marcadores non dispoñíbeis",
    "Failed to count archived bookmarks" : "Produciuse un fallo ao contar os marcadores arquivados",
    "Failed to count deleted bookmarks" : "Produciuse un fallo ao contar os marcadores eliminados",
    "Failed to count duplicated bookmarks" : "Produciuse un fallo ao contar os marcadores duplicados",
    "Failed to count bookmarks" : "Produciuse un fallo ao contar os marcadores",
    "Failed to load bookmark" : "Produciuse un fallo ao cargar o marcador",
    "Failed to find existing bookmark" : "Produciuse un fallo ao buscar un marcador existente",
    "Failed to create bookmark" : "Produciuse un fallo ao crear o marcador",
    "Failed to save bookmark" : "Produciuse un fallo ao gardar o marcador",
    "Failed to move bookmark" : "Produciuse un fallo ao mover os marcadores",
    "Failed to copy bookmark" : "Produciuse un fallo ao copiar o marcador",
    "Failed to delete bookmark" : "Produciuse un fallo ao eliminar os marcadores",
    "Failed to restore bookmark" : "Produciuse un fallo ao restaurar o marcador",
    "Import successful" : "Importouse satisfactoriamente",
    "Failed to rename tag" : "Produciuse un fallo ao cambiarlle o nome a etiqueta",
    "Failed to load tags" : "Produciuse un fallo ao cargar as etiquetas",
    "Failed to load folders" : "Produciuse un fallo ao cargar os cartafoles",
    "Failed to load deleted folders" : "Produciuse un fallo ao cargar os cartafoles eliminados",
    "Failed to load deleted bookmarks" : "Produciuse un fallo ao cargar os marcadores eliminados",
    "Failed to delete folder" : "Produciuse un fallo ao eliminar o cartafol",
    "Failed to move folder" : "Produciuse un fallo ao mover o cartafol",
    "Failed to restore folder" : "Produciuse un fallo ao restaurar o cartafol",
    "Failed to create folder" : "Produciuse un fallo ao crear o cartafol",
    "Failed to load children order" : "Produciuse un fallo ao cargar a orde dos fillos",
    "Failed to move parts of selection" : "Produciuse un fallo ao mover partes da selección",
    "Failed to copy parts of selection" : "Produciuse un fallo ao copiar partes da selección",
    "Failed to delete parts of selection" : "Produciuse un fallo ao eliminar partes da selección",
    "Failed to tag parts of selection" : "Produciuse un fallo ao etiquetar partes da selección",
    "Failed to fetch bookmarks." : "Produciuse un fallo ao recuperar os marcadores",
    "Failed to store setting" : "Produciuse un fallo ao almacenar o axuste",
    "Failed to load setting {key}" : "Produciuse un fallo ao cargar o axuste {key}",
    "Failed to create share for folder {folderId}" : "Produciuse un fallo ao crear a compartición para o cartafol {folderId}",
    "Failed to update share {shareId}" : "Produciuse un fallo ao actualizar a compartición {shareId}",
    "Failed to delete share {shareId}" : "Produciuse un fallo ao eliminar a compartición {shareId}",
    "Failed to create public link for folder {folderId}" : "Produciuse un fallo ao crear a ligazón pública para o cartafol {folderId}",
    "Failed to delete public link for folder {folderId}" : "Produciuse un fallo ao eliminar a ligazón pública para o cartafol {folderId}",
    "Failed to permanently delete parts of trash bin" : "Produciuse un fallo ao eliminar definitivamente partes do cesto do lixo",
    "Create bookmarks for mentioned links" : "Crear marcadores para as ligazóns mencionadas",
    "No links found in this message" : "Non se atopou ningunha ligazón nesta mensaxe",
    "Bookmarks feed" : "Fonte de marcadores"
},
"nplurals=2; plural=(n != 1);");
