<?php
$TRANSLATIONS = array(
"Bookmarks" => "Kirjanmerkit",
"Failed to import one bookmark, because: " => "Yhden kirjanmerkin tuominen epäonnistui, syy:",
"Bookm." => "Kirjanm.",
"No file provided for import" => "Yhtäkään tiedostoa ei määritetty tuotavaksi",
"Unsupported file type for import" => "Tuonti ei tue kyseistä tiedostotyyppiä",
"Some Error happened." => "Virhetilanne.",
"Error" => "Virhe",
"Tags" => "Tunnisteet",
"Filter by tag" => "Suodata tunnisteen perusteella",
"Are you sure you want to remove this bookmark?" => "Haluatko varmasti poistaa tämän kirjanmerkin?",
"Warning" => "Varoitus",
"Are you sure you want to remove this tag from every entry?" => "Haluatko varmasti poistaa tämän tunnisteen jokaiselta kohteelta?",
"Import error" => "Tuontivirhe",
"Import completed successfully." => "Tuonti valmistui onnistuneesti.",
"Uploading..." => "Lähetetään...",
"Add a bookmark" => "Lisää kirjanmerkki",
"This URL is already bookmarked! Overwrite?" => "Osoite on lisätty kirjanmerkkeihin. Korvataanko se?",
"The title of the page" => "Sivun otsikko",
"The address of the page" => "Sivun osoite",
"Description of the page" => "Sivun kuvaus",
"Save" => "Tallenna",
"Delete" => "Poista",
"Edit" => "Muokkaa",
"Cancel" => "Peru",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Vedä tämä selaimesi kirjanmerkkipalkkiin ja napsauta sitä, kun haluat lisätä kirjanmerkin nopeasti:",
"Add to ownCloud" => "Lisää ownCloudiin",
"Address" => "Osoite",
"Filterable Tags" => "Suodatettavat tunnisteet",
"You have no bookmarks" => "Sinulla ei ole kirjanmerkkejä",
"You can also import a bookmark file" => "Voit myös tuoda kirjanmerkkitiedoston",
"Bookmarklet" => "Kirjanmerkitsin",
"Export & Import" => "Vienti ja tuonti",
"Export" => "Vie",
"Import" => "Tuo"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
