<?php
$TRANSLATIONS = array(
"Bookmarks" => "Bladwijzers",
"Failed to import one bookmark, because: " => "Kon bladwijzer niet importeren omdat:",
"Bookm." => "Bladw.",
"No file provided for import" => "Geen bestand voor import opgegeven",
"Unsupported file type for import" => "Niet ondersteund bestandstype voor import",
"Some Error happened." => "Er trad een fout op.",
"Error" => "Fout",
"Tags" => "Tags",
"Filter by tag" => "Filter op tag",
"Are you sure you want to remove this bookmark?" => "Weet u zeker dat u de bladwijzer wilt verwijderen?",
"Warning" => "Waarschuwing",
"Are you sure you want to remove this tag from every entry?" => "Bent u zeker dat u deze tag van elk item wilt verwijderen.",
"Import error" => "Import fout",
"Import completed successfully." => "Het importeren is helemaal geslaagd",
"Uploading..." => "Uploading...",
"Add a bookmark" => "Voeg een bladwijzer toe",
"This URL is already bookmarked! Overwrite?" => "Deze URL bestaat al als bladwijzer, Overschrijven?",
"The title of the page" => "De pagina titel",
"The address of the page" => "Het pagina adres",
"Description of the page" => "Pagina beschrijving",
"Save" => "Bewaar",
"Delete" => "Verwijder",
"Edit" => "Bewerk",
"Cancel" => "Annuleer",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Sleep dit naar uw browser bladwijzer menu en klik erop, wanneer u een webpagina snel wilt voorzien van een bladwijzer:",
"Add to ownCloud" => "Toevoegen aan ownCloud",
"Address" => "Adres",
"Filterable Tags" => "Te filteren tages",
"You have no bookmarks" => "U heeft geen bladwijzers",
"You can also import a bookmark file" => "U kunt ook een bladwijzerbestand importeren",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Export & Import",
"Export" => "Exporteer",
"Import" => "Importeer"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
