OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Σελιδοδείκτες",
    "You bookmarked \"%s\"" : "Έχετε προσθέσει τον σελιδοδείκτη «%s»",
    "%1$s bookmarked \"%2$s\"" : "Ο %1$s πρόσθεσε τον σελιδοδείκτη «%2$s»",
    "Someone bookmarked \"%s\"" : "Κάποιος πρόσθεσε τον σελιδοδείκτη «%s»",
    "You deleted \"%s\"" : "Διεγράψατε το «%s»",
    "%1$s deleted \"%2$s\"" : "%1$s διέγραψε «%2$s»",
    "Someone deleted \"%s\"" : "Κάποιος διέγραψε «%s»",
    "You created folder \"%s\"" : "Δημιουργήσατε τον φάκελο «%s»",
    "%1$s created folder \"%2$s\"" : "Ο %1$s δημιούργησε φάκελο «%2$s»",
    "Someone created folder \"%s\"" : "Κάποιος δημιούργησε τον φάκελο «%s»",
    "You moved folder \"%s\"" : "Μετακινήσατε τον φάκελο «%s»",
    "%1$s moved folder \"%2$s\"" : "Ο %1$s μετακίνησε τον φάκελο «%2$s»",
    "Someone moved folder \"%s\"" : "Κάποιος μετακίνησε τον φάκελο «%s»",
    "You deleted folder \"%s\"" : "Διαγράψατε το φάκελο «%s»",
    "%1$s deleted folder \"%2$s\"" : "Ο %1$s διέγραψε το φάκελο «%2$s»",
    "Someone deleted folder \"%s\"" : "Κάποιος διέγραψε το φάκελο «%s»",
    "You shared folder \"%1$s\" with %2$s" : "Διαμοιράσατε το φάκελο «%1$s» με τον %2$s",
    "You shared folder \"%s\" with someone" : "Διαμοιράστε το φάκελο «%s» με κάποιον",
    "%1$s shared folder \"%2$s\" with you" : "Ο %1$s διαμοίρασε το φάκελο «%2$s» μαζί σας",
    "Someone shared folder \"%s\" with you" : "Κάποιος διαμοίρασε το φάκελο «%s» μαζί σας",
    "You unshared folder \"%1$s\" with %2$s" : "Καταργήσατε την κοινή χρήση του φακέλου «%1$s» με τον %2$s",
    "You unshared folder \"%s\" with someone" : "Καταργήσατε την κοινή χρήση του φακέλου «%s» με κάποιον",
    "%1$s unshared folder \"%2$s\" with you" : "Ο %1$s κατάργησε την κοινή χρήση του φακέλου «%2$s» μαζί σας",
    "Someone unshared folder \"%s\" with you" : "Κάποιος κατάργησε την κοινή χρήση του φακέλου «%s» μαζί σας",
    "No file provided for import" : "Κανένα αρχείο για εισαγωγή",
    "Failed to upload file" : "Αποτυχία μεταφόρτωσης αρχείου",
    "Unsupported file type for import: " : "Μη υποστηριζόμενος τύπος αρχείου για εισαγωγή: ",
    "Bookmarks shared by %s" : "Σελιδοδείκτες σε κοινή χρήση από %s",
    "Frequent bookmarks" : "Συχνοί σελιδοδείκτες",
    "Recent bookmarks" : "Τελευταίοι σελιδοδείκτες",
    "Bookmark" : "Σελιδοδείκτης",
    "Bookmark deleted" : "Ο σελιδοδείκτης διαγράφηκε",
    "Bookmark created" : "Ο σελιδοδείκτης δημιουργήθηκε",
    "Bookmark moved" : "Ο σελιδοδείκτης μετακινήθηκε",
    "Bookmark updated" : "Ο σελιδοδείκτης ενημερώθηκε",
    "Create bookmark" : "Δημιουργία σελιδοδείκτη",
    "Takes a link and adds it to your collection of bookmarks." : "Αυτή η ενέργεια, παίρνει έναν σύνδεσμο και τον προσθέτει στη συλλογή των σελιδοδεικτών σας.",
    "Bookmarks Backups" : "Αντίγραφα ασφαλείας σελιδοδεικτών",
    "Collect and manage bookmarks, synced with all your devices" : "Συλλογή και διαχείριση σελιδοδεικτών, συγχρονισμένων με όλες τις συσκευές σας",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Ταξινόμηση σελιδοδεικτών σε φακέλους\n- 🏷 Προσθήκη ετικετών και προσωπικών σημειώσεων\n- ☠ Εύρεση σπασμένων συνδέσμων και διπλοτυπιών\n- 📲 Συγχρονισμός με όλα τα προγράμματα περιήγησης και συσκευές σας\n- 📔 Αποθήκευση αρχειοθετημένων εκδόσεων των συνδέσμων σας σε περίπτωση που αποσυρθούν\n- 🔍 Πλήρης αναζήτηση κειμένου στα περιεχόμενα ιστοτόπων\n- 👪 Κοινή χρήση σελιδοδεικτών με άλλους χρήστες, ομάδες και ομάδες ή μέσω δημόσιων συνδέσμων\n- ⚛ Δημιουργία ροών RSS από τις συλλογές σας\n- 📈 Στατιστικά για το πόσο συχνά προσπελάζετε συγκεκριμένους συνδέσμους\n- 🔒 Αυτόματα αντίγραφα ασφαλείας της συλλογής σελιδοδεικτών σας\n- 💼 Ενσωματωμένα widgets Πίνακα Ελέγχου για συχνές και πρόσφατες συνδέσεις\n\nΑπαιτήσεις:\n - Επεκτάσεις PHP:\n   - intl: *\n   - mbstring: *\n - όταν χρησιμοποιείτε MySQL, χρησιμοποιήστε τουλάχιστον έκδοση 8.0",
    "Do you really want to delete this bookmark?" : "Θέλετε πραγματικά να διαγράψετε αυτόν τον σελιδοδείκτη;",
    "Link copied to clipboard" : "Ο σύνδεσμος αντιγράφηκε στο πρόχειρο",
    "Enter new title" : "Εισάγετε νέο τίτλο",
    "Select bookmark" : "Επιλογή σελιδοδείκτη",
    "You have never clicked this link" : "Δεν έχετε κάνει ποτέ κλικ σε αυτόν τον σύνδεσμο",
    "You have clicked this link {count} times" : "Έχετε κάνει κλικ σε αυτόν τον σύνδεσμο {count} φορές",
    "Details" : "Λεπτομέρειες",
    "Rename" : "Μετονομασία",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Move" : "Μετακίνηση",
    "Add to folders" : "Προσθήκη σε φακέλους",
    "Put bookmark into trash bin" : "Μετακίνηση σελιδοδείκτη στον κάδο ανακύκλωσης",
    "Restore bookmark" : "Επαναφορά σελιδοδείκτη",
    "Delete bookmark permanently" : "Μόνιμη διαγραφή σελιδοδείκτη",
    "Content pending" : "Περιεχόμενο σε εκκρεμότητα",
    "This content is being downloaded for offline use. Please check back later." : "Αυτό το περιεχόμενο κατεβαίνει για χρήση εκτός σύνδεσης. Ελέγξτε ξανά αργότερα.",
    "Bookmarked {time} ago" : "Προστέθηκε σελιδοδείκτης πριν από {time}",
    "Bookmarked on {date}" : "Προστέθηκε σελιδοδείκτης στις {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Αυτά είναι τα διαγεγραμμένα αντικείμενά σας. Τα αντικείμενα θα διαγραφούν μόνιμα μετά από δύο μήνες.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Οι σελιδοδείκτες για αρχεία στο διαδίκτυο, όπως φωτογραφίες ή PDF, θα αποθηκεύονται αυτόματα στα αρχεία του Nextcloud σας, ώστε να μπορείτε να τα βρείτε ακόμα και όταν ο σύνδεσμος δεν είναι διαθέσιμος.",
    "Searching in the current folder only." : "Αναζήτηση μόνο στον τρέχοντα φάκελο.",
    "Repeat search in all folders" : "Επανάληψη αναζήτησης σε όλους τους φακέλους",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Οι σελιδοδείκτες ελέγχονται τακτικά και αυτοί που δεν είναι προσβάσιμοι εμφανίζονται εδώ.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Μπορείτε να μοιραστείτε φακέλους σελιδοδεικτών με άλλους. Όλοι οι φάκελοι που έχουν μοιραστεί μαζί σας εμφανίζονται εδώ.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Ένας σελιδοδείκτης μπορεί να βρίσκεται σε πολλούς φακέλους ταυτόχρονα. Η ενημέρωσή του θα ενημερώσει όλα τα αντίγραφα. Όλοι οι διπλότυποι σελιδοδείκτες εμφανίζονται εδώ για ευκολία.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Επιλεγμένοι {folders} φάκελοι και {bookmarks} σελιδοδείκτες",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
    "_Selected %n folder_::_Selected %n folders_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
    "Do you really want to delete these items?" : "Θέλετε πραγματικά να διαγράψετε αυτά τα στοιχεία;",
    "Open all selected" : "Άνοιγμα των επιλεγμένων",
    "Move selection" : "Μετακίνηση επιλογής",
    "Edit tags of selection" : "Επεξεργασία ετικετών για τα επιλεγμένα",
    "Delete selection" : "Διαγραφή επιλογής",
    "Select all" : "Επιλογή όλων",
    "Cancel selection" : "Ακύρωση επιλογής",
    "Sort by created date" : "Ταξινόμηση κατά ημερομηνία δημιουργίας",
    "Sort by last modified" : "Ταξινόμηση κατά τελευταία τροποποίηση",
    "Sort by title" : "Ταξινόμηση κατά τίτλο",
    "Sort by click count" : "Ταξινόμηση κατά μέτρηση κλικ",
    "Sort by manual order" : "Ταξινόμηση κατά χειροκίνητη σειρά",
    "Sort by URL" : "Ταξινόμηση κατά URL",
    "RSS feed copied" : "Η ροή πληροφοριών RSS αντιγράφηκε",
    "Trash Bin" : "Κάδος Ανακύκλωσης",
    "Go back" : "Επιστροφή",
    "Share folder" : "Διαμοιρασμός φακέλου",
    "Open folder details" : "Άνοιγμα λεπτομερειών φακέλου",
    "Select one or more tags" : "Επιλέξτε μία ή περισσότερες ετικέτες",
    "New" : "Νέα",
    "New bookmark" : "Νέος σελιδοδείκτης",
    "New folder" : "Νέος φάκελος",
    "Change to grid view" : "Αλλαγή σε προβολή πλέγματος",
    "Change to list view" : "Αλλαγή σε προβολή λίστας",
    "Copy RSS Feed of current view" : "Αντιγραφή ροής RSS της τρέχουσας προβολής",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Η ροή RSS απαιτεί πιστοποίηση με τα διαπιστευτήρια Nextcloud σας",
    "Search" : "Αναζήτηση",
    "Empty trash bin" : "Άδειασμα κάδου",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Προσθήκη %n σελιδοδείκτη σε νέο φάκελο","Προσθήκη %n σελιδοδεικτών σε νέο φάκελο"],
    "Enter a link" : "Εισάγετε σύνδεσμο",
    "Enter a title" : "Εισάγετε ένα τίτλο",
    "No bookmarks found" : "Δεν βρέθηκαν σελιδοδείκτες",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} φάκελοι και {bookmarks} σελιδοδείκτες",
    "_%n bookmark_::_%n bookmarks_" : ["%n σελιδοδείκτης","%n σελιδοδείκτες"],
    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
    "Welcome to Bookmarks" : "Καλώς ορίσατε στους Σελιδοδείκτες",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Αυτή η εφαρμογή σας επιτρέπει να διαχειρίζεστε συνδέσμους προς τους αγαπημένους σας προορισμούς στο διαδίκτυο. Ταξινομήστε τους σελιδοδείκτες σας σε φακέλους, επισημάνετε τους με ετικέτες και μοιραστείτε τους με άλλους! Η εφαρμογή θα ελέγχει τακτικά όλους τους συνδέσμους σας για διαθεσιμότητα και θα εμφανίζει τους μη διαθέσιμους. Εάν προσθέσετε ένα σύνδεσμο προς ένα αρχείο στο διαδίκτυο, το αρχείο θα κατεβαίνει αυτόματα στα Αρχεία του Nextcloud σας. Μπορείτε επίσης να εισάγετε σελιδοδείκτες που έχουν εξαχθεί από άλλες υπηρεσίες ή να συγχρονίσετε απευθείας σελιδοδείκτες από όλα τα προγράμματα περιήγησής σας με αυτήν την εφαρμογή.",
    "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
    "Import bookmarks" : "Εισαγωγή σελιδοδεικτών",
    "Sync with your browser" : "Συγχρονισμός με τον περιηγητή σας",
    "Do you really want to permanently delete this folder?" : "Θέλετε σίγουρα να διαγράψετε μόνιμα αυτόν τον φάκελο;",
    "Select folder" : "Επιλογή φακέλου",
    "Enter folder title" : "Τίτλος φακέλου",
    "Shared by {user}" : "Διαμοιράστηκε από {user}",
    "Rename folder" : "Μετονομασία φακέλου",
    "Move folder" : "Μετακίνηση φακέλου",
    "Put folder into trashbin" : "Μετακίνηση φακέλου στον κάδο ανακύκλωσης",
    "Restore folder" : "Επαναφορά φακέλου",
    "Delete folder permanently" : "Μόνιμη διαγραφή φακέλου",
    "Choose folder" : "Επιλογή φακέλου",
    "Submit" : "Υποβολή",
    "Cancel" : "Ακύρωση",
    "Deleting bookmarks" : "Γίνεται διαγραφή σελιδοδεικτών",
    "Deleting selection" : "Γίνεται διαγραφή της επιλογής",
    "Importing bookmarks" : "Γίνεται εισαγωγή σελιδοδεικτών",
    "Moving selection" : "Γίνεται μετακίνηση της επιλογής",
    "Adding selection to folders" : "Προσθήκη επιλογής σε φακέλους",
    "Emptying trashbin" : "Αδειάζει ο κάδος ανακύκλωσης",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Μετακίνηση %n φακέλου και μερικων σελιδοδεικτών","Μετακίνηση %nφακέλων και μερικων σελιδοδεικτών"],
    "_Moving %n folder_::_Moving %n folders_" : ["Μετακίνηση %n φακέλου","Μετακίνηση %n φακέλων"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Μετακίνηση %n σελιδοδείκτη","Μετακίνηση %n σελιδοδεικτών"],
    "All bookmarks" : "Όλοι οι σελιδοδείκτες",
    "Recent" : "Πρόσφατα",
    "Shared with you" : "Διαμοιράστηκε με σας",
    "Files" : "Αρχεία",
    "Duplicates" : "Διπλότυπα",
    "Broken links" : "Κατεστραμμένοι σύνδεσμοι",
    "New tag" : "Νέα ετικέτα",
    "Search tags" : "Ετικέτες αναζήτησης",
    "Delete" : "Διαγραφή",
    "Untagged" : "Χωρίς ετικέτα",
    "{used} bookmarks of {available} available" : "Διαθέσιμοι  {available} σελιδοδείκτες από {used}",
    "Bookmarks Settings" : "Ρυθμίσεις Σελιδοδεικτών",
    "No bookmarked files" : "Δεν υπάρχουν αρχεία με σελιδοδείκτες",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Οι σελιδοδείκτες σε αρχεία όπως φωτογραφίες ή PDF θα αποθηκευτούν αυτόματα στα αρχεία Nextcloud, ώστε να μπορείτε να τα βρείτε ακόμα και όταν ο σύνδεσμος είναι εκτός σύνδεσης.",
    "Nothing found" : "Δεν βρέθηκε τίποτα",
    "Your search yielded no results in the current folder." : "Η αναζήτησή σας δεν επέστρεψε αποτελέσματα στον τρέχοντα φάκελο.",
    "No broken links" : "Δεν υπάρχουν σπασμένοι σύνδεσμοι",
    "No shared folders" : "Δεν υπάρχουν κοινόχρηστοι φάκελοι",
    "No duplicated bookmarks" : "Δεν υπάρχουν διπλότυποι σελιδοδείκτες",
    "No deleted bookmarks" : "Δεν υπάρχουν διαγεγραμμένοι σελιδοδείκτες",
    "You haven't deleted anything yet." : "Δεν έχετε διαγράψει τίποτα ακόμα.",
    "No bookmarks here" : "Δεν υπάρχουν σελιδοδείκτες εδώ",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Προσθέστε σελιδοδείκτες χειροκίνητα ή εισάγετε σελιδοδείκτες από αρχείο HTML.",
    "Archive path" : "Διαδρομή φακέλου αρχειοθέτησης",
    "Backup path" : "Διαδρομή αντιγράφου ασφαλείας",
    "Please select \"Add to home screen\" in your browser menu" : "Παρακαλούμε επιλέξτε «Προσθήκη στην αρχική οθόνη» από το μενού του περιηγητή",
    "Bookmarks settings" : "Ρυθμίσεις σελιδοδεικτών",
    "Import/Export" : "Εισαγωγή/Εξαγωγή",
    "Export bookmarks" : "Εξαγωγή σελιδοδεικτών",
    "Auto-archiving" : "Αυτόματη αρχειοθέτηση",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Η εφαρμογή σελιδοδεικτών μπορεί να αρχειοθετεί αυτόματα το περιεχόμενο των συνδέσμων που έχετε προσθέσει ως σελιδοδείκτες",
    "Enable archiving" : "Ενεργοποίηση αρχειοθέτησης",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Εισάγετε τη διαδρομή ενός φακέλου στα Αρχεία σας όπου θα αποθηκεύονται τα αρχεία με σελιδοδείκτες.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Προς το παρόν ο διαχειριστής σας έχει απενεργοποιήσει την πρόσβαση στο δίκτυο για αυτήν την εφαρμογή, γι' αυτό και η Αυτόματη αρχειοθέτηση είναι προς το παρόν απενεργοποιημένη.",
    "Auto-Backup" : "Αυτόματο αντίγραφο ασφαλείας",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Η εφαρμογή σελιδοδεικτών μπορεί να δημιουργεί αυτόματα αντίγραφα ασφαλείας των σελιδοδεικτών σας καθημερινά για να αποτρέψει την απώλεια δεδομένων κατά τον συγχρονισμό σελιδοδεικτών μεταξύ συσκευών.",
    "Enable backups" : "Ενεργοποίηση αντιγράφων ασφαλείας",
    "Enter the path of a folder in your Files where backups will be stored." : "Εισάγετε τη διαδρομή ενός φακέλου στα Αρχεία σας όπου θα αποθηκεύονται τα αντίγραφα ασφαλείας.",
    "Context Chat integration" : "Ενσωμάτωση με Context Chat",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Η εφαρμογή σελιδοδεικτών μπορεί να κάνει διαθέσιμα αυτόματα τα κειμενικά περιεχόμενα των ιστοτόπων που προσθέτετε ως σελιδοδείκτες στο Context Chat, το οποίο επιτρέπει την υποβολή ερωτήσεων και λήψη απαντήσεων βασισμένων σε αυτά τα περιεχόμενα. Αυτό είναι διαθέσιμο μόνο εάν η αυτόματη αρχειοθέτηση είναι ενεργοποιημένη.",
    "Context chat is currently not installed, but is required for this feature." : "Το Context chat δεν είναι εγκατεστημένο προς το παρόν, αλλά απαιτείται για αυτήν τη λειτουργία.",
    "Enable Context Chat integration" : "Ενεργοποίηση ενσωμάτωσης με Context Chat",
    "Client apps" : "Εφαρμογές πελάτη",
    "Also check out the collection of client apps that integrate with this app: " : "Ελέγξτε επίσης τη συλλογή των εφαρμογών που ενσωματώνονται με αυτήν την εφαρμογή: ",
    "Install web app" : "Εγκατάσταση εφαρμογής ιστού",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Μπορείτε να εγκαταστήσετε αυτήν την εφαρμογή στην αρχική οθόνη της συσκευής σας για γρήγορη πρόσβαση στους σελιδοδείκτες σας στο τηλέφωνό σας. Μπορείτε εύκολα να αφαιρέσετε ξανά την εφαρμογή από την αρχική οθόνη, αν δεν σας αρέσει.",
    "Install on home screen" : "Εγκατάσταση στην αρχική οθόνη",
    "Bookmarklet" : "Εφαρμογίδιο Σελιδοδεικτών",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Σύρετε αυτό στους σελιδοδείκτες του προγράμματος περιήγησής σας και κάντε κλικ σε αυτό για να προσθέσετε γρήγορα μια ιστοσελίδα στους σελιδοδείκτες.",
    "Add to {instanceName}" : "Προσθήκη στο {instanceName}",
    "Need help?" : "Θέλετε βοήθεια;",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Εάν έχετε προβλήματα με αυτήν την εφαρμογή Σελιδοδεικτών ή έχετε μια ιδέα για βελτίωση, μη διστάσετε να επικοινωνήσετε κάνοντας κλικ εδώ.",
    "Support this project" : "Υποστηρίξτε αυτό το έργο",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Η δουλειά μου σε αυτήν την εφαρμογή Σελιδοδεικτών τροφοδοτείται από ένα προαιρετικό μοντέλο συνδρομής. Εάν πιστεύετε ότι αυτό που κάνω αξίζει, θα χαιρόμουν αν μπορούσατε να υποστηρίξετε τη δουλειά μου. Επίσης, παρακαλώ σκεφτείτε να αφήσετε μια κριτική για την εφαρμογή στο κατάστημα εφαρμογών του Nextcloud. Σας ευχαριστώ 💙",
    "Created {time} ago" : "Δημιουργήθηκε πριν {time}",
    "Created on {date}" : "Δημιουργήθηκε στις {date}",
    "(Empty title)" : "(Κενός τίτλος)",
    "Title" : "Τίτλος",
    "Link" : "Σύνδεσμος",
    "Untitled folder" : "Φάκελος χωρίς τίτλο",
    "Root folder" : "Αρχικός φάκελος",
    "Tags" : "Ετικέτες",
    "Select tags and create new ones" : "Επιλέξτε ετικέτες και δημιουργήστε νέες",
    "Notes" : "Σημειώσεις",
    "Notes for this bookmark …" : "Σημειώσεις για αυτό το σελιδοδείκτη …",
    "Archived file" : "Αρχειοθετημένο αρχείο",
    "Open file" : "Άνοιγμα αρχείου",
    "Download file" : "Λήψη αρχείου",
    "Open file location" : "Άνοιγμα τοποθεσίας αρχείου",
    "Link copied" : "Ο σύνδεσμος αντιγράφηκε",
    "Owner" : "Κάτοχος",
    "Sharing" : "Διαμοιρασμός",
    "Select a user or group" : "Επιλογή χρήστη ή ομάδας",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Reading allowed" : "Επιτρέπεται η ανάγνωση",
    "Copy RSS feed" : "Αντιγραφή ροής πληροφοριών RSS",
    "Delete link" : "Διαγραφή συνδέσμου",
    "Create public link" : "Δημιουργία δημόσιου συνδέσμου",
    "Resharing allowed" : "Επιτρέπεται η αναδημοσίευση",
    "Editing allowed" : "Επιτρέπεται η επεξεργασία",
    "Allow editing" : "Επιτρέπεται η επεξεργασία",
    "Allow resharing" : "Επιτρέπεται ο επαναδιαμοιρασμός",
    "Remove share" : "Κατάργηση διαμοιρασμού",
    "Leave a rating on the Nextcloud App Store" : "Αφήστε μια βαθμολογία στο Nextcloud App Store",
    "Failed to save settings" : "Αποτυχία αποθήκευσης ρυθμίσεων",
    "Failed to load settings" : "Αποτυχία φόρτωσης ρυθμίσεων",
    "Privacy" : "Ιδιωτικότητα",
    "The app will try to access web pages that you add to automatically add information about them." : "Η εφαρμογή θα προσπαθήσει να αποκτήσει πρόσβαση σε ιστοσελίδες που προσθέτετε για να συλλέξει αυτόματα πληροφορίες σχετικά με αυτές.",
    "Enable accessing and collecting information from the web pages you add" : "Ενεργοποίηση πρόσβασης και συλλογής πληροφοριών από τις ιστοσελίδες που προσθέτετε",
    "Performance" : "Απόδοση",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Σε μια εγκατάσταση με πολλούς χρήστες μπορεί να είναι χρήσιμο να περιοριστεί ο αριθμός των σελιδοδεικτών ανά λογαριασμό.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Μέγιστος επιτρεπόμενος αριθμός σελιδοδεικτών ανά λογαριασμό. (0 χωρίς όριο; η προεπιλογή δεν έχει όριο)",
    "Previews" : "Προεπισκοπήσεις",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Για να εμφανίζει πραγματικά στιγμιότυπα οθόνης των ιστοτόπων που έχετε προσθέσει ως σελιδοδείκτες, η εφαρμογή μπορεί να χρησιμοποιήσει υπηρεσίες τρίτων για τη δημιουργία προεπισκοπήσεων.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Μπορείτε να εγγραφείτε δωρεάν στο screeenly.com είτε να ρυθμίσετε το δικό σας διακομιστή.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Κλειδί Screeenly API",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Γενική API για στιγμιότυπα οθόνης",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Εγγραφείτε σε οποιονδήποτε από τους πάροχους API για στιγμιότυπα οθόνης και τοποθετήστε τη διεύθυνση API παρακάτω. Χρησιμοποιήστε τη μεταβλητή {url} ως placeholder για τη διεύθυνση URL που θέλετε να καταγράψετε. Το API πρέπει να επιστρέφει μόνο την εικόνα απευθείας.",
    "Generic API URL" : "Γενική διεύθυνση API",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Απλά εγκαταστήστε το Pageres CLI του Sindre Sorhus στον διακομιστή σας και οι Σελιδοδείκτες θα το βρουν. Μπορείτε ακόμα να προσθέσετε επιπλέον μεταβλητές περιβάλλοντος για το pageres, π.χ. όπως υποδεικνύεται στο placeholder:",
    "Pageres ENV variables" : "Μεταβλητές περιβάλλοντος Pageres",
    "This URL is already bookmarked! Overwrite?" : "Υπάρχει ήδη σελιδοδείκτης με αυτή τη διεύθυνση URL! Αντικατάσταση;",
    "Enter bookmark title" : "Καταχωρίστε έναν τίτλο σελιδοδείκτη",
    "Enter bookmark URL" : "Καταχωρίστε τη διεύθυνση URL σελιδοδείκτη",
    "Folder" : "Φάκελος",
    "Root Folder" : "Αρχικός φάκελος",
    "Save" : "Αποθήκευση",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Η πρόσβαση στο δίκτυο είναι απενεργοποιημένη από προεπιλογή. Μεταβείτε στις ρυθμίσεις διαχειριστή για την εφαρμογή σελιδοδεικτών για να επιτρέψετε την ανάκτηση προεπισκοπήσεων και favicons.",
    "What's new?" : "Τι νέο υπάρχει;",
    "What" : "Τι να κάνετε",
    "Failed to count unavailable bookmarks" : "Αποτυχία μέτρησης μη διαθέσιμων σελιδοδεικτών",
    "Failed to count archived bookmarks" : "Αποτυχία μέτρησης αρχειοθετημένων σελιδοδεικτών",
    "Failed to count duplicated bookmarks" : "Αποτυχία μέτρησης διπλότυπων σελιδοδεικτών",
    "Failed to count bookmarks" : "Αποτυχία μέτρησης σελιδοδεικτών",
    "Failed to load bookmark" : "Αποτυχία φόρτωσης σελιδοδείκτη",
    "Failed to find existing bookmark" : "Απέτυχε η εύρεση υπάρχοντος σελιδοδείκτη",
    "Failed to create bookmark" : "Απέτυχε η δημιουργία σελιδοδείκτη",
    "Failed to save bookmark" : "Απέτυχε η αποθήκευση σελιδοδείκτη",
    "Failed to move bookmark" : "Απέτυχε η μετακίνηση σελιδοδείκτη",
    "Failed to copy bookmark" : "Απέτυχε η αντιγραφή σελιδοδείκτη",
    "Failed to delete bookmark" : "Απέτυχε η διαγραφή σελιδοδείκτη",
    "Failed to restore bookmark" : "Απέτυχε η επαναφορά σελιδοδείκτη",
    "Import successful" : "Επιτυχής εισαγωγή",
    "Failed to rename tag" : "Αποτυχία μετονομασίας ετικέτας",
    "Failed to load tags" : "Απέτυχε η φόρτωση ετικετών",
    "Failed to load folders" : "Απέτυχε η φόρτωση φακέλων",
    "Failed to load deleted folders" : "Απέτυχε η φόρτωση διαγεγραμμένων φακέλων",
    "Failed to load deleted bookmarks" : "Απέτυχε η φόρτωση διαγεγραμμένων σελιδοδεικτών",
    "Failed to delete folder" : "Απέτυχε η διαγραφή φακέλου",
    "Failed to move folder" : "Απέτυχε η μετακίνηση φακέλου",
    "Failed to restore folder" : "Απέτυχε η επαναφορά φακέλου",
    "Failed to create folder" : "Απέτυχε η δημιουργία φακέλου",
    "Failed to load children order" : "Απέτυχε η φόρτωση σειράς υποστοιχείων",
    "Failed to move parts of selection" : "Απέτυχε η μετακίνηση μέρους της επιλογής",
    "Failed to copy parts of selection" : "Απέτυχε η αντιγραφή μέρους της επιλογής",
    "Failed to delete parts of selection" : "Απέτυχε η διαγραφή μέρους της επιλογής",
    "Failed to tag parts of selection" : "Απέτυχε η προσθήκη ετικετών σε μέρος της επιλογής",
    "Failed to fetch bookmarks." : "Αποτυχία λήψης σελιδοδεικτών.",
    "Failed to store setting" : "Αποτυχία αποθήκευσης ρύθμισης",
    "Failed to load setting {key}" : "Αποτυχία φόρτωσης ρύθμισης {key}",
    "Failed to create share for folder {folderId}" : "Αποτυχία δημιουργίας κοινόχρηστου για φάκελο {folderId}",
    "Failed to update share {shareId}" : "Αποτυχία ενημέρωσης κοινόχρηστου {shareId}",
    "Failed to delete share {shareId}" : "Αποτυχία διαγραφής κοινόχρηστου {shareId}",
    "Failed to create public link for folder {folderId}" : "Αποτυχία δημιουργίας δημόσιου συνδέσμου για φάκελο {folderId}",
    "Failed to delete public link for folder {folderId}" : "Αποτυχία διαγραφής δημόσιου συνδέσμου για φάκελο {folderId}",
    "Failed to permanently delete parts of trash bin" : "Αποτυχία μόνιμης διαγραφής μερών του κάδου ανακύκλωσης",
    "Create bookmarks for mentioned links" : "Δημιουργία σελιδοδεικτών για αναφερόμενους συνδέσμους",
    "No links found in this message" : "Δεν βρέθηκαν σύνδεσμοι σε αυτό το μήνυμα",
    "Bookmarks feed" : "Ροή σελιδοδεικτών"
},
"nplurals=2; plural=(n != 1);");
