<?php
$TRANSLATIONS = array(
"Bookmarks" => "Markah",
"Bookm." => "Markah",
"No file provided for import" => "Tidak ada berkas untuk diimpor",
"Unsupported file type for import" => "Tipe berkas tidak didukung untuk diimpor",
"Some Error happened." => "Terjadi beberapa kesalahan.",
"Error" => "Kesalahan",
"Tags" => "Tag",
"Filter by tag" => "Filter berdasar tag",
"Are you sure you want to remove this bookmark?" => "Apakah Anda yakin ingin menghapus markah ini?",
"Warning" => "Peringatan",
"Are you sure you want to remove this tag from every entry?" => "Yakin ingin menghapus tag ini dari semua entri?",
"Import error" => "Galat ketika mengimpor",
"Import completed successfully." => "Proses impor selesai dengan sukses.",
"Uploading..." => "Mengunggah...",
"Add a bookmark" => "Tambah markah",
"This URL is already bookmarked! Overwrite?" => "URL ini telah di markahi! Timpa?",
"The title of the page" => "Judul halaman",
"The address of the page" => "Alamat halaman",
"Description of the page" => "Deskripsi halaman",
"Save" => "Simpan",
"Delete" => "Hapus",
"Edit" => "Sunting",
"Cancel" => "Batal",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Seret ke bilah alat markah peramban Anda untuk diklik, jika Anda ingin membuat markah halaman web dengan cepat:",
"Add to ownCloud" => "Tambah ke ownCloud",
"Address" => "Alamat",
"Filterable Tags" => "Tag dapat Disaring",
"You have no bookmarks" => "Anda tidak punya markah",
"You can also import a bookmark file" => "Anda juga dapat mengimpor berkas markah",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Ekspor & Impor",
"Export" => "Ekspor",
"Import" => "Impor"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
