<?php
$TRANSLATIONS = array(
"Bookmarks" => "Adreces d'interès",
"Bookm." => "Marcador",
"No file provided for import" => "No heu proporcionat cap fitxer a importar",
"Unsupported file type for import" => "Importació d'un tipus de fitxer no implementat",
"Some Error happened." => "Hi ha hagut algun error.",
"Error" => "Error",
"Tags" => "Etiquetes",
"Filter by tag" => "Filtrat per etiqueta",
"Are you sure you want to remove this bookmark?" => "Estàs segur de que vols eliminar aquest marcador?",
"Warning" => "Avís",
"Are you sure you want to remove this tag from every entry?" => "Segur que voleu eliminar aquesta etiqueta de cada entrada?",
"Import error" => "Error en importar",
"Import completed successfully." => "La importació ha acabat amb èxit",
"Uploading..." => "Pujant...",
"Add a bookmark" => "Afegeix una adreça d'interès",
"This URL is already bookmarked! Overwrite?" => "Aquesta URL ja és un marcador! Sobreescriure?",
"The title of the page" => "El títol de la pàgina",
"The address of the page" => "L'adreça de la pàgina",
"Description of the page" => "Descripció de la pàgina",
"Save" => "Desa",
"Delete" => "Esborra",
"Edit" => "Edita",
"Cancel" => "Cancel·la",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Arrossegueu-ho al navegador i feu-hi un clic quan volgueu marcar ràpidament una adreça d'interès:",
"Add to ownCloud" => "Afegeix a ownCloud",
"Address" => "Adreça",
"Filterable Tags" => "Etiquetes filtrables",
"You have no bookmarks" => "No teniu adreces d'interès",
"You can also import a bookmark file" => "També pots importar un arxiu de marcador",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Exporta i importa",
"Export" => "Exporta",
"Import" => "Importa"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
