OC.L10N.register(
    "bookmarks",
    {
    "Rename" : "﻿ಮರುಹೆಸರಿಸು",
    "Move" : "Move",
    "Select all" : "﻿ಎಲ್ಲಾ ಆಯ್ಕೆ ಮಾಡಿ",
    "New" : "﻿ಹೊಸ",
    "New folder" : "﻿ಹೊಸ ಕೋಶ",
    "Search" : "Search",
    "_%n folder_::_%n folders_" : ["%n ಕೋಶ(ಗಳು)","%n ಕೋಶ(ಗಳು)"],
    "Cancel" : "﻿ರದ್ದು",
    "Shared with you" : "Shared with you",
    "Files" : "ಕಡತಗಳು",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Title" : "ಶೀರ್ಷಿಕೆ",
    "Link" : "ಸಂಪರ್ಕ ಕೊಂಡಿ",
    "Notes" : "Notes",
    "Owner" : "Owner",
    "Sharing" : "﻿ಹಂಚಿಕೆ",
    "Share link" : "ಸಂಪರ್ಕ ಕೊಂಡಿಯನ್ನು  ﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
    "Allow editing" : "﻿ಸಂಪಾದನೆಗೆ ಅವಕಾಶ ಮಾಡಿಕೊಡಿ",
    "Folder" : "ಕೋಶ",
    "Save" : "﻿ಉಳಿಸಿ"
},
"nplurals=2; plural=(n > 1);");
