<?php
$TRANSLATIONS = array(
"Bookmarks" => "Žymekliai",
"Bookm." => "Žym.",
"No file provided for import" => "Nepateiktas failas importavimui",
"Unsupported file type for import" => "Netinkamas failo tipas importavimui",
"Some Error happened." => "Įvyko keletas klaidų.",
"Error" => "Klaida",
"Tags" => "Žymės",
"Filter by tag" => "Filtruoti pagal žymę",
"Warning" => "Įspėjimas",
"Import error" => "Importavimo klaida",
"Import completed successfully." => "Importavimas baigtas sėkmingai.",
"Uploading..." => "Įkeliama...",
"Add a bookmark" => "Pridėti žymelę",
"The title of the page" => "Puslapio antraštė",
"The address of the page" => "Puslapio adresas",
"Description of the page" => "Puslapio aprašymas",
"Save" => "Išsaugoti",
"Delete" => "Ištrinti",
"Edit" => "Redaguoti",
"Cancel" => "Atšaukti",
"Add to ownCloud" => "Pridėti į ownCloud",
"Address" => "Adresas",
"You have no bookmarks" => "Jūs neturite žymelių",
"Export & Import" => "Eksportavimas / Importavimas",
"Export" => "Eksportuoti",
"Import" => "Importuoti"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);";
