"use strict";(self.webpackChunkbookmarks=self.webpackChunkbookmarks||[]).push([["src_components_CustomPickerElement_vue"],{61279(e,t,s){s.d(t,{default:()=>i});var c=s(16269),o=s(66802),a=s(63814);const r={name:"CustomPickerElement",components:{NcSearch:c.oM},mounted(){setTimeout(()=>{this.$refs.picker?.focus()},300)},methods:{cancelSearch(){this.$emit("cancel")},async submitLink(e){const t=await o.Ay.get((0,a.Jv)("/apps/bookmarks/bookmark/"+e.slice(e.lastIndexOf("/")+1)));this.$emit("submit",t.data.item.url)}}};const i=(0,s(14486).A)(r,function(){var e=this,t=e._self._c;return t("div",{staticStyle:{width:"100%"}},[t("NcSearch",{ref:"picker",attrs:{provider:{search_providers_ids:["bookmarks"],title:e.t("bookmarks","Bookmarks")}},on:{cancel:e.cancelSearch,submit:e.submitLink}})],1)},[],!1,null,null,null).exports}}]);
//# sourceMappingURL=bookmarks-src_components_CustomPickerElement_vue.js.map?v=faafb8cd6b3373af90d5