<?php
$TRANSLATIONS = array(
"Bookmarks" => "Закладки",
"Bookm." => "Заклд.",
"No file provided for import" => "Немає файла для імпорту",
"Unsupported file type for import" => "Імпорт файлу даного типу не підтримується",
"Some Error happened." => "Виникла помилка.",
"Error" => "Помилка",
"Tags" => "Теги",
"Filter by tag" => "Фільтр по тегах",
"Are you sure you want to remove this bookmark?" => "Ви впевнені, що хочете видалити  цю закладку?",
"Warning" => "Попередження",
"Are you sure you want to remove this tag from every entry?" => "Ви впевнені, що бажаєте видалити цей тег з кожного запису ?",
"Import error" => "Помилка імпорту",
"Import completed successfully." => "Імпорт завершено успішно.",
"Uploading..." => "Вивантаження...",
"Add a bookmark" => "Додати закладку",
"This URL is already bookmarked! Overwrite?" => "Цей URL-адрес вже в закладках! Переписати?",
"The title of the page" => "Заголовок сторінки",
"The address of the page" => "Адреса сторінки",
"Description of the page" => "Опис сторінки",
"Save" => "Зберегти",
"Delete" => "Видалити",
"Edit" => "Редагувати",
"Cancel" => "Відмінити",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Перетягніть це в закладки вашого броузера і клікніть для того, щоб швидко закласти web-сторінку:",
"Add to ownCloud" => "Додати до ownCloud",
"Address" => "Адреса",
"Filterable Tags" => "Фільтровані мітки",
"You have no bookmarks" => "У вас немає закладок",
"You can also import a bookmark file" => "Ви можете також спробувати імпортувати файл закладок",
"Bookmarklet" => "Закладка-аплет",
"Export & Import" => "Експорт та Імпорт",
"Export" => "Експорт",
"Import" => "Імпорт"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
