OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Jikme-jiklikler",
    "Rename" : "Adyny üýtgetmek",
    "Copy link" : "Link-y nusgalaň",
    "Move" : "Göçüriň",
    "Select all" : "Hemmesini saýlaň",
    "New folder" : "Täze papka döretmek",
    "Search" : "Gözlemek",
    "Empty trash bin" : "Boşadylan zibil",
    "Cancel" : "ýatyrmak",
    "Files" : "Faýllar",
    "Delete" : "Pozmak",
    "Link" : "Baglanyşyk",
    "Tags" : "Bellikler",
    "Open file" : "Faýl açmak",
    "Link copied" : "Link-yň nusgasy alyndy",
    "Sharing" : "Paýlaşmak",
    "Share link" : "Baglanyşyk paýlaş",
    "Allow editing" : "Redaktirlemäge rugsat beriň",
    "Allow resharing" : "Täzeden paýlaşmaga rugsat beriň",
    "Privacy" : "Gizlinlik",
    "Save" : "Saklamak"
},
"nplurals=2; plural=(n != 1);");
