OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Detalji",
    "Rename" : "Rename",
    "Copy link" : "Kopiraj vezu",
    "Move" : "Move",
    "Select all" : "Označi sve",
    "New" : "Nov",
    "New folder" : "Nova fascikla",
    "Search" : "Traži",
    "Empty trash bin" : "Isprazni kantu",
    "_%n folder_::_%n folders_" : ["%n fascikla","%n fascikle","%n fascikli"],
    "Cancel" : "Otkaži",
    "Shared with you" : "Shared with you",
    "Files" : "Фајлови",
    "Delete" : "Delete",
    "Title" : "Naslov",
    "Link" : "Prečica",
    "Root folder" : "Korena fascikla",
    "Tags" : "Oznake",
    "Notes" : "Notes",
    "Open file" : "Отвори фајл",
    "Link copied" : "Veza iskopirana",
    "Owner" : "Vlasnik",
    "Sharing" : "Deljenje",
    "Share link" : "Podeli vezu",
    "Allow editing" : "Dozvoli uređivanje",
    "Privacy" : "Privatnost",
    "Folder" : "Folder",
    "Save" : "Save"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
