OC.L10N.register(
    "bookmarks",
    {
    "Rename" : "Preimenuj",
    "Move" : "Move",
    "Select all" : "Označi sve",
    "New" : "Novo",
    "New folder" : "Nova fascikla",
    "Search" : "Search",
    "_%n folder_::_%n folders_" : ["direktorij","direktoriji","direktoriji"],
    "Rename folder" : "Preimenuj fasciklu",
    "Cancel" : "Otkaži",
    "Shared with you" : "Shared with you",
    "Files" : "Datoteke",
    "Delete" : "Obriši",
    "Title" : "Naslov",
    "Link" : "Veza",
    "Notes" : "Notes",
    "Open file" : "Otvori Datoteku",
    "Owner" : "Vlasnik",
    "Sharing" : "Dijeljenje",
    "Share link" : "Podijelite vezu",
    "Allow editing" : "Dozvolite izmjenu",
    "Allow resharing" : "Dopustite ponovno dijeljenje",
    "Folder" : "Fasikla",
    "Save" : "Spremi"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
