OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Talqayt",
    "Rename" : "Beddel isem",
    "Copy link" : "Nɣel aseɣwen",
    "Move" : "Senkez",
    "Select all" : "Fren akk",
    "Go back" : "Tuɣalin",
    "New" : "Amaynut",
    "New folder" : "Akaram amaynut",
    "Search" : "Nadi",
    "Empty trash bin" : "Silem taqecwalt",
    "_%n folder_::_%n folders_" : ["%n n ukaram","%n n ikaramen"],
    "Cancel" : "Sefsex",
    "Recent" : "Melmi kan",
    "Files" : "Ifuyla",
    "Delete" : "Kkes",
    "Need help?" : "Tesriḍ tallelt?",
    "Title" : "Azwel",
    "Link" : "Aseɣwen",
    "Tags" : "Tibzimin",
    "Open file" : "Ldi afaylu",
    "Link copied" : "Aseɣwen yettwanɣel",
    "Owner" : "Bab",
    "Sharing" : "Beṭṭu",
    "Share link" : "Fren aseɣwen",
    "Privacy" : "Vie privée",
    "Folder" : "Akaram",
    "Save" : "Sekles"
},
"nplurals=2; plural=(n != 1);");
