<?php
$TRANSLATIONS = array(
"Bookmarks" => "Zabilješke",
"Close" => "Zatvori",
"Save" => "Snimi",
"Delete" => "Obriši",
"Edit" => "Uredi",
"Cancel" => "Odustani",
"Address" => "Adresa",
"Add" => "Dodaj",
"Settings" => "Postavke",
"Export" => "Izvoz",
"Import" => "Uvezi"
);
$PLURAL_FORMS = "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;";
