OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "სანიშნეები",
    "No file provided for import" : "იმპორტისთვის ფაილი არაა მოწოდებული",
    "Details" : "დეტალები",
    "Rename" : "სახელის შეცვლა",
    "Copy link" : "ბმულის კოპირება",
    "Move" : "გადატანა",
    "Select all" : "ყველას არჩევა",
    "Go back" : "უკან დაბრუნება",
    "New" : "ახალი",
    "New folder" : "ახალი დირექტორია",
    "Search" : "ძიება",
    "_%n folder_::_%n folders_" : ["%n დირექტორია","%n დირექტორია"],
    "Add a bookmark" : "სანიშნის დამატება",
    "Rename folder" : "ფოლდერის სახელის გადარქმევა",
    "Choose folder" : "აირჩიეთ დირექტორია",
    "Submit" : "გაგზავნა",
    "Cancel" : "უარყოფა",
    "Recent" : "ახალი",
    "Shared with you" : "გაზიარებული თქვენთან",
    "Files" : "ფაილები",
    "Delete" : "წაშლა",
    "Bookmarklet" : "Bookmarklet-ი",
    "Need help?" : "გესაჭიროებათ დახმარება?",
    "Title" : "სათაური",
    "Link" : "ბმული",
    "Tags" : "ტეგები",
    "Notes" : "ჩანაწერები",
    "Open file" : "ფაილის გახსნა",
    "Download file" : "ფაილის ჩამოტვირთვა",
    "Owner" : "მფლობელი",
    "Sharing" : "გაზიარება",
    "Share link" : "ბმულის გაზიარება",
    "Allow editing" : "შეცვლის ნების დართვა",
    "Allow resharing" : "ხელახალი გაზიარების დაშვება",
    "Privacy" : "კონფიდენციალურობა",
    "This URL is already bookmarked! Overwrite?" : "ეს URL უკვე მონიშნულია! გადავწეროთ?",
    "Folder" : "დირექტორია",
    "Save" : "შენახვა"
},
"nplurals=2; plural=(n!=1);");
