OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "الإشارات المرجعية Bookmarks",
    "You bookmarked \"%s\"" : "أنت أشّرت \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s أشّر \"%2$s\"",
    "Someone bookmarked \"%s\"" : "أحدُهم أشّر \"%s\"",
    "You deleted \"%s\"" : "أنت حذفت \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s حذف \"%2$s\"",
    "Someone deleted \"%s\"" : "أحدُهم حذف \"%s\"",
    "You created folder \"%s\"" : "أنت أنشأت المجلد \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s أنشأ المجلد \"%2$s\"",
    "Someone created folder \"%s\"" : "أحدُهم أنشأ المجلد \"%s\"",
    "You moved folder \"%s\"" : "أنت نقلت المجلد \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s نقل المجلد \"%2$s\"",
    "Someone moved folder \"%s\"" : "أحدُهم نقل المجلد \"%s\"",
    "You deleted folder \"%s\"" : "أنت حذفت المجلد \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$sحذف المجلد \"%2$s\"",
    "Someone deleted folder \"%s\"" : "أحدُهم حذف المجلد \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "أنت شاركت المجلد \"%1$s\" مع %2$s",
    "You shared folder \"%s\" with someone" : "أنت شاركت المجلد \"%s\" مع أحدِهم",
    "%1$s shared folder \"%2$s\" with you" : "%1$s شارك المجلد \"%2$s\" معك",
    "Someone shared folder \"%s\" with you" : "أحدُهم شارك المجلد \"%s\" معك",
    "You unshared folder \"%1$s\" with %2$s" : "أنت ألغيت مشاركة المجلد \"%1$s\" مع %2$s",
    "You unshared folder \"%s\" with someone" : "أنت ألغيت مشاركة المجلد \"%s\" مع أحدِهم",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s ألغى مشاركة المجلد \"%2$s\" معك",
    "Someone unshared folder \"%s\" with you" : "أحدُهم ألغى مشاركة المجلد \"%s\" معك",
    "No file provided for import" : "لم يتم تقديم ملف للاستيراد",
    "Failed to upload file" : "تعذّر رفع الملف",
    "Unsupported file type for import: " : "هذا النوع من الملف استيراده غير مدعوم:",
    "Bookmarks shared by %s" : "إشارات مرجعية مُشارَكة مع %s",
    "Frequent bookmarks" : "إشارات مرجعية متكررة",
    "Recent bookmarks" : "آخر ما تمّ تأشيره",
    "Bookmark" : "إشارة مرجعية bookmark",
    "Bookmark deleted" : "تمّ حذف الإشارة المرجعية",
    "Bookmark created" : "تمّ إنشاء الإشارة المرجعية",
    "Bookmark moved" : "تمً نقل الإشارة المرجعية",
    "Bookmark updated" : "تمً تعديل الإشارة المرجعية",
    "Create bookmark" : "إنشاء إشارة مرجعية bookmark",
    "Takes a link and adds it to your collection of bookmarks." : "تأخذ رابطاً و تضيفه إلى مجموعتك من الإشارات المرجعية",
    "Bookmarks Backups" : "نُسَخ احتياطية من الإشارات المرجعية bookmarks",
    "Collect and manage bookmarks, synced with all your devices" : "تجميع و إدارة الإشارات المرحعية bookmarks و مزامنتها عبر أجهزتك المتعددة",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 فرز الإشارات المرجعية إلى مجلدات \n- 🏷 إضافة علامات وملاحظات شخصية \n- ☠ البحث عن الروابط المعطلة والمكررة \n- 📲 المزامنة مع جميع متصفحاتك وأجهزتك \n- 📔 تخزين الإصدارات المؤرشفة من الروابط الخاصة بك في حالة إلغاء نشرها \n- 🔍 البحث عن النص الكامل في محتويات الموقع \n- 👪 مشاركة الإشارات المرجعية مع مستخدمين ومجموعات وفرق أخرى أو عبر الروابط العامة \n- ⚛ إنشاء موجزات RSS لمجموعاتك \n- 📈 إحصائيات حول عدد مرات وصولك إلى الروابط \n- 🔒 نسخ احتياطية تلقائية لمجموعة الإشارات المرجعية الخاصة بك \n- 💼 أدوات لوحة معلومات مدمجة للروابط المتكررة والحديثة \n\nالمتطلبات: \n- ملحقات PHP: - intl: * \n- mbstring: * \n- عند استخدام MySQL، استخدم الإصدار v8.0 على الأقل",
    "Do you really want to delete this bookmark?" : "هل ترغب حقاً في حذف الإشارة المرجعية؟",
    "Link copied to clipboard" : "تمّ نسخ الرابط إلى الحافظة",
    "Enter new title" : "أدخِل عنواناً جديداً",
    "Select bookmark" : "إختر إشارةً مرجعيةً bookmark",
    "You have never clicked this link" : "لم يسبق لك أن نقرت هذا الرابط",
    "You have clicked this link {count} times" : "أنت قمت بنقر هذا الرابط {count} مرة",
    "Details" : "التفاصيل",
    "Rename" : "إعادة التسمية",
    "Copy link" : "إنسخ الرابط",
    "Move" : "نقل",
    "Add to folders" : "إضافة إلى المجلدت",
    "Put bookmark into trash bin" : "ضع الإشارة المرجعية في سلة المهملات",
    "Restore bookmark" : "استعادة الإشارة المرجعية",
    "Delete bookmark permanently" : "حذف الإشارة المرجعية نهائيّاً",
    "Content pending" : "المحتوى مُعلّق pending",
    "This content is being downloaded for offline use. Please check back later." : "تمّ تنزيل المحتوى تحضيراً للعمل دون اتصالٍ بالإنترنت. يرجى التحقق مرة أخرى في وقت لاحق.",
    "Bookmarked {time} ago" : "تمّ التأشير منذ {time} مضت",
    "Bookmarked on {date}" : "تمّ التأشير في {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "هذه هي عناصرك المحذوفة. سوف يتم حذفها بشكل نهائي بعد شهرين.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "سيتم حفظ الإشارات المرجعية إلى الملفات الموجودة على الويب مثل الصور أو ملفات PDF تلقائيًا في ملفات نكست كلاود الخاصة بك، بحيث يظل بإمكانك العثور عليها حتى عندما يكون الرابط غير متصل بالإنترنت.",
    "Searching in the current folder only." : "البحث في المجلد الحالي فقط",
    "Repeat search in all folders" : "أعِدِ البحث في جميع المجلدات",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "يتم فحص الروابط المرجعية بانتظام. و الروابط التي لا يمكن الوصول إليها يتم سردها هنا.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "يمكنك مشاركة مجلدات الإشارات مع الآخرين. جميع المجلدات التي تمت مشاركتها معك مدرجة هنا.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "يمكن أن تكون إشارة مرجعية واحدة في مجلدات متعددة في وقت واحد. سيؤدي تحديث الإشارة إلى تحديث جميع النسخ. جميع الإشارات المرجعية المكررة مدرجة هنا للتيسير.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "تمّ تحديد {folders} مجلدات، و {bookmarks} إشارات مرجعية",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["تم اختيار %n إشارات مرجعية","تم اختيار %n إشارة مرجعية","تم اختيار %n إشارات مرجعية","تم اختيار %n إشارات مرجعية","تم اختيار%n إشارات مرجعية","تم اختيار%n إشارات مرجعية"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n مجلدات مختارة","%n مجلد مختار","%n مجلدات مختارة","%n مجلدات مختارة","%n مجلدات مختارة","%n مجلدات مختارة"],
    "Do you really want to delete these items?" : "هل ترغب حقّاً في حذف هذه العناصر؟",
    "Open all selected" : "فتح جميع المحدد",
    "Move selection" : "أنقُل ما تمّ تحديده",
    "Edit tags of selection" : "تحرير الوسوم للمحدد",
    "Delete selection" : "حذف ما تمّ تحديده",
    "Select all" : "تحديد الكل",
    "Cancel selection" : "إلغاء التحديد",
    "Sort by created date" : "ترتيب بحسب تاريخ الإنشاء",
    "Sort by last modified" : "الترتيب بحسب تاريخ آخر تعديل",
    "Sort by title" : "ترتيب بحسب العنوان",
    "Sort by click count" : "الترتيب بحسب عدد النقرات clicks",
    "Sort by manual order" : "الترتيب بحسب الفرز اليدوي",
    "Sort by URL" : "الترتيب بحسب العنوان URL",
    "RSS feed copied" : "تمّ نسخ موجز RSS ",
    "Trash Bin" : "سلة المهملات",
    "Go back" : "عودة",
    "Share folder" : "مشاركة مُجلّد",
    "Open folder details" : "تفاصيل المجلد المفتوح",
    "Select one or more tags" : "تحديد وسم أو أكثر",
    "New" : "جديد",
    "New bookmark" : "إشارة مرجعية جديدة",
    "New folder" : "مجلد جديد",
    "Change to grid view" : "بدّل إلى العرض الشبكي grid view",
    "Change to list view" : "بدّل إلى عرض القائمة list view",
    "Copy RSS Feed of current view" : "نسخ موجز RSS للعرض الحالي",
    "The RSS feed requires authentication with your Nextcloud credentials" : "موجز RSS تتطلب المصادقة باستخدام بيانات تسجيل الدخول الخاصة بك إلى نكست كلاود",
    "Search" : "البحث",
    "Empty trash bin" : "تفريغ سلة المهملات",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["إضافة %n إشارات مرجعية إلى المجلد الجديد","إضافة %n إشارة مرجعية إلى المجلد الجديد","إضافة %n إشارات مرجعية إلى المجلد الجديد","إضافة %n إشارات مرجعية إلى المجلد الجديد","إضافة %n إشارات مرجعية إلى المجلد الجديد","إضافة %n إشارات مرجعية إلى المجلد الجديد"],
    "Enter a link" : "أدخِل رابطاً",
    "Enter a title" : "أدخِل عنواناً",
    "No bookmarks found" : "لا توجد أي إشاراتٍ مرجعيةٍ",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} مُجلّد، و {bookmarks} إشارة مرجِعية",
    "_%n bookmark_::_%n bookmarks_" : ["%n إشارات مرجِعية","%n إشارة مرجِعية","%n إشارات مرجِعية","%n إشارات مرجِعية","%n إشارات مرجِعية","%n إشارات مرجِعية"],
    "_%n folder_::_%n folders_" : ["لا توجد مجلدات","مجلد واحد","مجلدان","%n مجلدات","%n مجلد","%n مجلدات"],
    "Welcome to Bookmarks" : "أهلا بكم في تطبيق \"الإشارات المرجِعيّة\" Bookmarks",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "يتيح لك هذا التطبيق إدارة الروابط إلى أماكنك المفضلة على الويب. قم بفرز إشاراتك المرجعية في مجلدات، وقم بوضع علامات labels عليها لتصنيفها، وشاركها مع الآخرين! \nسيتحقق التطبيق بانتظام من جميع الروابط الخاصة بك للتأكد من توفرها ويعرض الروابط غير المتاحة. \nإذا قمت بإضافة رابط إلى ملف على الويب، فسيتم تنزيل الملف تلقائيًا إلى ملفات نكست كلاود الخاصة بك. \nيمكنك أيضًا إستيراد الإشارات المرجعية المُصدّرة من خدمات أخرى، أو مزامنة الإشارات المرجعية مباشرةً من جميع المستعرضات الخاصة بك باستخدام هذا التطبيق.",
    "Add a bookmark" : "إضافة إشارة مرجعية bookmark",
    "Import bookmarks" : "إستيراد إشارات مرجعية",
    "Sync with your browser" : "زامن مع متصفحك",
    "Do you really want to permanently delete this folder?" : "هل أنت حقاً ترغب في حذف هذا المجلد نهائيّاً؟",
    "Select folder" : "إختر مجلداً",
    "Enter folder title" : "أدخل عنوان المجلد",
    "Shared by {user}" : "تمتّ مشاركتها من قِبَل {user}",
    "Rename folder" : "تغيير تسمية المجلد",
    "Move folder" : "أنقُل المُجلّد",
    "Put folder into trashbin" : "ضع المجلد في سلة المهملات",
    "Restore folder" : "استعادة المجلد من سلة المهملات",
    "Delete folder permanently" : "حذف المجلد نهائيّاً",
    "Choose folder" : "إختَر مُجلّداً",
    "Submit" : "إرسال ",
    "Cancel" : "إلغاء",
    "Deleting bookmarks" : "حذف إشارات مرجعية",
    "Deleting selection" : "حذف ما تمّ تحديده",
    "Importing bookmarks" : "إستيراد إشارات مرجعية",
    "Moving selection" : "نقل ما تمّ تحديده",
    "Adding selection to folders" : "إضافة ما تمّ تحديده إلى المجلدات",
    "Emptying trashbin" : "تفريغ سلة المهملات",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["نقل %n مجلدات وبعض الإشارات المرجعية","نقل %nمجلد وبعض الإشارات المرجعية","نقل %n مجلدات وبعض الإشارات المرجعية","نقل%n مجلدات وبعض الإشارات المرجعية","نقل %n مجلدات وبعض الإشارات المرجعية","نقل %nمجلدات وبعض الإشارات المرجعية"],
    "_Moving %n folder_::_Moving %n folders_" : ["جار نقل %nمجلدات","جار نقل %n مجلد","جار نقل %n مجلدات","جار نقل %n مجلدات","جار نقل %n مجلدات","جار نقل %n مجلدات"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["جار نقل %n إشارات مرجعية","جار نقل %n إشارة مرجعية","جار نقل %n إشارات مرجعية","جار نقل %n إشارات مرجعية","جار نقل %n إشارات مرجعية","جار نقل %n إشارات مرجعية"],
    "All bookmarks" : "كل الإشارات المرجِعية",
    "Recent" : "الحديثة",
    "Shared with you" : "تمّت مُشاركتها معك",
    "Files" : "الملفات",
    "Duplicates" : "التكرارات",
    "Broken links" : "الروابط المقطوعة",
    "New tag" : "وسم جديد",
    "Search tags" : "البحث عن الوسوم",
    "Delete" : "حذف ",
    "Untagged" : "بدون وسم",
    "{used} bookmarks of {available} available" : "{used} إشارة مرجعية أُستُخدِمت من أصل {available} إشارة متاحة",
    "Bookmarks Settings" : "إعدادات الإشارات المرجعية",
    "No bookmarked files" : "لا توجد أي ملفات عليها إشارات مرجعية",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "سيتم حفظ الإشارات المرجعية إلى ملفات مثل الصور أو ملفات PDF تلقائيًا في ملفات نكست كلاود الخاصة بك، بحيث يمكنك العثور عليها حتى عندما ينتقل الرابط إلى وضع عدم الاتصال.",
    "Nothing found" : "لم يعثر على شيء",
    "Your search yielded no results in the current folder." : "لم ينتج عن بحثك أي نتائج في المجلد الحالي",
    "No broken links" : "لا توجد روابط مقطوعة",
    "No shared folders" : "لا توجد مجلدات مشاركة",
    "No duplicated bookmarks" : "لا توجد إشارات مرجعية متكررة",
    "No deleted bookmarks" : "لا توجد أي إشارات مرجعية محذوفة",
    "You haven't deleted anything yet." : "أنت لم تقم بحذف شيءٍ بعد.",
    "No bookmarks here" : "لا توجد إشارات مرجعية هنا",
    "Add bookmarks manually or import bookmarks from a HTML file." : "أضِف الإشارات المرجعية يدويّاً أو قم باستيرادها من ملفات HTML.",
    "Archive path" : "مسار الأرشيف",
    "Backup path" : "مسار النسخ الاحتياطي",
    "Please select \"Add to home screen\" in your browser menu" : "الرجاء تحديد \"إضافة إلى الشاشة الرئيسية\" Add to home screen في قائمة المتصفح",
    "Bookmarks settings" : "إعدادات الإشارات المرجعية",
    "Import/Export" : "إستيراد/تصدير",
    "Export bookmarks" : "تصدير الإشارات المرجعية",
    "Auto-archiving" : "الأرشفة التلقائية",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "يُمكن لتطبيق الإشارات المرجعية أن يقوم بالأرشفة التلقائية لمحتوى الويب للروابط التي قمت بوضع إشارة مرجعية عليها",
    "Enable archiving" : "تمكين الأرشفة",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "أدخل مسار مجلد في ملفاتك Files حيث سيتم تخزين الملفات المُؤشّر عليها.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "حاليّاً، هذا التطبيق تمّ منعه من قِبَل مسؤول النظام من الوصول إلى الإنترنت. و لذا، فإن الأرشفة التلقائية معطلة في الوقت الحاضر.",
    "Auto-Backup" : "النسخ الاحتياطي التلقائي",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "يُمكن لتطبيق الإشارات المرجعية أن ينسخ احتياطيّاً و بشكل تلقائي إشاراتك المرجعية بشكل يومي لمنع فقدانها عند مزامنة الإشارات المرجعية بين أجهزتك المتعددة.",
    "Enable backups" : "تمكين النسخ الاحتياطي",
    "Enter the path of a folder in your Files where backups will be stored." : "أدخل مسار مجلد في ملفاتك Files حيث سيتم تخزين النسخ الاحتياطية.",
    "Client apps" : "تطبيقات العميل",
    "Also check out the collection of client apps that integrate with this app: " : "تحقق أيضًا من مجموعة تطبيقات العميل التي تتكامل مع هذا التطبيق:",
    "Install web app" : "تثبيت تطبيق وب",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "يمكنك تنصيب هذا التطبيق على الشاشة الرئيسية لجهازك للوصول بسرعة إلى إشاراتك المرجعية على هاتفك. يمكنك بسهولة إزالة التطبيق في أي وقت من شاشتك الرئيسية إذا لم تعجبك.",
    "Install on home screen" : "التنصيب على الشاشة الرئيسية",
    "Bookmarklet" : "بريمج الإشارة المرجعية \"Bookmarklet\"",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "اسحب هذا إلى الإشارات المرجعية في متصفحك وانقر عليه لوضع إشارة مرجعية سريعة على صفحة ويب.",
    "Add to {instanceName}" : "إضافة إلى {instanceName}",
    "Need help?" : "تحتاج إلى مساعدة؟",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "إذا واجهتك أي مشاكل مع تطبيق \"الإشارات المرجعية\" هذا أو كان لديك أي مقترح لتطويره, نرجوك ألّا تتتردد في التواصل معنا بالنقر هنا.",
    "Support this project" : "إدعَم هذا المشروع",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "عملي في هذا التطبيق \"الإشارات المرجعية\" Bookmarks  يتم دعمه من خلال نموذج الاشتراك الطوعي. إذا كنت تعتقد أن ما أقوم به يستحق العناء، سأكون سعيداً إذا ساهمت في دعم عملي. كذلك، يُرجى تقييم التطبيق على متجر تطبيقات نكست كلاود. و شكراً 💙",
    "Created {time} ago" : "أُنشِيءَ منذ {time} مضت",
    "Created on {date}" : "أُنشِيءَ في {date}",
    "(Empty title)" : "(عنوان فارغ)",
    "Title" : "العنوان",
    "Link" : "الرابط",
    "Untitled folder" : "مجلّد بلا عنوان Untitled ",
    "Root folder" : "المجلد الجذري root folder",
    "Tags" : "الوسوم",
    "Select tags and create new ones" : "تحديد الوسوم وإنشاء وسوم جديدة",
    "Notes" : "الملاحظات",
    "Notes for this bookmark …" : "ملاحظات على هذه الإشارة المرجعية ...",
    "Archived file" : "ملف مؤرشف",
    "Open file" : "فتح ملف",
    "Download file" : "تنزيل ملف",
    "Open file location" : "فتح موقع الملف",
    "Link copied" : "تمّ نسخ الرابط",
    "Owner" : "المالك",
    "Sharing" : "المشاركة",
    "Select a user or group" : "إختر مستخدِماً أو مجموعةً",
    "Share link" : "مشاركة الرابط",
    "Reading allowed" : "مسموحٌ بالقراءة",
    "Copy RSS feed" : "نسخ موجز RSS",
    "Delete link" : "حذف الرابط",
    "Create public link" : "إنشاء رابط عمومي",
    "Resharing allowed" : "مسموحٌ بإعادة المشاركة",
    "Editing allowed" : "مسموحٌ بالتعديل",
    "Allow editing" : "السّماح بالتعديل",
    "Allow resharing" : "السّماح بإعادة المشاركة ",
    "Remove share" : "حذف المشاركة",
    "Would you like to support this project?" : "هل ترغب في دعم هذا المشروع؟",
    "Leave a rating on the Nextcloud App Store" : "قم بتقييمنا في متجر تطبيقات نكست كلاود",
    "Failed to save settings" : "فشل حفظ الإعدادات",
    "Failed to load settings" : "فشل في تحميل الإعدادات",
    "Privacy" : "الخصوصية",
    "The app will try to access web pages that you add to automatically add information about them." : "سيحاول التطبيق الوصول إلى صفحات الويب التي تضيفها لإضافة معلومات عنها تلقائيًا",
    "Enable accessing and collecting information from the web pages you add" : "قم بتمكين الوصول إلى المعلومات وجمعها من صفحات الويب التي تضيفها",
    "Performance" : "سرعة الأداء",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "في الحالات التي يكون فيها عدد المستخدمين كبيراً جدّاً، قد يكون من المفيد تقييد عدد الإشارات المرجعية لكل حساب.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "العدد الأقصى المسموح به من الإشارات المرجعية لكل حساب. (0 بلا حدود؛ وهو الافتراضي)",
    "Previews" : "المعاينات",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "من أجل عرض لقطات شاشة حقيقية لمواقع الويب التي تم وضع إشارة مرجعية عليها، يمكن للتطبيق استخدام خدمة من طرف ثالث لإنشاء معاينات.",
    "Screeenly" : "\"سكرينلي\" Screeenly خدمة خارجية لتوليد معاينات لصور شاشات المواقع المُؤشّرة",
    "You can either sign up for free at screeenly.com or setup your own server." : "يمكنك إما التسجيل مجانًا في screeenly.com أو إعداد الخادم الخاص بك.",
    "Screeenly API URL" : "عنوان واجهة برمجة التطبيقات في \"سكرينلي\" Screeenly API URL",
    "Screeenly API key" : "مفتاح واجهة برمجة التطبيقات في \"سكرينلي\" Screeenly API URL",
    "ScreenshotMachine" : "\"سكرين شوت ماشين\" ScreenshotMachine خدمة خارجية لتوليد معاينات لصور شاشات المواقع المُؤشّرة",
    "ScreenshotMachine API key" : "عنوان واجهة برمجة التطبيقات في \"سكرين شوت ماشين\" ScreenshotMachine API URL",
    "Webshot" : "\"ويب شوت\" webshot خدمة خارجية لتوليد معاينات لصور شاشات المواقع المُؤشّرة",
    "Webshot API URL" : "عنوان واجهة برمجة التطبيقات في \"ويب شوت\" Webshot API URL",
    "Generic screenshot API" : "واجهة برمجة تطبيقات لخدمة لقطات الشاشة",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "قم بالتسجيل مع أي من مزود واجهة برمجة تطبيقات للقطات الشاشة؛ ثم قم بوضع عنوان URL تلك الواجهة أدناه. استخدم المتغير {url} كعنصر نائب لعنوان URL لالتقاط صورة الشاشة. يجب أن تقوم API مباشرةً بإرجاع الصورة فقط.",
    "Generic API URL" : "عنوان URL للواجهة API",
    "Pageres CLI" : "تطبيق واجهة سطر الأوامر \"بيجرز \"Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "ما عليك سوى تثبيت Pageres CLI من Sindre Sorhus على خادمك و ستجده الإشارات المرجعية. لا يزال بإمكانك إضافة متغيرات ENV إضافية ليتم تغذيتها إلى الصفحات، على سبيل المثال. كما هو موضح في العنصر النائب:",
    "Pageres ENV variables" : "مُتغيِّرات بيئة \"بيجرز\" Pageres ENV variables",
    "This URL is already bookmarked! Overwrite?" : "تمّ سلفاً وضع إشارة مرجعية bookmark على عنوان URL هذا! هل ترغب في استبدالها؟",
    "Enter bookmark title" : "أدخِل تسمية title الإشارة المرجعية",
    "Enter bookmark URL" : "أدخِل عنوان URL للإشارة المرجعية",
    "Folder" : "مجلد",
    "Root Folder" : "المجلد الجذري root folder",
    "Save" : "حفظ",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "الوصول إلى الشبكة معطل بشكل تلقائي. إنتقل إلى إعدادات مسؤول النظام في تطبيق الإشارات المرجعية للسماح بجلب المعاينات previews و الأيقونات favicons.",
    "What's new?" : "مالجديد؟",
    "What" : "ماذا",
    "Failed to count unavailable bookmarks" : "تعذّر حصر الإشارات المرجعية غير المتاحة",
    "Failed to count archived bookmarks" : "تعذّر حصر الإشارات المرجعية المؤرشفة",
    "Failed to count duplicated bookmarks" : "تعذّر حصر الإشارات المرجعية المُكرّرة",
    "Failed to load bookmark" : "تعذّر تحميل الإشارة المرجعية",
    "Failed to find existing bookmark" : "تعذّر العثور على إشارة مرجعية موجودة",
    "Failed to create bookmark" : "تعذّر إنشاء الإشارة المرجعية",
    "Failed to save bookmark" : "تعذّر حفظ الإشارة المرجعية",
    "Failed to move bookmark" : "تعذّر نقل الإشارة المرجعية",
    "Failed to copy bookmark" : "تعذّر نسخ الإشارة المرجعية",
    "Failed to delete bookmark" : "تعذّر حذف الإشارة المرجعية",
    "Import successful" : "تمّ الاستيراد بنجاحٍ",
    "Failed to rename tag" : "فشل في تغيير تسمية الوسم",
    "Failed to load tags" : "فشل في تحميل الوسوم",
    "Failed to load folders" : "تعذّر تحميل المجلد",
    "Failed to load deleted folders" : "يتعذّر تحميل المجلدات المحذوفة",
    "Failed to load deleted bookmarks" : "تعذّر تحميل الإشارات المرجعية المحذوفة",
    "Failed to delete folder" : "تعذّر حذف المجلد",
    "Failed to move folder" : "تعذّر نقل المجلد",
    "Failed to create folder" : "تعذّر إنشاء المجلد",
    "Failed to fetch bookmarks." : "تعذّر جلب الإشارات المرجعية",
    "Failed to store setting" : "تعذّر حفظ الإعدادات",
    "Failed to load setting {key}" : "تعذّر تحميل الإعداد {key}",
    "Failed to update share {shareId}" : "تعذّر تحديث المشاركة {shareId}",
    "Failed to delete share {shareId}" : "تعذّر حذف المشاركة {shareId}",
    "Create bookmarks for mentioned links" : "إنشاء إشارات مرجعية للروابط المذكورة",
    "No links found in this message" : "لا يوجد أي روابط في هذه الرسالة",
    "Bookmarks feed" : "تعذية الإشارات المرجعية Bookmarks feed"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
