<?php
$TRANSLATIONS = array(
"Bookmarks" => "Marcadores",
"Bookm." => "Marc.",
"No file provided for import" => "No se especificó un archivo para importar",
"Unsupported file type for import" => "Tipo de archivo no soportado para importar",
"Some Error happened." => "Ocurrió algún error",
"Error" => "Error",
"Tags" => "Etiquetas",
"Filter by tag" => "Filtrar por etiquetas",
"Are you sure you want to remove this bookmark?" => "¿Estás seguro de querer eliminar este marcado?",
"Warning" => "Precaución",
"Are you sure you want to remove this tag from every entry?" => "¿Está seguro de que desea eliminar esta etiqueta de todas las entradas?",
"Import error" => "Error de importación",
"Import completed successfully." => "Importación completada con éxito.",
"Uploading..." => "Subiendo...",
"Add a bookmark" => "Agregar a marcadores",
"This URL is already bookmarked! Overwrite?" => "Esta URL ya tiene un marcador! ¿Deseas sobreescribir?",
"The title of the page" => "Título de la página",
"The address of the page" => "Dirección de la página",
"Description of the page" => "Descripción de la página",
"Save" => "Guardar",
"Delete" => "Eliminar",
"Edit" => "Editar",
"Cancel" => "Cancelar",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Arrastre desde aquí a los marcadores de su navegador, y haga clic cuando quiera marcar una página web rápidamente:",
"Add to ownCloud" => "Agregar a ownCloud",
"Address" => "Dirección",
"Filterable Tags" => "Etiquetas filtrables",
"You have no bookmarks" => "No tiene marcadores",
"You can also import a bookmark file" => "También puedes importar un archivo de marcadores",
"Bookmarklet" => "Marcador de JavaScript",
"Export & Import" => "Exportar e Importar",
"Export" => "Exportar",
"Import" => "Importar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
