OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Закладки",
    "You bookmarked \"%s\"" : "Вы создали закладку «%s»",
    "%1$s bookmarked \"%2$s\"" : "%1$s создал закладку «%2$s»",
    "Someone bookmarked \"%s\"" : "Кто-то создал закладку «%s»",
    "You deleted \"%s\"" : "Вы удалили «%s»",
    "%1$s deleted \"%2$s\"" : "«%2$s» удалена %1$s",
    "Someone deleted \"%s\"" : "Кто-то удалил «%s»",
    "You created folder \"%s\"" : "Вы создали папку «%s»",
    "%1$s created folder \"%2$s\"" : "%1$s создал папку «%2$s»",
    "Someone created folder \"%s\"" : "Кто-то создал папку «%s»",
    "You moved folder \"%s\"" : "Вы переместили папку «%s»",
    "%1$s moved folder \"%2$s\"" : "%1$s переместил папку «%2$s»",
    "Someone moved folder \"%s\"" : "Кто-то переместил папку «%s»",
    "You deleted folder \"%s\"" : "Вы удалили папку «%s»",
    "%1$s deleted folder \"%2$s\"" : "%1$s удалил папку «%2$s»",
    "Someone deleted folder \"%s\"" : "Кто-то удалил папку «%s»",
    "You shared folder \"%1$s\" with %2$s" : "Вы открыли %2$s доступ к папке «%1$s»",
    "You shared folder \"%s\" with someone" : "Вы открыли доступ к папке «%s» для всех",
    "%1$s shared folder \"%2$s\" with you" : "%1$s открыл вам доступ к папке «%2$s»",
    "Someone shared folder \"%s\" with you" : "Кто-то открыл вам доступ к папке «%s»",
    "You unshared folder \"%1$s\" with %2$s" : "Вы закрыли %2$s доступ к папке «%1$s»",
    "You unshared folder \"%s\" with someone" : "Вы закрыли всем доступ к папке «%s»",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s закрыл вам доступ к папке «%2$s»",
    "Someone unshared folder \"%s\" with you" : "Кто-то закрыл вам доступ к папке «%s»",
    "No file provided for import" : "Не указан файл для импорта",
    "Failed to upload file" : "Не удалось загрузить файл",
    "Unsupported file type for import: " : "Неподдерживаемый тип файла для импорта:",
    "Bookmarks shared by %s" : "Закладки предоставлены пользователем %s ",
    "Frequent bookmarks" : "Частые закладки",
    "Recent bookmarks" : "Последние закладки",
    "Bookmark" : "Закладка",
    "Bookmark deleted" : "Закладка удалена",
    "Bookmark created" : "Закладка создана",
    "Bookmark moved" : "Закладка перенесена",
    "Bookmark updated" : "Закладка обновлена",
    "Create bookmark" : "Создать закладку",
    "Takes a link and adds it to your collection of bookmarks." : "Берет ссылку и добавляет ее в Вашу коллекцию закладок.",
    "Bookmarks Backups" : "Резервные копии закладок",
    "Collect and manage bookmarks, synced with all your devices" : "Собирайте и управляйте закладками, синхронизируйте их со всеми вашими устройствами",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "-📂 Сортировка закладок по папкам\n-🏷 Добавление тегов и личных заметок\n-☠ Поиск неработающих ссылок и дубликатов\n-📲 Синхронизация со всеми вашими браузерами и устройствами\n-📔 Хранение архивных версий ссылок на случай их удаления с исходного сайта\n-🔍 Полнотекстовый поиск по содержимому сайтов\n-👪 Совместное использование закладок с другими пользователями, группами и командами, а также через публичные ссылки\n-⚛ Генерация RSS-лент для ваших коллекций\n-📈 Статистика по частоте доступа к закладкам\n-🔒 Автоматическое резервное копирование коллекции закладок\n-💼 Встроенные виджеты на панели управления для быстрого доступа к часто используемым и недавним ссылкам\n\nТребования:\n - Расширения PHP:\n   - intl: *\n   - mbstring: *\n - при использовании MySQL — версия не ниже 8.0",
    "Do you really want to delete this bookmark?" : "Действительно удалить эту закладку?",
    "Link copied to clipboard" : "Ссылка скопирована в буфер обмена",
    "Enter new title" : "Введите новый заголовок",
    "Select bookmark" : "Выберите закладки",
    "You have never clicked this link" : "Вы никогда не нажимали на эту ссылку",
    "You have clicked this link {count} times" : "Вы нажали на эту ссылку {count} раз",
    "Details" : "Подробнее",
    "Rename" : "Переименовать",
    "Copy link" : "Скопировать ссылку",
    "Move" : "Переместить",
    "Add to folders" : "Добавить в папки",
    "Put bookmark into trash bin" : "Поместить закладку в корзину",
    "Restore bookmark" : "Восстановить закладку",
    "Delete bookmark permanently" : "Удалить закладку навсегда",
    "Content pending" : "Содержание на ожидании",
    "This content is being downloaded for offline use. Please check back later." : "Этот контент загружается для использования в автономном режиме. Пожалуйста, зайдите позже.",
    "Bookmarked {time} ago" : "Добавлено в закладки {time} назад",
    "Bookmarked on {date}" : "Добавлено в закладки {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Это ваши удаленные элементы. Элементы будут удалены навсегда через два месяца.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "При сохранении ссылок на фотографии, PDF-файлы и т.д., сами файлы также будут автоматически сохраняться в Nextcloud. Поэтому Вы всегда сможете найти их, даже если ссылка не работает.",
    "Searching in the current folder only." : "Поиск только в текущей папке.",
    "Repeat search in all folders" : "Повторить поиск во всех папках",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Ссылки, добавленные в закладки, регулярно проверяются, и здесь перечислены те, которые недоступны.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Вы можете поделиться папками с закладками с другими пользователями. Здесь перечислены все папки, к которым у вас есть доступ.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Одна закладка может находиться сразу в нескольких папках. Обновление закладки обновит все её копии. Все дублирующиеся закладки перечислены здесь для удобства.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Выделено {folders} папок и {bookmarks} закладок",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Выделена %n закладка","Выделено %n закладок","Выделено %n закладок","Выделено %n закладок"],
    "_Selected %n folder_::_Selected %n folders_" : ["Выделена %n папка","Выделено %n папок","Выделено %n папок","Выделено %n папок"],
    "Do you really want to delete these items?" : "Действительно удалить выбранные объекты?",
    "Open all selected" : "Открыть выбранные",
    "Move selection" : "Переместить выбранное",
    "Edit tags of selection" : "Редактировать теги выделенного",
    "Delete selection" : "Удалить выбранное",
    "Select all" : "Выбрать все",
    "Cancel selection" : "Отменить выбор",
    "Sort by created date" : "Сортировать по дате создания",
    "Sort by last modified" : "Сортировать по дате изменения",
    "Sort by title" : "Сортировать по названию",
    "Sort by click count" : "Сортировать по количеству кликов",
    "Sort by manual order" : "Сортировать по порядку вручную",
    "Sort by URL" : "Сортировка по URL",
    "RSS feed copied" : "RSS-лента скопирована",
    "Trash Bin" : "Мусорное ведро",
    "Go back" : "Назад",
    "Share folder" : "Поделиться папкой",
    "Open folder details" : "Открыть сведения о папке",
    "Select one or more tags" : "Выберите одну или больше меток",
    "New" : "Новая",
    "New bookmark" : "Новая закладка",
    "New folder" : "Новая папка",
    "Change to grid view" : "Перейти в режим просмотра сеткой",
    "Change to list view" : "Перейти в режим просмотра списком",
    "Copy RSS Feed of current view" : "Скопировать RSS-канал текущего просмотра",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-канал требует аутентификации с вашими учётными данными Nextcloud.",
    "Search" : "Поиск",
    "Empty trash bin" : "Очистить корзину",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Добавление %n закладки в новую папку","Добавление %n закладки в новую папку","Добавление %n закладок в новую папку","Добавление %n закладок в новую папку"],
    "Enter a link" : "Введите ссылку",
    "Enter a title" : "Введите заголовок",
    "No bookmarks found" : "Закладки не найдены",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} папок и {bookmarks} закладок",
    "_%n bookmark_::_%n bookmarks_" : ["%n закладка","%n закладки","%n закладок","%n закладок"],
    "_%n folder_::_%n folders_" : ["%n папка","%n папки","%n папок","%n папок"],
    "Welcome to Bookmarks" : "Добро пожаловать в Закладки",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Это приложение позволяет вам управлять ссылками на ваши любимые места в Интернете. Сортируйте свои закладки по папкам, помечайте их тегами и делитесь ими с другими! Приложение будет регулярно проверять все ваши ссылки на доступность и отображать недействительные ссылки. Если вы добавите ссылку на файл в Интернете, файл будет автоматически загружен в ваши следующие облачные файлы. Вы также можете импортировать закладки, экспортированные из других сервисов, или напрямую синхронизировать закладки из всех ваших браузеров с помощью этого приложения.",
    "Add a bookmark" : "Добавить закладку",
    "Import bookmarks" : "Импорт закладок",
    "Sync with your browser" : "Синхронизация с вашим браузером",
    "Do you really want to permanently delete this folder?" : "Вы действительно хотите навсегда удалить эту папку?",
    "Select folder" : "Выделить папку",
    "Enter folder title" : "Введите название папки",
    "Shared by {user}" : "Опубликовано пользователем {user} ",
    "Rename folder" : "Переименовать папку",
    "Move folder" : "Переместить папку",
    "Put folder into trashbin" : "Поместить папку в корзину",
    "Restore folder" : "Восстановить папку",
    "Delete folder permanently" : "Удалить папку навсегда",
    "Choose folder" : "Выберите папку",
    "Submit" : "Создать",
    "Cancel" : "Отмена",
    "Deleting bookmarks" : "Удаление закладок",
    "Deleting selection" : "Удаление выделенного",
    "Importing bookmarks" : "Импорт закладок",
    "Moving selection" : "Перемещение выделенного",
    "Adding selection to folders" : "Добавление выбора к папкам",
    "Emptying trashbin" : "Опустошение мусорного бака",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Перемещаем %n папку и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки"],
    "_Moving %n folder_::_Moving %n folders_" : ["Перемещаем %n папку","Перемещаем %n папок","Перемещаем %n папок","Перемещаем %n папок"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Перемещаем %n закладку","Перемещаем %n закладок","Перемещаем %n закладок","Перемещаем %n закладок"],
    "All bookmarks" : "Все закладки",
    "Recent" : "Недавние",
    "Shared with you" : "Поделился с вами",
    "Files" : "Файлы",
    "Duplicates" : "Дубликаты",
    "Broken links" : "Нерабочие ссылки",
    "New tag" : "Новый тег",
    "Search tags" : "Поиск по меткам",
    "Delete" : "Удалить",
    "Untagged" : "Без меток",
    "{used} bookmarks of {available} available" : "{used} закладок из {available} возможных",
    "Bookmarks Settings" : "Настройки закладок",
    "No bookmarked files" : "Нет файлов в закладках",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "При сохранении ссылок на фотографии, PDF-файлы и т.д., сами файлы также будут автоматически сохраняться в Nextcloud. Поэтому Вы всегда будете иметь к ним доступ, даже если ссылка не работает.",
    "Nothing found" : "Ничего не найдено",
    "Your search yielded no results in the current folder." : "Ваш поиск не дал результатов в текущей папке.",
    "No broken links" : "Нет нерабочих ссылок",
    "No shared folders" : "Нет общих папок",
    "No duplicated bookmarks" : "Нет дублирующихся ссылок",
    "No deleted bookmarks" : "Нет удаленных закладок",
    "You haven't deleted anything yet." : "Вы пока ничего не удалили.",
    "No bookmarks here" : "Здесь нет закладок",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Добавить закладки вручную или импортировать их из HTML-файла.",
    "Archive path" : "Путь к архиву",
    "Backup path" : "Путь к папке резервных копий",
    "Please select \"Add to home screen\" in your browser menu" : "Пожалуйста, выберите \"Добавить на главную страницу\" в меню Вашего браузера",
    "Bookmarks settings" : "Настройки закладок",
    "Import/Export" : "Импорт/Экспорт",
    "Export bookmarks" : "Экспорт закладок",
    "Auto-archiving" : "Автоархивирование",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Приложение закладок может автоматически архивировать веб-контент ссылок, которые вы добавили в закладки.",
    "Enable archiving" : "Включить архивацию",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Введите путь к папке в ваших файлах, где должны храниться файлы с закладками.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Однако в настоящее время ваш администратор отключил сетевой доступ для этого приложения, поэтому автоматическое архивирование в данный момент отключено.",
    "Auto-Backup" : "Автоматическое резервное копирование",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Приложение «Закладки» может автоматически создавать резервные копии ваших закладок ежедневно, чтобы предотвратить потерю данных при синхронизации закладок между устройствами.",
    "Enable backups" : "Включить резервное копирование",
    "Enter the path of a folder in your Files where backups will be stored." : "Введите путь к папке в ваших файлах, где будут храниться резервные копии.",
    "Context Chat integration" : "Интеграция контекста чата",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Приложение \"Закладки\" может автоматически предоставлять доступ к текстовому содержимому веб-сайтов, добавленных в закладки в \"Context Chat\", что позволяет задавать вопросы и получать ответы на основе этого содержимого. Эта функция доступна только при включенной функции автоматического архивирования.",
    "Context chat is currently not installed, but is required for this feature." : "Контекст чата не установлен, но необходим для данного функционала.",
    "Enable Context Chat integration" : "Включить интеграцию контекста чата",
    "Client apps" : "Клиентские приложения",
    "Also check out the collection of client apps that integrate with this app: " : "Так же попробуйте коллекцию клиентских приложений, которые могут интегрировать с этим приложением",
    "Install web app" : "Установить веб-приложение",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Вы можете установить это приложение на главном экране вашего устройства для быстрого доступа к закладкам на телефоне. Вы можете легко удалить приложение с главного экрана, если оно вам не нравится.",
    "Install on home screen" : "Установить на главную страницу",
    "Bookmarklet" : "Приложение для панели закладок",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Перетащите её в закладки браузера и нажмите на неё, чтобы быстро добавить веб-страницу в закладки.",
    "Add to {instanceName}" : "Добавить в {instanceName}",
    "Need help?" : "Требуется помощь?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Если у вас возникли проблемы с этим приложением «Закладки» или у вас есть идеи о том, что можно улучшить, не стесняйтесь связаться с нами, нажав здесь.",
    "Support this project" : "Поддержать этот проект",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Моя работа над этим приложением Bookmarks подпитывается моделью добровольной подписки. Если вы считаете, что то, что я делаю, стоит того, я буду рад, если вы поддержите мою работу. Также, пожалуйста, рассмотрите возможность дать приложению обзор в магазине приложений Nextcloud. Спасибо 💙",
    "Created {time} ago" : "Время создания: {time}",
    "Created on {date}" : "Дата создания: {date}",
    "(Empty title)" : "(Пустой заголовок)",
    "Title" : "Название",
    "Link" : "Ссылка",
    "Untitled folder" : "Папка без названия",
    "Root folder" : "Корневая папка",
    "Tags" : "Метки",
    "Select tags and create new ones" : "Выбрать метки и создать новую",
    "Notes" : "Заметки",
    "Notes for this bookmark …" : "Примечания к закладкам...",
    "Archived file" : "Архивный файл",
    "Open file" : "Открыть файл",
    "Download file" : "Скачать файл",
    "Open file location" : "Открыть расположение файла",
    "Link copied" : "Ссылка скопирована",
    "Owner" : "Владелец",
    "Sharing" : "Общий доступ",
    "Select a user or group" : "Выберите пользователя или группу",
    "Share link" : "Предоставление общего доступа по ссылке",
    "Reading allowed" : "Чтение разрешено",
    "Copy RSS feed" : "Скопировать RSS-ленту",
    "Delete link" : "Удалить ссылку",
    "Create public link" : "Создать общедоступную ссылку",
    "Resharing allowed" : "Повторная публикация разрешена",
    "Editing allowed" : "Редактирование разрешено",
    "Allow editing" : "Разрешить редактирование",
    "Allow resharing" : "Разрешить повторную публикацию",
    "Remove share" : "Закрыть общий доступ",
    "Leave a rating on the Nextcloud App Store" : "Оставьте оценку в Nextcloud App Store",
    "Failed to save settings" : "Не удалось сохранить настройки",
    "Failed to load settings" : "Не удалось загрузить настройки",
    "Privacy" : "Приватность",
    "The app will try to access web pages that you add to automatically add information about them." : "Приложение попытается получить доступ к добавленным вами веб-страницам, чтобы автоматически добавить информацию о них.",
    "Enable accessing and collecting information from the web pages you add" : "Включить доступ и сбор информации с веб-страниц, добавляемых вами",
    "Performance" : "Производительность",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "При установке с большим числом пользователей может оказаться полезным ограничение количества закладок на одну учетную запись",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Максимально допустимое количество закладок для аккаунта (0 для безлимита, он же по-умолчанию)",
    "Previews" : "Предварительный просмотр",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Чтобы отображать реальные скриншоты добавленных вами в закладки веб-сайтов, приложение может использовать сторонние сервисы для создания предпросмотров.",
    "Screeenly" : "Screenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Вы можете либо зарегистрироваться бесплатно на screeenly.com или настроить свой сервер.",
    "Screeenly API URL" : "Ссылка на Screenly API",
    "Screeenly API key" : "API-ключ Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Универсальный API для создания снимков экрана",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Зарегистрируйтесь у любого поставщика API скриншотов и введите URL API ниже. Используйте переменную {url} как заполнитель для URL для скриншота. API должен возвращать только изображение напрямую.",
    "Generic API URL" : "Общий URL-адрес API",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Просто установите Pageres CLI от Sindre Sorhus на свой сервер, и Bookmarks найдет его. Вы все еще можете добавить дополнительные переменные ENV для передачи в pageres, например, как указано в плейсхолдере:",
    "Pageres ENV variables" : "Переменные Pageres ENV",
    "This URL is already bookmarked! Overwrite?" : "Эта ссылка уже в закладках! Перезаписать?",
    "Enter bookmark title" : "Введите заголовок закладки",
    "Enter bookmark URL" : "Введите URL закладки",
    "Folder" : "Каталог",
    "Root Folder" : "Корневая папка",
    "Save" : "Сохранить",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "По умолчанию доступ к сети отключен. Перейдите в настройки администратора для приложения закладок, чтобы разрешить получение превью и значков.",
    "What's new?" : "Что нового?",
    "What" : "Что",
    "Failed to count unavailable bookmarks" : "Не удалось определить число недоступных закладок",
    "Failed to count archived bookmarks" : "Не удалось определить число архивных закладок",
    "Failed to count duplicated bookmarks" : "Не удалось подсчитать дублирующиеся закладки",
    "Failed to count bookmarks" : "Не удалось подсчитать закладки",
    "Failed to load bookmark" : "Не удалось загрузить закладку",
    "Failed to find existing bookmark" : "Не удалось найти существующую закладку",
    "Failed to create bookmark" : "Не удалось создать закладку",
    "Failed to save bookmark" : "Не удалось сохранить закладку",
    "Failed to move bookmark" : "Не удалось переместить закладку",
    "Failed to copy bookmark" : "Не удалось скопировать закладку",
    "Failed to delete bookmark" : "Не удалось удалить закладку",
    "Failed to restore bookmark" : "Не удалось восстановить закладку",
    "Import successful" : "Импорт успешно завершён",
    "Failed to rename tag" : "Не удалось переименовать закладку",
    "Failed to load tags" : "Не удалось загрузить метки",
    "Failed to load folders" : "Не удалось загрузить папки",
    "Failed to load deleted folders" : "Не удалось загрузить удаленные папки.",
    "Failed to load deleted bookmarks" : "Не удалось загрузить удаленные закладки.",
    "Failed to delete folder" : "Не удалось удалить папку",
    "Failed to move folder" : "Не удалось переместить папку",
    "Failed to restore folder" : "Не удалось восстановить папку",
    "Failed to create folder" : "Не удалось создать папку",
    "Failed to load children order" : "Не удалось загрузить порядок вложенных элементов",
    "Failed to move parts of selection" : "Не удалось переместить часть выделенных объектов",
    "Failed to copy parts of selection" : "Не удалось скопировать часть выбранных элементов",
    "Failed to delete parts of selection" : "Не удалось удалить часть выделенных объектов",
    "Failed to tag parts of selection" : "Не удалось добавить метки к части выбранных элементов",
    "Failed to fetch bookmarks." : "Не удалось извлечь закладки.",
    "Failed to store setting" : "Не удалось сохранить настройку",
    "Failed to load setting {key}" : "Не удалось загрузить настройку {key}",
    "Failed to create share for folder {folderId}" : "Не удалось создать общий доступ для папки {folderId}",
    "Failed to update share {shareId}" : "Не удалось обновить общий ресурс {shareId}",
    "Failed to delete share {shareId}" : "Не удалось удалить общий ресурс {shareId}",
    "Failed to create public link for folder {folderId}" : "Не удалось создать публичную ссылку для папки {folderId}",
    "Failed to delete public link for folder {folderId}" : "Не удалось удалить публичную ссылку для папки {folderId}",
    "Failed to permanently delete parts of trash bin" : "Не удалось безвозвратно удалить часть содержимого корзины",
    "Create bookmarks for mentioned links" : "Создать закладки для упомянутых ссылок",
    "No links found in this message" : "В этом сообщении не найдено ссылок",
    "Bookmarks feed" : "Лента закладок"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
