OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Manylion",
    "Rename" : "Ailenwi",
    "Copy link" : "Copïo dolen",
    "Move" : "Symud",
    "Go back" : "Nôl",
    "New" : "Newydd",
    "New folder" : "Ffolder newydd",
    "Search" : "Chwilio",
    "Empty trash bin" : "Bin sbwriel gwag",
    "Cancel" : "Diddymu",
    "Recent" : "Diweddar",
    "Shared with you" : "Shared with you",
    "Files" : "Ffeiliau",
    "Delete" : "Dileu",
    "Title" : "Teitl",
    "Link" : "Dolen",
    "Tags" : "Tagiau",
    "Notes" : "Nodiadau",
    "Link copied" : "Dolen wedi'i gopïo",
    "Owner" : "Owner",
    "Share link" : "Rhannu dolen",
    "Allow editing" : "Caniatáu golygu",
    "Folder" : "Plygell",
    "Save" : "Cadw"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
