OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Vialamisho",
    "You bookmarked \"%s\"" : "Umealamisha \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s imealamisha \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Mtu fulani alialamisha \"%s\"",
    "You deleted \"%s\"" : "Ulifuta \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s imefuta \"%2$s\"",
    "Someone deleted \"%s\"" : "Mtu fulani amefuta \"%s\"",
    "You created folder \"%s\"" : "Umeunda folda \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s ameunda folda \"%2$s\"",
    "Someone created folder \"%s\"" : "Mtu fulani ameunda folda \"%s\"",
    "You moved folder \"%s\"" : "Umehamisha folda \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s amehamisha folda \"%2$s\"",
    "Someone moved folder \"%s\"" : "Mtu fulani amehamisha folda \"%s\"",
    "You deleted folder \"%s\"" : "Umefuta folda \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s amefuta folda \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Mtu fulani amefuta folda \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Umeshiriki folda \"%1$s\" na %2$s",
    "You shared folder \"%s\" with someone" : "Umeshiriki folda \"%s\" na mtu fulani",
    "%1$s shared folder \"%2$s\" with you" : "%1$s shared folder \"%2$s\" with you",
    "Someone shared folder \"%s\" with you" : "Mtu fulani alishiriki folda \"%s\" nawe",
    "You unshared folder \"%1$s\" with %2$s" : "Umebatilisha kushiriki folda \"%1$s\" na %2$s",
    "You unshared folder \"%s\" with someone" : "Umeghairi folda \"%s\" na mtu fulani",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s folda ambayo haijashirikiwa nawe \"%2$s\"",
    "Someone unshared folder \"%s\" with you" : "Mtu fulani ameghairi folda \"%s\" na wewe",
    "No file provided for import" : "Hakuna faili iliyotolewa kwa uingizaji",
    "Failed to upload file" : "Imeshindwa kupakia faili",
    "Unsupported file type for import: " : "Aina ya faili isiyotumika kwa uletaji:",
    "Bookmarks shared by %s" : "Alamisho zilizoshirikiwa na %s",
    "Frequent bookmarks" : "Alamisho za mara kwa mara",
    "Recent bookmarks" : "Alamisho za hivi karibuni",
    "Bookmark" : "Alamisho",
    "Bookmark deleted" : "Alamisho imefutwa",
    "Bookmark created" : "Alamisho imeundwa",
    "Bookmark moved" : "Alamisho imeondolewa",
    "Bookmark updated" : "Alamisho imesasishwa",
    "Create bookmark" : "Unda alamisho",
    "Takes a link and adds it to your collection of bookmarks." : "Huchukua kiungo na kukiongeza kwenye mkusanyiko wako wa vialamisho.",
    "Bookmarks Backups" : "Hifadhi za Alamisho",
    "Collect and manage bookmarks, synced with all your devices" : "Kusanya na udhibiti alamisho, zilizosawazishwa na vifaa vyako vyote",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Panga alamisho kwenye folda\n- 🏷 Ongeza vitambulisho na maelezo ya kibinafsi\n- ☠ Tafuta viungo na nakala zilizovunjika\n- 📲 Sawazisha na vivinjari na vifaa vyako vyote\n- 📔 Hifadhi matoleo yaliyohifadhiwa ya viungo vyako endapo yatabatilishwa kuchapishwa\n- 🔍 Utafutaji wa maandishi kamili kwenye yaliyomo kwenye tovuti\n- 👪 Shiriki alamisho na watumiaji wengine, vikundi na timu au kupitia viungo vya umma\n- ⚛ Tengeneza milisho ya RSS ya mikusanyiko yako\n- 📈 Takwimu za mara ngapi unapata viungo vipi\n- 🔒 Hifadhi nakala za kiotomatiki za mkusanyiko wako wa alamisho\n- 💼 Wijeti za Dashibodi Zilizojengwa ndani kwa viungo vya mara kwa mara na vya hivi majuzi\n\nMahitaji:\n- Viendelezi vya PHP:\n- intl: *\n-mbstring:*\n- unapotumia MySQL, tumia angalau v8.0",
    "Do you really want to delete this bookmark?" : "Je, kweli unataka kufuta alamisho hii?",
    "Link copied to clipboard" : "Kiungo kimenakiliwa kwenye ubao wakunakilia",
    "Enter new title" : "Weka kichwa kipya",
    "Select bookmark" : "Chagua alamisho",
    "You have never clicked this link" : "Hujawahi kubofya kiungo hiki",
    "You have clicked this link {count} times" : "Umebofya kiungo hiki mara {count}",
    "Details" : "Maelezo ya kina",
    "Rename" : "Ipe jina jipya",
    "Copy link" : "Nakili kiungio",
    "Move" : "Hamisha",
    "Add to folders" : "Ongeza folda",
    "Put bookmark into trash bin" : "Weka alamisho kwenye pipa la taka",
    "Restore bookmark" : "Rejesha alamisho",
    "Delete bookmark permanently" : "Futa alamisho kabisa",
    "Content pending" : "Maudhui yanasubiri",
    "This content is being downloaded for offline use. Please check back later." : "Maudhui haya yanapakuliwa kwa matumizi ya nje ya mtandao. Tafadhali angalia tena baadaye.",
    "Bookmarked {time} ago" : "Imewekwa alama {time} zilizopita",
    "Bookmarked on {date}" : "Imewekwa alama tarehe {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Hivi ni vipengee vyako vilivyofutwa. Vipengee vitafutwa kabisa baada ya miezi miwili.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Alamisho za faili zilizo kwenye wavuti kama vile picha au PDF zitahifadhiwa kiotomatiki kwenye faili zako za Nextcloud, kwa hivyo bado unaweza kuzipata hata kiungo kikiwa nje ya mtandao.",
    "Searching in the current folder only." : "Inatafuta katika folda ya sasa pekee.",
    "Repeat search in all folders" : "Rudia utafutaji katika folda zote",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Viungo vilivyoalamishwa huangaliwa mara kwa mara na vile ambavyo haviwezi kufikiwa vimeorodheshwa hapa.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Unaweza kushiriki folda za alamisho na wengine. Folda zote zilizoshirikiwa nawe zimeorodheshwa hapa.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Alamisho moja inaweza kuwa katika folda nyingi mara moja. Kuisasisha kutasasisha nakala zote. Alamisho zote zilizorudiwa zimeorodheshwa hapa kwa urahisi.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Umechagua {folders}folda na {bookmarks}alamisho ",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Selected %n bookmark","Alamisho %n zimechaguliwa"],
    "_Selected %n folder_::_Selected %n folders_" : ["Selected %n folder","Umechagua folda %n"],
    "Do you really want to delete these items?" : "Je, kweli unataka kufuta vipengee hivi?",
    "Open all selected" : "Fungua zote zilizochaguliwa",
    "Move selection" : "Sogeza uteuzi",
    "Edit tags of selection" : "Hariri lebo za uteuzi",
    "Delete selection" : "Futa machaguo",
    "Select all" : "Chagua zote",
    "Cancel selection" : "Ghairi uteuzi",
    "Sort by created date" : "Panga kwa tarehe ya kuundwa",
    "Sort by last modified" : "Panga kwa tarehe ya mwisho kubadilishwa",
    "Sort by title" : "Panga kwa kichwa",
    "Sort by click count" : "Panga kwa hesabu ya kubofya",
    "Sort by manual order" : "Panga kwa agizo la mwongozo",
    "Sort by URL" : "Panga kwa URL",
    "RSS feed copied" : "Mipasho ya RSS imenakiliwa",
    "Trash Bin" : "Pipa la takataka",
    "Go back" : "Rudi nyuma",
    "Share folder" : "Shirikisha folda",
    "Open folder details" : "Fungua maelezo ya folda",
    "Select one or more tags" : "Chagua lebo moja au zaidi",
    "New" : "Mpya",
    "New bookmark" : "Alamisho mpya",
    "New folder" : "Kisanduku kipya",
    "Change to grid view" : "Badilisha hadi mwonekano wa gridi",
    "Change to list view" : "Badilisha hadi mwonekano wa orodha",
    "Copy RSS Feed of current view" : "Nakili Mlisho wa RSS wa mwonekano wa sasa",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Mlisho wa RSS unahitaji uthibitishaji na hati zako za Nextcloud",
    "Search" : "Tafuta",
    "Empty trash bin" : "Weka tupu chombo cha takataka",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Adding %n bookmark to new folder","Inaongeza alamisho %n kwenye folda mpya"],
    "Enter a link" : "Ingiza kiungo",
    "Enter a title" : "Ingiza kichwa",
    "No bookmarks found" : "Hakuna alamisho zilizopatikana",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} folda na {bookmarks} vialamisho",
    "_%n bookmark_::_%n bookmarks_" : ["%n bookmark","%n vialamisho "],
    "_%n folder_::_%n folders_" : ["%n folder","%n folda"],
    "Welcome to Bookmarks" : "Karibu kwenye Alamisho",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Programu hii hukuruhusu kudhibiti viungo vya maeneo unayopenda kwenye wavuti. Panga alamisho zako katika folda, ziweke lebo na uzishiriki na wengine! Programu itaangalia mara kwa mara viungo vyako vyote kwa upatikanaji na kuonyesha viungo visivyopatikana. Ukiongeza kiungo kwa faili kwenye wavuti, faili itapakuliwa kiotomatiki kwa Faili zako za Nextcloud. Unaweza pia kuleta alamisho zilizohamishwa kutoka kwa huduma zingine au kusawazisha alamisho moja kwa moja kutoka kwa vivinjari vyako vyote na programu hii.",
    "Add a bookmark" : "Ongeza alamisho",
    "Import bookmarks" : "Ingiza alamisho",
    "Sync with your browser" : "Sawazisha na kivinjari chako",
    "Do you really want to permanently delete this folder?" : "Je, kweli unataka kufuta folda hii kabisa?",
    "Select folder" : "Chagua folda",
    "Enter folder title" : "Ingiza kichwa cha folda",
    "Shared by {user}" : "Imeshirikishwa na{user}",
    "Rename folder" : "Rename folder",
    "Move folder" : "Sogeza folda",
    "Put folder into trashbin" : "Weka folda kwenye chombo cha taka taka",
    "Restore folder" : "Rejesha folda",
    "Delete folder permanently" : "Futa folda kabisa",
    "Choose folder" : "Chagua folda",
    "Submit" : "Wasilisha",
    "Cancel" : "Ghairi",
    "Deleting bookmarks" : "Kufuta alamisho",
    "Deleting selection" : "Kufuta uteuzi",
    "Importing bookmarks" : "Kuagiza alamisho",
    "Moving selection" : "Kuhamisha uteuzi",
    "Adding selection to folders" : "Kuongeza uteuzi kwenye folda",
    "Emptying trashbin" : "Kutupa takataka",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Moving %n folder and some bookmarks","Inahamisha folda %n na baadhi ya vialamisho"],
    "_Moving %n folder_::_Moving %n folders_" : ["Moving %n folder","Inahamisha folda %n"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Moving %n bookmark","Inahamisha vialamisho %n"],
    "All bookmarks" : "Alamisho zote",
    "Recent" : "Hivi karibuni",
    "Shared with you" : "Imeshirikiwa na wewe",
    "Files" : "Mafaili",
    "Duplicates" : "Nakala rudufu",
    "Broken links" : "Viungo vilivyovunjika",
    "New tag" : "Lebo mpya",
    "Search tags" : "Tafuta vitambulisho",
    "Delete" : "Futa",
    "Untagged" : "Haijabandikwa",
    "{used} bookmarks of {available} available" : "alamisho {used} za {available} zinapatikana",
    "Bookmarks Settings" : "Mipangilio ya Alamisho",
    "No bookmarked files" : "Hakuna faili zilizoalamishwa",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Alamisho za faili kama vile picha au PDF zitahifadhiwa kiotomatiki kwenye faili zako za Nextcloud, kwa hivyo bado unaweza kuzipata hata kiungo kikiwa nje ya mtandao.",
    "Nothing found" : "Hakuna kitu kilichopatikana",
    "Your search yielded no results in the current folder." : "Utafutaji wako haukuzaa matokeo katika folda ya sasa.",
    "No broken links" : "Hakuna viungo vilivyoharibika",
    "No shared folders" : "Hakuna folda zilizoshirikiwa",
    "No duplicated bookmarks" : "Hakuna alamisho zilizorudiwa",
    "No deleted bookmarks" : "Hakuna alamisho zilizofutwa",
    "You haven't deleted anything yet." : "Hakuna alamisho zilizofutwa",
    "No bookmarks here" : "Hakuna alamisho hapa",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Ongeza vialamisho wewe mwenyewe au leta alamisho kutoka kwa faili ya HTML.",
    "Archive path" : "Njia ya kumbukumbu",
    "Backup path" : "Njia ya chelezo",
    "Please select \"Add to home screen\" in your browser menu" : "Tafadhali chagua \"Ongeza kwenye skrini ya nyumbani\" katika menyu ya kivinjari chako",
    "Bookmarks settings" : "Mipangilio ya vialamisho",
    "Import/Export" : "Ingiza/Hamisha",
    "Export bookmarks" : "Hamisha alamisho",
    "Auto-archiving" : "Kuhifadhi kumbukumbu kiotomatiki",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Programu ya alamisho inaweza kuweka kiotomatiki maudhui ya wavuti ya viungo ulivyoalamisha",
    "Enable archiving" : "Washa uwekaji kumbukumbu",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Ingiza njia ya folda katika Faili zako ambapo faili zilizoalamishwa zinapaswa kuhifadhiwa.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Kwa sasa msimamizi wako amezima ufikiaji wa mtandao wa programu hii, hata hivyo, ndiyo maana uhifadhi wa kumbukumbu kiotomatiki umezimwa kwa sasa.",
    "Auto-Backup" : "Hifadhi Nakala Kiotomatiki",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Programu ya alamisho inaweza kuhifadhi nakala za alamisho zako kiotomatiki kila siku ili kuzuia upotezaji wa data wakati wa kusawazisha alamisho kwenye vifaa vyote.",
    "Enable backups" : "Washa chelezo",
    "Enter the path of a folder in your Files where backups will be stored." : "Ingiza njia ya folda katika Faili zako ambapo chelezo zitahifadhiwa.",
    "Context Chat integration" : "Muunganisho wa Gumzo la Muktadha",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Programu ya alamisho inaweza kutoa kiotomatiki maudhui ya maandishi ya tovuti unazoalamisha kwa Context Chat, ambayo inaruhusu kuuliza maswali kuhusu na kupata majibu kulingana na yaliyomo. Hii inapatikana tu ikiwa kuhifadhi kiotomatiki kumewashwa.",
    "Context chat is currently not installed, but is required for this feature." : "Gumzo la muktadha halijasakinishwa kwa sasa, lakini linahitajika kwa kipengele hiki.",
    "Enable Context Chat integration" : "Washa muunganisho wa Gumzo la Muktadha",
    "Client apps" : "Programu za mteja",
    "Also check out the collection of client apps that integrate with this app: " : "Pia angalia mkusanyiko wa programu za mteja zinazounganishwa na programu hii:",
    "Install web app" : "Sakinisha programu ya wavuti",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Unaweza kusakinisha programu hii kwenye skrini ya kwanza ya kifaa chako ili kufikia alamisho zako kwenye simu yako kwa haraka. Unaweza kuondoa programu kwa urahisi kutoka skrini yako ya kwanza tena, ikiwa huipendi.",
    "Install on home screen" : "Sakinisha kwenye skrini ya nyumbani",
    "Bookmarklet" : "Alamisho ndogo",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Buruta hii hadi kwenye vialamisho vya kivinjari chako na ubofye ili kualamisha ukurasa wa tovuti haraka.",
    "Add to {instanceName}" : "Ongeza kwenye {instanceName}",
    "Need help?" : "Unahitaji masaada?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Ikiwa una matatizo na programu hii ya Alamisho au una wazo kuhusu kinachoweza kuboreshwa, usisite kuwasiliana kwa kubofya hapa.",
    "Support this project" : "Saidia mradi huu",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Kazi yangu kwenye programu hii ya Alamisho huchochewa na muundo wa usajili wa hiari. Ikiwa unafikiri ninachofanya ni cha manufaa, ningefurahi ikiwa unaweza kuunga mkono kazi yangu. Pia, tafadhali zingatia kuipa programu hakiki kwenye Duka la programu la Nextcloud. Asante 💙",
    "Created {time} ago" : "Iliundwa {time} zilizopita",
    "Created on {date}" : "Iliundwa tarehe {date}",
    "(Empty title)" : "(Jina tupu)",
    "Title" : "Kichwa cha habari",
    "Link" : "Kiungio",
    "Untitled folder" : "Folda isiyo na jina",
    "Root folder" : "Folda ya mizizi",
    "Tags" : "Maoni",
    "Select tags and create new ones" : "Chagua lebo na uunde mpya",
    "Notes" : "Madokezo",
    "Notes for this bookmark …" : "Vidokezo vya alamisho hii…",
    "Archived file" : "Faili iliyohifadhiwa",
    "Open file" : "Open file",
    "Download file" : "Pakua faili",
    "Open file location" : "Fungua eneo la faili",
    "Link copied" : "Kiungo kimenakiliwa",
    "Owner" : "Mmiliki",
    "Sharing" : "inashirikisha",
    "Select a user or group" : "Chagua mtumiaji au kikundi",
    "Share link" : "Shirikisha kiungo",
    "Reading allowed" : "Kusoma kuruhusiwa",
    "Copy RSS feed" : "Nakili mlisho wa RSS",
    "Delete link" : "Futa kiungo",
    "Create public link" : "Tengeneza kiungo cha umma",
    "Resharing allowed" : "Kushiriki upya kunaruhusiwa",
    "Editing allowed" : "Uhariri unaruhusiwa",
    "Allow editing" : "Ruhusu kuhariri",
    "Allow resharing" : "Ruhusu kushiriki upya",
    "Remove share" : "Ondoa kushiriki",
    "Leave a rating on the Nextcloud App Store" : "Acha ukadiriaji kwenye Nextcloud App Store",
    "Failed to save settings" : "Imeshindwa kuhifadhi mipangilio",
    "Failed to load settings" : "Imeshindwa kupakia mipangilio",
    "Privacy" : "Faragha",
    "The app will try to access web pages that you add to automatically add information about them." : "Programu itajaribu kufikia kurasa za wavuti unazoongeza ili kuongeza maelezo kuzihusu kiotomatiki.",
    "Enable accessing and collecting information from the web pages you add" : "Wezesha kufikia na kukusanya taarifa kutoka kwa kurasa za wavuti unazoongeza",
    "Performance" : "Utendaji",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Katika usakinishaji na watumiaji wengi inaweza kuwa na manufaa kuzuia idadi ya vialamisho kwa kila akaunti.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Idadi ya juu inayoruhusiwa ya vialamisho kwa kila akaunti. (0 bila kikomo; chaguo-msingi hakuna kikomo)",
    "Previews" : "Muhtasari",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Ili kuonyesha picha halisi za skrini za tovuti zako zilizoalamishwa, programu inaweza kutumia huduma za wahusika wengine kutoa uhakiki.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Unaweza kujisajili bila malipo kwenye screeenly.com au kusanidi seva yako mwenyewe.",
    "Screeenly API URL" : "URL ya API ya screenly",
    "Screeenly API key" : "Kitufe cha API cha screenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Kitufe cha API cha ScreenshotMachine",
    "Webshot" : "Picha ya wavuti",
    "Webshot API URL" : "URL ya API ya Wavuti",
    "Generic screenshot API" : "API ya picha ya skrini ya jumla",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Jisajili na watoa huduma wowote wa API ya skrini na uweke URL ya API hapa chini. Tumia kibadala cha {url} kama kishikilia nafasi kwa URL kupiga picha ya skrini. API lazima irudishe tu picha moja kwa moja.",
    "Generic API URL" : "URL ya API ya Jumla",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Sakinisha tu Pageres CLI na Sindre Sorhus kwenye seva yako na Alamisho utaipata. Bado unaweza kuongeza vazi za ziada za ENV ili kulishwa kwa kurasa, k.m. kama inavyoonyeshwa kwenye kishika nafasi:",
    "Pageres ENV variables" : "Vigezo vya Pageres ENV",
    "This URL is already bookmarked! Overwrite?" : "URL hii tayari imealamishwa! Ungependa kufuta?",
    "Enter bookmark title" : "Weka kichwa cha alamisho",
    "Enter bookmark URL" : "Weka URL ya alamisho",
    "Folder" : "Kisanduku",
    "Root Folder" : "Folda ya Mizizi",
    "Save" : "Hifadhi",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Ufikiaji wa mtandao umezimwa kwa chaguomsingi. Nenda kwenye mipangilio ya msimamizi kwa programu ya alamisho ili kuruhusu kuleta muhtasari na favicon",
    "What's new?" : "Nini kipya?",
    "What" : "Nini",
    "Failed to count unavailable bookmarks" : "Imeshindwa kuhesabu alamisho ambazo hazipatikani",
    "Failed to count archived bookmarks" : "Imeshindwa kuhesabu vialamisho vilivyohifadhiwa kwenye kumbukumbu",
    "Failed to count deleted bookmarks" : "Imeshindwa kuhesabu alamisho zilizofutwa",
    "Failed to count duplicated bookmarks" : "Imeshindwa kuhesabu alamisho zilizorudiwa",
    "Failed to count bookmarks" : "Imeshindwa kuhesabu vialamisho",
    "Failed to load bookmark" : "Imeshindwa kupakia alamisho",
    "Failed to find existing bookmark" : "Imeshindwa kupata alamisho iliyopo",
    "Failed to create bookmark" : "Imeshindwa kuunda alamisho",
    "Failed to save bookmark" : "Imeshindwa kuhifadhi alamisho",
    "Failed to move bookmark" : "Imeshindwa kuhamisha alamisho",
    "Failed to copy bookmark" : "Imeshindwa kunakili alamisho",
    "Failed to delete bookmark" : "Imeshindwa kufuta alamisho",
    "Failed to restore bookmark" : "Imeshindwa kurejesha alamisho",
    "Import successful" : "Imefaulu kuleta",
    "Failed to rename tag" : "Imeshindwa kubadilisha jina la lebo",
    "Failed to load tags" : "Imeshindwa kupakia lebo",
    "Failed to load folders" : "Imeshindwa kupakia folda",
    "Failed to load deleted folders" : "Imeshindwa kupakia folda zilizofutwa",
    "Failed to load deleted bookmarks" : "Imeshindwa kupakia alamisho zilizofutwa",
    "Failed to delete folder" : "Imeshindwa kufuta folda",
    "Failed to move folder" : "Imeshindwa kuhamisha folda",
    "Failed to restore folder" : "Imeshindwa kurejesha folda",
    "Failed to create folder" : "Imeshindwa kuunda folda",
    "Failed to load children order" : "Imeshindwa kupakia agizo la watoto",
    "Failed to move parts of selection" : "Imeshindwa kuhamisha sehemu za uteuzi",
    "Failed to copy parts of selection" : "Imeshindwa kunakili sehemu za uteuzi",
    "Failed to delete parts of selection" : "Imeshindwa kufuta sehemu za uteuzi",
    "Failed to tag parts of selection" : "Imeshindwa kuweka lebo kwenye sehemu za uteuzi",
    "Failed to fetch bookmarks." : "Imeshindwa kuleta vialamisho.",
    "Failed to store setting" : "Imeshindwa kuhifadhi mipangilio",
    "Failed to load setting {key}" : "Imeshindwa kupakia mipangilio {key}",
    "Failed to create share for folder {folderId}" : "Imeshindwa kuunda kishiriki kwa folda {folderId}",
    "Failed to update share {shareId}" : "Imeshindwa kusasisha share {shareId}",
    "Failed to delete share {shareId}" : "Imeshindwa kufuta shiriki {shareId}",
    "Failed to create public link for folder {folderId}" : "Imeshindwa kuunda kiungo cha umma cha folda {folderId}",
    "Failed to delete public link for folder {folderId}" : "Imeshindwa kufuta kiungo cha umma cha folda {folderId}",
    "Failed to permanently delete parts of trash bin" : "Imeshindwa kufuta kabisa sehemu za pipa la taka",
    "Create bookmarks for mentioned links" : "Unda alamisho za viungo vilivyotajwa",
    "No links found in this message" : "Hakuna viungo vilivyopatikana katika ujumbe huu",
    "Bookmarks feed" : "Mlisho wa vialamisho"
},
"nplurals=2; plural=(n != 1);");
