<?php
$TRANSLATIONS = array(
"Bookmarks" => "Favoris",
"Bookm." => "Fav.",
"No file provided for import" => "Aucun fichier fourni pour l'importation",
"Unsupported file type for import" => "Type de fichier non pris en charge à l'importation",
"Some Error happened." => "Une erreur est survenue.",
"Error" => "Erreur",
"Tags" => "Étiquettes",
"Filter by tag" => "Filtrer par étiquette",
"Are you sure you want to remove this bookmark?" => "Êtes-vous sûr de vouloir supprimer ce favori ?",
"Warning" => "Attention",
"Are you sure you want to remove this tag from every entry?" => "Êtes-vous certain de vouloir retirer cette étiquette de chaque entrée ?",
"Import error" => "Erreur d'importation",
"Import completed successfully." => "L'importation s'est achevée avec succès.",
"Uploading..." => "Téléversement en cours…",
"Add a bookmark" => "Ajouter un favori",
"This URL is already bookmarked! Overwrite?" => "Cet URL est déjà en favori ! Le ré-écrire ?",
"The title of the page" => "Le titre de la page",
"The address of the page" => "L'adresse de la page",
"Description of the page" => "Description de la page",
"Save" => "Sauvegarder",
"Delete" => "Supprimer",
"Edit" => "Modifier",
"Cancel" => "Annuler",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Glissez ceci dans les marque-pages de votre navigateur et cliquez dessus pour ajouter la page courante à vos favoris :",
"Add to ownCloud" => "Ajouter à ownCloud",
"Address" => "Adresse",
"Filterable Tags" => "Étiquettes filtrables",
"You have no bookmarks" => "Vous n'avez aucun favori",
"You can also import a bookmark file" => "Vous pouvez également importer un fichier de favoris",
"Bookmarklet" => "Applisignet",
"Export & Import" => "Importer et exporter",
"Export" => "Exporter",
"Import" => "Importer"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
