OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Отметки",
    "You bookmarked \"%s\"" : "Вие поставихте отметка  „%s“",
    "%1$s bookmarked \"%2$s\"" : "%1$s поставена отметка  „%2$s“",
    "Someone bookmarked \"%s\"" : "Някой постави отметка „%s“",
    "You deleted \"%s\"" : "Вие изтрихте „%s“",
    "%1$s deleted \"%2$s\"" : "%1$s изтрито  „%2$s“",
    "Someone deleted \"%s\"" : "Някой изтри „%s“",
    "You created folder \"%s\"" : "Вие създадохте папка „%s“",
    "%1$s created folder \"%2$s\"" : "%1$s създадена папка „%2$s“",
    "Someone created folder \"%s\"" : "Някой създаде папка „%s“",
    "You moved folder \"%s\"" : "Вие преместихте папка „%s“",
    "%1$s moved folder \"%2$s\"" : "%1$s премести папка „%2$s“",
    "Someone moved folder \"%s\"" : "Някой премести папка „%s“",
    "You deleted folder \"%s\"" : "Вие изтрихте папка „%s“",
    "%1$s deleted folder \"%2$s\"" : "%1$s изтри папка „%2$s“",
    "Someone deleted folder \"%s\"" : "Някой изтри папка „%s“",
    "You shared folder \"%1$s\" with %2$s" : "Вие споделихте папка „%1$s“ с %2$s",
    "You shared folder \"%s\" with someone" : "Споделихте папка „%s“ с някой",
    "%1$s shared folder \"%2$s\" with you" : "%1$s сподели папка „%2$s“ с вас",
    "Someone shared folder \"%s\" with you" : "Някой сподели папка „%s“ с вас",
    "You unshared folder \"%1$s\" with %2$s" : "Вие прекратихте споделянето на папка „%1$s“ с %2$s",
    "You unshared folder \"%s\" with someone" : "Вие прекратихте споделянето на папка „%s“ с някого",
    "%1$s unshared folder \"%2$s\" with you" : "%1$sпрекрати споделянето на папка „%2$s“ с вас",
    "Someone unshared folder \"%s\" with you" : "Някой прекрати споделянето на папка „%s“ с вас",
    "No file provided for import" : "Няма избран файл за внасяне",
    "Bookmarks shared by %s" : "Отметки, споделени от %s",
    "Frequent bookmarks" : "Чести отметки",
    "Recent bookmarks" : "Скорошни отметки",
    "Bookmark" : "Отметка",
    "Bookmark deleted" : "Изтрита е отметка",
    "Bookmark created" : "Създадена е отметка",
    "Bookmark moved" : "Преместене е отметка",
    "Bookmark updated" : "Актуализирана е отметка",
    "Create bookmark" : "Създаване на отметка",
    "Takes a link and adds it to your collection of bookmarks." : "Взема връзка и я добавя към вашата колекция от отметки.",
    "Bookmarks Backups" : "Резервни копия на отметки",
    "Do you really want to delete this bookmark?" : "Наистина ли желаете да изтрете тази отметка?",
    "Link copied to clipboard" : "Връзката е копирана в клипборда",
    "Enter new title" : "Въвеждане на ново заглавие",
    "Select bookmark" : "Избор на отметка",
    "Details" : "Подробности",
    "Rename" : "Преименувай",
    "Copy link" : "Копирай връзката",
    "Move" : "Преместване",
    "Add to folders" : "Добави към папки",
    "Content pending" : "Чака се съдържание",
    "This content is being downloaded for offline use. Please check back later." : "Това съдържание се изтегля за офлайн употреба. Моля, проверете отново по-късно.",
    "Bookmarked {time} ago" : "Маркирано /отметнато/ преди {time}",
    "Bookmarked on {date}" : "Маркирано /отметнато/ на {date}",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Отметките към файлове в мрежата, като снимки или PDF файлове, автоматично ще бъдат запазени във вашите Nextcloud файлове, така че все още ще можете да ги намерите, дори когато връзката е офлайн.",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Връзките с отметки се проверяват редовно и тези, които не могат да бъдат достигнати са изброени тук.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Можете да споделяте папки с отметки с другите. Всички папки, споделени с вас, са изброени тук.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Една отметка може да бъде в няколко папки наведнъж. При актуализирането и ще се актуализират всички копия. Всички дублирани отметки са изброени тук за удобство.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Избрани {folders} папки и {bookmarks} отметки",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Избрани са %n отметки","Избрани са %n отметки"],
    "_Selected %n folder_::_Selected %n folders_" : ["Избрани са %n папки","Избрани са %n папки"],
    "Do you really want to delete these items?" : "Наистина ли искате да изтриете тези елементи?",
    "Open all selected" : "Отворяне на всички избрани",
    "Move selection" : "Преместване на селекцията",
    "Edit tags of selection" : "Редактиране на маркери на селекцията",
    "Delete selection" : "Изтриите селекцията",
    "Select all" : "Избери всички",
    "Cancel selection" : "Отказване на селекцията",
    "Sort by created date" : "Сортиране по дата на създаване",
    "Sort by last modified" : "Сортиране по последна промяна",
    "Sort by title" : "Сортиране по заглавие",
    "Sort by click count" : "Сортиране по брой щраквания",
    "Sort by manual order" : "Сортиране по ръчен ред",
    "Sort by URL" : "Сортиране по URLадрес",
    "RSS feed copied" : "RSS емисия е копирана",
    "Go back" : "Назад",
    "Share folder" : "Споделяне на папка",
    "Select one or more tags" : "Избор един или повече етикета",
    "New" : "Нов",
    "New bookmark" : "Нова отметка",
    "New folder" : "Нова папка",
    "Change to grid view" : "Промяна към изглед на мрежа",
    "Change to list view" : "Промяна към изглед на списък",
    "Copy RSS Feed of current view" : "Копиране на RSS емисия на текущ изглед",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS емисия изисква удостоверяване с вашите идентификационни данни в Nextcloud",
    "Search" : "Търсене",
    "Empty trash bin" : "Изпразни кошчето",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Добавяне на %n отметки към нова папка","Добавяне на %n отметки към нова папка"],
    "Enter a link" : "Въведете връзка",
    "Enter a title" : "Въведете заглавие",
    "No bookmarks found" : "Няма намерени отметки.",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} папки и {bookmarks} отметки",
    "_%n bookmark_::_%n bookmarks_" : ["%n отметки ","%n отметки"],
    "_%n folder_::_%n folders_" : ["%nпапки ","%n папки"],
    "Welcome to Bookmarks" : "Добре дошли в Отметки /Bookmarks/",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Това приложение ви позволява да управлявате връзките към любимите си места в мрежата. Сортирайте отметките си в папки, маркирайте ги с етикети и ги споделяйте с други хора! Приложението редовно ще проверява всички ваши връзки за наличност и ще показва недостъпните връзки. Ако добавите връзка към файл в мрежата, файлът ще бъде автоматично изтеглен във вашите Nextcloud файлове. Можете също така да импортирате отметки, експортирани от други услуги, или директно да синхронизирате отметки от всичките си браузъри с това приложение.",
    "Add a bookmark" : "Добави отметка",
    "Import bookmarks" : "Импортиране на отметки",
    "Sync with your browser" : "Синхронизиране с вашия браузър",
    "Select folder" : "Избор на папка",
    "Enter folder title" : "Въведете заглавие на папка",
    "Shared by {user}" : "Споделен от {user}",
    "Rename folder" : "Преименуване на папка",
    "Move folder" : "Преместване на папка",
    "Choose folder" : "Избор на папка",
    "Submit" : "Изпращане",
    "Cancel" : "Отказ",
    "Deleting bookmarks" : "Изтриване на отметки",
    "Deleting selection" : "Изтрване на селекцията",
    "Importing bookmarks" : "Импортиране на отметки",
    "Moving selection" : " Селекцията се премества",
    "Adding selection to folders" : "Добавяне на избор към папки",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Преместват се %n папки и някои отметки","Преместват се %n папки и някои отметки"],
    "_Moving %n folder_::_Moving %n folders_" : ["Преместват се %n папки","Преместват се %n папки"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Преместват се %n отметки","Преместват се %n отметки"],
    "All bookmarks" : "Всички отметки",
    "Recent" : "Последни",
    "Shared with you" : "Споделено с вас",
    "Files" : "Файлове",
    "Duplicates" : "Дубликати",
    "Broken links" : "Повредени връзки",
    "New tag" : "Нов етикет",
    "Search tags" : "Търсене на етикети",
    "Delete" : "Изтрий",
    "Untagged" : "Без отметки",
    "{used} bookmarks of {available} available" : " {used} отметки от {available} налични",
    "No bookmarked files" : "Няма файлове с поставена отметка",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Отметките към файлове като снимки или PDF файлове автоматично ще бъдат запазени във вашите Nextcloud файлове, така че все още ще можете да ги намерите дори когато връзката е офлайн.",
    "No broken links" : "Няма повредени връзки",
    "No shared folders" : "Няма споделени папки",
    "No duplicated bookmarks" : "Няма дублирани отметки",
    "No bookmarks here" : "Тук няма отметки.",
    "Add bookmarks manually or import bookmarks from a HTML file." : " Ръчно добавяне на отметки или импортиране на отметки от HTML файл.",
    "Archive path" : "Архивиране на път",
    "Backup path" : "Път към архив",
    "Please select \"Add to home screen\" in your browser menu" : "Моля, изберете \"Добавяне към началния екран\" в менюто на вашия браузър",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Въведете пътя на папка във вашите Файлове, където трябва да се съхраняват файловете с отметка.",
    "Enter the path of a folder in your Files where backups will be stored." : "Въведете пътя на папка във вашите файлове, където ще се съхраняват архиви.",
    "Client apps" : "Клиентски приложения",
    "Also check out the collection of client apps that integrate with this app: " : "Вижте също колекцията от клиентски приложения, които се интегрират с това приложение:",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Можете да инсталирате това приложение на началния екран на устройството си, за да получите бърз достъп до отметките на телефона си. Отново можете лесно да премахнете приложението от началния екран, ако не ви харесва.",
    "Install on home screen" : "Инсталиране на началния екан",
    "Bookmarklet" : "Скриптова отметка",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Завлечете това в отметките на браузъра си и щракнете върху него, за да поставте бързо отметка на уеб страница.",
    "Add to {instanceName}" : "Добавяне към {instanceName}",
    "Need help?" : "Нуждаете се от помощ?",
    "Created {time} ago" : "Създаден {time} преди",
    "Created on {date}" : "Създаден на {date}",
    "Title" : "Име",
    "Link" : "Връзка",
    "Untitled folder" : "Папка без заглавие",
    "Root folder" : "Основна папка",
    "Tags" : "Етикети",
    "Select tags and create new ones" : "Избор на маркери и създаване на нови",
    "Notes" : "Бележки",
    "Notes for this bookmark …" : "Бележки за тази отметка…",
    "Archived file" : "Архивиран файл",
    "Open file" : "Отваряне на файл",
    "Download file" : "Изтегли файл",
    "Open file location" : "Отваряне на местоположението на файл",
    "Link copied" : "Връзката е копирана",
    "Owner" : "Създател",
    "Sharing" : "Споделяне",
    "Select a user or group" : "Избор на потребител или група",
    "Share link" : "Връзка за споделяне",
    "Reading allowed" : "Разрешено четене",
    "Copy RSS feed" : "Копиране на RSS емисия",
    "Delete link" : "Изтриване на връзка",
    "Create public link" : "Създаване на публична връзка",
    "Resharing allowed" : "Разрешено е повторното споделяне",
    "Editing allowed" : "Разрешено е редактиране",
    "Allow editing" : "Разреши редактиране",
    "Allow resharing" : "Разреши повторно споделяне.",
    "Remove share" : "Премахване на споделяне",
    "Failed to save settings" : "Неуспешно записване на настройки",
    "Failed to load settings" : "Неуспешно зареждане на настройки",
    "Privacy" : "Защита на лични данни",
    "Enable accessing and collecting information from the web pages you add" : "Активирайте достъпа и събирането на информация от уеб страниците, които добавяте",
    "Performance" : "Производителност",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "При инсталация с много потребители може да е полезно да ограничите броя на отметките на профил.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Максимален брой разрешени отметки на профил. (0 за без ограничение; по подразбиране няма ограничение)",
    "Previews" : "Визуализации",
    "Screeenly" : "Screeenly/Екранно/ уеб приложение",
    "You can either sign up for free at screeenly.com or setup your own server." : "Можете или да се регистрирате безплатно на screeneenly.com, или да настроите свой собствен сървър.",
    "Screeenly API URL" : "URL адрес на Screeenly API",
    "Screeenly API key" : "Screeenly APIключ",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API ключ",
    "Webshot" : "Webshot /Екранна снимка на уебсайт/уебстраница/",
    "Webshot API URL" : " URL адрес на Webshot API",
    "Pageres CLI" : "Pageres CLI/интерфейс/",
    "Pageres ENV variables" : "Pageres ENV променливи",
    "This URL is already bookmarked! Overwrite?" : "Този адрес е вече добавен към отметките! Искате ли да презапишете?",
    "Enter bookmark title" : "Въведете заглавие на отметка",
    "Enter bookmark URL" : "Въведете URL адрес на отметка",
    "Folder" : "Папка",
    "Root Folder" : "Основна Папка",
    "Save" : "Запиши",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Достъп до мрежата е деактивиран по подразбиране. Отидете в настройките на администратора за приложението на отметки, за да разрешите извличане на визуализации и аватари тип favicon.",
    "What's new?" : "Какви са промените?",
    "What" : "Какво",
    "Failed to count unavailable bookmarks" : "Неуспешно преброяване на недостъпните отметки",
    "Failed to count archived bookmarks" : "Неуспешно преброяване на архивираните отметки",
    "Failed to count duplicated bookmarks" : "Неуспешно преброяване на дублираните отметки",
    "Failed to load bookmark" : "Неуспешно зареждане на отметка",
    "Failed to find existing bookmark" : "Неуспешно намиране на съществуваща отметка",
    "Failed to create bookmark" : "Неуспешно създавне на отметка",
    "Failed to save bookmark" : "Неуспешно записване на отметка",
    "Failed to move bookmark" : "Неуспешно преместване на отметка",
    "Failed to copy bookmark" : "Неуспешно копиране на отметка",
    "Failed to delete bookmark" : "Неуспешно изтриване на отметка",
    "Failed to rename tag" : "Неуспешно преименуване на етикет",
    "Failed to load tags" : "Неуспешно зареждане на етикети",
    "Failed to load folders" : "Неуспешно зареждане на папки",
    "Failed to delete folder" : "Неуспешно изтриване на папка",
    "Failed to create folder" : "Неуспешно създавне на папка",
    "Failed to fetch bookmarks." : "Неуспешно извличане на отметка",
    "Failed to load setting {key}" : "Неуспешно зареждане на настройка {key}",
    "Failed to update share {shareId}" : "Неуспешно актуализиране на споделянето {shareId}",
    "Failed to delete share {shareId}" : "Неуспешно изтриване на споделянето {shareId}",
    "Create bookmarks for mentioned links" : "Създаване на отметки за споменатите връзки",
    "No links found in this message" : "Няма намерени връзки в това съобщение",
    "Bookmarks feed" : "Емисия на отметки"
},
"nplurals=2; plural=(n != 1);");
