<?php
$TRANSLATIONS = array(
"Bookmarks" => "Marcadores",
"Bookm." => "Marc.",
"No file provided for import" => "Non foi fornecido un ficheiro para importar",
"Unsupported file type for import" => "Tipo de ficheiro non admitido para a importación",
"Some Error happened." => "Produciuse algún erro.",
"Error" => "Erro",
"Tags" => "Etiquetas",
"Filter by tag" => "Filtrar segundo a etiqueta",
"Are you sure you want to remove this bookmark?" => "Confirma que quere eliminar este marcador?",
"Warning" => "Aviso",
"Are you sure you want to remove this tag from every entry?" => "Confirma que quere eliminar esta etiqueta de todas as entradas?",
"Import error" => "Produciuse un erro na importación",
"Import completed successfully." => "A importación completouse correctamente.",
"Uploading..." => "Enviando...",
"Add a bookmark" => "Engadir un marcador",
"This URL is already bookmarked! Overwrite?" => "Este URL xa está marcado! Quere sobrescribilo?",
"The title of the page" => "O título da páxina",
"The address of the page" => "O enderezo desta páxina",
"Description of the page" => "Descrición da páxina",
"Save" => "Gardar",
"Delete" => "Eliminar",
"Edit" => "Editar",
"Cancel" => "Cancelar",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Arrastre isto aos marcadores do seu navegador e prema nel cando queira marcar unha páxina con rapidez:",
"Add to ownCloud" => "Engadir no ownCloud",
"Address" => "Enderezo",
"Filterable Tags" => "Etiquetas filtrábeis",
"You have no bookmarks" => "Non ten marcadores",
"You can also import a bookmark file" => "Tamén pode importar un ficheiro de marcadores",
"Bookmarklet" => "Marcador",
"Export & Import" => "Exportar e importar",
"Export" => "Exportar",
"Import" => "Importar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
