/*
 * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
 *
 * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
 */

// import FlowCreateBookmark from './components/FlowCreateBookmark'

window.OCA.WorkflowEngine.registerOperator({
	id: 'OCA\\Bookmarks\\Flow\\CreateBookmark',
	color: '#d90743',
	operation: '',
	// options: FlowCreateBookmark,
})
