OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "You bookmarked \"%s\"" : "Has marcado como favorito \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s ha marcado como favorito \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Alguien ha marcado como favorito \"%s\"",
    "You deleted \"%s\"" : "Has eliminado \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s ha eliminado \"%2$s\"",
    "Someone deleted \"%s\"" : "Alguien ha eliminado \"%s\"",
    "You created folder \"%s\"" : "Has creado la carpeta \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s ha creado la carpeta \"%2$s\"",
    "Someone created folder \"%s\"" : "Alguien ha creado la carpeta \"%s\"",
    "You moved folder \"%s\"" : "Has movido la carpeta \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s ha movido la carpeta \"%2$s\"",
    "Someone moved folder \"%s\"" : "Alguien ha movido la carpeta \"%s\"",
    "You deleted folder \"%s\"" : "Has eliminado la carpeta \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s ha eliminado la carpeta \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Alguien ha eliminado la carpeta \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Has compartido la carpeta \"%1$s\" con %2$s",
    "You shared folder \"%s\" with someone" : "Has compartido la carpeta \"%s\" con alguien",
    "%1$s shared folder \"%2$s\" with you" : "%1$s ha compartido la carpeta \"%2$s\" contigo",
    "Someone shared folder \"%s\" with you" : "Alguien ha compartido la carpeta \"%s\" contigo",
    "You unshared folder \"%1$s\" with %2$s" : "Has dejado de compartir la carpeta \"%1$s\" con %2$s",
    "You unshared folder \"%s\" with someone" : "Has dejado de compartir la carpeta \"%s\" con alguien",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s ha dejado de compartir la carpeta \"%2$s\" contigo",
    "Someone unshared folder \"%s\" with you" : "Alguien ha dejado de compartir la carpeta \"%s\" contigo",
    "No file provided for import" : "No se especificó un archivo para importar",
    "Bookmarks shared by %s" : "Marcadores compartidos por %s",
    "Frequent bookmarks" : "Marcadores frecuentes",
    "Recent bookmarks" : "Marcadores recientes",
    "Bookmark" : "Marcador",
    "Bookmark deleted" : "Marcador eliminado",
    "Bookmark created" : "Marcador creado",
    "Bookmark moved" : "Marcador movido",
    "Bookmark updated" : "Marcador actualizado",
    "Create bookmark" : "Crear marcador",
    "Takes a link and adds it to your collection of bookmarks." : "Toma un enlace y agrégalo a tu colección de marcadores.",
    "Bookmarks Backups" : "Respaldo de marcadores",
    "Do you really want to delete this bookmark?" : "¿Realmente deseas eliminar este marcador?",
    "Link copied to clipboard" : "Enlace copiado al portapapeles",
    "Enter new title" : "Ingresa un nuevo título",
    "Select bookmark" : "Seleccionar marcador",
    "Details" : "Detalles",
    "Rename" : "Renombrar",
    "Copy link" : "Copiar liga",
    "Move" : "Mover",
    "Add to folders" : "Agregar a carpetas",
    "Content pending" : "Contenido pendiente",
    "This content is being downloaded for offline use. Please check back later." : "Este contenido se está descargando para su uso sin conexión. Vuelve a consultar más tarde.",
    "Bookmarked {time} ago" : "Marcardo hace {time}",
    "Bookmarked on {date}" : "Marcado en {date}",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Los marcadores de enlaces a archivos en la web, como fotos o PDF, se guardarán automáticamente en tus archivos de Nextcloud, para que puedas encontrarlos incluso cuando el enlace esté fuera de línea.",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Los marcadores se comprueban regularmente y se enumeran aquellos que no se pueden alcanzar.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Puedes compartir carpetas de marcadores con otros. Todas las carpetas compartidas contigo se enumeran aquí.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Un marcador puede estar en varias carpetas a la vez. Actualizarlo actualizará todas las copias. Todos los marcadores duplicados se enumeran aquí para mayor comodidad.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} carpetas y {bookmarks} marcadores seleccionados",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n marcador seleccionado","%n marcadores seleccionados","%n marcadores seleccionados"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n carpeta seleccionada","%n carpetas seleccionadas","%n carpetas seleccionadas"],
    "Do you really want to delete these items?" : "¿Realmente deseas eliminar estos elementos?",
    "Open all selected" : "Abrir todo lo seleccionado",
    "Move selection" : "Mover selección",
    "Edit tags of selection" : "Editar etiquetas de la selección",
    "Delete selection" : "Eliminar selección",
    "Select all" : "Seleccionar todo",
    "Cancel selection" : "Cancelar selección",
    "Sort by created date" : "Ordenar por fecha de creación",
    "Sort by last modified" : "Ordenar por última modificación",
    "Sort by title" : "Ordenar por título",
    "Sort by click count" : "Ordenar por cantidad de clics",
    "Sort by manual order" : "Ordenar por orden manual",
    "Sort by URL" : "Ordenar por URL",
    "RSS feed copied" : "Feed RSS copiado",
    "Go back" : "Regresar",
    "Share folder" : "Compartir carpeta",
    "Select one or more tags" : "Selecciona una o más etiquetas",
    "New" : "Nuevo",
    "New bookmark" : "Nuevo marcador",
    "New folder" : "Carpeta nueva",
    "Change to grid view" : "Cambiar a vista de cuadrícula",
    "Change to list view" : "Cambiar a vista de lista",
    "Copy RSS Feed of current view" : "Copiar feed RSS de la vista actual",
    "The RSS feed requires authentication with your Nextcloud credentials" : "El feed RSS requiere autenticación con tus credenciales de Nextcloud",
    "Search" : "Buscar",
    "Empty trash bin" : "Eliminar papelera de reciclaje",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Añadiendo %n marcador a la carpeta nueva","Añadiendo %n marcadores a la carpeta nueva","Añadiendo %n marcadores a la carpeta nueva"],
    "Enter a link" : "Ingresa un enlace",
    "Enter a title" : "Ingresa un título",
    "No bookmarks found" : "No se encontraron marcadores",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} carpetas y {bookmarks} marcadores",
    "_%n bookmark_::_%n bookmarks_" : ["%n marcador","%n marcadores","%n marcadores"],
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
    "Welcome to Bookmarks" : "Bienvenido a Marcadores",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Esta aplicación te permite gestionar enlaces a tus lugares favoritos en la web. ¡Organiza tus marcadores en carpetas, añade etiquetas y compártelos con otros! La aplicación comprobará regularmente todos tus enlaces para ver si están disponibles y mostrará los enlaces no disponibles. Si agregas un enlace a un archivo en la web, el archivo se descargará automáticamente en tus archivos de Nextcloud. También puedes importar marcadores exportados desde otros servicios o sincronizar directamente los marcadores de todos tus navegadores con esta aplicación.",
    "Add a bookmark" : "Agregar un marcador",
    "Import bookmarks" : "Importar marcadores",
    "Sync with your browser" : "Sincronizar con tu navegador",
    "Select folder" : "Seleccionar carpeta",
    "Enter folder title" : "Ingresa el título de la carpeta",
    "Shared by {user}" : "Compartido por {user}",
    "Rename folder" : "Renombrar carpeta",
    "Move folder" : "Mover carpeta",
    "Choose folder" : "Seleccioanr carpeta",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Deleting bookmarks" : "Eliminando marcadores",
    "Deleting selection" : "Eliminando selección",
    "Importing bookmarks" : "Importando marcadores",
    "Moving selection" : "Moviendo selección",
    "Adding selection to folders" : "Añadiendo selección a carpetas",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Moviendo %n carpeta y algunos marcadores","Moviendo %n carpetas y algunos marcadores","Moviendo %n carpetas y algunos marcadores"],
    "_Moving %n folder_::_Moving %n folders_" : ["Moviendo %n carpeta","Moviendo %n carpetas","Moviendo %n carpetas"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Moviendo %n marcador","Moviendo %n marcadores","Moviendo %n marcadores"],
    "All bookmarks" : "Todos los marcadores",
    "Recent" : "Reciente",
    "Shared with you" : "Compartido con usted",
    "Files" : "Archivos",
    "Duplicates" : "Duplicados",
    "Broken links" : "Enlaces rotos",
    "New tag" : "Nueva etiqueta",
    "Search tags" : "Buscar etiquetas",
    "Delete" : "Borrar",
    "Untagged" : "Sin etiqueta",
    "{used} bookmarks of {available} available" : "{used} marcadores de {available} disponibles",
    "No bookmarked files" : "No hay archivos marcados",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Los marcadores a archivos como fotos o PDF se guardarán automáticamente en tus archivos de Nextcloud, para que puedas encontrarlos incluso cuando el enlace esté fuera de línea.",
    "No broken links" : "No hay enlaces rotos",
    "No shared folders" : "No hay carpetas compartidas",
    "No duplicated bookmarks" : "No hay marcadores duplicados",
    "No bookmarks here" : "No hay marcadores aquí",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Agrega marcadores manualmente o importa marcadores desde un archivo HTML.",
    "Archive path" : "Ruta de archivo",
    "Backup path" : "Ruta de respaldo",
    "Please select \"Add to home screen\" in your browser menu" : "Selecciona \"Agregar a pantalla de inicio\" en el menú de tu navegador",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Ingresa la ruta de una carpeta en tus Archivos donde se guardarán los archivos marcados.",
    "Enter the path of a folder in your Files where backups will be stored." : "Ingresa la ruta de una carpeta en tus Archivos donde se guardarán los respaldos.",
    "Client apps" : "Aplicaciones cliente",
    "Also check out the collection of client apps that integrate with this app: " : "Consulta la colección de aplicaciones cliente que se integran con esta aplicación:",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Puedes instalar esta aplicación en la pantalla de inicio de tu dispositivo para acceder rápidamente a tus marcadores en tu teléfono. Puedes eliminar fácilmente la aplicación de tu pantalla de inicio si no te gusta.",
    "Install on home screen" : "Instalar en pantalla de inicio",
    "Bookmarklet" : "Marcador a código ",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Arrastra esto a tus marcadores del navegador y haz clic en él para marcar rápidamente una página web.",
    "Add to {instanceName}" : "Agregar a {instanceName}",
    "Need help?" : "¿Necesitas ayuda?",
    "Created {time} ago" : "Creado hace {time}",
    "Created on {date}" : "Creado en {date}",
    "Title" : "Título",
    "Link" : "Liga",
    "Untitled folder" : "Carpeta sin título",
    "Root folder" : "Carpeta raíz",
    "Tags" : "Etiquetas",
    "Select tags and create new ones" : "Selecciona etiquetas y crea nuevas",
    "Notes" : "Notas",
    "Notes for this bookmark …" : "Notas para este marcador ...",
    "Archived file" : "Archivo archivado",
    "Open file" : "Abrir archivo",
    "Download file" : "Descargar archivo",
    "Open file location" : "Abrir ubicación del archivo",
    "Link copied" : "Enlace copiado",
    "Owner" : "Dueño",
    "Sharing" : "Compartiendo",
    "Select a user or group" : "Seleccionar un usuario o grupo",
    "Share link" : "Compartir enlace",
    "Reading allowed" : "Permitir lectura",
    "Copy RSS feed" : "Copiar feed RSS",
    "Delete link" : "Eliminar enlace",
    "Create public link" : "Crear enlace público",
    "Resharing allowed" : "Permitir compartir nuevamente",
    "Editing allowed" : "Permitir edición",
    "Allow editing" : "Permitir edición",
    "Allow resharing" : "Permitir volver a compartir",
    "Remove share" : "Eliminar compartir",
    "Failed to save settings" : "Error al guardar la configuración",
    "Failed to load settings" : "Error al cargar la configuración",
    "Privacy" : "Privacidad",
    "Enable accessing and collecting information from the web pages you add" : "Habilitar el acceso y la recopilación de información de las páginas web que agregues",
    "Performance" : "Rendimiento",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "En una instalación con muchos usuarios, puede ser útil restringir la cantidad de marcadores por cuenta.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Número máximo permitido de marcadores por cuenta. (0 para sin límite; el valor predeterminado es sin límite)",
    "Previews" : "Vistas previas",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Puedes registrarte gratis en screeenly.com o configurar tu propio servidor.",
    "Screeenly API URL" : "URL de la API de Screeenly",
    "Screeenly API key" : "Clave de API de Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clave de API de ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL de la API de Webshot",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Variables de entorno de Pageres",
    "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
    "Enter bookmark title" : "Ingresa el título del marcador",
    "Enter bookmark URL" : "Ingresa la URL del marcador",
    "Folder" : "Carpeta",
    "Root Folder" : "Carpeta raíz",
    "Save" : "Guardar",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "El acceso a la red está desactivado de forma predeterminada. Ve a la configuración del administrador de la aplicación de marcadores para permitir la obtención de vistas previas e iconos.",
    "What's new?" : "¿Qué hay de nuevo?",
    "What" : "Qué",
    "Failed to count unavailable bookmarks" : "Error al contar marcadores no disponibles",
    "Failed to count archived bookmarks" : "Error al contar marcadores archivados",
    "Failed to count duplicated bookmarks" : "Error al contar marcadores duplicados",
    "Failed to load bookmark" : "Error al cargar el marcador",
    "Failed to find existing bookmark" : "Error al encontrar el marcador existente",
    "Failed to create bookmark" : "Error al crear el marcador",
    "Failed to save bookmark" : "Error al guardar el marcador",
    "Failed to move bookmark" : "Error al mover el marcador",
    "Failed to copy bookmark" : "Error al copiar el marcador",
    "Failed to delete bookmark" : "Error al eliminar el marcador",
    "Failed to rename tag" : "Error al cambiar el nombre de la etiqueta",
    "Failed to load tags" : "Error al cargar las etiquetas",
    "Failed to load folders" : "Error al cargar las carpetas",
    "Failed to delete folder" : "Error al eliminar la carpeta",
    "Failed to create folder" : "Error al crear la carpeta",
    "Failed to fetch bookmarks." : "Error al obtener los marcadores.",
    "Failed to load setting {key}" : "Error al cargar la configuración {key}",
    "Failed to update share {shareId}" : "Error al actualizar el compartir {shareId}",
    "Failed to delete share {shareId}" : "Error al eliminar el compartir {shareId}",
    "Create bookmarks for mentioned links" : "Crea marcadores para los enlaces mencionados",
    "No links found in this message" : "No se encontraron enlaces en este mensaje",
    "Bookmarks feed" : "Feed de marcadores"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
