<?php
$TRANSLATIONS = array(
"Bookmarks" => "Legosignoj",
"Bookm." => "Legsign.",
"No file provided for import" => "Neniu dosiero aldonita por enporti",
"Unsupported file type for import" => "Dosiertipo nekongrua kun enporto",
"Some Error happened." => "Iu eraro okazis.",
"Error" => "Eraro",
"Tags" => "Etikedoj",
"Filter by tag" => "Filtri laŭ etikedo",
"Are you sure you want to remove this bookmark?" => "Ĉu vi certe volas forigi ĉi tiun legosignon?",
"Warning" => "Averto",
"Are you sure you want to remove this tag from every entry?" => "Ĉu vi vere volas forigi ĉi tiun etikedon el ĉiu ero?",
"Import error" => "Enporta eraro",
"Import completed successfully." => "Enporto plenumiĝis sukcese.",
"Uploading..." => "Alŝutante...",
"Add a bookmark" => "Aldoni legosignon",
"This URL is already bookmarked! Overwrite?" => "Ĉu tiu adreso jam estas legosigno! Ĉu anstataŭigi?",
"The title of the page" => "Titolo de la paĝo",
"The address of the page" => "Adreso de la paĝo",
"Description of the page" => "Priskribo de la paĝo",
"Save" => "Konservi",
"Delete" => "Forigi",
"Edit" => "Redakti",
"Cancel" => "Nuligi",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Ŝovu tion ĉi al la legosignoj de via TTT-legilo kaj klaku ĝin, se vi volas rapide legosignigi TTT-paĝon:",
"Add to ownCloud" => "Aldoni al ownCloud",
"Address" => "Adreso",
"Filterable Tags" => "Filtreblaj etikedoj",
"You have no bookmarks" => "Vi havas neniun legosignon",
"You can also import a bookmark file" => "Vi ankaŭ povas enporti legosignodosieron",
"Bookmarklet" => "Kodosigno",
"Export & Import" => "Malenporti kaj enporti",
"Export" => "Elporti",
"Import" => "Enporti"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
