<?php
$TRANSLATIONS = array(
"Bookmarks" => "ঠিকাসমূহ",
"Bookm." => "ঠিকা",
"No file provided for import" => "কোনো ফাইল আমদানীর জন্য নেই",
"Unsupported file type for import" => "আমদানি করার জন্য ফাইলের ফর্ম্যাটটি সঠিক নয়",
"Error" => "সমস্যা",
"Tags" => "ট্যাগ",
"Filter by tag" => "ট্যাগ অনুসারে ছাঁক",
"Warning" => "সতর্কবাণী",
"Are you sure you want to remove this tag from every entry?" => "প্রত্যেক ভুক্তি থেকে এই ট্যাগটি অপসারণ করতে আপনি কি বদ্ধপরিকর?",
"Import error" => "আমদানী ভ্রান্তি",
"Import completed successfully." => "আমদানি সুসম্পন্ন হয়েছে।",
"Uploading..." => "আপলোড করা হচ্ছে..........",
"Add a bookmark" => "ঠিকা যোগ করুন",
"The title of the page" => "পৃষ্ঠার শিরোনাম",
"The address of the page" => "পৃষ্ঠার ঠিকানা",
"Description of the page" => "পৃষ্ঠার বিবরণ",
"Save" => "সংরক্ষণ কর",
"Delete" => "মুছে ফেল",
"Edit" => "সম্পাদনা",
"Cancel" => "বাতিল",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "দ্রুত কোন ওয়েবপেজ ঠিকাতে সংরক্ষণ করতে চাইলে এটিকে টেনে ব্রাউজারের ঠিকাতে নিয়ে যান এবং তাতে ক্লিক করুনঃ",
"Add to ownCloud" => "ownCloud এ যুক্ত কর",
"Address" => "ঠিকানা",
"You have no bookmarks" => "আপনার কোন ঠিক নেই",
"Bookmarklet" => "অনুঠিকা",
"Export & Import" => "আমদানি এবং রপ্তানি",
"Export" => "রপ্তানি",
"Import" => "আমদানি"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
