OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bookmarks",
    "You bookmarked \"%s\"" : "You bookmarked \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s bookmarked \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Someone bookmarked \"%s\"",
    "You deleted \"%s\"" : "You deleted \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s deleted \"%2$s\"",
    "Someone deleted \"%s\"" : "Someone deleted \"%s\"",
    "You created folder \"%s\"" : "You created folder \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s created folder \"%2$s\"",
    "Someone created folder \"%s\"" : "Someone created folder \"%s\"",
    "You moved folder \"%s\"" : "You moved folder \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s moved folder \"%2$s\"",
    "Someone moved folder \"%s\"" : "Someone moved folder \"%s\"",
    "You deleted folder \"%s\"" : "You deleted folder \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s deleted folder \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Someone deleted folder \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "You shared folder \"%1$s\" with %2$s",
    "You shared folder \"%s\" with someone" : "You shared folder \"%s\" with someone",
    "%1$s shared folder \"%2$s\" with you" : "%1$s shared folder \"%2$s\" with you",
    "Someone shared folder \"%s\" with you" : "Someone shared folder \"%s\" with you",
    "You unshared folder \"%1$s\" with %2$s" : "You unshared folder \"%1$s\" with %2$s",
    "You unshared folder \"%s\" with someone" : "You unshared folder \"%s\" with someone",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s unshared folder \"%2$s\" with you",
    "Someone unshared folder \"%s\" with you" : "Someone unshared folder \"%s\" with you",
    "No file provided for import" : "No file provided for import",
    "Failed to upload file" : "Failed to upload file",
    "Unsupported file type for import: " : "Unsupported file type for import: ",
    "Bookmarks shared by %s" : "Bookmarks shared by %s",
    "Frequent bookmarks" : "Frequent bookmarks",
    "Recent bookmarks" : "Recent bookmarks",
    "Bookmark" : "Bookmark",
    "Bookmark deleted" : "Bookmark deleted",
    "Bookmark created" : "Bookmark created",
    "Bookmark moved" : "Bookmark moved",
    "Bookmark updated" : "Bookmark updated",
    "Create bookmark" : "Create bookmark",
    "Takes a link and adds it to your collection of bookmarks." : "Takes a link and adds it to your collection of bookmarks.",
    "Bookmarks Backups" : "Bookmarks Backups",
    "Collect and manage bookmarks, synced with all your devices" : "Collect and manage bookmarks, synced with all your devices",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0",
    "Do you really want to delete this bookmark?" : "Do you really want to delete this bookmark?",
    "Link copied to clipboard" : "Link copied to clipboard",
    "Enter new title" : "Enter new title",
    "Select bookmark" : "Select bookmark",
    "You have never clicked this link" : "You have never clicked this link",
    "You have clicked this link {count} times" : "You have clicked this link {count} times",
    "Details" : "Details",
    "Rename" : "Rename",
    "Copy link" : "Copy link",
    "Move" : "Move",
    "Add to folders" : "Add to folders",
    "Put bookmark into trash bin" : "Put bookmark into trash bin",
    "Restore bookmark" : "Restore bookmark",
    "Delete bookmark permanently" : "Delete bookmark permanently",
    "Content pending" : "Content pending",
    "This content is being downloaded for offline use. Please check back later." : "This content is being downloaded for offline use. Please check back later.",
    "Bookmarked {time} ago" : "Bookmarked {time} ago",
    "Bookmarked on {date}" : "Bookmarked on {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "These are your deleted items. Items will be deleted permanently after two months.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline.",
    "Searching in the current folder only." : "Searching in the current folder only.",
    "Repeat search in all folders" : "Repeat search in all folders",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bookmarked links are checked regularly and the ones that cannot be reached are listed here.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "You can share bookmark folders with others. All folders shared with you are listed here.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Selected {folders} folders and {bookmarks} bookmarks",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Selected %n bookmark","Selected %n bookmarks"],
    "_Selected %n folder_::_Selected %n folders_" : ["Selected %n folder","Selected %n folders"],
    "Do you really want to delete these items?" : "Do you really want to delete these items?",
    "Open all selected" : "Open all selected",
    "Move selection" : "Move selection",
    "Edit tags of selection" : "Edit tags of selection",
    "Delete selection" : "Delete selection",
    "Select all" : "Select all",
    "Cancel selection" : "Cancel selection",
    "Sort by created date" : "Sort by created date",
    "Sort by last modified" : "Sort by last modified",
    "Sort by title" : "Sort by title",
    "Sort by click count" : "Sort by click count",
    "Sort by manual order" : "Sort by manual order",
    "Sort by URL" : "Sort by URL",
    "RSS feed copied" : "RSS feed copied",
    "Trash Bin" : "Trash Bin",
    "Go back" : "Go back",
    "Share folder" : "Share folder",
    "Open folder details" : "Open folder details",
    "Select one or more tags" : "Select one or more tags",
    "New" : "New",
    "New bookmark" : "New bookmark",
    "New folder" : "New folder",
    "Change to grid view" : "Change to grid view",
    "Change to list view" : "Change to list view",
    "Copy RSS Feed of current view" : "Copy RSS Feed of current view",
    "The RSS feed requires authentication with your Nextcloud credentials" : "The RSS feed requires authentication with your Nextcloud credentials",
    "Search" : "Search",
    "Empty trash bin" : "Empty trash bin",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Adding %n bookmark to new folder","Adding %n bookmarks to new folder"],
    "Enter a link" : "Enter a link",
    "Enter a title" : "Enter a title",
    "No bookmarks found" : "No bookmarks found",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} folders and {bookmarks} bookmarks",
    "_%n bookmark_::_%n bookmarks_" : ["%n bookmark","%n bookmarks"],
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "Welcome to Bookmarks" : "Welcome to Bookmarks",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "This app allows you to manage links to your favourite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app.",
    "Add a bookmark" : "Add a bookmark",
    "Import bookmarks" : "Import bookmarks",
    "Sync with your browser" : "Sync with your browser",
    "Do you really want to permanently delete this folder?" : "Do you really want to permanently delete this folder?",
    "Select folder" : "Select folder",
    "Enter folder title" : "Enter folder title",
    "Shared by {user}" : "Shared by {user}",
    "Rename folder" : "Rename folder",
    "Move folder" : "Move folder",
    "Put folder into trashbin" : "Put folder into trashbin",
    "Restore folder" : "Restore folder",
    "Delete folder permanently" : "Delete folder permanently",
    "Choose folder" : "Choose folder",
    "Submit" : "Submit",
    "Cancel" : "Cancel",
    "Deleting bookmarks" : "Deleting bookmarks",
    "Deleting selection" : "Deleting selection",
    "Importing bookmarks" : "Importing bookmarks",
    "Moving selection" : "Moving selection",
    "Adding selection to folders" : "Adding selection to folders",
    "Emptying trashbin" : "Emptying trashbin",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Moving %n folder and some bookmarks","Moving %n folders and some bookmarks"],
    "_Moving %n folder_::_Moving %n folders_" : ["Moving %n folder","Moving %n folders"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Moving %n bookmark","Moving %n bookmarks"],
    "All bookmarks" : "All bookmarks",
    "Recent" : "Recent",
    "Frequently clicked" : "Frequently clicked",
    "Shared with you" : "Shared with you",
    "Files" : "Files",
    "Duplicates" : "Duplicates",
    "Broken links" : "Broken links",
    "New tag" : "New tag",
    "Search tags" : "Search tags",
    "Delete" : "Delete",
    "Untagged" : "Untagged",
    "{used} bookmarks of {available} available" : "{used} bookmarks of {available} available",
    "Bookmarks Settings" : "Bookmarks Settings",
    "No bookmarked files" : "No bookmarked files",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline.",
    "Nothing found" : "Nothing found",
    "Your search yielded no results in the current folder." : "Your search yielded no results in the current folder.",
    "No broken links" : "No broken links",
    "No shared folders" : "No shared folders",
    "No duplicated bookmarks" : "No duplicated bookmarks",
    "No deleted bookmarks" : "No deleted bookmarks",
    "You haven't deleted anything yet." : "You haven't deleted anything yet.",
    "No bookmarks here" : "No bookmarks here",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Add bookmarks manually or import bookmarks from a HTML file.",
    "Archive path" : "Archive path",
    "Backup path" : "Backup path",
    "Please select \"Add to home screen\" in your browser menu" : "Please select \"Add to home screen\" in your browser menu",
    "Bookmarks settings" : "Bookmarks settings",
    "Import/Export" : "Import/Export",
    "Export bookmarks" : "Export bookmarks",
    "Auto-archiving" : "Auto-archiving",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "The bookmarks app can automatically archive the web content of links you have bookmarked",
    "Enable archiving" : "Enable archiving",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Enter the path of a folder in your Files where bookmarked files should be stored.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment.",
    "Auto-Backup" : "Auto-Backup",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices.",
    "Enable backups" : "Enable backups",
    "Enter the path of a folder in your Files where backups will be stored." : "Enter the path of a folder in your Files where backups will be stored.",
    "Context Chat integration" : "Context Chat integration",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled.",
    "Context chat is currently not installed, but is required for this feature." : "Context chat is currently not installed, but is required for this feature.",
    "Enable Context Chat integration" : "Enable Context Chat integration",
    "Client apps" : "Client apps",
    "Also check out the collection of client apps that integrate with this app: " : "Also check out the collection of client apps that integrate with this app: ",
    "Install web app" : "Install web app",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it.",
    "Install on home screen" : "Install on home screen",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Drag this to your browser bookmarks and click it to quickly bookmark a webpage.",
    "Add to {instanceName}" : "Add to {instanceName}",
    "Need help?" : "Need help?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here.",
    "Support this project" : "Support this project",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 ",
    "Created {time} ago" : "Created {time} ago",
    "Created on {date}" : "Created on {date}",
    "(Empty title)" : "(Empty title)",
    "Title" : "Title",
    "Link" : "Link",
    "Untitled folder" : "Untitled folder",
    "Root folder" : "Root folder",
    "Tags" : "Tags",
    "Select tags and create new ones" : "Select tags and create new ones",
    "Notes" : "Notes",
    "Notes for this bookmark …" : "Notes for this bookmark …",
    "Archived file" : "Archived file",
    "Open file" : "Open file",
    "Download file" : "Download file",
    "Open file location" : "Open file location",
    "Link copied" : "Link copied",
    "Owner" : "Owner",
    "Sharing" : "Sharing",
    "Select a user or group" : "Select a user or group",
    "Share link" : "Share link",
    "Reading allowed" : "Reading allowed",
    "Copy RSS feed" : "Copy RSS feed",
    "Delete link" : "Delete link",
    "Create public link" : "Create public link",
    "Resharing allowed" : "Resharing allowed",
    "Editing allowed" : "Editing allowed",
    "Allow editing" : "Allow editing",
    "Allow resharing" : "Allow resharing",
    "Remove share" : "Remove share",
    "Would you like to support this project?" : "Would you like to support this project?",
    "Leave a rating on the Nextcloud App Store" : "Leave a rating on the Nextcloud App Store",
    "Failed to save settings" : "Failed to save settings",
    "Failed to load settings" : "Failed to load settings",
    "Privacy" : "Privacy",
    "The app will try to access web pages that you add to automatically add information about them." : "The app will try to access web pages that you add to automatically add information about them.",
    "Enable accessing and collecting information from the web pages you add" : "Enable accessing and collecting information from the web pages you add",
    "Performance" : "Performance",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)",
    "Previews" : "Previews",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "You can either sign up for free at screeenly.com or setup your own server.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Generic screenshot API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly.",
    "Generic API URL" : "Generic API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:",
    "Pageres ENV variables" : "Pageres ENV variables",
    "This URL is already bookmarked! Overwrite?" : "This URL is already bookmarked! Overwrite?",
    "Enter bookmark title" : "Enter bookmark title",
    "Enter bookmark URL" : "Enter bookmark URL",
    "Folder" : "Folder",
    "Root Folder" : "Root Folder",
    "Save" : "Save",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons.",
    "What's new?" : "What's new?",
    "What" : "What",
    "Failed to count unavailable bookmarks" : "Failed to count unavailable bookmarks",
    "Failed to count archived bookmarks" : "Failed to count archived bookmarks",
    "Failed to count deleted bookmarks" : "Failed to count deleted bookmarks",
    "Failed to count duplicated bookmarks" : "Failed to count duplicated bookmarks",
    "Failed to count bookmarks" : "Failed to count bookmarks",
    "Failed to load bookmark" : "Failed to load bookmark",
    "Failed to find existing bookmark" : "Failed to find existing bookmark",
    "Failed to create bookmark" : "Failed to create bookmark",
    "Failed to save bookmark" : "Failed to save bookmark",
    "Failed to move bookmark" : "Failed to move bookmark",
    "Failed to copy bookmark" : "Failed to copy bookmark",
    "Failed to delete bookmark" : "Failed to delete bookmark",
    "Failed to restore bookmark" : "Failed to restore bookmark",
    "Import successful" : "Import successful",
    "Failed to rename tag" : "Failed to rename tag",
    "Failed to load tags" : "Failed to load tags",
    "Failed to load folders" : "Failed to load folders",
    "Failed to load deleted folders" : "Failed to load deleted folders",
    "Failed to load deleted bookmarks" : "Failed to load deleted bookmarks",
    "Failed to delete folder" : "Failed to delete folder",
    "Failed to move folder" : "Failed to move folder",
    "Failed to restore folder" : "Failed to restore folder",
    "Failed to create folder" : "Failed to create folder",
    "Failed to load children order" : "Failed to load children order",
    "Failed to move parts of selection" : "Failed to move parts of selection",
    "Failed to copy parts of selection" : "Failed to copy parts of selection",
    "Failed to delete parts of selection" : "Failed to delete parts of selection",
    "Failed to tag parts of selection" : "Failed to tag parts of selection",
    "Failed to fetch bookmarks." : "Failed to fetch bookmarks.",
    "Failed to store setting" : "Failed to store setting",
    "Failed to load setting {key}" : "Failed to load setting {key}",
    "Failed to create share for folder {folderId}" : "Failed to create share for folder {folderId}",
    "Failed to update share {shareId}" : "Failed to update share {shareId}",
    "Failed to delete share {shareId}" : "Failed to delete share {shareId}",
    "Failed to create public link for folder {folderId}" : "Failed to create public link for folder {folderId}",
    "Failed to delete public link for folder {folderId}" : "Failed to delete public link for folder {folderId}",
    "Failed to permanently delete parts of trash bin" : "Failed to permanently delete parts of trash bin",
    "Create bookmarks for mentioned links" : "Create bookmarks for mentioned links",
    "No links found in this message" : "No links found in this message",
    "Bookmarks feed" : "Bookmarks feed"
},
"nplurals=2; plural=(n != 1);");
