OC.L10N.register(
    "bookmarks",
    {
    "Details" : "معلومات",
    "Rename" : "نوم بدلول",
    "Copy link" : "لېنک کاپي کول",
    "Move" : "انتقال",
    "Select all" : "ټول ټاکل",
    "New" : "نوی",
    "New folder" : "نوی فولډر",
    "_%n folder_::_%n folders_" : ["%n فولډر","%n فولډرونه"],
    "Cancel" : "پرېښول",
    "Recent" : "وروستي",
    "Shared with you" : "تاسې سره شريک شوي",
    "Files" : "فایلونه",
    "Delete" : "ړنګول",
    "Created on {date}" : "په {date} جوړ شوی",
    "Link" : "لېنک",
    "Tags" : "نښکې",
    "Notes" : "شسیب",
    "Open file" : "فایل پرانيستل",
    "Share link" : "د شرېکېدو لېنک",
    "Allow editing" : "د سمون اجازه ورکول",
    "Save" : "ساتل"
},
"nplurals=2; plural=(n != 1);");
