<?php
$TRANSLATIONS = array(
"Bookmarks" => "Bokmärken",
"Bookm." => "Bokm.",
"No file provided for import" => "Ingen fil försedd för import",
"Unsupported file type for import" => "Filtypen stöds ej för import",
"Some Error happened." => "Något fel inträffade",
"Error" => "Fel",
"Tags" => "Taggar",
"Filter by tag" => "Filtrera på etikett",
"Are you sure you want to remove this bookmark?" => "Är du säker på att du vill ta bort detta bokmärke?",
"Warning" => "Varning",
"Are you sure you want to remove this tag from every entry?" => "Är du säker på att du vill ta bort denna tagg från varje post?",
"Import error" => "Importfel",
"Import completed successfully." => "Import slutförd.",
"Uploading..." => "Laddar upp...",
"Add a bookmark" => "Lägg till ett bokmärke",
"This URL is already bookmarked! Overwrite?" => "Denna länk är redan bokmärkt. Skriva över?",
"The title of the page" => "Titel på sidan",
"The address of the page" => "Adress till sidan",
"Description of the page" => "Beskrivning av sidan",
"Save" => "Spara",
"Delete" => "Radera",
"Edit" => "Redigera",
"Cancel" => "Avbryt",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Dra till din webbläsares bokmärken och klicka på det när du vill bokmärka en webbsida snabbt:",
"Add to ownCloud" => "Lägg till på ownCloud",
"Address" => "Adress",
"Filterable Tags" => "Filtrerbara Taggar",
"You have no bookmarks" => "Du har inga bokmärken",
"You can also import a bookmark file" => "Du kan också importera en bokmärkesfil",
"Bookmarklet" => "Bokmärke",
"Export & Import" => "Export & Import",
"Export" => "Exportera",
"Import" => "Importera"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
