<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'fivefilters\\Readability\\' => array($vendorDir . '/fivefilters/readability.php/src'),
    'Symfony\\Polyfill\\Mbstring\\' => array($vendorDir . '/symfony/polyfill-mbstring'),
    'Symfony\\Polyfill\\Intl\\Normalizer\\' => array($vendorDir . '/symfony/polyfill-intl-normalizer'),
    'Symfony\\Polyfill\\Ctype\\' => array($vendorDir . '/symfony/polyfill-ctype'),
    'Symfony\\Component\\DomCrawler\\' => array($vendorDir . '/symfony/dom-crawler'),
    'Symfony\\Component\\CssSelector\\' => array($vendorDir . '/symfony/css-selector'),
    'Rowbot\\URL\\' => array($vendorDir . '/rowbot/url/src'),
    'Rowbot\\Punycode\\' => array($vendorDir . '/rowbot/punycode/src'),
    'Rowbot\\Idna\\Resource\\' => array($vendorDir . '/rowbot/idna/resources'),
    'Rowbot\\Idna\\' => array($vendorDir . '/rowbot/idna/src'),
    'Psr\\Log\\' => array($vendorDir . '/psr/log/src'),
    'Psr\\Http\\Message\\' => array($vendorDir . '/psr/http-factory/src', $vendorDir . '/psr/http-message/src'),
    'Psr\\Http\\Client\\' => array($vendorDir . '/psr/http-client/src'),
    'OCA\\Bookmarks\\' => array($baseDir . '/lib'),
    'Mimey\\' => array($vendorDir . '/xantios/mimey/src'),
    'Masterminds\\' => array($vendorDir . '/masterminds/html5/src'),
    'Marcelklehr\\LinkPreview\\' => array($vendorDir . '/marcelklehr/link-preview/src'),
    'League\\Uri\\' => array($vendorDir . '/league/uri', $vendorDir . '/league/uri-interfaces'),
    'Doctrine\\Inflector\\' => array($vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector'),
    'Doctrine\\Common\\Inflector\\' => array($vendorDir . '/doctrine/inflector/lib/Doctrine/Common/Inflector'),
    'Brick\\Math\\' => array($vendorDir . '/brick/math/src'),
);
