<?php
$TRANSLATIONS = array(
"Bookmarks" => "Järjehoidjad",
"Bookm." => "Järjeh.",
"No file provided for import" => "Imporditav fail puudub",
"Unsupported file type for import" => "Toetuseta failitüübi import",
"Some Error happened." => "Ilmnes mingi tõrge.",
"Error" => "Tõrge",
"Tags" => "Sildid",
"Filter by tag" => "Filtreeri siltide järgi",
"Are you sure you want to remove this bookmark?" => "Kas sa tõesti soovid seda järjehoidjat eemaldada?",
"Warning" => "Hoiatus",
"Are you sure you want to remove this tag from every entry?" => "Oled sa kindel, et sa soovid kõigilt sissekannetelt seda silti eemaldada?",
"Import error" => "Viga importimisel",
"Import completed successfully." => "Import on edukalt lõpetatud.",
"Uploading..." => "Üleslaadimine...",
"Add a bookmark" => "Lisa järjehoidja",
"This URL is already bookmarked! Overwrite?" => "See URL on juba järjehoidjates. Kas kirjutada üle?",
"The title of the page" => "Lehe pealkiri",
"The address of the page" => "Lehe aadress",
"Description of the page" => "Lehe kirjeldus",
"Save" => "Salvesta",
"Delete" => "Kustuta",
"Edit" => "Muuda",
"Cancel" => "Loobu",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Lohista see oma veebilehitseja järjehoidjatesse ja kliki sellele, kui sa soovid veebilehte kiirelt lisada:",
"Add to ownCloud" => "Lisa ownCloudi",
"Address" => "Aadress",
"Filterable Tags" => "Filtreeritavad sildid",
"You have no bookmarks" => "Sul pole järjehoidjaid",
"You can also import a bookmark file" => "Järjehoidjafaili on võimalik importida",
"Bookmarklet" => "Järjehoidja vidin",
"Export & Import" => "Eksport ja import",
"Export" => "Ekspordi",
"Import" => "Impordi"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
