<?php
$TRANSLATIONS = array(
"Bookmarks" => "ბუქმარკები",
"Bookm." => "Bookm.",
"No file provided for import" => "არ არის ფაილი იმპორტისთვის",
"Unsupported file type for import" => "დაუშვებელი ფაილის ტიპი იმპორტისთვის",
"Error" => "შეცდომა",
"Tags" => "ტაგები",
"Filter by tag" => "ტეგების მიხედვით ფილტრაცია",
"Warning" => "გაფრთხილება",
"Are you sure you want to remove this tag from every entry?" => "დარწმუნებული ხართ რომ აღნიშნული ტაგის წაშლა გინდათ ყველა ჩანაწერიდა?",
"Import error" => "შეცდომა იმპორტის დროს",
"Import completed successfully." => "იმპორტირება დასრულებულია.",
"Uploading..." => "მიმდინარეობს ატვირთვა...",
"Add a bookmark" => "ბუქმარქში დამატება",
"The title of the page" => "გვერდის სათაური",
"The address of the page" => "გვერდის მისამართი",
"Description of the page" => "გვერდის დახასიათება",
"Save" => "შენახვა",
"Delete" => "წაშლა",
"Edit" => "რედაქტირება",
"Cancel" => "უარყოფა",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "გადაათრიეთ ეს თქვენს ბუქმარკებში თუ გინდათ რომ საითი სწრაფად დაბუქმარკდეს",
"Address" => "მისამართი",
"You have no bookmarks" => "თქვენ არ გაქვთ ბუქმარკები",
"Bookmarklet" => "ბუქმარქლეტი",
"Export & Import" => "ექსპორტ & იმპორტი",
"Export" => "ექსპორტი",
"Import" => "იმპორტი"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
