OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoris",
    "You bookmarked \"%s\"" : "Vous avez mis en favori \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s à mis en favori \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Quelqu'un a mis en favori \"%s\"",
    "You deleted \"%s\"" : "Vous avez supprimé \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s a supprimé \"%2$s\"",
    "Someone deleted \"%s\"" : "Quelqu'un à supprimé \"%s\"",
    "You created folder \"%s\"" : "Vous avez créé le dossier \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s à créé le dossier \"%2$s\"",
    "Someone created folder \"%s\"" : "Quelqu'un à créé le dossier \"%s\"",
    "You moved folder \"%s\"" : "Vous avez déplacé le dossier \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s à déplacé le dossier \"%2$s\"",
    "Someone moved folder \"%s\"" : "Quelqu'un à déplacé le dossier \"%s\"",
    "You deleted folder \"%s\"" : "Vous avez supprimé le dossier \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s à supprimé le dossier %2$s",
    "Someone deleted folder \"%s\"" : "Quelqu'un à supprimé le dossier \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Vous avez partagé le dossier \"%1$s\" avec \"%2$s\"",
    "You shared folder \"%s\" with someone" : "Vous avez partagé le dossier \"%s\" avec quelqu'un",
    "%1$s shared folder \"%2$s\" with you" : "%1$s a partagé le dossier \"%2$s\" avec vous",
    "Someone shared folder \"%s\" with you" : "Quelqu'un à partagé le dossier \"%s\" avec vous",
    "You unshared folder \"%1$s\" with %2$s" : "Vous avez annulé le partage du dossier \"%1$s\" avec %2$s",
    "You unshared folder \"%s\" with someone" : "Vous avez annulé le partage du dossier \"%s\" avec quelqu'un",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s a annulé le partage du dossier \"%2$s\" avec vous",
    "Someone unshared folder \"%s\" with you" : "Quelqu'un a annulé le partage du dossier \"%s\" avec vous",
    "No file provided for import" : "Aucun fichier à importer",
    "Failed to upload file" : "Impossible de téléverser le fichier",
    "Unsupported file type for import: " : "Type de fichier non pris en charge pour l'import :",
    "Bookmarks shared by %s" : "Favoris partagés par %s",
    "Frequent bookmarks" : "Favoris fréquents",
    "Recent bookmarks" : "Favoris récents",
    "Bookmark" : "Favori",
    "Bookmark deleted" : "Favori supprimé",
    "Bookmark created" : "Favori créé",
    "Bookmark moved" : "Favori déplacé",
    "Bookmark updated" : "Favori mis à jour",
    "Create bookmark" : "Créer un favori",
    "Takes a link and adds it to your collection of bookmarks." : "Prenez un lien et ajoutez-le à votre collection de favoris.",
    "Bookmarks Backups" : "Sauvegardes de favoris",
    "Collect and manage bookmarks, synced with all your devices" : "Collectez et gérez vos marque-pages, synchronisés avec tous vos appareils",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Trier les marque-pages dans des dossiers\n- 🏷 Ajouter des étiquettes et des notes personnelles\n- ☠ Rechercher les liens mort et les doublons\n- 📲 Synchroniser avec tous vos navigateurs et appareils\n- 📔 Stocker les versions archivées de vos liens au cas où ils seraient dépubliés\n- 🔍 Recherche en texte intégral sur le contenu du site\n- 👪 Partager les marque-pages avec d'autres utilisateurs, groupes et équipes ou via des liens publics\n- ⚛ Générer des flux RSS de vos collections\n- 📈 Statistiques sur la fréquence à laquelle vous accédez à quels liens\n- 🔒 Sauvegardes automatiques de votre collection de marque-pages\n- 💼 Widgets de tableau de bord intégrés pour les liens fréquents et récents\n\nRequit:\n- Extensions PHP :\n- intl : *\n- mbstring : *\n- si vous utilisez MySQL, utilisez au moins la version 8.0",
    "Do you really want to delete this bookmark?" : "Voulez-vous vraiment supprimer ce favori ?",
    "Link copied to clipboard" : "Lien copié dans le presse-papier",
    "Enter new title" : "Saisissez un nouveau titre",
    "Select bookmark" : "Sélectionner le favori",
    "You have never clicked this link" : "Vous n'avez jamais cliqué sur ce lien",
    "You have clicked this link {count} times" : "Vous avez cliqué sur ce lien {count} fois",
    "Details" : "Détails",
    "Rename" : "Renommer",
    "Copy link" : "Copier le lien",
    "Move" : "Déplacer",
    "Add to folders" : "Ajouter aux dossiers",
    "Put bookmark into trash bin" : "Mettre le favori dans la corbeille",
    "Restore bookmark" : "Restaurer le favori",
    "Delete bookmark permanently" : "Supprimer définitivement le favori",
    "Content pending" : "Contenu en attente",
    "This content is being downloaded for offline use. Please check back later." : "Ce contenu est en cours de téléchargement pour une utilisation hors-ligne. Merci de revenir plus tard.",
    "Bookmarked {time} ago" : "Ajouté en favori il y a {time}",
    "Bookmarked on {date}" : "Ajouté en favori le {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Voici vos éléments supprimés. Les éléments seront supprimés définitivement après deux mois.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les favoris vers des fichiers comme des photos ou des PDF seront automatiquement enregistrés dans vos fichiers Nextcloud, de sorte que vous puissiez toujours les trouver même lorsque le lien est hors ligne.",
    "Searching in the current folder only." : "Recherche dans le dossier actuel uniquement.",
    "Repeat search in all folders" : "Répéter la recherche dans tous les dossiers",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Les liens mis en favoris sont vérifiés régulièrement et ceux qui ne peuvent pas être atteints sont répertoriés ici.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Vous pouvez partager des dossiers de favoris avec d’autres. Tous les dossiers partagés avec vous sont répertoriés ici.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Un favori peut être dans plusieurs dossiers à la fois. La modification mettra à jour toutes les copies. Tous les favoris dupliqués sont répertoriés ici pour plus de facilité.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} dossiers et {bookmarks} favoris sélectionnés",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n favori sélectionné","%n favoris sélectionnés","%n favoris sélectionnés"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n  dossier sélectionné","%n dossiers sélectionnés","%n dossiers sélectionnés"],
    "Do you really want to delete these items?" : "Voulez-vous vraiment supprimer ces éléments ?",
    "Open all selected" : "Ouvrir toute la sélection",
    "Move selection" : "Déplacer la sélection",
    "Edit tags of selection" : "Modifier les étiquettes de la sélection",
    "Delete selection" : "Supprimer la sélection",
    "Select all" : "Tout sélectionner",
    "Cancel selection" : "Annuler la sélection",
    "Sort by created date" : "Trier par date de création",
    "Sort by last modified" : "Trier par dernière modification",
    "Sort by title" : "Trier par titre",
    "Sort by click count" : "Trier par nombre de clics",
    "Sort by manual order" : "Trier manuellement",
    "Sort by URL" : "Trier par URL",
    "RSS feed copied" : "Flux RSS copié",
    "Trash Bin" : "Corbeille",
    "Go back" : "Revenir en arrière",
    "Share folder" : "Partager le dossier",
    "Open folder details" : "Ouvrir les détails du dossier",
    "Select one or more tags" : "Sélectionnez une ou plusieurs étiquettes",
    "New" : "Nouveau",
    "New bookmark" : "Nouveau favori",
    "New folder" : "Nouveau dossier",
    "Change to grid view" : "Passer à la vue en grille",
    "Change to list view" : "Passer à la vue en liste",
    "Copy RSS Feed of current view" : "Copier le flux RSS de la vue actuelle",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Le flux RSS nécessite une authentification avec vos identifiants Nextcloud",
    "Search" : "Rechercher",
    "Empty trash bin" : "Vider la corbeille",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Ajout de %n favori au nouveau dossier","Ajout de %n favoris au nouveau dossier","Ajout de %n favoris au nouveau dossier"],
    "Enter a link" : "Saisissez un lien",
    "Enter a title" : "Saisissez un titre",
    "No bookmarks found" : "Aucun favori",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} dossiers et {bookmarks} favoris",
    "_%n bookmark_::_%n bookmarks_" : ["%n favori","%n favoris","%n favoris"],
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers","%n dossiers"],
    "Welcome to Bookmarks" : "Bienvenu dans les favoris",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Cette application vous permet de gérer les liens vers vos sites préférés sur le Web ? Classez vos marques pages dans des dossiers, marquez-les avec des étiquettes et partagez-les ! L'application vérifiera régulièrement le fonctionnement des liens et affichera ceux indisponibles. Si vous ajoutez un lien vers un fichier sur le Web, ce dernier sera automatiquement téléchargé vers vos fichiers Nextcloud. Vous pouvez également importer des marques pages exportés depuis d'autres services, ou directement synchroniser vos marques pages depuis tous vos navigateurs avec cette application.",
    "Add a bookmark" : "Ajouter un favori",
    "Import bookmarks" : "Importer des favoris",
    "Sync with your browser" : "Synchronisez avec votre navigateur",
    "Do you really want to permanently delete this folder?" : "Voulez-vous vraiment supprimer définitivement ce dossier ?",
    "Select folder" : "Sélectionner un dossier",
    "Enter folder title" : "Saisissez le nom du dossier",
    "Shared by {user}" : "Partagé par {user}",
    "Rename folder" : "Renommer le dossier",
    "Move folder" : "Déplacer le dossier",
    "Put folder into trashbin" : "Mettre le dossier dans la corbeille",
    "Restore folder" : "Restaurer le dossier",
    "Delete folder permanently" : "Supprimer définitivement le dossier",
    "Choose folder" : "Choisir le dossier",
    "Submit" : "Envoyer",
    "Cancel" : "Annuler",
    "Deleting bookmarks" : "Suppression des favoris",
    "Deleting selection" : "Suppression de la sélection",
    "Importing bookmarks" : "Import des favoris",
    "Moving selection" : "Déplacement de la sélection",
    "Adding selection to folders" : "Ajout de la sélection aux dossiers",
    "Emptying trashbin" : "Vider la corbeille",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Déplacement de %n dossier et de certains signets","Déplacement de %n dossiers et de certains signets","Déplacement de %n dossiers et de certains signets"],
    "_Moving %n folder_::_Moving %n folders_" : ["Déplacement de %n dossier","Déplacement de %n dossiers","Déplacement de %n dossiers"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Déplacement de %n favori","Déplacement de %n favoris","Déplacement de %n favoris"],
    "All bookmarks" : "Tous les favoris",
    "Recent" : "Récent",
    "Frequently clicked" : "Cliqués fréquemment",
    "Shared with you" : "Partagés avec vous",
    "Files" : "Fichiers",
    "Duplicates" : "Doublons",
    "Broken links" : "Liens brisés",
    "New tag" : "Nouvelle étiquette",
    "Search tags" : "Rechercher des étiquettes",
    "Delete" : "Supprimer",
    "Untagged" : "Sans étiquette",
    "{used} bookmarks of {available} available" : "{used} favoris sur {available} disponibles",
    "Bookmarks Settings" : "Paramètres de Favoris",
    "No bookmarked files" : "Aucun fichier en favori",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les favoris vers des fichiers comme des photos ou des PDF seront automatiquement enregistrés dans vos fichiers Nextcloud, pour que vous puissiez y accéder même quand le lien est hors connexion.",
    "Nothing found" : "Aucun résultat",
    "Your search yielded no results in the current folder." : "Votre recherche n’a donné aucun résultat dans le dossier actuel.",
    "No broken links" : "Aucun lien rompu",
    "No shared folders" : "Aucun dossier partagé",
    "No duplicated bookmarks" : "Aucun favori en double",
    "No deleted bookmarks" : "Aucun favori supprimé",
    "You haven't deleted anything yet." : "Vous n’avez encore rien supprimé.",
    "No bookmarks here" : "Aucun favori ici",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Ajouter des favoris manuellement ou importer des favoris à partir d’un fichier HTML.",
    "Archive path" : "Archiver le chemin d'accès",
    "Backup path" : "Dossier de sauvegarde",
    "Please select \"Add to home screen\" in your browser menu" : "Veuillez sélectionner \"Ajouter à l'écran d'accueil\" dans le menu de votre navigateur",
    "Bookmarks settings" : "Paramètres de Favoris",
    "Import/Export" : "Importer/Exporter",
    "Export bookmarks" : "Exporter les favoris",
    "Auto-archiving" : "Auto-archivage",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "L’application Favoris peut automatiquement archiver le contenu web des liens que vous avez marqués",
    "Enable archiving" : "Activer l’archivage",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Entrer le chemin d’accès d’un dossier dans vos fichiers où les fichiers favoris doivent être stockés.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Actuellement, votre administrateur a désactivé l'accès au réseau pour cette application, c'est pourquoi l'archivage automatique est désactivé pour le moment.",
    "Auto-Backup" : "Sauvegarde automatique",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "L’application bookmarks peut automatiquement sauvegarder vos favoris tous les jours pour éviter la perte de données lors de la synchronisation des favoris entre les appareils.",
    "Enable backups" : "Activer les sauvegardes",
    "Enter the path of a folder in your Files where backups will be stored." : "Entrer le chemin d'accès d’un dossier dans vos fichiers où les sauvegardes seront stockées.",
    "Context Chat integration" : "Intégration du chat contextuel",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "L'application Favoris peut automatiquement mettre à disposition le contenu des sites web que vous ajoutez à vos signets dans le chat contextuel, ce qui vous permet de poser des questions et d'obtenir des réponses basées sur ce contenu. Cette fonctionnalité n'est disponible que si l'archivage automatique est activé.",
    "Context chat is currently not installed, but is required for this feature." : "Le chat contextuel n'est actuellement pas installé, mais il est nécessaire pour cette fonctionnalité.",
    "Enable Context Chat integration" : "Activer l'intégration du chat contextuel",
    "Client apps" : "Applications clientes",
    "Also check out the collection of client apps that integrate with this app: " : "Découvrez également une collection d'applications qui s'intègrent à cette application : ",
    "Install web app" : "Installer l'application web",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Vous pouvez installer cette application sur l’écran d’accueil de votre téléphone pour accéder rapidement à vos favoris. Vous pourrez facilement retirer cette application de votre écran si elle ne vous plaît pas.",
    "Install on home screen" : "Installer sur l'écran d'accueil",
    "Bookmarklet" : "Signets",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Faites glisser ce lien vers les favoris de votre navigateur et cliquez dessus pour ajouter rapidement une page web à vos favoris.",
    "Add to {instanceName}" : "Ajouter à {instanceName}",
    "Need help?" : "Besoin d’aide ?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Si vous avez des problèmes avec cette application Favoris ou si vous avez une idée de ce qui pourrait être amélioré, n’hésitez pas à nous contacter en cliquant ici.",
    "Support this project" : "Soutenir ce projet",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Mon travail sur cette application est financé par un modèle d'abonnement volontaire. Si vous pensez que ce que je fais en vaut la peine, je serais heureux que vous souteniez mon travail. N'hésitez pas non plus à laisser un avis sur l'application dans la boutique d'applications Nextcloud. Merci 💙 ",
    "Created {time} ago" : "Créé il y a {time}",
    "Created on {date}" : "Créé le {date}",
    "(Empty title)" : "(Sans titre)",
    "Title" : "Titre",
    "Link" : "Lien",
    "Untitled folder" : "Dossier sans titre",
    "Root folder" : "Dossier racine",
    "Tags" : "Étiquettes",
    "Select tags and create new ones" : "Sélectionner des étiquettes ou en créer de nouvelles",
    "Notes" : "Notes",
    "Notes for this bookmark …" : "Notes pour ce favori...",
    "Archived file" : "Fichier archivé",
    "Open file" : "Ouvrir le fichier",
    "Download file" : "Télécharger le fichier",
    "Open file location" : "Ouvrir l’emplacement du fichier",
    "Link copied" : "Lien copié",
    "Owner" : "Propriétaire",
    "Sharing" : "Partagé",
    "Select a user or group" : "Sélectionnez un utilisateur ou un groupe",
    "Share link" : "Lien de partage",
    "Reading allowed" : "Lecture autorisée",
    "Copy RSS feed" : "Copier le flux RSS",
    "Delete link" : "Supprimer le lien",
    "Create public link" : "Créer une lien de partage public",
    "Resharing allowed" : "Repartage autorisé",
    "Editing allowed" : "Modification autorisée",
    "Allow editing" : "Autoriser la modification",
    "Allow resharing" : "Autoriser le repartage",
    "Remove share" : "Supprimer le partage",
    "Would you like to support this project?" : "Voulez-vous apporter votre soutien à ce projet ?",
    "Leave a rating on the Nextcloud App Store" : "Laissez une note sur l'App Store Nextcloud",
    "Failed to save settings" : "Impossible de sauvegarder les paramètres",
    "Failed to load settings" : "Impossible de charger les paramètres",
    "Privacy" : "Vie privée",
    "The app will try to access web pages that you add to automatically add information about them." : "L'application tentera d'accéder aux pages web que vous ajoutez afin d'y intégrer automatiquement des informations à leur sujet.",
    "Enable accessing and collecting information from the web pages you add" : "Activer l'accès et la collecte d'informations à partir des pages web que vous enregistrez",
    "Performance" : "Performance",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Dans une installation avec un grand nombre d'utilisateurs, il peut être utile de limiter le nombre de favoris par compte.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre maximum de favoris autorisés par compte (0 pour aucune limite ; par défaut, aucune limite)",
    "Previews" : "Aperçus",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Afin d'afficher des véritables captures d'écran de vos sites Web favoris, l'application peut utiliser des services tiers pour générer des aperçus.",
    "Screeenly" : "A l'écran",
    "You can either sign up for free at screeenly.com or setup your own server." : "Vous pouvez vous inscrire gratuitement sur screeenly.com ou configurer votre propre serveur.",
    "Screeenly API URL" : "URL de l'API Screenly",
    "Screeenly API key" : "Clé d'API Screenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clé d'API de ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL de l'API Webshot",
    "Generic screenshot API" : "API de capture d'écran générique",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Inscrivez-vous auprès de l'un des fournisseurs d'API de capture d'écran et indiquez l'URL de l'API ci-dessous. Utilisez la variable {url} comme espace réservé pour l'URL de la page à capturer. L'API doit renvoyer uniquement l'image en direct.",
    "Generic API URL" : "URL d'API générique",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Installez simplement Pageres CLI par Sindre Sorhus sur votre serveur et Favoris la trouvera. Vous pouvez toujours ajouter des variables d'environnement (ENV) supplémentaires à fournir à Pageres, comme indiqué dans l'exemple :",
    "Pageres ENV variables" : "Variable d'environnement Pageres",
    "This URL is already bookmarked! Overwrite?" : "Cette URL est déjà dans les favoris ! Remplacer ?",
    "Enter bookmark title" : "Saisissez le nom du favori",
    "Enter bookmark URL" : "Saisissez l'url du favori",
    "Folder" : "Dossier",
    "Root Folder" : "Dossier racine",
    "Save" : "Enregistrer",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "L’accès au réseau est désactivé par défaut. Accédez aux paramètres administrateur de l'application Favoris pour autoriser la récupération des aperçus et des favicons.",
    "What's new?" : "Quoi de neuf ?",
    "What" : "Quoi",
    "Failed to count unavailable bookmarks" : "Impossible de compter les favoris indisponibles",
    "Failed to count archived bookmarks" : "Impossible de compter les favoris archivés",
    "Failed to count deleted bookmarks" : "Impossible de compter les favoris supprimés",
    "Failed to count duplicated bookmarks" : "Impossible de compter les favoris dupliqués",
    "Failed to count bookmarks" : "Impossible de compter les favoris",
    "Failed to load bookmark" : "Impossible de charger le favori",
    "Failed to find existing bookmark" : "Impossible de trouver le favori existant",
    "Failed to create bookmark" : "Impossible de créer le favori",
    "Failed to save bookmark" : "Impossible de sauvegarder le favori",
    "Failed to move bookmark" : "Impossible de déplacer le favori",
    "Failed to copy bookmark" : "Impossible de copier le favori",
    "Failed to delete bookmark" : "Impossible de supprimer le favori",
    "Failed to restore bookmark" : "Impossible de restaurer le favori",
    "Import successful" : "Import terminé avec succès",
    "Failed to rename tag" : "Impossible de renommer l'étiquette",
    "Failed to load tags" : "Impossible de charger les étiquettes",
    "Failed to load folders" : "Impossible de charger les dossiers",
    "Failed to load deleted folders" : "Impossible de charger les dossiers supprimés",
    "Failed to load deleted bookmarks" : "Impossible de charger les favoris supprimés",
    "Failed to delete folder" : "Impossible de supprimer le dossier",
    "Failed to move folder" : "Impossible de déplacer le dossier",
    "Failed to restore folder" : "Impossible de restaurer le dossier",
    "Failed to create folder" : "Impossible de créer le dossier",
    "Failed to load children order" : "Impossible de charger l'ordre des éléments",
    "Failed to move parts of selection" : "Impossible de déplacer certains éléments de la sélection",
    "Failed to copy parts of selection" : "Impossible de copier certains éléments de la sélection",
    "Failed to delete parts of selection" : "Impossible de supprimer certains éléments de la sélection",
    "Failed to tag parts of selection" : "Impossible d'ajouter l'étiquette sur certains éléments de la sélection",
    "Failed to fetch bookmarks." : "Impossible de récupérer les favoris.",
    "Failed to store setting" : "Impossible d'enregistrer le paramètre",
    "Failed to load setting {key}" : "Impossible de charger le paramètre {key}",
    "Failed to create share for folder {folderId}" : "Impossible de partager le dossier {folderId}",
    "Failed to update share {shareId}" : "Impossible de mettre à jour le partage {shareId}",
    "Failed to delete share {shareId}" : "Impossible de supprimer le partage {shareId}",
    "Failed to create public link for folder {folderId}" : "Impossible de créer le lien public pour le dossier {folderId}",
    "Failed to delete public link for folder {folderId}" : "Impossible de supprimer le lien public pour le dossier {folderId}",
    "Failed to permanently delete parts of trash bin" : "Impossible de supprimer définitivement certains éléments de la corbeille",
    "Create bookmarks for mentioned links" : "Créer des marque-pages pour les liens mentionnés",
    "No links found in this message" : "Aucun lien trouvé dans ce message",
    "Bookmarks feed" : "Flux de favoris"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
