<?php
$TRANSLATIONS = array(
"Bookmarks" => "Закладки",
"Warning" => "Предупреждение",
"Save" => "Сохранить",
"Delete" => "Удалить",
"Edit" => "Редактировать",
"Cancel" => "Отмена",
"Settings" => "Настройки"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
