OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Signalibros",
    "You bookmarked \"%s\"" : "At agiuntu unu signalibru de \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s at  agiuntu unu signalibru de\"%2$s\"",
    "Someone bookmarked \"%s\"" : "Calicunu at agiuntu unu signalibru de \"%s\"",
    "You deleted \"%s\"" : "As cantzelladu \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s cantzelladu \"%2$s\"",
    "Someone deleted \"%s\"" : "Calicunu at cantzelladu \"%s\"",
    "You created folder \"%s\"" : "As creadu una cartella \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s as creadu una cartella \"%2$s\"",
    "Someone created folder \"%s\"" : "Calicunu at creadu una cartella \"%s\"",
    "You moved folder \"%s\"" : "As tramudadu una cartella \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s tràmuda cartella \"%2$s\"",
    "Someone moved folder \"%s\"" : "Calicunu at tramudadu una cartella \"%s\"",
    "You deleted folder \"%s\"" : "As cantzelladu sa cartella \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s at cantzelladu sa cartella \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Calicunu at cantzelladu sa cartella \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Cumpartzi sa cartella \"%1$s\" cun %2$s",
    "You shared folder \"%s\" with someone" : "As cumpartzidu sa cartella \"%s\" cun calicunu",
    "%1$s shared folder \"%2$s\" with you" : "%1$s at cumpartzidu sa cartella \"%2$s\" cun tegus",
    "Someone shared folder \"%s\" with you" : "Calicunu at cumpartzidu sa cartella \"%s\" cun tegus",
    "You unshared folder \"%1$s\" with %2$s" : "Nch'as bogadu sa cumpartzidura de sa cartella \"%1$s\" cun %2$s",
    "You unshared folder \"%s\" with someone" : "Nch'as bogadu sa cumpartzidura de sa cartella \"%s\" cun calicunu",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s nch'at bogadu sa cumpartzidura de sa cartella \"%2$s\" cun tegus",
    "Someone unshared folder \"%s\" with you" : "Calicunu nch'at bogadu sa cumpartzidura de sa cartella \"%s\" cun tegus",
    "No file provided for import" : "Perunu archìviu est frunidu pro s'importatzione",
    "Failed to upload file" : "No at fatu a carrigare su documentu",
    "Bookmarks shared by %s" : "Signalibros cumpartzidos dae %s",
    "Frequent bookmarks" : "Signalibros frecuentes",
    "Recent bookmarks" : "Signalibros reghentes",
    "Bookmark" : "Signalibru",
    "Bookmark deleted" : "Signalibru cantzelladu",
    "Bookmark created" : "Signalibru creadu",
    "Bookmark moved" : "Signalibru tramudadu",
    "Bookmark updated" : "Signalibru assignadu",
    "Create bookmark" : "Crea unu signalibru",
    "Takes a link and adds it to your collection of bookmarks." : "Pigat unu ligòngiu e dd'agiunghet a sa colletzione tua de signalibros.",
    "Do you really want to delete this bookmark?" : "A beru cheres cantzellare custu signalibru?",
    "Link copied to clipboard" : "Ligòngiu copiadu in punta de billete",
    "Enter new title" : "Inserta unu tìtulu nou",
    "Select bookmark" : "Seletziona signalibru",
    "Details" : "Detàllios",
    "Rename" : "Torra a numenare",
    "Copy link" : "Còpia ligòngiu",
    "Move" : "Tràmuda",
    "Content pending" : "Cuntenutu in suspesu",
    "This content is being downloaded for offline use. Please check back later." : "Custu cuntenutu s'est iscarrigadu pro impreu fora de lìnia. Torra a controllare a pustis.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Cartellas {folders} e signalibros {bookmarks} seletzionados",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Signalibros %n seletzionados","Seletziona %n signalibros"],
    "_Selected %n folder_::_Selected %n folders_" : ["Cartella %n seletzionadas","Selected %n folders"],
    "Do you really want to delete these items?" : "A beru cheres cantzellare custos elementos?",
    "Open all selected" : "Aberi totu is seletzionados",
    "Move selection" : "Tràmuda seletzione",
    "Edit tags of selection" : "Modìfica etichetas de seletzione",
    "Delete selection" : "Cantzella seletzione",
    "Select all" : "Seletziona totu",
    "Cancel selection" : "Annulla seletzione",
    "Sort by created date" : "Assenta segunu data de creatzione",
    "Sort by last modified" : "Assenta segundu ùrtima modìfica",
    "Sort by title" : "Assenta segundu tìtulu",
    "Sort by click count" : "Assenta seguntu contu de incarcos",
    "Sort by manual order" : "Assenta segundu ordine manuale",
    "RSS feed copied" : "Sorgente RSS copiada",
    "Go back" : "Bae in segus",
    "Share folder" : "Cumpartzi cartella",
    "Select one or more tags" : "Seletziona una o prus etichetas",
    "New" : "Nou",
    "New bookmark" : "Signalibru nou",
    "New folder" : "Cartella noa",
    "Change to grid view" : "Càmbia a vista a grìllia",
    "Change to list view" : "Càmbia a vista a elencu",
    "Copy RSS Feed of current view" : "Còpia fonte RSS de sa bista atuale",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Sa fonte RSS rechedet s'autenticatzione cun is credentziales de Nextcloud",
    "Search" : "Chirca",
    "Empty trash bin" : "Bòida s'àliga",
    "Enter a link" : "Inserta unu ligòngiu",
    "Enter a title" : "Inserta unu tìtulu",
    "No bookmarks found" : "Perunu signalibru agatadu",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} cartellas e {bookmarks} signalibros",
    "_%n bookmark_::_%n bookmarks_" : ["%n signalibru","%n signalibros"],
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartellas"],
    "Add a bookmark" : "Agiunghe unu signalibru",
    "Import bookmarks" : "Importa signalibros",
    "Sync with your browser" : "Sincroniza cun su navigadore tuo",
    "Select folder" : "Seletziona cartella",
    "Enter folder title" : "Inserta tìtulu cartella",
    "Shared by {user}" : "Cumpartzidu dae {user}",
    "Rename folder" : "Torra a numenare sa cartella",
    "Move folder" : "Tràmuda sa cartella",
    "Choose folder" : "Sèbera sa cartella",
    "Submit" : "Imbia",
    "Cancel" : "Annulla",
    "Deleting bookmarks" : "Eliminatzione signalibros",
    "Deleting selection" : "Eliminatzione seletzione",
    "Importing bookmarks" : "Importatzione signalibros",
    "Moving selection" : "Tràmuda de sa seletzione",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Tràmuda %n cartellas e de calicunu signalibru"," Tràmuda%n de cartellas e de calicunu signalibru"],
    "_Moving %n folder_::_Moving %n folders_" : ["Tràmuda %n cartella","Tràmuda%n cartellas"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Tràmuda %n signalibru","Tràmuda %n signalibros"],
    "All bookmarks" : "Totu is signalibros",
    "Recent" : "Reghente",
    "Shared with you" : "Cumpartzidu cun tegus",
    "Files" : "Archìvios",
    "Broken links" : "Ligòngios segados",
    "New tag" : "Eticheta noa",
    "Search tags" : "Chirca etichetas",
    "Delete" : "Cantzella",
    "Untagged" : "Sena eticheta",
    "{used} bookmarks of {available} available" : "{used} signalibros de {available} a disponimentu",
    "No bookmarked files" : "Perunu archìviu de signalibros",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Is signalibros pro archìvios che a fotos o PDF ant a èssere sarvados in automàticu in is archìvios tuos de Nextcloud, in manera chi tue ddos potzas agatare fintzas cando ses fora de lìnia.",
    "No bookmarks here" : "Perunu signalibru inoghe",
    "Archive path" : "Caminu archìviu",
    "Please select \"Add to home screen\" in your browser menu" : "Pro praghere, seletziona \"Agiunghe a s'ischermada printzipale\" in su menu de su navigadore tuo",
    "Client apps" : "Aplicatziones cliente",
    "Also check out the collection of client apps that integrate with this app: " : "Controlla fintzas sa colletzione de aplicatziones clientes intergradas cun custa aplicatzione",
    "Install web app" : "Installa aplicatzione internet",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Podes installare cust'aplicatzione in s'ischermada printzipale de su dispositivu tuo pro atzèdere a lestru a is preferidos in su telèfonu tuo. Chi no ti praghet, podes torrare a nde bogare s'aplicatzione manera fàtzile.",
    "Install on home screen" : "Installa in s'ischermada printzipale",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName}" : "Agiunghe a {instanceName}",
    "Need help?" : "Boles agiudu?",
    "Created {time} ago" : "Creadu {time} a immoe",
    "Created on {date}" : "Creadu su {date}",
    "Title" : "Tìtulu",
    "Link" : "Ligòngiu",
    "Root folder" : "Cartella sorgente",
    "Tags" : "Etichetas",
    "Select tags and create new ones" : "Seletziona etichetas e crea·nde àteras noas",
    "Notes" : "Notas",
    "Notes for this bookmark …" : "Notas pro custu signalibru ...",
    "Archived file" : "Documentu archiviadu",
    "Open file" : "Aberi archìviu",
    "Download file" : "Iscàrriga archìviu",
    "Open file location" : "Aberi positzione de s'archìviu",
    "Link copied" : "Ligòngiu copiadu",
    "Owner" : "Mere",
    "Sharing" : "Cumpartzidura",
    "Select a user or group" : "Seletziona un'utente o grupu",
    "Share link" : "Cumpartzi ligòngiu",
    "Reading allowed" : "Letura permìtida",
    "Copy RSS feed" : "Còpia sorgente RSS",
    "Delete link" : "Cantzella ligòngiu",
    "Create public link" : "Crea unu ligòngiu pùblicu",
    "Resharing allowed" : "Cumpartzidura permìtida",
    "Editing allowed" : "Modìfica permìtida",
    "Allow editing" : "Permite sa modìfica",
    "Allow resharing" : "Permite de torrare a cumpartzire",
    "Remove share" : "Boga cumpartzidura",
    "Failed to save settings" : "No at fatu a sarvare is informatziones",
    "Failed to load settings" : "Impossìbile carrigare sa cunfiguratzione",
    "Privacy" : "Riservadesa",
    "Enable accessing and collecting information from the web pages you add" : "Abilita s'atzessu a sa regollida de informatziones dae is pàginas internet chi agiùnghes",
    "Performance" : "Atuatzione",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "In un'installatzione cun ùtentes medas, diat pòdere torrare ùtile a minimare su nùmeru de signalibros pro cada contu.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Su nùmeru màssimu cunsentidu de signalibros pro cada contu. (0 pro illimitadu; predefinidu illimitadu)",
    "Previews" : "Anteprima",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Ti podes registrare sena pagare in screeenly.com o cunfigurare su serbidore.",
    "Screeenly API URL" : "API URL de Screeenly ",
    "Screeenly API key" : "Crae API de Screeenly ",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Crae ScreenshotMachine API ",
    "Webshot" : "Webshot",
    "Webshot API URL" : " API URL Webshot",
    "Pageres CLI" : "Pageres CLI",
    "This URL is already bookmarked! Overwrite?" : "Custu URL est giai unu signalibru! Ddu cheres subraiscrìere?",
    "Enter bookmark title" : "Inserta tìtulu de su signalibru",
    "Enter bookmark URL" : "Inserta URL de su signalibru",
    "Folder" : "Cartella",
    "Root Folder" : "Cartella sorgente",
    "Save" : "Sarva",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "S'intrada a sa rete est disativada in manera predefinida. Bae a sa cunfiguratzione de amministratzione pro s'aplicatzione sinnalibros pro cunsentire su recùperu de anteprimas e favicon.",
    "What's new?" : "Ite noas?",
    "Failed to count unavailable bookmarks" : "No at fatu a tènnere su contu de is signalibros",
    "Failed to count archived bookmarks" : "No at fatu a tènnere su contu de is signalibros",
    "Failed to load bookmark" : "No at fatu a carrigare is signalibros",
    "Failed to find existing bookmark" : "No at fatu a agatare is signalibros",
    "Failed to create bookmark" : "No at fatu a creare unu signalibru",
    "Failed to save bookmark" : "No at fatu a sarvare signalibru",
    "Failed to move bookmark" : "No at fatu a tramudare is signalibros",
    "Failed to delete bookmark" : "No at fatu a cantzellare signalibros",
    "Failed to rename tag" : "No at fatu a torrare a numenare is etichetas",
    "Failed to load tags" : "No at fatu a carrigare is etichetas",
    "Failed to load folders" : "No at fatu a carrigare is cartellas",
    "Failed to delete folder" : "No at fatu a cantzellare sa cartella",
    "Failed to create folder" : "No at fatu a creare sa cartella",
    "Failed to fetch bookmarks." : "No at fatu a recuperare is signalibros.",
    "Failed to load setting {key}" : "No at fatu a carrigare sa cunfiguratzione {key}",
    "Failed to update share {shareId}" : "No at fatu a carrigare s'agiornamentu {shareId}",
    "Failed to delete share {shareId}" : "No at fatu a annullare sa cumpartzidura {shareId}",
    "Bookmarks feed" : "Sorgente de is signalibros"
},
"nplurals=2; plural=(n != 1);");
