OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Munudoù",
    "Rename" : "Adenvel",
    "Copy link" : "Kopiañ al liamm",
    "Move" : "Diplasañ",
    "Select all" : "Dibab pep tra",
    "Sort by created date" : "Renkañ dre deizat krouidigezh",
    "New" : "Nevez",
    "New folder" : "Teuliad nevez",
    "Search" : "Klask",
    "Empty trash bin" : "Pod-lastez goullo",
    "_%n folder_::_%n folders_" : ["%nteuliad","%n deuliad","teuliadoù zo","an darn vrasañ eus an teuliadoù","%n teuliad"],
    "Submit" : "Kinnig",
    "Cancel" : "Nullañ",
    "Recent" : "Nevez",
    "Shared with you" : "Rannet ganeoc'h",
    "Files" : "Restroù",
    "Broken links" : "Liammoù toret",
    "Delete" : "Dilemel",
    "Need help?" : "Sikour o po ?",
    "Created on {date}" : "Krouet da  {date}",
    "Title" : "Titl",
    "Link" : "Liamm",
    "Tags" : "Klavioù",
    "Notes" : "Notennoù",
    "Open file" : "Digeriñ ur restr",
    "Download file" : "Pelkargañ restr",
    "Link copied" : "Liamm eilet",
    "Owner" : "Perc'henner",
    "Sharing" : "Rannan",
    "Share link" : "Rannan liamm",
    "Allow editing" : "Cheñchamentoù aotreet",
    "Allow resharing" : "Aotrea an adrannañ",
    "Privacy" : "Prevezder",
    "Folder" : "Teuliad",
    "Save" : "Enrollañ"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
