OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Adresynas",
    "You bookmarked \"%s\"" : "Jūs pridėjote „%s“ į žymes",
    "%1$s bookmarked \"%2$s\"" : "%1$s pridėta į žymes „%2$s“",
    "Someone bookmarked \"%s\"" : "Kažkas pridėjo „%s“ į žymes",
    "You deleted \"%s\"" : "Jūs ištrynėte \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s ištrynė \"%2$s\"",
    "Someone deleted \"%s\"" : "Kažkas ištrynė \"%s\"",
    "You created folder \"%s\"" : "Jūs sukūrėte aplanką \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s sukūrė aplanką \"%2$s\"",
    "Someone created folder \"%s\"" : "Kažkas sukūrė aplanką \"%s\"",
    "You moved folder \"%s\"" : "Jūs perkėlėte aplanką \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s perkėlė aplanką \"%2$s\"",
    "Someone moved folder \"%s\"" : "Kažkas perkėlė aplanką \"%s\"",
    "You deleted folder \"%s\"" : "Jūs ištrynėte aplanką \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s ištrynė aplanką \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Kažkas ištrynė aplanką \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Jūs pradėjote bendrinti aplanką „%1$s“ su %2$s",
    "You shared folder \"%s\" with someone" : "Jūs pasidalinote aplanku „%s“ su kažkuo",
    "%1$s shared folder \"%2$s\" with you" : "%1$s su jumis pasidalijo aplanku „%2$s“",
    "Someone shared folder \"%s\" with you" : "Kažkas su jumis pasidalijo aplanku „%s“",
    "You unshared folder \"%1$s\" with %2$s" : "Jūs atšaukėte aplanko „%1$s“ bendrinimą su %2$s",
    "You unshared folder \"%s\" with someone" : "Jūs atšaukėte aplanko „%s“ bendrinimą su kažkuo",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s atšaukė „%2$s“ aplanko bendrinimą su jumis",
    "Someone unshared folder \"%s\" with you" : "Kažkas atšaukė „%s“ aplanko bendrinimą su jumis",
    "No file provided for import" : "Importavimui nepateiktas joks failas",
    "Failed to upload file" : "Nepavyko įkelti failo",
    "Unsupported file type for import: " : "Nepalaikomas importuojamo failo tipas:",
    "Bookmarks shared by %s" : "%s pasidalino adresynu",
    "Frequent bookmarks" : "Dažni adresynai",
    "Recent bookmarks" : "Naujausi adresynai",
    "Bookmark" : "Adresynas",
    "Bookmark deleted" : "Adresynas ištrintas",
    "Bookmark created" : "Adresynas sukurtas",
    "Bookmark moved" : "Adresynas perkeltas",
    "Bookmark updated" : "Adresynas atnaujintas",
    "Create bookmark" : "Sukurti adresyną",
    "Takes a link and adds it to your collection of bookmarks." : "Paima nuorodą ir įtraukia ją į jūsų adresynų kolekciją.",
    "Bookmarks Backups" : "Adresynų atsarginės kopijos",
    "Collect and manage bookmarks, synced with all your devices" : "Rinkti ir tvarkyti adresynus, sinchronizuotus su visais jūsų įrenginiais",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Rūšiuokite adresynus į aplankus\n- 🏷 Pridėkite žymes ir asmenines pastabas\n- ☠ Raskite neveikiančias nuorodas ir duplikatus\n- 📲 Sinchronizuokite su visomis savo naršyklėmis ir įrenginiais\n- 📔 Saugokite archyvuotas nuorodų versijas, jei jos būtų pašalintos\n- 🔍 Atlikite visatekstinę paiešką svetainės turinyje\n- 👪 Dalykitės adresynais su kitais vartotojais, grupėmis ir komandomis arba per viešas nuorodas\n- ⚛ Sukurkite savo kolekcijų RSS sklaidos kanalus\n- 📈 Statistika, kaip dažnai pasiekiate tam tikras nuorodas\n- 🔒 Automatinės jūsų adresynų kolekcijos atsarginės kopijos\n- 💼 Įdiegtos valdymo skydo valdikliai dažnai naudojamoms ir naujausioms nuorodoms\n\nReikalavimai:\n- PHP plėtiniai:\n- intl: *\n- mbstring: *\n- naudojant MySQL, naudokite bent v8.0",
    "Do you really want to delete this bookmark?" : "Ar tikrai norite ištrinti šį adresyną?",
    "Link copied to clipboard" : "Nuoroda nukopijuota į iškarpinę",
    "Enter new title" : "Įvesti naują antraštę",
    "Select bookmark" : "Pasirinkti adresyno įrašą",
    "You have never clicked this link" : "Niekada nespaudėte šios nuorodos",
    "You have clicked this link {count} times" : "Šią nuorodą spustelėjote {count} kartų",
    "Details" : "Išsamiau",
    "Rename" : "Pervadinti",
    "Copy link" : "Kopijuoti nuorodą",
    "Move" : "Perkelti",
    "Add to folders" : "Pridėti į aplankus",
    "Put bookmark into trash bin" : "Įdėti adresyną į šiukšliadėžę",
    "Restore bookmark" : "Atkurti adresyną",
    "Delete bookmark permanently" : "Ištrinti adresyną visam laikui",
    "Content pending" : "Laukiama turinio",
    "This content is being downloaded for offline use. Please check back later." : "Šis turinys atsisiunčiamas naudojimui neprisijungus. Patikrinkite vėliau.",
    "Bookmarked {time} ago" : "Įtraukta į adresyną prieš {time}",
    "Bookmarked on {date}" : "Įtraukta į adresyną {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Tai yra jūsų ištrinti elementai. Elementai bus visam laikui ištrinti po dviejų mėnesių.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Adresynai į failus žiniatinklyje, pvz., nuotraukas ar PDF failus, bus automatiškai išsaugoti jūsų „Nextcloud“ failuose, todėl juos galėsite rasti net ir tada, kai nuoroda bus neprisijungusi.",
    "Searching in the current folder only." : "Ieškoma tik dabartiniame aplanke.",
    "Repeat search in all folders" : "Pakartoti paiešką visuose aplankuose",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Į adresynus įkeltos nuorodos yra reguliariai tikrinamos, o tos, kurių negalima pasiekti, pateikiamos čia.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Adresyno aplankus galite bendrinti su kitais. Čia pateikiami visi su jumis bendrinami aplankai.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Vienas adresynas gali būti keliuose aplankuose vienu metu. Jį atnaujinus bus atnaujintos visos kopijos. Visi pasikartojantys adresynai pateikiami čia patogumo dėlei.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Pasirinkti {folders} aplankai ir {bookmarks} adresynai",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Pažymėtas %n adresyno įrašas","Pažymėti %n adresyno įrašai","Pažymėta %n adresyno įrašų","Pažymėtas %n adresyno įrašas"],
    "_Selected %n folder_::_Selected %n folders_" : ["Pasirinktas %n aplankas","Pasirinkti %n aplankai","Pasirinkta %n aplankų","Pasirinkta %n aplankų"],
    "Do you really want to delete these items?" : "Ar tikrai norite ištrinti šiuos elementus?",
    "Open all selected" : "Atidaryti visus pasirinktus",
    "Move selection" : "Perkelti žymėjimą",
    "Edit tags of selection" : "Redaguoti pasirinkimo žymas",
    "Delete selection" : "Ištrinti žymėjimą",
    "Select all" : "Pažymėti viską",
    "Cancel selection" : "Atšaukti pasirinkimą",
    "Sort by created date" : "Rūšiuoti pagal sukūrimo datą",
    "Sort by last modified" : "Rūšiuoti pagal paskutinį keitimą",
    "Sort by title" : "Rikiuoti pagal sąveiką",
    "Sort by click count" : "Rūšiuoti pagal paspaudimų skaičių",
    "Sort by manual order" : "Rūšiuoti pagal rankiniu būdu nustatytą tvarką",
    "Sort by URL" : "Rūšiuoti pagal URL",
    "RSS feed copied" : "RSS kanalas nukopijuotas",
    "Trash Bin" : "Šiukšlinė",
    "Go back" : "Grįžti",
    "Share folder" : "Bendrinti aplanką",
    "Open folder details" : "Atverti išsamesnę informaciją",
    "Select one or more tags" : "Pasirinkite vieną ar daugiau žymų",
    "New" : "Nauja",
    "New bookmark" : "Naujas adresynas",
    "New folder" : "Naujas aplankas",
    "Change to grid view" : "Keisti į tinklelio rodinį",
    "Change to list view" : "Keisti į sąrašo rodinį",
    "Copy RSS Feed of current view" : "Kopijuoti dabartinio vaizdo RSS srautą",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS srautui reikia prisijungti naudojant savo „Nextcloud“ prisijungimo duomenis",
    "Search" : "Ieškoti",
    "Empty trash bin" : "Išvalyti šiukšlinę",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["%n adresyno perkėlimas į naują aplanką","%n adresynų perkėlimas į naują aplanką","%n adresynų perkėlimas į naują aplanką","%n adresynų perkėlimas į naują aplanką"],
    "Enter a link" : "Įveskite nuorodą",
    "Enter a title" : "Įveskite antraštę",
    "No bookmarks found" : "Adresynų nerasta",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} aplankai ir {bookmarks} adresynai",
    "_%n bookmark_::_%n bookmarks_" : ["%n adresynas","%n adresynai","%n adresynų","%n adresynų"],
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankas"],
    "Welcome to Bookmarks" : "Sveiki atvykę į „Adresynai“",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Ši programėlė leidžia tvarkyti nuorodas į mėgstamas vietas internete. Rūšiuokite adresynus į aplankus, žymėkite juos žymėmis ir dalinkitės jomis su kitais! Programėlė reguliariai tikrins visų jūsų nuorodų prieinamumą ir parodys neveikiančias nuorodas. Jei pridėsite nuorodą į failą internete, jis bus automatiškai atsisiųstas į jūsų „Nextcloud Files“. Taip pat galite importuoti iš kitų paslaugų eksportuotus adresynus arba tiesiogiai sinchronizuoti adresynus iš visų savo naršyklių su šia programa.",
    "Add a bookmark" : "Pridėti adresyno įrašą",
    "Import bookmarks" : "Importuoti adresynus",
    "Sync with your browser" : "Sinchronizuoti su naršykle",
    "Do you really want to permanently delete this folder?" : "Ar tikrai norite visam laikui ištrinti šį aplanką?",
    "Select folder" : "Pasirinkite aplanką",
    "Enter folder title" : "Įveskite aplanko pavadinimą",
    "Shared by {user}" : "Bendrina {user}",
    "Rename folder" : "Pervadinti aplanką",
    "Move folder" : "Perkelti aplanką",
    "Put folder into trashbin" : "Įdėti aplanką į šiukšliadėžę",
    "Restore folder" : "Atkurti aplanką",
    "Delete folder permanently" : "Ištrinti aplanką visam laikui",
    "Choose folder" : "Pasirinkti aplanką",
    "Submit" : "Pateikti",
    "Cancel" : "Atsisakyti",
    "Deleting bookmarks" : "Adresynų ištrynimas",
    "Deleting selection" : "Pasirinkimo trynimas",
    "Importing bookmarks" : "Adresynų importavimas",
    "Moving selection" : "Pasirinkimo perkėlimas",
    "Adding selection to folders" : "Pasirinkimo įtraukimas į aplankus",
    "Emptying trashbin" : "Šiukšliadėžės ištuštinimas",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Perkeliamas %n aplankas ir keli adresyno įrašai","Perkeliami %n aplankai ir keli adresyno įrašai","Perkeliama %n aplankų ir keli adresyno įrašai","Perkeliamas %n aplankas ir keli adresyno įrašai"],
    "_Moving %n folder_::_Moving %n folders_" : ["Perkeliamas %n aplankas","Perkeliami %n aplankai","Perkeliama %n aplankų","Perkeliamas %n aplankas"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Perkeliamas %n adresyno įrašas","Perkeliami %n adresyno įrašai","Perkeliama %n adresyno įrašų","Perkeliamas %n adresyno įrašas"],
    "All bookmarks" : "Visi adresynai",
    "Recent" : "Paskiausi",
    "Frequently clicked" : "Dažnai spustelėjama",
    "Shared with you" : "Bendrinama su jumis",
    "Files" : "Failai",
    "Duplicates" : "Dublikatai",
    "Broken links" : "Neveikiančios nuorodos",
    "New tag" : "Nauja žyma",
    "Search tags" : "Ieškoti žymų",
    "Delete" : "Ištrinti",
    "Untagged" : "Be žymų",
    "{used} bookmarks of {available} available" : "{used} adresynai iš {available} pasiekiamų",
    "Bookmarks Settings" : "Adresynų nustatymai",
    "No bookmarked files" : "Nėra failų įtrauktų į adresynus",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Failų, tokių kaip nuotraukos ar PDF, adresynai bus automatiškai išsaugoti jūsų „Nextcloud“ failuose, todėl galėsite juos rasti net ir tada, kai nuoroda bus neprisijungusi.",
    "Nothing found" : "Nieko nerasta",
    "Your search yielded no results in the current folder." : "Jūsų paieška dabartiniame aplanke nedavė jokių rezultatų.",
    "No broken links" : "Nėra neveikiančių nuorodų",
    "No shared folders" : "Nėra bendrinamų aplankų",
    "No duplicated bookmarks" : "Nėra besidubliuojančių adresynų",
    "No deleted bookmarks" : "Nėra ištrintų adresynų",
    "You haven't deleted anything yet." : "Dar nieko neištrynėte.",
    "No bookmarks here" : "Čia adresyno įrašų nėra",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Pridėkite adresynus rankiniu būdu arba importuokite adresynus iš HTML failo.",
    "Archive path" : "Kelias į archyvą",
    "Backup path" : "Kelias į atsargines kopijas",
    "Please select \"Add to home screen\" in your browser menu" : "Naršyklės meniu pasirinkite „Pridėti prie pagrindinio ekrano“",
    "Bookmarks settings" : "Adresynų nustatymai",
    "Import/Export" : "Importuoti/Eksportuoti",
    "Export bookmarks" : "Eksportuoti adresynus",
    "Auto-archiving" : "Automatinis archyvavimas",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Adresynų programėlė gali automatiškai archyvuoti jūsų pažymėtų nuorodų žiniatinklio turinį",
    "Enable archiving" : "Įgalinti archyvavimą",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Įveskite aplanko, kuriame turėtų būti saugomi pažymėtieji failai, kelią aplanke „Failai“.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Šiuo metu jūsų administratorius išjungė šios programėlės prieigą prie tinklo, todėl automatinis archyvavimas šiuo metu yra išjungtas.",
    "Auto-Backup" : "Automatinis atsarginis kopijavimas",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Adresynų programėlė gali automatiškai kasdien kurti atsargines adresynų kopijas, kad būtų išvengta duomenų praradimo sinchronizuojant adresynus skirtinguose įrenginiuose.",
    "Enable backups" : "Įgalinti atsarginių kopijų darymą",
    "Enter the path of a folder in your Files where backups will be stored." : "Įveskite aplanko, kuriame bus saugomos atsarginės kopijos, kelią aplanke „Failai“.",
    "Context Chat integration" : "Kontekstinis pokalbių integravimas",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Adresynų programėlė gali automatiškai pateikti jūsų adresynuose pažymėtų svetainių tekstinį turinį „Context Chat“ funkcijai, kuri leidžia užduoti klausimus ir gauti atsakymus pagal tą turinį. Tai galima tik tada, jei įjungtas automatinis archyvavimas.",
    "Context chat is currently not installed, but is required for this feature." : "Kontekstinis pokalbis šiuo metu neįdiegtas, bet šiai funkcijai būtinas.",
    "Enable Context Chat integration" : "Įgalinti kontekstinio pokalbio integravimą",
    "Client apps" : "Kliento programėlės",
    "Also check out the collection of client apps that integrate with this app: " : "Taip pat peržiūrėkite klientų programėlių, kurios integruojasi su šia programėle, kolekciją:",
    "Install web app" : "Įdiegti žiniatinklio programėlę",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Šią programėlę galite įdiegti savo įrenginio pagrindiniame ekrane, kad greitai pasiektumėte žymes telefone. Jei programėlė jums nepatiks, galėsite ją lengvai pašalinti iš pagrindinio ekrano.",
    "Install on home screen" : "Įdiegti pagrindiniame ekrane",
    "Bookmarklet" : "Adresyno skriptas",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Nuvilkite tai į naršyklės adresynus ir spustelėkite, kad greitai pridėtumėte tinklalapį prie adresyno.",
    "Add to {instanceName}" : "Pridėti į {instanceName}",
    "Need help?" : "Reikia pagalbos?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Jei kyla problemų dėl šios Adresynai programėlės arba turite idėjų, ką būtų galima patobulinti, nedvejodami susisiekite su mumis spustelėdami čia.",
    "Support this project" : "Palaikykite šį projektą",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Mano darbas kuriant šią Adresynai programėlę remiasi savanoriško prenumeratos modeliu. Jei manote, kad tai, ką darau, yra vertinga, būčiau dėkingas, jei galėtumėte paremti mano veiklą. Taip pat prašau apsvarstyti galimybę parašyti atsiliepimą apie programėlę „Nextcloud“ programėlių parduotuvėje. Ačiū 💙 ",
    "Created {time} ago" : "Sukurta prieš {time}",
    "Created on {date}" : "Sukurta {date}",
    "(Empty title)" : "(Tuščia antraštė)",
    "Title" : "Pareigos",
    "Link" : "Nuoroda",
    "Untitled folder" : "Aplankas be pavadinimo",
    "Root folder" : "Šakninis aplankas",
    "Tags" : "Žymos",
    "Select tags and create new ones" : "Pasirinkite žymes ir sukurkite naujas",
    "Notes" : "Pastabos",
    "Notes for this bookmark …" : "Pastabos apie šį adresyną …",
    "Archived file" : "Suarchyvuotas failas",
    "Open file" : "Atverti failą",
    "Download file" : "Atsisiųsti failą",
    "Open file location" : "Atidaryti failo vietą",
    "Link copied" : "Nuoroda nukopijuota",
    "Owner" : "Savininkas",
    "Sharing" : "Bendrinimas",
    "Select a user or group" : "Pasirinkti naudotoją ar grupę",
    "Share link" : "Viešinio nuoroda",
    "Reading allowed" : "Skaityti leidžiama",
    "Copy RSS feed" : "Kopijuoti RSS kanalą",
    "Delete link" : "Ištrinti nuorodą",
    "Create public link" : "Sukurti viešąją nuorodą",
    "Resharing allowed" : "Bendrinimas iš naujo yra leidžiamas",
    "Editing allowed" : "Leidžiamas redagavimas",
    "Allow editing" : "Leisti redaguoti",
    "Allow resharing" : "Leisti bendrinti iš naujo",
    "Remove share" : "Šalinti viešinį",
    "Would you like to support this project?" : "Ar norėtumėte paremti šį projektą?",
    "Leave a rating on the Nextcloud App Store" : "Palikite įvertinimą „Nextcloud“ programėlių parduotuvėje",
    "Failed to save settings" : "Nepavyko įrašyti nustatymų",
    "Failed to load settings" : "Nepavyko įkelti nustatymų",
    "Privacy" : "Privatumas",
    "The app will try to access web pages that you add to automatically add information about them." : "Programėlė bandys pasiekti jūsų pridėtus tinklalapius, kad automatiškai pridėtų apie juos informaciją.",
    "Enable accessing and collecting information from the web pages you add" : "Leisti apsilankyti ir rinkti iš saityno informaciją apie jūsų pridedamus internetinius puslapius",
    "Performance" : "Našumas",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Sistemoje, kurioje yra daug vartotojų, gali būti naudinga apriboti adresynų skaičių vienam paskyros savininkui.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Didžiausias, vienai paskyrai leidžiamas, adresyno įrašų skaičius. (0, kad būtų neribojama; pagal numatymą yra neribojama)",
    "Previews" : "Peržiūros",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Kad būtų rodomi tikri jūsų į adresynus įtrauktų svetainių ekrano vaizdai, programėlė gali naudoti trečiųjų šalių paslaugas peržiūrų kūrimui.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Galite arba nemokamai užsiregistruoti adresu screeenly.com, arba nusistatyti savo asmeninį serverį.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API raktas",
    "ScreenshotMachine" : "\"ScreenshotMachine\"",
    "ScreenshotMachine API key" : "\"ScreenshotMachine\" API raktas",
    "Webshot" : "\"Webshot\"",
    "Webshot API URL" : "\"Webshot\" API URL",
    "Generic screenshot API" : "Bendra ekrano kopijos API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Užsiregistruokite pas bet kurį iš ekrano kopijų API teikėjų ir įrašykite API URL adresą žemiau. Naudokite kintamąjį {url} kaip vietą, kurioje bus įterptas URL adresas, kurio ekrano kopija bus daroma. API turi grąžinti tik patį vaizdą.",
    "Generic API URL" : "Bendrasis API URL",
    "Pageres CLI" : "\"Pageres CLI\"",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Tiesiog įdiekite „Sindre Sorhus“ sukurtą „Pageres CLI“ savo serveryje ir Adresynai ją ras. Vis tiek galite pridėti papildomų ENV kintamųjų, kurie bus tiekiami į „Pageres“, pvz., kaip nurodyta vietos žymeklyje:",
    "Pageres ENV variables" : "\"Pageres ENV\" kintamieji",
    "This URL is already bookmarked! Overwrite?" : "Šis URL jau įtrauktas į adresyną! Perrašyti?",
    "Enter bookmark title" : "Įveskite adresyno įrašo pavadinimą",
    "Enter bookmark URL" : "Įveskite adresyno įrašo URL",
    "Folder" : "Aplankas",
    "Root Folder" : "Šakninis aplankas",
    "Save" : "Įrašyti",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Tinklo prieiga pagal numatytuosius nustatymus yra išjungta. Eikite į adresynų programėlės administratoriaus nustatymus, kad būtų galima gauti peržiūras ir mėgstamiausias piktogramas.",
    "What's new?" : "Kas naujo?",
    "What" : "Ką",
    "Failed to count unavailable bookmarks" : "Nepavyko suskaičiuoti nepasiekiamus adresynus",
    "Failed to count archived bookmarks" : "Nepavyko suskaičiuoti suarchyvuos adresynus",
    "Failed to count deleted bookmarks" : "Nepavyko suskaičiuoti ištrintus adresynus",
    "Failed to count duplicated bookmarks" : "Nepavyko suskaičiuoti pasikartojančius adresynus",
    "Failed to count bookmarks" : "Nepavyko suskaičiuoti adresynus",
    "Failed to load bookmark" : "Nepavyko įkelti adresyno",
    "Failed to find existing bookmark" : "Nepavyko rasti esamo adresyno įrašo",
    "Failed to create bookmark" : "Nepavyko sukurti adresyno įrašo",
    "Failed to save bookmark" : "Nepavyko įrašyti adresyno įrašo",
    "Failed to move bookmark" : "Nepavyko perkelti adresyno įrašo",
    "Failed to copy bookmark" : "Nepavyko nukopijuoti adresyno",
    "Failed to delete bookmark" : "Nepavyko ištrinti adresyno įrašo",
    "Failed to restore bookmark" : "Nepavyko atkurti adresyno",
    "Import successful" : "Importavimas pavyko",
    "Failed to rename tag" : "Nepavyko pervadinti žymos",
    "Failed to load tags" : "Nepavyko įkelti žymų",
    "Failed to load folders" : "Nepavyko įkelti aplankų",
    "Failed to load deleted folders" : "Nepavyko įkelti ištrintų aplankų",
    "Failed to load deleted bookmarks" : "Nepavyko įkelti ištrintų adresynų",
    "Failed to delete folder" : "Nepavyko ištrinti aplanko",
    "Failed to move folder" : "Nepavyko perkelti aplanko",
    "Failed to restore folder" : "Nepavyko atkurti aplanko",
    "Failed to create folder" : "Nepavyko sukurti aplanko",
    "Failed to load children order" : "Nepavyko įkelti poaplankių rūšiavimo tvarkos",
    "Failed to move parts of selection" : "Nepavyko perkelti tam tikros žymėjimo dalies",
    "Failed to copy parts of selection" : "Nepavyko nukopijuoti pasirinkimo dalių",
    "Failed to delete parts of selection" : "Nepavyko ištrinti tam tikros žymėjimo dalies",
    "Failed to tag parts of selection" : "Nepavyko pažymėti pasirinkimo dalių",
    "Failed to fetch bookmarks." : "Nepavyko gauti adresyno įrašų.",
    "Failed to store setting" : "Nepavyko išsaugoti nustatymo",
    "Failed to load setting {key}" : "Nepavyko įkelti nustatymo {key}",
    "Failed to create share for folder {folderId}" : "Nepavyko sukurti aplanko {folderId} bendrinimo",
    "Failed to update share {shareId}" : "Nepavyko atnaujinti viešinio {shareId}",
    "Failed to delete share {shareId}" : "Nepavyko ištrinti viešinio {shareId}",
    "Failed to create public link for folder {folderId}" : "Nepavyko sukurti viešos nuorodos aplankui {folderId}",
    "Failed to delete public link for folder {folderId}" : "Nepavyko ištrinti viešos nuorodos į aplanką {folderId}",
    "Failed to permanently delete parts of trash bin" : "Nepavyko visam laikui ištrinti šiukšliadėžės dalių",
    "Create bookmarks for mentioned links" : "Sukurkite žymes paminėtoms nuorodoms",
    "No links found in this message" : "Šiame pranešime nerasta nuorodų",
    "Bookmarks feed" : "Adresyno įrašų kanalas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
