"use strict";(self.webpackChunkbookmarks=self.webpackChunkbookmarks||[]).push([["node_modules_nextcloud_vue_dist_Components_NcSelect_mjs"],{67607(e,s,o){o.r(s),o.d(s,{default:()=>k.N});var k=o(12973)}}]);