<?php
$TRANSLATIONS = array(
"Warning" => "హెచ్చరిక",
"Close" => "మూసివేయి",
"Save" => "భద్రపరచు",
"Delete" => "తొలగించు",
"Cancel" => "రద్దుచేయి",
"Address" => "చిరునామా",
"Add" => "చేర్చు",
"Settings" => "అమరికలు",
"Export" => "ఎగుమతించు",
"Import" => "దిగుమతించు"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
