<?php
$TRANSLATIONS = array(
"Bookmarks" => "Обележивачи",
"Bookm." => "Обел.",
"No file provided for import" => "Нема фајла за увоз",
"Unsupported file type for import" => "Неподржан тип фајла за увоз",
"Some Error happened." => "Десила се нека грешка.",
"Error" => "Грешка",
"Tags" => "Ознаке",
"Filter by tag" => "Филтрирај по ознаци",
"Are you sure you want to remove this bookmark?" => "Желите ли заиста да уклоните овај обележивач?",
"Warning" => "Упозорење",
"Are you sure you want to remove this tag from every entry?" => "Желите ли заиста да уклоните ову ознаку из сваког уноса?",
"Import error" => "Грешка увоза",
"Import completed successfully." => "Увоз је успешно завршен.",
"Uploading..." => "Отпремам…",
"Add a bookmark" => "Додај обележивач",
"This URL is already bookmarked! Overwrite?" => "Овај УРЛ је већ обележен! Да пребришем?",
"The title of the page" => "Наслов странице",
"The address of the page" => "Адреса странице",
"Description of the page" => "Опис странице",
"Save" => "Сачувај",
"Delete" => "Обриши",
"Edit" => "Уреди",
"Cancel" => "Одустани",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Превуците ово у обележиваче прегледача и кликните ако на брзину желите да обележите веб страницу:",
"Add to ownCloud" => "Додај у оунКлауд",
"Address" => "Адреса",
"Filterable Tags" => "Филтрирајуће ознаке",
"You have no bookmarks" => "Немате обележивача",
"You can also import a bookmark file" => "Можете и да увезете фајл обележивача",
"Bookmarklet" => "Аплет обележивача",
"Export & Import" => "Извоз и увоз",
"Export" => "Извези",
"Import" => "Увези"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
