<?php
$TRANSLATIONS = array(
"Bookmarks" => "Bogmærker",
"Bookm." => "Bogm.",
"No file provided for import" => "Ingen fil opgivet til import",
"Unsupported file type for import" => "Filtypen understøttes ikke for import",
"Some Error happened." => "Der opstod en fejl.",
"Error" => "Fejl",
"Tags" => "Mærker",
"Filter by tag" => "Filtrér efter mærke",
"Are you sure you want to remove this bookmark?" => "Er du sikker på du vil slette dette bogmærke?",
"Warning" => "Advarsel",
"Are you sure you want to remove this tag from every entry?" => "Er du sikker på at du vil fjerne dette mærke fra alle poster?",
"Import error" => "Fejl ved import",
"Import completed successfully." => "Importen blev fuldført.",
"Uploading..." => "Uploader...",
"Add a bookmark" => "Tilføj bogmærke",
"This URL is already bookmarked! Overwrite?" => "Der er allerede et bogmærke for denne URL! Overskriv?",
"The title of the page" => "Sidens titel",
"The address of the page" => "Sidens adresse",
"Description of the page" => "Sidens beskrivelse",
"Save" => "Gem",
"Delete" => "Slet",
"Edit" => "Redigér",
"Cancel" => "Annullér",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Træk denne til dine browserbogmærker og klik på den, når du ønsker at et bogmærke til hjemmesiden hurtigt:",
"Add to ownCloud" => "Tilføj til ownCloud",
"Address" => "Adresse",
"Filterable Tags" => "Filtrérbare mærker",
"You have no bookmarks" => "Du har ingen bogmærker",
"You can also import a bookmark file" => "Du kan også importere en fil med bogmærker",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Eksport & import",
"Export" => "Eksportér",
"Import" => "Importér"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
