OC.L10N.register(
    "bookmarks",
    {
    "Select bookmark" : "Chọn bookmark",
    "Details" : "Thông tin",
    "Rename" : "Đổi tên",
    "Copy link" : "Sao chép liên kết",
    "Move" : "Dịch chuyển",
    "Select all" : "Chọn tất cả",
    "Go back" : "Quay lại",
    "Share folder" : "Chia sẻ thư mục",
    "Select one or more tags" : "Chọn một hoặc nhiều thẻ",
    "New" : "Tạo mới",
    "New folder" : "Tạo thư mục",
    "Search" : "Tìm kiếm",
    "Empty trash bin" : "Dọn thùng rác",
    "_%n folder_::_%n folders_" : ["%n thư mục"],
    "Add a bookmark" : "Thêm một bookmark",
    "Enter folder title" : "Nhập tiêu đề thư mục",
    "Rename folder" : "Đổi tên thư mục",
    "Submit" : "Gửi đi",
    "Cancel" : "Hủy bỏ",
    "Recent" : "Gần đây",
    "Shared with you" : "Đã chia sẻ với bạn",
    "Files" : "Tệp",
    "Delete" : "Xóa",
    "Need help?" : "Cần hỗ trợ ?",
    "Title" : "Tên",
    "Link" : "Liên kết",
    "Root folder" : "Thư mục gốc",
    "Tags" : "Thẻ",
    "Notes" : "Ghi chép",
    "Open file" : "Mở tệp",
    "Link copied" : "Đã sao chép liên kết",
    "Owner" : "Chủ",
    "Sharing" : "Đang chia sẽ",
    "Share link" : "Chia sẽ liên kết",
    "Allow editing" : "Cho phép chỉnh sửa",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "Failed to save settings" : "Lưu cấu hình thất bại",
    "Failed to load settings" : "Tải cấu hình thất bại",
    "Privacy" : "Riêng tư",
    "Enter bookmark title" : "Nhập tiêu đề bookmark",
    "Folder" : "Thư mục",
    "Root Folder" : "Thư mục gốc",
    "Save" : "Lưu"
},
"nplurals=1; plural=0;");
