OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Knjižne oznake",
    "You bookmarked \"%s\"" : "Dodali ste knjižnu oznaku na „%s“",
    "%1$s bookmarked \"%2$s\"" : "%1$s je dodao knjižnu oznaku na „%2$s“",
    "Someone bookmarked \"%s\"" : "Netko je dodao knjižnu oznaku na „%s“",
    "You deleted \"%s\"" : "Izbrisali ste „%s“",
    "%1$s deleted \"%2$s\"" : "%1$s je izbrisao „%2$s“",
    "Someone deleted \"%s\"" : "Netko je izbrisao „%s“",
    "You created folder \"%s\"" : "Stvorili ste mapu „%s“",
    "%1$s created folder \"%2$s\"" : "%1$s je stvorio mapu „%2$s“",
    "Someone created folder \"%s\"" : "Netko je stvorio mapu „%s“",
    "You moved folder \"%s\"" : "Premjestili ste mapu „%s“",
    "%1$s moved folder \"%2$s\"" : "%1$s je premjestio mapu „%2$s“",
    "Someone moved folder \"%s\"" : "Netko je premjestio mapu „%s“",
    "You deleted folder \"%s\"" : "Izbrisali ste mapu „%s“",
    "%1$s deleted folder \"%2$s\"" : "%1$s je izbrisao mapu „%2$s“",
    "Someone deleted folder \"%s\"" : "Netko je izbrisao mapu „%s“",
    "You shared folder \"%1$s\" with %2$s" : "Dijelite mapu „%1$s“ s „%2$s“",
    "You shared folder \"%s\" with someone" : "Dijelite mapu „%s“ s nekim",
    "%1$s shared folder \"%2$s\" with you" : "%1$s dijeli mapu „%2$s“ s vama",
    "Someone shared folder \"%s\" with you" : "Netko s vama dijeli mapu „%s“",
    "You unshared folder \"%1$s\" with %2$s" : "Više ne dijelite mapu „%1$s“ s %2$s",
    "You unshared folder \"%s\" with someone" : "Više ne dijelite mapu „%s“ s nekim",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s više ne dijeli mapu „%2$s“ s vama",
    "Someone unshared folder \"%s\" with you" : "Netko više ne dijeli mapu „%s“ s vama",
    "No file provided for import" : "Nije navedena datoteka za uvoz",
    "Failed to upload file" : "Učitavanje datoteke nije uspjelo",
    "Unsupported file type for import: " : "Nepodržana vrsta datoteke za uvoz: ",
    "Bookmarks shared by %s" : "Knjižne oznake dijeljene s %s",
    "Frequent bookmarks" : "Česte knjižne oznake",
    "Recent bookmarks" : "Nedavne knjižne oznake",
    "Bookmark" : "Dodaj knjižnu oznaku",
    "Bookmark deleted" : "Knjižna oznaka je izbrisana",
    "Bookmark created" : "Knjižna oznaka je stvorena",
    "Bookmark moved" : "Knjižna oznaka je premještena",
    "Bookmark updated" : "Knjižna oznaka je ažurirana",
    "Create bookmark" : "Stvori knjižnu oznaku",
    "Takes a link and adds it to your collection of bookmarks." : "Dodaje poveznicu u zbirku knjižnih oznaka.",
    "Bookmarks Backups" : "Sigurnosne kopije knjižnih oznaka",
    "Collect and manage bookmarks, synced with all your devices" : "Prikupljajte i upravljajte oznakama, sinkronizirano na svim vašim uređajima",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Razvrstajte oznake u mape\n- 🏷 Dodajte oznake i osobne bilješke\n- ☠ Pronađite neispravne poveznice i duplikate\n- 📲 Sinkronizirajte sa svim svojim preglednicima i uređajima\n- 📔 Spremite arhivirane verzije svojih poveznica za slučaj da budu uklonjene\n- 🔍 Pretraživanje punog teksta sadržaja stranica\n- 👪 Dijelite oznake s drugim korisnicima, grupama i timovima ili putem javnih poveznica\n- ⚛ Generirajte RSS kanale svojih zbirki\n- 📈 Statistika koliko često pristupate kojim poveznicama\n- 🔒 Automatske sigurnosne kopije vaše zbirke oznaka\n- 💼 Ugrađeni widgeti nadzorne ploče za česte i nedavne poveznice\n\nZahtjevi:\n - PHP proširenja:\n   - intl: *\n   - mbstring: *\n - ako koristite MySQL, koristite najmanje v8.0",
    "Do you really want to delete this bookmark?" : "Želite li zaista izbrisati ovu knjižnu oznaku?",
    "Link copied to clipboard" : "Poveznica je kopirana u međuspremnik",
    "Enter new title" : "Unesi novi naslov",
    "Select bookmark" : "Odaberi knjižnu oznaku",
    "You have never clicked this link" : "Nikada niste kliknuli ovu poveznicu",
    "You have clicked this link {count} times" : "Kliknuli ste ovu poveznicu {count} puta",
    "Details" : "Pojedinosti",
    "Rename" : "Preimenuj",
    "Copy link" : "Kopiraj poveznicu",
    "Move" : "Premjesti",
    "Add to folders" : "Dodaj u mape",
    "Put bookmark into trash bin" : "Premjesti oznaku u Koš za smeće",
    "Restore bookmark" : "Vrati oznaku",
    "Delete bookmark permanently" : "Trajno izbriši oznaku",
    "Content pending" : "Sadržaj na čekanju",
    "This content is being downloaded for offline use. Please check back later." : "Ovaj se sadržaj preuzima radi vanmrežne uporabe. Provjerite kasnije.",
    "Bookmarked {time} ago" : "Označeno prije {time}",
    "Bookmarked on {date}" : "Označeno {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Ovo su vaše obrisane stavke. Stavke će biti trajno obrisane nakon dva mjeseca.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Knjižne oznake za datoteke na internetu, kao što su fotografije ili PDF datoteke, automatski će se spremiti među datoteke u vašem Nextcloudu tako da ih i dalje možete pronaći čak i izvan mreže.",
    "Searching in the current folder only." : "Pretraživanje samo u trenutnoj mapi.",
    "Repeat search in all folders" : "Ponovi pretraživanje u svim mapama",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Označene poveznice redovito se provjeravaju, a one do kojih nije moguće doći navedene su ovdje.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Mape s oznakama možete dijeliti s drugima. Sve mape koje su podijeljene s vama navedene su ovdje.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Jedna oznaka može istodobno biti u više mapa. Ažuriranje će ažurirati sve kopije. Radi praktičnosti ovdje su navedene sve duplicirane oznake.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Odabrane mape {folders} i knjižne oznake {bookmarks}",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Odabrana %n knjižna oznaka","Odabrane %n knjižne oznake","Odabrano %n knjižnih oznaka"],
    "_Selected %n folder_::_Selected %n folders_" : ["Odabrana %n mapa","Odabrane %n mape","Odabrano %n mapa"],
    "Do you really want to delete these items?" : "Želite li zaista izbrisati ove stavke?",
    "Open all selected" : "Otvori sve odabrano",
    "Move selection" : "Premjesti odabir",
    "Edit tags of selection" : "Uredi oznake odabira",
    "Delete selection" : "Izbriši odabir",
    "Select all" : "Odaberi sve",
    "Cancel selection" : "Poništi odabir",
    "Sort by created date" : "Razvrstaj prema datumu stvaranja",
    "Sort by last modified" : "Razvrstaj prema posljednjoj izmjeni",
    "Sort by title" : "Razvrstaj prema naslovu",
    "Sort by click count" : "Razvrstaj prema broju klikova",
    "Sort by manual order" : "Razvrstaj prema ručno odabranom redoslijedu",
    "Sort by URL" : "Razvrstaj po URL-u",
    "RSS feed copied" : "Sažetak događaja RSS kopiran",
    "Trash Bin" : "Koš za smeće",
    "Go back" : "Natrag",
    "Share folder" : "Dijeli mapu",
    "Open folder details" : "Otvori detalje mape",
    "Select one or more tags" : "Odaberite jednu ili više oznaka",
    "New" : "Novo",
    "New bookmark" : "Nova knjižna oznaka",
    "New folder" : "Nova mapa",
    "Change to grid view" : "Promijeni u prikaz rešetke",
    "Change to list view" : "Promijeni u prikaz popisa",
    "Copy RSS Feed of current view" : "Kopiraj sažetak događaja RSS trenutnog prikaza",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Sažetak događaja RSS zahtijeva autentifikaciju s pomoću Nextcloudovih vjerodajnica",
    "Search" : "Traži",
    "Empty trash bin" : "Isprazni kantu za smeće",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Dodavanje %n knjižne oznake u novu mapu","Dodavanje %n knjižne oznake u novu mapu","Dodavanje %n knjižnih oznaka u novu mapu"],
    "Enter a link" : "Unesite poveznicu",
    "Enter a title" : "Unesite naslov",
    "No bookmarks found" : "Nije pronađena nijedna knjižna oznaka",
    "{folders} folders and {bookmarks} bookmarks" : "Mape {folders} i knjižne oznake {bookmarks}",
    "_%n bookmark_::_%n bookmarks_" : ["%n knjižna oznaka","%n knjižne oznake","%n knjižnih oznaka"],
    "_%n folder_::_%n folders_" : ["%n mapa","%n mape","%n mapa"],
    "Welcome to Bookmarks" : "Dobro došli u Knjižne oznake",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Ova aplikacija omogućuje vam upravljanje poveznicama na omiljena mjesta na webu. Razvrstajte oznake u mape, označite ih oznakama i dodajte osobne bilješke. Možete uvesti postojeće oznake iz HTML datoteke ili ih dodavati ručno.",
    "Add a bookmark" : "Dodaj knjižnu oznaku",
    "Import bookmarks" : "Uvezi knjižne oznake",
    "Sync with your browser" : "Sinkronizirajte s preglednikom",
    "Do you really want to permanently delete this folder?" : "Želite li zaista trajno izbrisati ovu mapu?",
    "Select folder" : "Odaberi mapu",
    "Enter folder title" : "Unesite naslov mape",
    "Shared by {user}" : "Dijeli {user}",
    "Rename folder" : "Preimenuj mapu",
    "Move folder" : "Premjesti mapu",
    "Put folder into trashbin" : "Premjesti mapu u Koš za smeće",
    "Restore folder" : "Vrati mapu",
    "Delete folder permanently" : "Trajno izbriši mapu",
    "Choose folder" : "Odaberi mapu",
    "Submit" : "Šalji",
    "Cancel" : "Odustani",
    "Deleting bookmarks" : "Brisanje knjižnih oznaka",
    "Deleting selection" : "Brisanje odabira",
    "Importing bookmarks" : "Uvoz knjižnih oznaka",
    "Moving selection" : "Premještanje odabira",
    "Adding selection to folders" : "Dodavanje odabira u mape",
    "Emptying trashbin" : "Pražnjenje koša za smeće",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Premještanje %n mape i nekih knjižnih oznaka","Premještanje %n mape i nekih knjižnih oznaka","Premještanje %n mapa i nekih knjižnih oznaka"],
    "_Moving %n folder_::_Moving %n folders_" : ["Premještanje %n mape","Premještanje %n mape","Premještanje %n mapa"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Premještanje %n knjižne oznake","Premještanje %n knjižne oznake","Premještanje %n knjižnih oznaka"],
    "All bookmarks" : "Sve knjižne oznake",
    "Recent" : "Nedavni",
    "Frequently clicked" : "Često klikano",
    "Shared with you" : "Podijeljeno s vama",
    "Files" : "Datoteke",
    "Duplicates" : "Duplikati",
    "Broken links" : "Prekinute poveznice",
    "New tag" : "Nova oznaka",
    "Search tags" : "Oznake pretraživanja",
    "Delete" : "Izbriši",
    "Untagged" : "Uklonjene oznake",
    "{used} bookmarks of {available} available" : "{used} knjižnih oznaka od {available} dostupnih",
    "Bookmarks Settings" : "Postavke knjižnih oznaka",
    "No bookmarked files" : "Nema datoteka označenih kao knjižne oznake",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Knjižne oznake za datoteke, kao što su fotografije ili PDF datoteke, automatski će se spremiti među datoteke u vašem Nextcloudu tako da ih i dalje možete pronaći čak i izvan mreže.",
    "Nothing found" : "Ništa nije pronađeno",
    "Your search yielded no results in the current folder." : "Pretraživanje nije dalo rezultate u trenutnoj mapi.",
    "No broken links" : "Nema neispravnih poveznica",
    "No shared folders" : "Nema dijeljenih mapa",
    "No duplicated bookmarks" : "Nema dupliciranih oznaka",
    "No deleted bookmarks" : "Nema obrisanih oznaka",
    "You haven't deleted anything yet." : "Još niste ništa obrisali.",
    "No bookmarks here" : "Ovdje nema knjižnih oznaka",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Dodajte oznake ručno ili uvezite oznake iz HTML datoteke.",
    "Archive path" : "Put arhive",
    "Backup path" : "Putanja sigurnosne kopije",
    "Please select \"Add to home screen\" in your browser menu" : "Odaberite „Dodaj na početni zaslon“ u izborniku preglednika",
    "Bookmarks settings" : "Postavke oznaka",
    "Import/Export" : "Uvoz/Izvoz",
    "Export bookmarks" : "Izvezi oznake",
    "Auto-archiving" : "Automatsko arhiviranje",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Aplikacija Knjižne oznake može automatski arhivirati web-sadržaj poveznica koje ste označili",
    "Enable archiving" : "Omogući arhiviranje",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Unesite put do mape u aplikaciji Files u kojoj trebaju biti pohranjene datoteke označene kao knjižne oznake.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Vaš administrator trenutačno je onemogućio mrežni pristup za ovu aplikaciju, zbog čega je Automatsko arhiviranje onemogućeno.",
    "Auto-Backup" : "Automatsko sigurnosno kopiranje",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Aplikacija Knjižne oznake može automatski izrađivati dnevne sigurnosne kopije vaših oznaka kako bi spriječila gubitak podataka pri sinkronizaciji oznaka i aplikacija trećih strana.",
    "Enable backups" : "Omogući sigurnosne kopije",
    "Enter the path of a folder in your Files where backups will be stored." : "Unesite putanju mape u svojoj aplikaciji Datoteke u kojoj će se spremati sigurnosne kopije.",
    "Context Chat integration" : "Integracija s Context Chatom",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Aplikacija Knjižne oznake može automatski učiniti tekstualni sadržaj web-stranica koje označite dostupnim u Context Chatu, što omogućuje bolju pretragu i razgovor o sadržaju.",
    "Context chat is currently not installed, but is required for this feature." : "Context Chat trenutačno nije instaliran, ali je potreban za ovu značajku.",
    "Enable Context Chat integration" : "Omogući integraciju s Context Chatom",
    "Client apps" : "Korisnička aplikacija",
    "Also check out the collection of client apps that integrate with this app: " : "Također pregledajte zbirku klijentskih aplikacija koje se mogu integrirati s ovom aplikacijom:",
    "Install web app" : "Instaliraj web aplikaciju",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Ovu aplikaciju možete instalirati na početni zaslon uređaja kako biste mogli brzo pristupiti knjižnim oznakama na telefonu. Ako vam se aplikacija ne sviđa, lako je možete ukloniti s početnog zaslona.",
    "Install on home screen" : "Instaliraj na početni zaslon",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Odvucite na knjižne oznake u svom pregledniku i kliknite kako biste brzo spremili mrežno mjesto u knjižne oznake.",
    "Add to {instanceName}" : "Dodaj u {instanceName}",
    "Need help?" : "Treba li vam pomoć?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Ako imate problema s ovom aplikacijom Knjižne oznake ili imate ideju što bi se moglo poboljšati, slobodno se javite. Povratne informacije su uvijek dobrodošle!",
    "Support this project" : "Podržite ovaj projekt",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Moj rad na ovoj aplikaciji Knjižne oznake temelji se na modelu dobrovoljne pretplate. Ako smatrate da je ono što radim vrijedno, bio bih zahvalan na vašoj podršci. 💙",
    "Created {time} ago" : "Stvoreno prije {time}",
    "Created on {date}" : "Stvoreno {date}",
    "(Empty title)" : "(Prazan naslov)",
    "Title" : "Naslov",
    "Link" : "Poveznica",
    "Untitled folder" : "Mapa bez naslova",
    "Root folder" : "Korijenska mapa",
    "Tags" : "Oznake",
    "Select tags and create new ones" : "Odaberite oznake i stvorite nove",
    "Notes" : "Bilješke",
    "Notes for this bookmark …" : "Bilješke za ovu knjižnu oznaku…",
    "Archived file" : "Arhivirana datoteka",
    "Open file" : "Otvori datoteku",
    "Download file" : "Preuzmi datoteku",
    "Open file location" : "Otvori lokaciju datoteke",
    "Link copied" : "Poveznica je kopirana",
    "Owner" : "Vlasnik",
    "Sharing" : "Dijeljenje",
    "Select a user or group" : "Odaberite korisnika ili grupu",
    "Share link" : "Dijeli poveznicu",
    "Reading allowed" : "Čitanje dopušteno",
    "Copy RSS feed" : "Kopiraj sažetak događaja RSS",
    "Delete link" : "Izbriši poveznicu",
    "Create public link" : "Stvori javnu poveznicu",
    "Resharing allowed" : "Ponovno dijeljenje dopušteno",
    "Editing allowed" : "Uređivanje dopušteno",
    "Allow editing" : "Dopusti uređivanje",
    "Allow resharing" : "Dopusti ponovno dijeljenje",
    "Remove share" : "Ukloni dijeljenje",
    "Would you like to support this project?" : "Želite li podržati ovaj projekt?",
    "Leave a rating on the Nextcloud App Store" : "Ostavite ocjenu u Nextcloud Trgovini",
    "Failed to save settings" : "Spremanje postavki nije uspjelo",
    "Failed to load settings" : "Učitavanje postavki nije uspjelo",
    "Privacy" : "Privatnost",
    "The app will try to access web pages that you add to automatically add information about them." : "Aplikacija će pokušati pristupiti web-stranicama koje dodate kako bi automatski dodala informacije o njima.",
    "Enable accessing and collecting information from the web pages you add" : "Omogući pristup i prikupljanje informacija s dodanih mrežnih mjesta",
    "Performance" : "Učinkovitost",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Kod instalacija s većim brojem korisnika može biti korisno ograničiti broj knjižnih oznaka po računu.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Najveći dopušteni broj knjižnih oznaka po računu. (0 znači da nema ograničenja; zadano je bez ograničenja)",
    "Previews" : "Pretpregledi",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Kako bi prikazala stvarne snimke zaslona vaših označenih web-stranica, aplikacija može koristiti usluge trećih strana za generiranje pregleda. Ako to ne želite, možete koristiti alternativni način na poslužitelju (Pageres) ili potpuno onemogućiti snimke zaslona.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Besplatno se prijavite na screeenly.com ili postavite vlastiti poslužitelj.",
    "Screeenly API URL" : "URL Screeenly API-ja",
    "Screeenly API key" : "Ključ Screeenly API-ja",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Ključ ScreenshotMachine API-ja",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL Webshot API-ja",
    "Generic screenshot API" : "Generički API za snimke zaslona",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Registrirajte se kod bilo kojeg pružatelja API-ja za snimke zaslona i unesite API URL u nastavku. Varijablu {url} koristite kao zamjenu za URL stranice koju treba snimiti.",
    "Generic API URL" : "Generički API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Jednostavno instalirajte Pageres CLI autora Sindre Sorhusa na svoj poslužitelj i aplikacija Knjižne oznake će ga pronaći. I dalje možete dodati dodatne ENV varijable za Pageres.",
    "Pageres ENV variables" : "Pageres ENV varijable",
    "This URL is already bookmarked! Overwrite?" : "Ovaj URL je već označen! Prepiši?",
    "Enter bookmark title" : "Unesite naslov knjižne oznake",
    "Enter bookmark URL" : "Unesite URL knjižne oznake",
    "Folder" : "Mapa",
    "Root Folder" : "Korijenska mapa",
    "Save" : "Spremi",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Pristup mreži je onemogućen sukladno zadanim postavkama. Otvorite administratorske postavke aplikacije za knjižne oznake kako biste omogućili dohvaćanje pretpregleda i favicona.",
    "What's new?" : "Što je novog?",
    "What" : "Što",
    "Failed to count unavailable bookmarks" : "Brojanje nedostupnih knjižnih oznaka nije uspjelo",
    "Failed to count archived bookmarks" : "Brojanje arhiviranih knjižnih oznaka nije uspjelo",
    "Failed to count deleted bookmarks" : "Brojanje obrisanih knjižnih oznaka nije uspjelo",
    "Failed to count duplicated bookmarks" : "Nije uspjelo prebrojiti duplicirane oznake",
    "Failed to count bookmarks" : "Nije uspjelo prebrojiti oznake",
    "Failed to load bookmark" : "Učitavanje knjižne oznake nije uspjelo",
    "Failed to find existing bookmark" : "Knjižna oznaka nije pronađena",
    "Failed to create bookmark" : "Stvaranje knjižne oznake nije uspjelo",
    "Failed to save bookmark" : "Spremanje knjižne oznake nije uspjelo",
    "Failed to move bookmark" : "Premještanje knjižne oznake nije uspjelo",
    "Failed to copy bookmark" : "Kopiranje knjižne oznake nije uspjelo",
    "Failed to delete bookmark" : "Brisanje knjižne oznake nije uspjelo",
    "Failed to restore bookmark" : "Vraćanje knjižne oznake nije uspjelo",
    "Import successful" : "Uspješan uvoz",
    "Failed to rename tag" : "Preimenovanje oznake nije uspjelo",
    "Failed to load tags" : "Učitavanje oznaka nije uspjelo",
    "Failed to load folders" : "Učitavanje mapa nije uspjelo",
    "Failed to load deleted folders" : "Učitavanje obrisane mape nije uspjelo",
    "Failed to load deleted bookmarks" : "Učitavanje obrisane oznake nije uspjelo",
    "Failed to delete folder" : "Brisanje mape nije uspjelo",
    "Failed to move folder" : "Premještanje mape nije uspjelo",
    "Failed to restore folder" : "Vraćanje mape nije uspjelo",
    "Failed to create folder" : "Stvaranje mape nije uspjelo",
    "Failed to load children order" : "Učitavanje redoslijeda podmapa nije uspjelo",
    "Failed to move parts of selection" : "Premještanje dijelova odabranih stavki nije uspjelo",
    "Failed to copy parts of selection" : "Kopiranje dijelova odabira nije uspjelo",
    "Failed to delete parts of selection" : "Brisanje dijelova odabranih stavki nije uspjelo",
    "Failed to tag parts of selection" : "Označavanje dijelova odabira nije uspjelo",
    "Failed to fetch bookmarks." : "Dohvaćanje knjižnih oznaka nije uspjelo.",
    "Failed to store setting" : "Spremanje postavke nije uspjelo",
    "Failed to load setting {key}" : "Učitavanje postavke {key} nije uspjelo",
    "Failed to create share for folder {folderId}" : "Stvaranje dijeljenje mape {folderId} nije uspjelo",
    "Failed to update share {shareId}" : "Ažuriranje dijeljenja {shareId} nije uspjelo",
    "Failed to delete share {shareId}" : "Brisanje dijeljenja {shareId} nije uspjelo",
    "Failed to create public link for folder {folderId}" : "Stvoranje javne poveznicu za mapu {folderId} nije uspjelo",
    "Failed to delete public link for folder {folderId}" : "Brisanje javne poveznicu za mapu {folderId} nije uspjelo",
    "Failed to permanently delete parts of trash bin" : "Trajno brisanje stavki iz Koša za smeće nije uspjelo",
    "Create bookmarks for mentioned links" : "Stvori oznake za spomenute poveznice",
    "No links found in this message" : "U ovoj poruci nisu pronađene poveznice",
    "Bookmarks feed" : "Sažetak knjižnih oznaka"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
