OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "خەتكۈچلەر",
    "You bookmarked \"%s\"" : "سىز \"%s\" نى خەتكۈچلىدىڭىز",
    "%1$s bookmarked \"%2$s\"" : "%1$s بولسا \"%2$s\" نى خەتكۈچلىدى",
    "Someone bookmarked \"%s\"" : "بىرەيلەن «%s» دەپ بەلگە قويدى",
    "You deleted \"%s\"" : "\"%s\" نى ئۆچۈردىڭىز",
    "%1$s deleted \"%2$s\"" : "%1$s بولسا \"%2$s\" نى ئۆچۈردى",
    "Someone deleted \"%s\"" : "بىرەيلەن «%s» نى ئۆچۈردى",
    "You created folder \"%s\"" : "\"%s\" ھۆججەت قىسقۇچىنى قۇردىڭىز",
    "%1$s created folder \"%2$s\"" : "%1$s بولسا قىسقۇچ \"%2$s\" نى قۇردى",
    "Someone created folder \"%s\"" : "بىرەيلەن «%s» ھۆججەت قىسقۇچىنى قۇردى",
    "You moved folder \"%s\"" : "«%s» ھۆججەت قىسقۇچىنى يۆتكىدىڭىز",
    "%1$s moved folder \"%2$s\"" : "%1$s قىسقۇچ \"%2$s\" نى يۆتكىدى",
    "Someone moved folder \"%s\"" : "بىرەيلەن «%s» ھۆججەت قىسقۇچىنى يۆتكىدى",
    "You deleted folder \"%s\"" : "\"%s\" ھۆججەت قىسقۇچىنى ئۆچۈردىڭىز",
    "%1$s deleted folder \"%2$s\"" : "%1$s قىسقۇچ \"%2$s\" نى ئۆچۈردى",
    "Someone deleted folder \"%s\"" : "بىرەيلەن «%s» ھۆججەت قىسقۇچىنى ئۆچۈردى",
    "You shared folder \"%1$s\" with %2$s" : "سىز %2$s بىلەن \"%1$s\" ھۆججەت قىسقۇچىنى ئورتاقلاشتىڭىز",
    "You shared folder \"%s\" with someone" : "سىز «%s» ھۆججەت قىسقۇچىنى باشقىلار بىلەن ئورتاقلاشتىڭىز",
    "%1$s shared folder \"%2$s\" with you" : "%1$s سىز بىلەن قىسقۇچ \"%2$s\" نى ئورتاقلاشتى",
    "Someone shared folder \"%s\" with you" : "بەزىلەر «%s» ھۆججەت قىسقۇچىنى سىز بىلەن ئورتاقلاشتى",
    "You unshared folder \"%1$s\" with %2$s" : "سىز %2$s بىلەن ھۆججەت قىسقۇچ \"%1$s\" نى ئورتاقلاشمىدىڭىز",
    "You unshared folder \"%s\" with someone" : "سىز باشقىلار بىلەن ئورتاقلاشمىغان «%s» ھۆججەت قىسقۇچى",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s سىز بىلەن ھۆججەت قىسقۇچ \"%2$s\" نى ئورتاقلاشمىدى",
    "Someone unshared folder \"%s\" with you" : "باشقىلار سىز بىلەن ھۆججەت قىسقۇچ \"%s\" نى ئورتاقلاشمىدى",
    "No file provided for import" : "ئىمپورت قىلىشقا ھۆججەت يوق",
    "Failed to upload file" : "ھۆججەت يوللاش مەغلۇب بولدى",
    "Unsupported file type for import: " : "قوللىمايدىغان ھۆججەت تىپى: ",
    "Bookmarks shared by %s" : "%s ئورتاقلاشقان خەتكۈچلەر",
    "Frequent bookmarks" : "دائىم خەتكۈچ",
    "Recent bookmarks" : "يېقىنقى خەتكۈچلەر",
    "Bookmark" : "خەتكۈچ",
    "Bookmark deleted" : "خەتكۈچ ئۆچۈرۈلدى",
    "Bookmark created" : "خەتكۈچ قۇرۇلدى",
    "Bookmark moved" : "خەتكۈچ يۆتكەلدى",
    "Bookmark updated" : "خەتكۈچ يېڭىلاندى",
    "Create bookmark" : "خەتكۈچ قۇر",
    "Takes a link and adds it to your collection of bookmarks." : "ئۇلانمىنى ئېلىپ ، خەتكۈچلەر توپلىمىڭىزغا قوشىدۇ.",
    "Bookmarks Backups" : "خەتكۈچ زاپاسلاش",
    "Collect and manage bookmarks, synced with all your devices" : "بارلىق ئۈسكۈنىلىرىڭىز بىلەن ماس قەدەملىك خەتكۈچلەرنى توپلاڭ ۋە باشقۇرۇڭ",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 خەتكۈچلەرنى قىسقۇچلارغا ئايرىڭ\n- 🏷 بەلگە ۋە شەخسىي خاتىرىلەرنى قوشۇڭ\n- ☠ بۇزۇلغان ئۇلىنىشلار ۋە كۆپەيتىلگەن ئۇلىنىشلارنى تېپىڭ\n- 📲 بارلىق تور كۆرگۈچلىرىڭىز ۋە ئۈسكۈنىلىرىڭىز بىلەن ماسلاشتۇرۇڭ\n- 📔 ئۇلىنىشلىرىڭىزنىڭ ئارخىپلانغان نۇسخىلىرىنى نەشر قىلىنمىغان ئەھۋال ئاستىدا ساقلاڭ\n- 🔍 تور بېكەت مەزمۇنىدىن تولۇق تېكىست ئىزدەش\n- 👪 خەتكۈچلەرنى باشقا ئىشلەتكۈچىلەر، گۇرۇپپىلار ۋە گۇرۇپپىلار بىلەن ياكى ئاممىۋى ئۇلىنىشلار ئارقىلىق ئورتاقلىشىڭ\n- ⚛ توپلاملىرىڭىزنىڭ RSS ئۇچۇرلىرىنى ھاسىل قىلىڭ\n- 📈 قايسى ئۇلىنىشلارغا قانچىلىك قېتىم كىرىدىغانلىقىڭىز توغرىسىدىكى ستاتىستىكىلار\n- 🔒 خەتكۈچ توپلاملىرىڭىزنىڭ ئاپتوماتىك زاپاسلىنىشى\n- 💼 دائىملىق ۋە يېقىنقى ئۇلىنىشلار ئۈچۈن ئىچكى باشقۇرۇش تاختىسى كىچىك قوراللىرى\n\nتەلەپلەر:\n- PHP كېڭەيتىلمىلىرى:\n- intl: *\n- mbstring: *\n- MySQL ئىشلەتكەندە، كەم دېگەندە v8.0 ئىشلىتىڭ",
    "Do you really want to delete this bookmark?" : "بۇ خەتكۈچنى ئۆچۈرمەكچىمۇ؟",
    "Link copied to clipboard" : "ئۇلىنىش چاپلاش تاختىسىغا كۆچۈرۈلدى",
    "Enter new title" : "يېڭى ماۋزۇ كىرگۈزۈڭ",
    "Select bookmark" : "خەتكۈچنى تاللاڭ",
    "You have never clicked this link" : "بۇ ئۇلىنىشنى ئەزەلدىن چېكىپ باقمىدىڭىز",
    "You have clicked this link {count} times" : "بۇ ئۇلىنىشنى {count} قېتىم چەكتىڭىز",
    "Details" : "تەپسىلاتى",
    "Rename" : "ئات ئۆزگەرت",
    "Copy link" : "ئۇلانمىنى كۆچۈرۈڭ",
    "Move" : "يۆتكە",
    "Add to folders" : "قىسقۇچقا قوشۇڭ",
    "Put bookmark into trash bin" : "خەتكۈچنى ئەخلەت ساندۇقىغا سېلىڭ",
    "Restore bookmark" : "خەتكۈچنى ئەسلىگە كەلتۈرۈڭ",
    "Delete bookmark permanently" : "خەتكۈچنى مەڭگۈلۈك ئۆچۈرۈڭ",
    "Content pending" : "ساقلىنىۋاتقان مەزمۇن",
    "This content is being downloaded for offline use. Please check back later." : "بۇ مەزمۇن تورسىز ئىشلىتىش ئۈچۈن چۈشۈرۈلىۋاتىدۇ. كېيىن قايتا تەكشۈرۈپ بېقىڭ.",
    "Bookmarked {time} ago" : "{time} ئىلگىرى خەتكۈچلەندى",
    "Bookmarked on {date}" : "{date}دا خەتكۈچلەندى",
    "These are your deleted items. Items will be deleted permanently after two months." : "بۇلار ئۆچۈرۈلگەن تۈرلىرىڭىز. تۈرلەر ئىككى ئايدىن كېيىن مەڭگۈلۈك ئۆچۈرۈلىدۇ.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "رەسىم ياكى PDF غا ئوخشاش توردىكى ھۆججەتلەرنىڭ خەتكۈچلىرى Nextcloud ھۆججىتىڭىزگە ئاپتوماتىك ساقلىنىدۇ ، شۇڭا ئۇلىنىش تورسىز ھالەتتىمۇ ئۇلارنى تاپالايسىز.",
    "Searching in the current folder only." : "نۆۋەتتىكى ھۆججەت قىسقۇچتىنلا ئىزدەش.",
    "Repeat search in all folders" : "بارلىق ھۆججەت قىسقۇچلاردا قايتا-قايتا ئىزدەڭ",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "خەتكۈچ ئۇلانمىلىرى قەرەللىك تەكشۈرۈلۈپ ، ئېرىشكىلى بولمايدىغان ئۇلىنىشلار بۇ يەردە كۆرسىتىلدى.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "خەتكۈچ قىسقۇچنى باشقىلار بىلەن ئورتاقلىشالايسىز. سىز بىلەن ئورتاقلاشقان بارلىق ھۆججەت قىسقۇچلار بۇ يەردە كۆرسىتىلدى.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "بىر خەتكۈچ بىرلا ۋاقىتتا كۆپ ھۆججەت قىسقۇچتا بولىدۇ. ئۇنى يېڭىلاش بارلىق نۇسخىلارنى يېڭىلايدۇ. كۆپەيتىلگەن خەتكۈچلەرنىڭ ھەممىسى قۇلايلىق ئۈچۈن بۇ يەردە كۆرسىتىلدى.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "تاللانغان {folders} ھۆججەت قىسقۇچ ۋە {bookmarks} خەتكۈچ",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n خەتكۈچ تاللاندى","%n خەتكۈچ تاللاندى"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n قىسقۇچ تاللاندى","%n قىسقۇچ تاللاندى"],
    "Do you really want to delete these items?" : "بۇ تۈرلەرنى ئۆچۈرمەكچىمۇ؟",
    "Open all selected" : "تاللانغانلارنىڭ ھەممىسىنى ئېچىڭ",
    "Move selection" : "تاللاشنى يۆتكەڭ",
    "Edit tags of selection" : "تاللاش خەتكۈچلىرىنى تەھرىرلەڭ",
    "Delete selection" : "تاللاشنى ئۆچۈرۈڭ",
    "Select all" : "ھەممىنى تاللاڭ",
    "Cancel selection" : "تاللاشنى ئەمەلدىن قالدۇرۇڭ",
    "Sort by created date" : "قۇرۇلغان ۋاقىت بويىچە تەرتىپلەش",
    "Sort by last modified" : "ئاخىرقى قېتىم ئۆزگەرتىلگەن",
    "Sort by title" : "ماۋزۇ بويىچە تەرتىپلەش",
    "Sort by click count" : "چېكىش ئارقىلىق تەرتىپلەش",
    "Sort by manual order" : "قولدا تەرتىپ بويىچە تەرتىپلەش",
    "Sort by URL" : "URL بويىچە تەرتىپلەش",
    "RSS feed copied" : "RSS يەم كۆچۈرۈلدى",
    "Trash Bin" : "ئەخلەت ساندۇقى",
    "Go back" : "قايتىڭ",
    "Share folder" : "قىسقۇچنى ئورتاقلىشىش",
    "Open folder details" : "ھۆججەت قىسقۇچ تەپسىلاتلىرىنى ئېچىڭ",
    "Select one or more tags" : "بىر ياكى بىر نەچچە خەتكۈچنى تاللاڭ",
    "New" : "يېڭى",
    "New bookmark" : "يېڭى خەتكۈچ",
    "New folder" : "يېڭى قىسقۇچ",
    "Change to grid view" : "كاتەكچە كۆرۈنۈشكە ئۆزگەرتىش",
    "Change to list view" : "تىزىملىك كۆرۈنۈشىنى ئۆزگەرتىش",
    "Copy RSS Feed of current view" : "نۆۋەتتىكى كۆرۈنۈشنىڭ RSS تەمىناتىنى كۆچۈرۈڭ",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS تەمىناتى Nextcloud سالاھىيىتىڭىز بىلەن دەلىللەشنى تەلەپ قىلىدۇ",
    "Search" : "ئىزدە",
    "Empty trash bin" : "ئەخلەت ساندۇقى",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["%n خەتكۈچنى يېڭى قىسقۇچقا قوشىۋاتىدۇ","%n خەتكۈچنى يېڭى قىسقۇچقا قوشىۋاتىدۇ"],
    "Enter a link" : "ئۇلانمىنى كىرگۈزۈڭ",
    "Enter a title" : "ماۋزۇ كىرگۈزۈڭ",
    "No bookmarks found" : "خەتكۈچ تېپىلمىدى",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} قىسقۇچ ۋە {bookmarks} خەتكۈچ",
    "_%n bookmark_::_%n bookmarks_" : ["%n خەتكۈچ","%n خەتكۈچلەر"],
    "_%n folder_::_%n folders_" : ["%n قىسقۇچ","%n قىسقۇچلار"],
    "Welcome to Bookmarks" : "خەتكۈچكە كەلگىنىڭىزنى قارشى ئالىمىز",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "بۇ ئەپ توردىكى ئۆزىڭىز ياقتۇرىدىغان ئورۇنلارنىڭ ئۇلىنىشىنى باشقۇرالايسىز. خەتكۈچلىرىڭىزنى قىسقۇچقا تىزىڭ ، بەلگە بىلەن بەلگە قويۇڭ ۋە باشقىلار بىلەن ئورتاقلىشىڭ! بۇ ئەپ بارلىق ئۇلىنىشلىرىڭىزنى قەرەللىك تەكشۈرۈپ تۇرىدۇ ھەمدە ئىشلەتكىلى بولمايدىغان ئۇلىنىشلارنى كۆرسىتىدۇ. ئەگەر توردىكى ھۆججەتكە ئۇلىنىش قوشسىڭىز ، ھۆججەت ئاپتوماتىك ھالدا Nextcloud ھۆججىتىڭىزگە چۈشۈرۈلىدۇ. سىز باشقا مۇلازىمەتلەردىن ئېكسپورت قىلىنغان خەتكۈچلەرنى ياكى بۇ ئەپ ئارقىلىق بارلىق توركۆرگۈلىرىڭىزدىن خەتكۈچلەرنى بىۋاسىتە ماسقەدەملىيەلەيسىز.",
    "Add a bookmark" : "خەتكۈچ قوشۇڭ",
    "Import bookmarks" : "خەتكۈچ ئەكىرىش",
    "Sync with your browser" : "تور كۆرگۈچىڭىز بىلەن ماسقەدەملەڭ",
    "Do you really want to permanently delete this folder?" : "بۇ ھۆججەت قىسقۇچنى مەڭگۈلۈك ئۆچۈرمەكچىمۇ؟",
    "Select folder" : "ھۆججەت قىسقۇچنى تاللاڭ",
    "Enter folder title" : "ھۆججەت قىسقۇچ نامىنى كىرگۈزۈڭ",
    "Shared by {user}" : "{user}",
    "Rename folder" : "قىسقۇچ ئاتىنى ئۆزگەرت",
    "Move folder" : "ھۆججەت قىسقۇچنى يۆتكەڭ",
    "Put folder into trashbin" : "ھۆججەت قىسقۇچنى ئەخلەت ساندۇقىغا سېلىڭ",
    "Restore folder" : "قىسقۇچنى ئەسلىگە كەلتۈرۈڭ",
    "Delete folder permanently" : "ھۆججەت قىسقۇچنى مەڭگۈلۈك ئۆچۈرۈڭ",
    "Choose folder" : "ھۆججەت قىسقۇچنى تاللاڭ",
    "Submit" : "يوللاڭ",
    "Cancel" : "ۋاز كەچ",
    "Deleting bookmarks" : "خەتكۈچلەرنى ئۆچۈرۈش",
    "Deleting selection" : "تاللاشنى ئۆچۈرۈش",
    "Importing bookmarks" : "خەتكۈچ ئەكىرىش",
    "Moving selection" : "يۆتكىلىشچان تاللاش",
    "Adding selection to folders" : "قىسقۇچقا تاللاش قوشۇش",
    "Emptying trashbin" : "ئەخلەت ساندۇقى",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n قىسقۇچنى ھەمدە بەزى خەتكۈچلەرنى يۆتكەۋاتىدۇ","%n قىسقۇچنى ھەمدە بەزى خەتكۈچلەرنى يۆتكەۋاتىدۇ"],
    "_Moving %n folder_::_Moving %n folders_" : ["%n قىسقۇچلارنى يۆتكەۋاتىدۇ","%n قىسقۇچلارنى يۆتكەۋاتىدۇ"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n خەتكۈچنى يۆتكەۋاتىدۇ","%n خەتكۈچنى يۆتكەۋاتىدۇ"],
    "All bookmarks" : "بارلىق خەتكۈچلەر",
    "Recent" : "يېقىنقى",
    "Shared with you" : "سىز بىلەن ئورتاقلاشتى",
    "Files" : "ھۆججەتلەر",
    "Duplicates" : "كۆپەيتىلگەن",
    "Broken links" : "ئۈزۈلگەن ئۇلىنىشلار",
    "New tag" : "يېڭى خەتكۈچ",
    "Search tags" : "ئىزدەش خەتكۈچلىرى",
    "Delete" : "ئۆچۈر",
    "Untagged" : "بەلگە قۇيۇلمىغان",
    "{used} bookmarks of {available} available" : "{used} خەتكۈچلەر {available} بولىدۇ",
    "Bookmarks Settings" : "خەتكۈچ تەڭشەكلىرى",
    "No bookmarked files" : "خەتكۈچلەنگەن ھۆججەت يوق",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "رەسىم ياكى PDF قاتارلىق ھۆججەتلەرنىڭ خەتكۈچلىرى Nextcloud ھۆججىتىڭىزگە ئاپتوماتىك ساقلىنىدۇ ، شۇڭا ئۇلىنىش تورسىز ھالەتتىمۇ ئۇلارنى تاپالايسىز.",
    "Nothing found" : "ھېچنېمە تېپىلمىدى",
    "Your search yielded no results in the current folder." : "ئىزدىشىڭىز نۆۋەتتىكى ھۆججەت قىسقۇچتا ھېچقانداق نەتىجىگە ئېرىشەلمىدى.",
    "No broken links" : "بۇزۇلغان ئۇلىنىش يوق",
    "No shared folders" : "ئورتاق ھۆججەت قىسقۇچ يوق",
    "No duplicated bookmarks" : "تەكرارلانغان خەتكۈچ يوق",
    "No deleted bookmarks" : "ئۆچۈرۈلگەن خەتكۈچ يوق",
    "You haven't deleted anything yet." : "سىز تېخى ھېچقانداق نەرسىنى ئۆچۈرمىدىڭىز.",
    "No bookmarks here" : "بۇ يەردە خەتكۈچ يوق",
    "Add bookmarks manually or import bookmarks from a HTML file." : "خەتكۈچنى قولدا قوشۇڭ ياكى HTML ھۆججىتىدىن خەتكۈچ ئەكىرىڭ.",
    "Archive path" : "ئارخىپ يولى",
    "Backup path" : "زاپاسلاش يولى",
    "Please select \"Add to home screen\" in your browser menu" : "توركۆرگۈ تىزىملىكىڭىزدىكى «باش ئېكرانغا قوشۇش» نى تاللاڭ",
    "Bookmarks settings" : "خەتكۈچ تەڭشىكى",
    "Import/Export" : "ئەكىرىش / چىقىرىش",
    "Export bookmarks" : "خەتكۈچلەرنى چىقىرىش",
    "Auto-archiving" : "ئاپتوماتىك ئارخىپلاشتۇرۇش",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "خەتكۈچ دېتالى سىز بەلگە قىلغان ئۇلىنىشلارنىڭ تور مەزمۇنىنى ئاپتوماتىك ئارخىپلىيالايدۇ",
    "Enable archiving" : "ئارخىپنى قوزغىتىڭ",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "ھۆججەتلىرىڭىزگە خەتكۈچلەنگەن ھۆججەتلەرنى ساقلاش كېرەك بولغان ھۆججەت قىسقۇچنىڭ يولىنى كىرگۈزۈڭ.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "ھازىر باشقۇرغۇچىڭىز بۇ دېتالنىڭ تور زىيارىتىنى چەكلىدى ، ئەمما ، ھازىرچە ئاپتوماتىك ئارخىپ چەكلەنگەن.",
    "Auto-Backup" : "ئاپتوماتىك زاپاسلاش",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "خەتكۈچ دېتالى ھەر كۈنى خەتكۈچلىرىڭىزنى ئاپتوماتىك زاپاسلىيالايدۇ ، خەتكۈچلەرنى ئۈسكۈنىلەر ئارا ماسقەدەملىگەندە سانلىق مەلۇمات يوقاپ كېتىشنىڭ ئالدىنى ئالىدۇ.",
    "Enable backups" : "زاپاسلاشنى قوزغىتىڭ",
    "Enter the path of a folder in your Files where backups will be stored." : "ھۆججەتلىرىڭىزدە زاپاسلىنىدىغان ھۆججەت قىسقۇچنىڭ يولىنى كىرگۈزۈڭ.",
    "Context Chat integration" : "مەزمۇن پاراڭ بىرلەشتۈرۈش",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "خەتكۈچ ئەپ دېتالى سىز خەتكۈچكە كىرگۈزگەن تور بەتلەرنىڭ تېكىست مەزمۇنىنى ئاپتوماتىك ھالدا Context Chat غا يوللىيالايدۇ، بۇ ئارقىلىق سوئال سوراشقا ۋە بۇ مەزمۇنلارغا ئاساسەن جاۋاب ئېلىشقا بولىدۇ. بۇ پەقەت ئاپتوماتىك ئارخىپلاش ئىقتىدارى قوزغىتىلغاندىلا ئىشلىتىشكە بولىدۇ.",
    "Context chat is currently not installed, but is required for this feature." : "مەزمۇن پاراڭ نۆۋەتتە قاچىلانمىدى، لىكىن بۇ ئىقتىدار ئۈچۈن كېرەك.",
    "Enable Context Chat integration" : "مەزمۇن پاراڭ بىرلەشتۈرۈشنى قوزغات",
    "Client apps" : "خېرىدار ئەپ",
    "Also check out the collection of client apps that integrate with this app: " : "بۇ ئەپ بىلەن بىرلەشتۈرۈلگەن خېرىدارلار ئەپلىرىنىڭ توپلىنىشىنىمۇ تەكشۈرۈپ بېقىڭ: ",
    "Install web app" : "تور دېتالى قاچىلاڭ",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "تېلېفونىڭىزدىكى خەتكۈچلىرىڭىزنى تېز زىيارەت قىلىش ئۈچۈن بۇ ئەپنى ئۈسكۈنىڭىزنىڭ باش ئېكرانىغا قاچىلىسىڭىز بولىدۇ. ئەگەر ياقتۇرمىسىڭىز بۇ ئەپنى ئائىلە ئېكرانىدىن ئاسانلا ئۆچۈرەلەيسىز.",
    "Install on home screen" : "باش ئېكرانغا قاچىلاڭ",
    "Bookmarklet" : "خەتكۈچ",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "بۇنى تور كۆرگۈڭىزنىڭ خەتكۈچلىرىگە سۆرەپ ، ئۇنى چېكىپ تور بەتنى تېزلىكتە خەتكۈچلەڭ.",
    "Add to {instanceName}" : "{instanceName} to غا قوشۇڭ",
    "Need help?" : "ياردەمگە ئېھتىياجلىقمۇ؟",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "ئەگەر بۇ خەتكۈچ دېتالىدا مەسىلىگە يولۇقسىڭىز ياكى ياخشىلىغىلى بولىدىغانلىقى توغرىسىدا چۈشەنچىڭىز بولسا ، ئىككىلەنمەي بۇ يەرنى چېكىپ ئالاقىلىشىڭ.",
    "Support this project" : "بۇ تۈرنى قوللاڭ",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "مېنىڭ بۇ خەتكۈچ دېتالىدىكى خىزمىتىم ئىختىيارىي مۇشتەرىلىك ئەندىزىسىنىڭ تۈرتكىسىدە. ئەگەر مېنىڭ قىلغانلىرىمنى ئەرزىيدۇ دەپ ئويلىسىڭىز ، مېنىڭ خىزمىتىمنى قوللىسىڭىز مەن خۇشال بولاتتىم. ئۇنىڭدىن باشقا ، Nextcloud ئەپ دۇكىنىدا بۇ دېتالغا باھا بېرىپ بېقىشنى ئويلىشىڭ. رەھمەت سىزگە ",
    "Created {time} ago" : "{time} بۇرۇن قۇرۇلدى",
    "Created on {date}" : "{date} دا قۇرۇلدى",
    "(Empty title)" : "(قۇرۇق تېما)",
    "Title" : "ماۋزۇ",
    "Link" : "ئۇلىنىش",
    "Untitled folder" : "نامسىز ھۆججەت قىسقۇچ",
    "Root folder" : "يىلتىز قىسقۇچ",
    "Tags" : "بەلگەلەر",
    "Select tags and create new ones" : "خەتكۈچلەرنى تاللاڭ ۋە يېڭىسىنى قۇرۇڭ",
    "Notes" : "ئىزاھاتلار",
    "Notes for this bookmark …" : "بۇ خەتكۈچنىڭ ئىزاھلىرى…",
    "Archived file" : "ئارخىپلانغان ھۆججەت",
    "Open file" : "ھۆججەتنى ئېچىش",
    "Download file" : "ھۆججەت چۈشۈرۈش",
    "Open file location" : "ھۆججەت ئورنىنى ئېچىڭ",
    "Link copied" : "ئۇلىنىش كۆچۈرۈلدى",
    "Owner" : "ئىگىسى",
    "Sharing" : "ھەمبەھىر",
    "Select a user or group" : "ئىشلەتكۈچى ياكى گۇرۇپپىنى تاللاڭ",
    "Share link" : "ئۇلىنىشنى ھەمبەھىرلە",
    "Reading allowed" : "ئوقۇشقا رۇخسەت قىلىنغان",
    "Copy RSS feed" : "RSS يوللانمىسىنى كۆچۈرۈڭ",
    "Delete link" : "ئۇلىنىشنى ئۆچۈرۈڭ",
    "Create public link" : "ئاممىۋى ئۇلىنىش قۇر",
    "Resharing allowed" : "قايتا ئىشلىتىشكە رۇخسەت قىلىندى",
    "Editing allowed" : "تەھرىرلەشكە رۇخسەت قىلىندى",
    "Allow editing" : "تەھرىرلەشكە يول قويۇڭ",
    "Allow resharing" : "قايتا تولۇقلاشقا يول قويۇڭ",
    "Remove share" : "ھەمبەھىرنى ئۆچۈرۈڭ",
    "Leave a rating on the Nextcloud App Store" : "Nextcloud ئەپ دۇكىنىغا باھا قويۇڭ",
    "Failed to save settings" : "تەڭشەكلەرنى ساقلىيالمىدى",
    "Failed to load settings" : "تەڭشەكلەرنى يۈكلىيەلمىدى",
    "Privacy" : "مەخپىيەتلىك",
    "The app will try to access web pages that you add to automatically add information about them." : "بۇ دېتال سىز قوشقان تور بەتلەرنى زىيارەت قىلىشقا ئۇرۇنىدۇ.",
    "Enable accessing and collecting information from the web pages you add" : "سىز قوشقان تور بەتلەردىن ئۇچۇرلارنى زىيارەت قىلىش ۋە توپلاشنى قوزغىتىڭ",
    "Performance" : "ئىقتىدار",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "نۇرغۇن ئىشلەتكۈچىلەر بىلەن قاچىلاشتا ، ھەر بىر ھېسابات خەتكۈچ سانىنى چەكلەش پايدىلىق بولۇشى مۇمكىن.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "ھەر بىر ھېسابات نومۇرىغا ئەڭ كۆپ رۇخسەت قىلىنغان خەتكۈچ سانى. (0 چەكلىمىگە ئۇچرىمايدۇ ؛ سۈكۈتتىكى چەك يوق)",
    "Previews" : "ئالدىن كۆرۈش",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "خەتكۈچلەنگەن تور بەتلىرىڭىزنىڭ ھەقىقىي كۆرۈنۈشلىرىنى كۆرسىتىش ئۈچۈن ، بۇ دېتال ئۈچىنچى تەرەپ مۇلازىمىتىنى ئىشلىتىپ ئالدىن كۆرۈش ھاسىل قىلالايدۇ.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "سىز screeenly.com دا ھەقسىز تىزىملاتسىڭىز ياكى ئۆزىڭىزنىڭ مۇلازىمېتىرىنى تەڭشىسىڭىز بولىدۇ.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API كۇنۇپكىسى",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API ئاچقۇچى",
    "Webshot" : "تور بەت",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "ئادەتتىكى ئېكران رەسىمى API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "ئېكران رەسىمى API تەمىنلىگۈچىلەرنىڭ خالىغان بىرى بىلەن تىزىملىتىڭ ھەمدە ئاستىدىكى API URL نى قويۇڭ. ئۆزگەرگۈچى مىقدار {url} نى URL نىڭ ئېكران رەسىمى ئورنىدا ئىشلىتىڭ. API چوقۇم رەسىمنى بىۋاسىتە قايتۇرىدۇ.",
    "Generic API URL" : "ئادەتتىكى API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Sindre Sorhus نىڭ Pageres CLI نى مۇلازىمېتىرىڭىزغا قاچىلاڭ ، Bookmarks ئۇنى تاپالايدۇ. قەغەزگە بېقىش ئۈچۈن يەنىلا قوشۇمچە ENV ۋاراقلىرىنى قوشالايسىز ، مەسىلەن. ئورۇن ئىگىسىدە كۆرسىتىلگەندەك:",
    "Pageres ENV variables" : "Pageres ENV ئۆزگەرگۈچى مىقدار",
    "This URL is already bookmarked! Overwrite?" : "بۇ URL ئاللىقاچان خەتكۈچلەنگەن! ئۆزگەرتەمسىز؟",
    "Enter bookmark title" : "خەتكۈچ نامىنى كىرگۈزۈڭ",
    "Enter bookmark URL" : "خەتكۈچ ئادرېسىنى كىرگۈزۈڭ",
    "Folder" : "قىسقۇچ",
    "Root Folder" : "يىلتىز قىسقۇچ",
    "Save" : "ساقلا",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "كۆڭۈلدىكى ئەھۋالدا تورغا چىقىش چەكلەنگەن. خەتكۈچ دېتالىنىڭ باشقۇرغۇچى تەڭشىكىگە كىرىپ ، ئالدىن كۆرۈش ۋە ياقتۇرۇش ئېلىپ بارالايسىز.",
    "What's new?" : "نېمە يېڭىلىق؟",
    "What" : "نېمە",
    "Failed to count unavailable bookmarks" : "ئىشلەتكىلى بولمايدىغان خەتكۈچلەرنى ساناش مەغلۇب بولدى",
    "Failed to count archived bookmarks" : "ئارخىپتىكى خەتكۈچلەرنى ساناش مەغلۇب بولدى",
    "Failed to count duplicated bookmarks" : "تەكرارلانغان خەتكۈچلەرنى ساناش مەغلۇب بولدى",
    "Failed to count bookmarks" : "خەتكۈچلەرنى ساناش مەغلۇپ بولدى",
    "Failed to load bookmark" : "خەتكۈچنى يۈكلىيەلمىدى",
    "Failed to find existing bookmark" : "مەۋجۇت خەتكۈچنى تاپالمىدى",
    "Failed to create bookmark" : "خەتكۈچ قۇرالمىدى",
    "Failed to save bookmark" : "خەتكۈچنى ساقلاش مەغلۇب بولدى",
    "Failed to move bookmark" : "خەتكۈچ يۆتكەش مەغلۇب بولدى",
    "Failed to copy bookmark" : "خەتكۈچنى كۆچۈرەلمىدى",
    "Failed to delete bookmark" : "خەتكۈچنى ئۆچۈرەلمىدى",
    "Failed to restore bookmark" : "خەتكۈچلەرنى ئەسلىگە قايتۇرۇش مەغلۇپ بولدى",
    "Import successful" : "مۇۋەپپەقىيەتلىك ئىمپورت قىلىڭ",
    "Failed to rename tag" : "خەتكۈچنىڭ نامىنى ئۆزگەرتىش مەغلۇب بولدى",
    "Failed to load tags" : "خەتكۈچلەرنى يۈكلىيەلمىدى",
    "Failed to load folders" : "ھۆججەت قىسقۇچلارنى يۈكلىيەلمىدى",
    "Failed to load deleted folders" : "ئۆچۈرۈلگەن ھۆججەت قىسقۇچلارنى يۈكلىيەلمىدى",
    "Failed to load deleted bookmarks" : "ئۆچۈرۈلگەن خەتكۈچلەرنى يۈكلىيەلمىدى",
    "Failed to delete folder" : "ھۆججەت قىسقۇچنى ئۆچۈرەلمىدى",
    "Failed to move folder" : "ھۆججەت قىسقۇچنى يۆتكەش مەغلۇب بولدى",
    "Failed to restore folder" : "قىسقۇچنى ئەسلىگە قايتۇرۇش مەغلۇب بولدى",
    "Failed to create folder" : "ھۆججەت قىسقۇچ قۇرۇش مەغلۇب بولدى",
    "Failed to load children order" : "بالىلار بۇيرۇقىنى يۈكلەش مەغلۇپ بولدى",
    "Failed to move parts of selection" : "تاللانمىنىڭ بىر قىسمىنى يۆتكەش مەغلۇپ بولدى",
    "Failed to copy parts of selection" : "تاللانمىنىڭ بىر قىسمىنى كۆچۈرۈش مەغلۇپ بولدى",
    "Failed to delete parts of selection" : "تاللانمىنىڭ بىر قىسمىنى ئۆچۈرۈش مەغلۇپ بولدى",
    "Failed to tag parts of selection" : "تاللانمىنىڭ بىر قىسمىغا بەلگە قۇيۇش مەغلۇپ بولدى",
    "Failed to fetch bookmarks." : "خەتكۈچ ئالالمىدى.",
    "Failed to store setting" : "تەڭشەكنى ساقلاش مەغلۇب بولدى",
    "Failed to load setting {key}" : "تەڭشەك {key} يۈكلىيەلمىدى",
    "Failed to create share for folder {folderId}" : "قىسقۇچ {folderId} قا ھەمبەھىر قۇرۇش مەغلۇپ بولدى",
    "Failed to update share {shareId}" : "ھەمبەھىر {shareId} يېڭىلانمىدى",
    "Failed to delete share {shareId}" : "ھەمبەھىر {shareId} ئۆچۈرۈلمىدى",
    "Failed to create public link for folder {folderId}" : "قىسقۇچ {folderId} قا ئاممىۋى ئۇلىنىش قۇرۇش مەغلۇپ بولدى",
    "Failed to delete public link for folder {folderId}" : "قىسقۇچ {folderId} نىڭ ئاممىۋى ئۇلىنىشىنى ئۆچۈرۈش مەغلۇپ بولدى",
    "Failed to permanently delete parts of trash bin" : "ئەخلەت ساندۇقىنىڭ بىر قىسمىنى مەڭگۈلۈك ئۆچۈرۈش مەغلۇپ بولدى",
    "Create bookmarks for mentioned links" : "تىلغا ئېلىنغان ئۇلىنىشلار ئۈچۈن خەتكۈچ قۇر",
    "No links found in this message" : "بۇ ئۇچۇردا ھېچقانداق ئۇلىنىش تېپىلمىدى",
    "Bookmarks feed" : "خەتكۈچلەر"
},
"nplurals=2; plural=(n != 1);");
