<?php
$TRANSLATIONS = array(
"Warning" => "انتباہ",
"Close" => "بند ",
"Save" => "حفظ",
"Delete" => "حذف کریں",
"Edit" => "تدوین کریں",
"Cancel" => "منسوخ کریں",
"Add" => "شامل کریں",
"Settings" => "سیٹینگز"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
