OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Kirjanmerkit",
    "You bookmarked \"%s\"" : "Lisäsit kirjanmerkin \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s lisäsi kirjanmerkin \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Joku lisäsi kirjanmerkin \"%s\"",
    "You deleted \"%s\"" : "Poistit \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s poisti \"%2$s\"",
    "Someone deleted \"%s\"" : "Joku poisti \"%s\"",
    "You created folder \"%s\"" : "Loit kansion \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s loi kansion \"%2$s\"",
    "Someone created folder \"%s\"" : "Joku loi kansion \"%s\"",
    "You moved folder \"%s\"" : "Siirsit kansion \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s siirsi kansion \"%2$s\"",
    "Someone moved folder \"%s\"" : "Joku siirsi kansion \"%s\"",
    "You deleted folder \"%s\"" : "Poistit kansion \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s poisti kansion \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Joku poisti kansion \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Jaoit kansion \"%1$s\" henkilön %2$s kanssa",
    "You shared folder \"%s\" with someone" : "Jaoit kansion \"%s\" jonkun kanssa",
    "%1$s shared folder \"%2$s\" with you" : "%1$s jakoi kansion \"%2$s\" kanssasi",
    "Someone shared folder \"%s\" with you" : "Joku jakoi kansion \"%s\" kanssasi",
    "You unshared folder \"%1$s\" with %2$s" : "Kansion \"%1$s\" jako lopetettu henkilön %2$s kanssa ",
    "You unshared folder \"%s\" with someone" : "Kansion \"%s\" jako lopetettu jonkun kanssa",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s lopetti kansion \"%2$s\" jakamisen kanssasi",
    "Someone unshared folder \"%s\" with you" : "Joku lopetti kansion \"%s\" jaon kanssasi",
    "No file provided for import" : "Tuotavaa tiedostoa ei ole valittu",
    "Failed to upload file" : "Tiedoston lähettäminen epäonnistui",
    "Bookmarks shared by %s" : "Henkilön %s jakamat kirjanmerkit",
    "Frequent bookmarks" : "Usein käytetyt kirjanmerkit",
    "Recent bookmarks" : "Viimeisimmät kirjanmerkit",
    "Bookmark" : "Kirjanmerkki",
    "Bookmark deleted" : "Kirjanmerkki poistettu",
    "Bookmark created" : "Kirjanmerkki luotu",
    "Bookmark moved" : "Kirjanmerkki siirretty",
    "Bookmark updated" : "Kirjanmerkki päivitetty",
    "Create bookmark" : "Luo kirjanmerkki",
    "Takes a link and adds it to your collection of bookmarks." : "Poimii linkin ja lisää sen kirjanmerkkikokoelmaasi",
    "Bookmarks Backups" : "Kirjanmerkkien varmuuskopiot",
    "Collect and manage bookmarks, synced with all your devices" : "Kerää ja hallitse kirjanmerkkejä, synkronoituna kaikille laitteillesi",
    "Do you really want to delete this bookmark?" : "Haluatko varmasti poistaa tämän kirjanmerkin?",
    "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
    "Enter new title" : "Syötä uusi nimi",
    "Select bookmark" : "Valitse kirjanmerkki",
    "You have never clicked this link" : "Et ole koskaan napsauttanut tätä linkkiä.",
    "You have clicked this link {count} times" : "Olet napsauttanut tätä linkkiä {count} kertaa",
    "Details" : "Tiedot",
    "Rename" : "Nimeä uudelleen",
    "Copy link" : "Kopioi linkki",
    "Move" : "Siirrä",
    "Add to folders" : "Lisää kansioihin",
    "Put bookmark into trash bin" : "Aseta kirjanmerkki roskakoriin",
    "Restore bookmark" : "Palauta kirjanmerkki",
    "Delete bookmark permanently" : "Poista kirjanmerkki pysyvästi",
    "Content pending" : "Odotetaan sisältöä",
    "This content is being downloaded for offline use. Please check back later." : "Sisältöä ladataan offline-käyttöä varten. Palaa myöhemmin takaisin.",
    "Bookmarked {time} ago" : "Lisätty kirjanmerkkeihin {time} sitten",
    "Bookmarked on {date}" : "Lisätty kirjanmerkkeihin {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Nämä ovat poistamasi kohteet. Ne poistetaan pysyvästi kahden kuukauden jälkeen.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Kirjanmerkit internetin tiedostoihin, kuten kuviin ja PDF-tiedostoihin, tallennetaan automaattisesti Nextcloud-tiedostoihisi jotta voit löytää ne vaikka linkki ei enää toimisi.",
    "Searching in the current folder only." : "Etsitään vain nykyisestä kansiosta.",
    "Repeat search in all folders" : "Toista haku kaikkiin kansioihin",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Kirjanmerkit tarkistetaan säännöllisesti ja ne, joihin ei saada yhteyttä, listataan tänne.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Voit jakaa kirjanmerkkikansioita muiden kanssa. Kaikki sinulle jaetut kansiot näkyvät täällä.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Kirjanmerkki voi olla useammassa kansiossa samaan aikaan ja myös kopiot päivitetään, jos kirjanmerkkiä päivitetään. Kaikki kirjanmerkit, joista on kaksoiskappaleita, näkyvät tässä.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valittu {folders} kansiota ja {bookmarks} kirjanmerkkiä",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valittu %n kirjanmerkki","Valittu %n kirjanmerkkiä"],
    "_Selected %n folder_::_Selected %n folders_" : ["Valittu %n kansio","Valittu %n kansiota"],
    "Do you really want to delete these items?" : "Haluatko varmasti poistaa kohteet?",
    "Open all selected" : "Avaa kaikki valitut",
    "Move selection" : "Siirrä valintaa",
    "Edit tags of selection" : "Muokkaa valinnan tunnisteita",
    "Delete selection" : "Poista valinta",
    "Select all" : "Valitse kaikki",
    "Cancel selection" : "Peruuta valinta",
    "Sort by created date" : "Lajittele luontipäivämäärän mukaan",
    "Sort by last modified" : "Lajittele viimeisen muokkauspäivän mukaan",
    "Sort by title" : "Lajittele nimen mukaan",
    "Sort by click count" : "Lajittele klikkausmäärän mukaan",
    "Sort by manual order" : "Lajittele manuaalisen järjestyksen mukaan",
    "Sort by URL" : "Järjestä URL-osoitteen mukaan",
    "RSS feed copied" : "RSS-syöte kopioitu",
    "Trash Bin" : "Roskakori",
    "Go back" : "Mene takaisin",
    "Share folder" : "Jaa kansio",
    "Open folder details" : "Avaa kansion yksityiskohdat",
    "Select one or more tags" : "Valitse yksi tai useampi tunniste",
    "New" : "Uusi",
    "New bookmark" : "Uusi kirjanmerkki",
    "New folder" : "Uusi kansio",
    "Change to grid view" : "Vaihda ruudukkonäkymään",
    "Change to list view" : "Vaihda listanäkymään",
    "Copy RSS Feed of current view" : "Kopioi nykyisen näkymän RSS-syöte",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-syöte vaatii tunnistautumisen Nextcloud-tunnuksillasi",
    "Search" : "Etsi",
    "Empty trash bin" : "Tyhjennä roskakori",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Lisätään %n kirjanmerkki uuteen kansioon","Lisätään %n kirjanmerkkiä uuteen kansioon"],
    "Enter a link" : "Anna linkki",
    "Enter a title" : "Syötä nimi",
    "No bookmarks found" : "Kirjanmerkkejä ei löytynyt",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} kansiota ja {bookmarks} kirjanmerkkiä",
    "_%n bookmark_::_%n bookmarks_" : ["%n kirjanmerkki","%n kirjanmerkkiä"],
    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
    "Welcome to Bookmarks" : "Tervetuloa kirjanmerkkeihin",
    "Add a bookmark" : "Lisää kirjanmerkki",
    "Import bookmarks" : "Tuo kirjanmerkit",
    "Sync with your browser" : "Synkronoi selaimesi kanssa",
    "Do you really want to permanently delete this folder?" : "Haluatko varmasti poistaa tämän kansion pysyvästi?",
    "Select folder" : "Valitse kansio",
    "Enter folder title" : "Anna nimi kansiolle",
    "Shared by {user}" : "Jakanut {user}",
    "Rename folder" : "Nimeä kansio uudelleen",
    "Move folder" : "Siirrä kansio",
    "Put folder into trashbin" : "Aseta kansio roskakoriin",
    "Restore folder" : "Palauta kansio",
    "Delete folder permanently" : "Poista kansio pysyvästi",
    "Choose folder" : "Valitse kansio",
    "Submit" : "Lähetä",
    "Cancel" : "Peruuta",
    "Deleting bookmarks" : "Poistetaan kirjanmerkkejä",
    "Deleting selection" : "Poistetaan valittu kohde",
    "Importing bookmarks" : "Tuodaan kirjanmerkkejä",
    "Moving selection" : "Siirretään valittua kohdetta",
    "Adding selection to folders" : "Lisätään valinta kansioihin",
    "Emptying trashbin" : "Tyhjennetään roskakoria",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Siirretään %n kansio ja joitain kirjanmerkkejä","Siirretään %n kansiota ja joitain kirjanmerkkejä"],
    "_Moving %n folder_::_Moving %n folders_" : ["Siirretään %n kansio","Siirretään %n kansiota"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Siirretään %n kirjanmerkki","Siirretään %n kirjanmerkkiä"],
    "All bookmarks" : "Kaikki kirjanmerkit",
    "Recent" : "Viimeisimmät",
    "Shared with you" : "Jaettu kanssasi",
    "Files" : "Tiedostot",
    "Duplicates" : "Kaksoiskappaleet",
    "Broken links" : "Rikkinäisiä linkkejä",
    "New tag" : "Uusi tunniste",
    "Search tags" : "Etsi tunnisteita",
    "Delete" : "Poista",
    "Untagged" : "Ilman tunnistetta",
    "{used} bookmarks of {available} available" : "{used}/{available} kirjanmerkkiä käytettävissä",
    "Bookmarks Settings" : "Kirjanmerkkien asetukset",
    "No bookmarked files" : "Ei kirjanmerkiksi lisättyjä tiedostoja",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Kirjanmerkit tiedostoihin, kuten kuviin tai PDF-tiedostoihin tallennetaan automaattisesti Nextcloudin tiedostoihin, joten löydät ne vaikka linkki ei olisi käytössä.",
    "Nothing found" : "Mitään ei löytynyt",
    "Your search yielded no results in the current folder." : "Hakusi ei palauttanut tuloksia tässä kansiossa.",
    "No broken links" : "Ei rikkinäisiä linkkejä",
    "No shared folders" : "Ei jaettuja kansioita",
    "No duplicated bookmarks" : "Ei kaksoiskappaleita",
    "No deleted bookmarks" : "Ei poistettuja kirjanmerkkejä",
    "You haven't deleted anything yet." : "Et ole poistanut vielä mitään.",
    "No bookmarks here" : "Ei kirjanmerkkejä täällä",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Lisää kirjanmerkkejä manuaalisesti tai tuo HTML-tiedostosta.",
    "Archive path" : "Arkiston sijainti",
    "Backup path" : "Varmuuskopiokansio",
    "Please select \"Add to home screen\" in your browser menu" : "Valitse \"Lisää kotinäytölle\" selaimesi valikosta",
    "Bookmarks settings" : "Kirjanmerkkien asetukset",
    "Import/Export" : "Tuo/vie",
    "Export bookmarks" : "Vie kirjanmerkit",
    "Auto-archiving" : "Automaattinen arkistointi",
    "Enable archiving" : "Käytä arkistointia",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Syötä Tiedostoissa olevan kansion sijainti, johon kirjanmerkkisi tallennetaan.",
    "Auto-Backup" : "Automaattinen varmuuskopiointi",
    "Enable backups" : "Käytä varmuuskopioita",
    "Enter the path of a folder in your Files where backups will be stored." : "Syötä polku kansioon, johon varmuuskopiot tallennetaan.",
    "Client apps" : "Asiakasohjelmat",
    "Also check out the collection of client apps that integrate with this app: " : "Katso kokoelma asiakassovelluksista, jotka toimivat tämän sovelluksen kanssa:",
    "Install web app" : "Asenna web-sovellus",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Voit asentaa sovelluksen puhelimesi kotinäytölle, jotta sen käyttö on vaivatonta.",
    "Install on home screen" : "Asenna kotinäytölle",
    "Bookmarklet" : "Sovelluskirjanmerkki",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Vedä tämä selaimesi kirjanmerkkeihin ja paina kun haluat tehdä nettisivusta kirjanmerkin.",
    "Add to {instanceName}" : "Lisää kohteeseen {instanceName}",
    "Need help?" : "Tarvitsetko apua?",
    "Support this project" : "Tue tätä projektia",
    "Created {time} ago" : "Luotu {time} sitten",
    "Created on {date}" : "Luotu {date}",
    "(Empty title)" : "(Tyhjä otsikko)",
    "Title" : "Otsikko",
    "Link" : "Linkki",
    "Untitled folder" : "Nimetön kansio",
    "Root folder" : "Juurikansio",
    "Tags" : "Tunnisteet",
    "Select tags and create new ones" : "Valitse tunnisteet tai luo uusia",
    "Notes" : "Muistiinpanot",
    "Notes for this bookmark …" : "Muistiinpanot tähän kirjanmerkkiin liittyen…",
    "Archived file" : "Arkistoitu tiedosto",
    "Open file" : "Avaa tiedosto",
    "Download file" : "Lataa tiedosto",
    "Open file location" : "Avaa tiedoston sijainti",
    "Link copied" : "Linkki kopioitu",
    "Owner" : "Omistaja",
    "Sharing" : "Jakaminen",
    "Select a user or group" : "Valitse käyttäjä tai ryhmä",
    "Share link" : "Jaa linkki",
    "Reading allowed" : "Lukeminen sallittu",
    "Copy RSS feed" : "Kopioi RSS-syöte",
    "Delete link" : "Poista linkki",
    "Create public link" : "Luo julkinen linkki",
    "Resharing allowed" : "Uudelleenjakaminen sallittu",
    "Editing allowed" : "Muokkaaminen sallittu",
    "Allow editing" : "Salli muokkaus",
    "Allow resharing" : "Salli uudelleenjakaminen",
    "Remove share" : "Poista jako",
    "Leave a rating on the Nextcloud App Store" : "Jätä arvostelu Nextcloud-sovelluskaupassa",
    "Failed to save settings" : "Asetusten tallentaminen epäonnistui",
    "Failed to load settings" : "Asetusten lataaminen epäonnistui",
    "Privacy" : "Yksityisyys",
    "Enable accessing and collecting information from the web pages you add" : "Ota käyttöön tiedonhaku kirjanmerkiksi lisätyiltä verkkosivuilta",
    "Performance" : "Suorituskyky",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Tilikohtaisten kirjanmerkkien määrää voi olla hyödyllistä rajoittaa usean käyttäjän kokoonpanoissa.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Käyttäjätilikohtaisten kirjanmerkkien enimmäismäärä. (0 tarkoittaa ei rajoitusta; oletus on ei rajoitusta)",
    "Previews" : "Esikatselut",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Voit rekisteröityä veloituksetta osoitteessa screeenly.com tai pystyttää oman palvelimen.",
    "Screeenly API URL" : "Screeenly-palvelun API:n URL",
    "Screeenly API key" : "Screeenly-palvelun API-avain",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachinen API-avain",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshotin API:n URL",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Pageresin ENV-muuttujat",
    "This URL is already bookmarked! Overwrite?" : "Osoite on jo lisätty kirjanmerkkeihin. Korvataanko se?",
    "Enter bookmark title" : "Anna nimi kirjanmerkille",
    "Enter bookmark URL" : "Kirjoita kirjanmerkin osoite",
    "Folder" : "Kansio",
    "Root Folder" : "Juurikansio",
    "Save" : "Tallenna",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Kirjanmerkkisovelluksen verkkokäyttö on oletuksena pois käytöstä. Avaa ylläpidon asetuksista sovelluksen asetukset ottaaksesi käyttöön esikatseluiden ja suosikkikuvakkeiden haut.",
    "What's new?" : "Mitä uutta?",
    "What" : "Mitä",
    "Failed to count unavailable bookmarks" : "Käytöstä poissa olevien kirjanmerkkien laskeminen epäonnistui",
    "Failed to count archived bookmarks" : "Arkistoitujen kirjanmerkkien laskeminen epäonnistui",
    "Failed to count deleted bookmarks" : "Poistettujen kirjanmerkkien määrän laskeminen epäonnistui",
    "Failed to count duplicated bookmarks" : "Kaksoiskappaleiden laskenta epäonnistui",
    "Failed to count bookmarks" : "Kirjanmerkkien laskeminen epäonnistui",
    "Failed to load bookmark" : "Kirjanmerkin lataaminen epäonnistui",
    "Failed to find existing bookmark" : "Olemassa olevaa kirjanmerkkiä ei löytynyt",
    "Failed to create bookmark" : "Kirjanmerkin luominen epäonnistui",
    "Failed to save bookmark" : "Kirjanmerkin tallentaminen epäonnistui",
    "Failed to move bookmark" : "Kirjanmerkin siirtäminen epäonnistui",
    "Failed to copy bookmark" : "Kirjanmerkin kopioiminen epäonnistui",
    "Failed to delete bookmark" : "Kirjanmerkin poistaminen epäonnistui",
    "Failed to restore bookmark" : "Kirjanmerkin palauttaminen epäonnistui",
    "Import successful" : "Tuonti onnistui",
    "Failed to rename tag" : "Tunnisteen uudelleen nimeäminen epäonnistui",
    "Failed to load tags" : "Tunnisteiden lataaminen epäonnistui",
    "Failed to load folders" : "Kansioiden lataaminen epäonnistui",
    "Failed to load deleted folders" : "Poistettujen kansioiden lataaminen epäonnistui",
    "Failed to load deleted bookmarks" : "Poistettujen kirjanmerkkien lataaminen epäonnistui",
    "Failed to delete folder" : "Kansion poistaminen epäonnistui",
    "Failed to move folder" : "Kansion siirtäminen epäonnistui",
    "Failed to restore folder" : "Kansion palauttaminen epäonnistui",
    "Failed to create folder" : "Kansion luominen epäonnistui",
    "Failed to move parts of selection" : "Joidenkin valinnan osien siirtäminen epäonnistui",
    "Failed to delete parts of selection" : "Joidenkin valinnan osien poistaminen epäonnistui",
    "Failed to fetch bookmarks." : "Kirjanmerkkien noutaminen epäonnistui.",
    "Failed to load setting {key}" : "Asetuksen {key} lataaminen epäonnistui",
    "Failed to update share {shareId}" : "Jaon {shareId} päivittäminen epäonnistui",
    "Failed to delete share {shareId}" : "Jaon {shareId} poistaminen epäonnistui",
    "Failed to create public link for folder {folderId}" : "Kansioon {folderId} johtavan julkisen linkin luominen epäonnistui",
    "Failed to delete public link for folder {folderId}" : "Kansioon {folderId} johtavan julkisen linkin poistaminen epäonnistui",
    "Create bookmarks for mentioned links" : "Luo kirjanmerkit mainituista linkeistä",
    "No links found in this message" : "Viestistä ei löytynyt linkkejä",
    "Bookmarks feed" : "Kirjanmerkkien syöte"
},
"nplurals=2; plural=(n != 1);");
